C *********************************************************************
C ESDU International plc
C
      PROGRAM A9931
C
C     ESDUpac Number:   A9931
C     ESDUpac Title:    COMPUTER PROGRAM FOR ESTIMATION OF LIFT CURVE
C                       TO MAXIMUM LIFT FOR WING-FUSELAGE COMBINATIONS
C                       WITH HIGH-LIFT DEVICES AT LOW SPEEDS
C
C     Data Item Number: 99031
C     Data Item Title:  COMPUTER PROGRAM FOR ESTIMATION OF LIFT CURVE
C                       TO MAXIMUM LIFT FOR WING-FUSELAGE COMBINATIONS
C                       WITH HIGH-LIFT DEVICES AT LOW SPEEDS
C
C     ESDUpac Status
C     --------------
C     Version:    2.1   Issued July 2002
C
C                       Significant figures in C_L alpha list increased
C
C     Version:    2.0   Issued September 2000
C
C                       linked on compilation with
C                       A9931A20.FOR  A9931B20.FOR A9931C20.FOR
C
c                       The changes are to source codes
C                       to satisfy compiler options
C
C                       FL /4Ys /4Yd /Fs
C
c                       The calculation routines are unchanged
C
C
C     Version:    1.0   Issued October 1999
C
C                       linked on compilation with
C                       A9931X01.FOR  A9931X02.FOR A9931X03.FOR
C
C     -----------------------------------------------------------------
C
C
C
C     Character Data
C     ==============
C     TITLE(3) - three lines of up to 72 characters
C     TYPE     - aerofoil section type:
C                 "P" means program decides
C                 "M" means modern
C                 "C" means conventional
C
C     Integer Data
C     ============
C     CALC   - calculation type (1 to 18)
C     NMR    - number of Mach number, Reynolds number pairs
C              (1<=NMR<=10)
C     TES    - slotted trailing-edge flap at ETAP flag
C              0 means absent, 1 means present
C     INT    - flag on fuselage effect on trailing-edge
C              flap performance (0 means neglect, 1 means include)
C     NDL    - number of leading edge device settings (0<=NDL<=10)
C     NDT    - number of trailing-edge device settings (0<=NDT<=10)
C     NNL    - number of leading-edge device panels (0<=NNL<=5)
C     NNT    - number of trailing-edge device panels (0<=NNT<=5)
C     NLJ(5) - leading-edge device types   [(Nl)j]
C     NTJ(5) - trailing-edge device types  [(Nt)j]
C     NL     - aerofoil leading-edge device type [Nl]
C     NT     - aerofoil trailing-edge device type[Nt]
C
C     ITYPE  - integer version of TYPE:
C              1 = 'P' = program decides
C               2 = 'M' = modern
C                3 = 'C' = conventional
C     NCL    - number of items in plot of CL vs. alpha
C     MSG    - message number (about ITYPE)
C
C     ICOUNT - output loop counter
C     IZERO  - to zero ICOUNT
C     IST    - first loop identifier
C
C     Floating Point Data
C     ===================
C     MN(10),   - NMR pairs of Mach and Reynolds numbers
C     RN(10)
C     A         - aspect ratio of wing    [A]
C     TR        - taper ratio of wing     [lambda]
C     N         - fractional chord line   [n]
C     LDN       - sweep of nth chord line [Lambda n]
C     EP        - dimensionless spanwise location of most highly
C                 loaded section [eta p]
C
C     Section properties of basic aerofoil or section at EP
C     -----------------------------------------
C     T         - thickness to chord ratio [t/c]
C     XTR       - dimensionless chordwise location of boundary layer
C     XTR2      - used to carry XTR between subroutines
C                 transition point [xtr/c]
C     XUM,ZUM   - dimensionless chordwise location and height
C                 maximum height [xum/c and zum/c]
C     TAU       - trailing edge angle (deg) [tau]
C     XG(17),   - dimensionless upper-surface and lower-surface
C     ZUG(17),    coordinates at each of 17 standard chordwise
C     ZLG(17)     locations [(x/c)g, (zu/c)g and (zl/c)g]
C     ZC92      - ratio of camber ordinate at x=0.92c to camber4
C                 ordinate at x=0.5c  [zc92/zc50]
C     D23       - geometric twist angle (deg) at eta = 2/3, relative
C                 to root chord, positive nose up   [delta 2/3]
C
C     Data for root (centre-line) section
C     -----------------------------------
C     XRG(15),  - dimensionless upper and lower surface coordinates
C     ZURG(15),   at 15 standard dimensionless locations along root
C     ZLRG(15)    chord   [(x/c)rg, (zu/c)rg, (zl/c)rg]
C     Z92R      - ratio of camber ordinate at x=0.92c to that at x=0.5c
C                 on root chord  [(zc92/zc50)r]
C
C     Data for section at eta = 2/3
C     -----------------------------
C     X23G(15), - dimensionless upper and lower surface coordinates
C     ZU23G(15),  at 15 standard dimensionless locations
C     ZL23G(15)   [(x/c)2/3g, (zu/c)2/3g, (zl/c)2/3g]
C     Z9223     - ratio of camber ordinate at x=0.92c to that at x=0.5c
C                 [(zc92/zc50)2/3]
C
C     Restricted section data for basic aerofoil
C     ------------------------------------------
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C     TAUAU     - trailing edge angle (deg) in Sketch 1.1c  [tau au]
C     ZU5,ZL5   - ordinates at x/c = 0.05   [(zu/c)5 and (zl/c)5]
C
C     Fuselage data
C     -------------
C     W         - ratio of body width to semi-span  [W/s]
C     IW        - setting angle of wing centre-line chord relative
C                 to fulselage centre linen (deg)   [iW]
C     H         - wing height over fuselage height  [h/H]
C
C
C     Leading edge devices - data for aerofoil
C     -----------------------------------
C     DL(10)    - NDL deflection angles (deg)       [delta l]
C     RL(10)    - NDL leading edge radii / c        [rhol/c]
C     CXL(10)   - NDL leading edge extended chords  [c'l/c]
C     DCL(10)   - NDL chord extensions due to deployment of leading
C                 edge device                       [Delta cl / c]
C     GL(10)    - NDL normal distances between slat trailing edge and
C                 section surface                   [Gl / c]
C     HL(10)    - NDL heights of slat trailing edge above chord line
C                                                   [Hl / c]
C     LL(10)    - NDL overlaps between deployed slat and fixed-section
C                 nose                              [Ll / c]
C     XL(10)    - NDL chordwise locations of undeployed slat trailing
C                 edge                              [xl / c]
C     XN(10)    - NDL chordwise locations of fixed section nose
C                                                   [xn / c]
C
C     Trailing edge flaps - data for aerofoil
C     ----------------------------------
C     DT(3,10)  - NDT deflection angles (deg) of up to 3 elements
C                                                        [delta t]
C     DCT(3,10) - NDT chord extensions due to deployment of up to 3
C                 elements                               [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements     [ct/c]
C     RLT       - leading edge radius of section or of deployed leading
C                 edge device / thickness                [rhol/t]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)                 [phit]
C     XLM,ZLM   - coordinates of section maximum lower surface ordinate
C                                                        [xlm/c, zlm/c]
C     ZCM       - section maximum camber height          [zcm/c]
C     ZU125,    - section upper and lower surface ordinates
C     ZL125       at x=0.0125c                 [(zu/c)1.25, (zl/c)1.25]
C     XTS       - location of flap shroud trailing edge  [xts/c]
C     LDH       - hinge-line sweep (deg)                 [Lambda h]
C
C     Data at mid-span of device panels
C     ---------------------------------
C     EIL(5),   - positions of inner and outer edges of NNL leading
C     EOL(5)      edge panels                 [(eta il)j and (eta ol)j]
C     EIT(5),   - positions of inner and outer edges of NNT trailing
C     EOT(5)      edge panels                 [(eta il)j and (eta ol)j]
C
C     Data for leading-edge devices
C     -----------------------------
C     DLJ(5,10)  - NNL*NDL deflection angles                [(delta l)j]
C     RLJ(5,10)   - NNL*NDL leading edge radii / c           [(rhol/c)j]
C     CXLJ(5,10) - NNL*NDL extented chords                  [(c'l / c)j]
C     DCLJ(5,10) - NNL*NDL extensions on deployment    [(Delta cl / c)j]
C     GLJ(5,10)   - NNL*NDL normal distances between slat trailing edge
C                  and section surface                      [(Gl / c)j]
C     HLJ(5,10)   - NNL*NDL heights of slat trailing edge above chord
C                  line                                     [(Hl / c)j]
C     LLJ(5,10)   - NNL*NDL overlaps between deployed slat and
C                  fixed-section nose                        [(Ll / c)j]
C     XLJ(5,10)   - NNL*NDL chordwise locations of undeployed slat
C                  trailing edge                             [(xl / c)j]
C     XNJ(5,10)   - NNL*NDL chordwise locations of fixed section nose
C                                                            [(xn / c)j]
C
C     Data for trailing-edge devices
C     ------------------------------
C     DTJ(3,5,10)  - deflection angles for up to 3 elements, for NNT
C                    trailing edge devices, for NDT device settings
C                                                        [(delta t)j]
C     DCTJ(3,5,10) - chord extensions for up to 3 elements, for NNT
C                    trailing edge devices, for NDT device settings
C                                                    [(Delta ct / c)j]
C     CTJ(3,5)     - flap chords for up to 3 elements, for NNT devices
C                                                            [(ct/c)j]
C     RLTJ(5)      - leading edge radius of section or of deployed
C                    leading edge device / thickness for NNT
C                    trailing edge devices                  [(rhol/t)j]
C     PHITJ(5)     - angle from aerofoil datum to tangent to upper
C                    surface at trailing edge for NNT trailing edge
C                    devices                                [(phi t)j]
C     XLMJ(5)      - chordwise location of section maximum lower surface
C                    coordinate  [(xlm/c)j]
C     ZLMJ(5)      - section maximum (negative) lower surface ordinate
C                    for NNT trailing edge devices        [(zlm/c)j]
C     ZCMJ(5)      - section maximum camber height
C                    for NNT trailing edge devices    [zcm/c]
C     ZU125J(5),   - section upper and lower surface ordinates
C     ZL125J(5)      at x=0.0125c    for NNT trailing edge devices
C                                        [((zu/c)1.25)j,((zl/c)1.25)j]
C     XTSJ(5)      - chordwise location of flap shroud trailing edge
C                    for NNT trailing edge devices            [(xts/c)j]
C     LDHJ(5)      - hinge-line sweep (deg)
C                    for NNT trailing edge devices         [(Lambda h)j]
C
C     User input in place of program output
C     -------------------------------------
C     XCL0B(10), - zero angle and maximum lift coefficients of basic
C     XCLMB(10)    aerofoil             [CL0B(NMR) and CLmB(NMR)]
C     XCL0BW(10),- zero angle and maximum lift coefficients of basic
C     XCLMBW(10)   wing                 [CL0BW(NMR) and CLmaxB(NMR)]
C     XCL0BF(10),- zero angle and maximum lift coefficients of basic
C     XCLMBF(10)   wing and fuselage    [CL0Bf(NMR) and CLmaxBf(NMR)]
C     XDCLMF(10) - increment in maximum lift coefficient
C                  due to fuselage      [DeltaCLmaxf]
C
C     Floating Point Results
C     ======================
C
C     Results for Aerofoils
C     ---------------------
C     DCL0L      - increment in aerofoil lift coefficient at zero angle
C                  of attack due to deployment of leading-edge device
C                  [Delta CL0l]
C     DCL0T      - increment in aerofoil lift coefficient at zero angle
C                  of attack due to deployment of trailing-edge device
C                  [Delta CL0t]
C     DCL0       - increment in aerofoil lift coefft. at zero angle of
C                  attack due to deployment of high-lift devices
C                  [Delta CL0]
C     CL0B       - lift coefft. at zero angle of attack for basic
C                  aerofoil (high-lift devices not deployed) [CL0B]
C     CL0        - aerofoil lift coefft. at zero angle of attack with
C                  high-lift devices deployed [CL0]
C     DCLML      - increment in aerofoil max. lift coefft. due to
C                  leading-edge device [Delta CLml]
C     DCLMT      - increment in aerofoil max. lift coefft. due to
C                  trailing-edge device [Delta CLmt]
C     DCLM       - increment in aerofoil max. lift coefft. due to
C                  high-lift devices [Delta CLm]
C     CLMB       - max. lift coefft. of basic aerofoil
C                  (high-lift devices not deployed) [CLmB]
C     CLM        - max. lift coefft. of aerofoil with high-lift devices
C                  deployed [CLm]
C
C     Results for Wings
C     -----------------
C     DC0LWJ(NNL) - increments in wing lift coefft. at zero angle of
C                   attack due to NNL leading-edge devices
C                   [(Delta CL0lw)j]
C     DC0TWJ(NNT) - increments in wing lift coefft. at zero angle of
C                   attack due to NNT trailing-edge devices
C                   [(Delta CL0tw)j]
C     DCL0LW      - increment in wing lift coefft. at zero angle of
C                   attack due to leading-edge devices [Delta CL0lw]
C     DCL0TW      - increment in wing lift coefft. at zero angle of
C                   attack due to trailing-edge devices [Delta CL0tw]
C     DCL0W       - increment in wing lift coefft. at zero angle of
C                   attack due to high-lift devices
C     CL0BW       - lift coefft. at zero angle of attack for basic wing
C                   (high-lift devices not deployed)
C     CL0W        - lift coefft. of wing at zero angle of attack with
C                   high-lift devices deployed
C
C     DCLMLJ(NNL) - increment in max. lift coefft. of wing
C                   deployment of NNL
C                   leading-edge high-lift devices [(DCL max l)j]
C                   ( NOT NEED AS NNL=1 IN CLMAX CALCS)
C     DCLMTJ(NNT) - increment in max. lift coefft. of wing
C                   due to deployment of  NNT
C                   trailing-edge high-lift devices [(DCL max t)j]
C     DCLMXL      - increment in max. lift coefft. of wing
C                   due to deployment of
C                   leading-edge high-lift devices [DCL max l]
C     DCLMXT      - increment in max. lift coefft. of wing
C                   due to deployment of
C                   trailing-edge high-lift devices [DCL max t]
C     DCLMX       - increment in wing max. lift coefft. due to high-
C                   lift devices [Delta CL max]
C     CLMXB       - max. lift coefft. of basic wing (high-lift devices
C                   not deployed) [CL max B]
C     CLMXW       - max lift coefft. of wing with high-lift devices
C                   deployed [CL max W]
C
C     Results for Wing-Fuselage Combinations
C     --------------------------------------
C     CL0BF       - lift coefft. at zero angle of attack for basic
C                   wing-fuselage combination [CL0Bf]
C     CL0WF       - lift coefft. at zero angle of attack for
C                   wing-fuselage combination with high-lift devices
C                   deployed [CL0wf]
C     DCLMXF      - increment in max. lift coefft. due to fuselage
C                   [Delta CL max f]
C     CLMXBF      - max. lift coefft. of basic wing-fuselage combination
C                   [CL max Bf]
C     CLMXWF      - max. lift coefft. of wing-fuselage combination with
C                   high-lift devices deployed [CL max wf]
C
C     Plot of CL vs. alpha
C     --------------------
C     A0          - angle of attack for zero lift (deg) [alpha 0]
C     ACLMX       - angle of attack for maximum lift (deg) [alpha CLmax]
C     AD(200)     - NCL angles of attack (deg) [alpha d]
C     CL(200)     - NCL corresponding lift coefficients [CL]
C
C     Intermediate Results
C     ====================
C     NTLJ(5)  - integer denoting trailing edge flap type
C                aft of leading edge device [(Ntl)j]
C     NLTJ(5)  - integer denoting leading edge flap type
C                forward of trailing edge device [(Ntt)j]
C     CHKLDX(4)   - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     KAPPA    - kappa in Section a2
C     CPCBB    - chord ratio in Section a3 [cp / c double bar]
C     CRCBB    - chord ratio in Section a4 [cr / c double bar]
C     C23CBB   - chord ratio in Section a5 [c2/3 / c double bar]
C     LCS      - lift-curve slope in Section b1 [a1]
C     EB       - spanwise centre of pressure in Section b2 [eta bar]
C     RXK      - Reynolds number based on cp in Section b3 [R'k]
C     RXKR     - Reynolds number based on cr in Section b4 [R'kr]
C     RXK23    - Reynolds number based on c2/3 in Section b4 [R'k23]
C     MUP      - peak loading in Section b5 [mu p]
C     A0BW     - zero lift angle (rad) of basic wing in Section c1
C                [alpha 0Bw]
C     A0BF     - wing-fuselage zer0-lift angle (rad) in Section c2
C     A0BT     - zero-lift aNGLE (rad) of basic aerofoil in Section c4
C                [alpha 0BT]
C     LCS0T    - theoretical lift-curve slope of basic aerofoil
C                in Section c4 [(a1)0T]
C     A0BTP    - zero-lift angle for section at eta p in Section d1
C                [(alpha 0BT)p]
C     LCS0P    - lift-curve slope for section at eta p in Section d1
C                [(a1)0p]
C     CXCL     - extended chord / chord for aerofoil with leading edge
C                extended  [(c'/c)l]
C     CXCT     - extended chord / chord for aerofoil with trailing edge
C                extended  [(c'/c)t]
C     CXC      - extended chord / chord with both leading
C                and trailing edges extended
C     CXCLJ(5) - extended chords / chords with leading edges
C                extended [((c'/c)l)j]
C     CXCTJ(5) - extended chords / chords with trailing edges
C                extended [((c'/c)t)j]
C     CXCM IS NOW EXTENDED CHORD FOR LEADIND EDGE DEVICE CLMAX CALCS
C     CXCM     - extended chord / chord for maximum lift calculation
C                [(c'/c)m] MAY BE SET TO CXC SOMETIMES TO SAVE REWRITE
C     CELCXM   - (cel/c')m for maximum lift calculation
C
C     CXCTMJ(5)- extended chord when trailing edgr flap contributions
C                to Clmax calculated
C     DCLTJ(5) - chord extension at mid-span chord of leading edge
C                device due to trailing edge [(Delta clt)j]
C     DCTLJ(5) - chord extension at mid-span chord of trailing edge
C                device due to leading edge  [(Delta ctl)j]
C     EIL1EF   - effective spanwise position of inboard edge
C                of innermost leading-edge device as a proportion
C                of semi-span [(eta il)1 eff]
C     EIT1EF   - effective spanwise position of inboard edge
C                of innermost trailing-edge device as a proportion
C                of semi-span [(eta it)1 eff]
C     QJ(5)    - the quantities (Delta ct / c - K delta ct / c)j
C                in Section k1
C     Q        - the quantity QJ for aerofoils
C     D        - the factor D in Section k2
C     P        - the power p in Section k3
C
C     -----------------------------------------------------------------
C     MAIN ROUTINE
C     ============
C
C     Purpose
C     -------
C     Manages reading of data, calculations and printing of results
C
C     Local
C     -----
C     INFIL      - input unit number
C     OUTFIL     - output unit number
C     NMR        - number of Mach number, Reynolds number pairs
C     NDL        - number of leading-edge device settings
C     NDT        - number of trailing-edge device settings
C     K          - current Mach number, Reynolds number pair
C     JDL        - current leading-edge device setting
C     JDT        - current trailing-edge device setting
C     NFLTS      - number of faults
C     FAULTS(60) - list of up to 60 fault numbers
C
C     -----------------------------------------------------------------
C
      INTEGER INFIL,OUTFIL,NMR,NDL,NDT,K,JL,JT,NFLTS,FAULTS(60)
C
      INFIL = 5
      OUTFIL = 6
C
      NFLTS = 0
      FAULTS(1) = 0
C
C     Set all the data to nought
C     --------------------------
      CALL AA9931
C
C     Read the data
C     -------------
      CALL AB9931(INFIL,NMR,NDL,NDT,FAULTS(1))
C
C     Print the data
C     --------------
      CALL AC9931(OUTFIL)
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Check the data
C     --------------
      CALL DATCHK(NFLTS,FAULTS)
      IF (NFLTS .NE. 0) GO TO 100
C
C     Section AA is not used in this version of program
C     Section AA - Duplicate device data at section eta = (eta p)
C     as device data at mid-span of device panels according to switches
C     CSL and CST
C     -----------------------------------------------------------------
      CALL SUBRAA
C
C     Section a - Calculate additional wing parameters
C     that are independent of Mk
C     --------------------------------------------------
      CALL SUBRA
C
C     Take each Mach number, Reynolds number pair in turn
C     ===================================================
      DO 30 K = 1,NMR
C
C     Copy any user supplied data for this Mach, Reynolds number pair
C     from the input data to the results (CALC = 2,4,8,10,13,14,16)
C     (Zeros will be copied for other calculation types.)
C     ---------------------------------------------------------------
      CALL AG9931(K)
C
C     Section b - Calculate wing parameters that depend
C     on Mach and Reynolds numbers
C     -------------------------------------------------
      CALL SUBRBB(K,FAULTS(1))
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Section c - Calculate CL0 for the basic wing-fuselage
C     -------------------------------------------------------
      CALL SUBRCC(K,FAULTS(1))
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Section d - Calculate CLmax for the basic wing-fuselage
C     ---------------------------------------------------------
      CALL SUBRDD(K,FAULTS(1))
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Take each leading-edge device setting in turn
C     =============================================
      DO 20 JL = 1,MAX0(NDL,1)
C
C     Take each trailing-edge device setting in turn
C     ==============================================
      DO 10 JT = 1,MAX0(NDT,1)
C
C     Section e - Calculate additional geometric parameters
C     for high-lift systems including fuselage inteference
C     -------------------------------------------------------
      CALL SUBREE(JL,JT,FAULTS(1))
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Section f - Calculate Delta CL0 due to leading-edge devices
C     -------------------------------------------------------------
      CALL SUBRFF(JL,FAULTS(1))
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Section g - Calculate Delta CL0 due to trailing-edge devices
C     --------------------------------------------------------------
      CALL SUBRGG(K,JT,FAULTS(1))
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Section h - Calculate Delta CLmax due to leading-edge devices
C     ---------------------------------------------------------------
      CALL SUBRHH(K,JL,FAULTS(1))
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Section i - Calculate delta CLmax due to trailing-edge devices
C     ----------------------------------------------------------------
      CALL SUBRII(K,JL,JT,FAULTS(1))
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Section j - Calculate CL0 and CLmax for wing-fuselage
C     with high-lift devices deployed or/and overall increments
C     ---------------------------------------------------------
      CALL SUBRJJ
C
C     Section k - Calculate lift curve
C     ----------------------------------
      CALL SUBRKK(JL,JT,FAULTS(1))
      IF (FAULTS(1) .NE. 0) GO TO 100
C
C     Section l - Print the results for the current K, JL and JT
C     ------------------------------------------------------------
      CALL SUBRLL(OUTFIL,K,JL,JT)
C
   10 CONTINUE
C
   20 CONTINUE
C
   30 CONTINUE
C
      WRITE (OUTFIL,6666)
 6666 FORMAT(1X,///,1X,'----------------------------------------------')
      GO TO 200
C
C     Print any faults that were found
C     --------------------------------
  100 CALL AD9931(OUTFIL,NFLTS,FAULTS)
C
  200 STOP 'NORMAL END'
      END
C     -----------------------------------------------------------------
      SUBROUTINE AA9931
C     =================
C
C     Purpose
C     -------
C     To set all data to nought
C
C     Output
C     ------
C     IDAT(23)    - integer data
C     RDAT(943)   - floating point data
C
C     -----------------------------------------------------------------
C
      CHARACTER TITLE*75,TYPE*1
      COMMON /ZA9931/TITLE(3),TYPE
C
      INTEGER IDAT
      INTEGER NTLJ,NLTJ
C
      REAL RDAT,RSLTSA,RSLTSB,BBZERO
      REAL XTR2,RK2,CXCTMJ,DCLMTJ
C
      COMMON /ZB9931/IDAT(26)
      COMMON /ZD9931/RDAT(943)
      COMMON /ZE9931/RSLTSA(437)
      COMMON /ZF9931/RSLTSB(46)
      COMMON /ZK9931/BBZERO(325)
C
      COMMON /ZH9931/XTR2
      COMMON /ZJ9931/RK2
      COMMON /ZL9931/NTLJ(5)
      COMMON /ZM9931/NLTJ(5)
      COMMON /ZN9931/CXCTMJ(5)
      COMMON /ZP9931/DCLMTJ(5)
C
      INTEGER ICOUNT,IZERO,IST
      COMMON /ZQ9931/ ICOUNT,IZERO,IST
C
      INTEGER I
C
C SET ZEROES
      ICOUNT = 0
      IZERO = 0
      IST = 0
      XTR2 = 0.0
      RK2 = 0.0
C
      DO 10 I = 1,3
      TITLE(I) = ' '
   10 CONTINUE
      TYPE = 'P'
C
      DO 20 I = 1,26
      IDAT(I) = 0
   20 CONTINUE
C
      DO 30 I = 1,943
      RDAT(I) = 0.0
   30 CONTINUE
C
      DO 40 I = 1,437
      RSLTSA(I) = 0.0
   40 CONTINUE
C
      DO 50 I = 1,46
      RSLTSB(I) = 0.0
   50 CONTINUE
C
      DO 60 I = 1,325
      BBZERO(I) = 0.0
   60 CONTINUE
C
      DO 70 I = 1,5
      NTLJ(I) = 0
      NLTJ(I) = 0
      CXCTMJ(I) = 0.0
      DCLMTJ(I) = 0.0
   70 CONTINUE
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE AB9931(INFIL,KMR,KDL,KDT,FAULT)
C     ==========================================
C
C     Purpose
C     -------
C     To read the data
C
C     Input
C     -----
C     INFIL   - input unit number
C
C     Output
C     ------
C     FAULT   - fault number (0 means none)
C     KMR     - Number of Mach number, Reynolds number pairs
C     KDL     - number of leading-edge device settings
C     KDT     - number of trailing-edge device settings
C     The main output is to various common blocks.
C
C     -----------------------------------------------------------------
C
      INTEGER INFIL,KMR,KDL,KDT,FAULT
C
C     Common block to contain string data
C     -----------------------------------
      CHARACTER TITLE*75,TYPE*1
      COMMON /ZA9931/TITLE(3),TYPE
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
C
      REAL           XTR2
      REAL           RLTJ,RLJ
      REAL           GLJ,HLJ,LLJ,XLJ,XNJ
      REAL           LDHJ,ZU125J,ZL125J,ZCMJ
C
C NEXT BLOCK IS TO TAKE EXTRA PANEL DATA XXXJ'S NOT ALREADY USED
C       INTO ECHO AC9931, DATCHK ,SUBRHH ,SUBRII
      COMMON  /ZK9931/ LDHJ(5),ZU125J(5),ZL125J(5),ZCMJ(5), RLTJ(5),
     *                 RLJ(5,10),  GLJ(5,10),HLJ(5,10),LLJ(5,10),
     +                 XLJ(5,10),XNJ(5,10)
C
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C NEXT LINE TO TAKE XTR2 INTO SUBRD1 SUBRD3
      COMMON /ZH9931/XTR2
C
      INTEGER I,J,K,NELMTS
C
      INTEGER CLIST(14,18)
C
C     Multiple tests of CALC (one row per test)
C     -----------------------------------------
      DATA ((CLIST(I,J), J = 1,18), I = 1,14) /
     1  0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     2  0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     3  1, 2, 0, 4, 5, 6, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     4  1, 0, 3, 0, 0, 0, 7, 0, 0, 0, 0, 0,13, 0, 0, 0, 0, 0,
     5  0, 2, 0, 0, 5, 0, 0, 8, 0, 0,11, 0, 0,14, 0, 0,17, 0,
     6  1, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     7  0, 0, 0, 0, 0, 0, 7, 0, 9, 0, 0, 0,13, 0,15, 0, 0, 0,
     8  0, 0, 0, 4, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     9  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13,14,15,16,17,18,
     *  1, 2, 3, 4, 5, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     1  0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     2  0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     3  0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     4  0, 0, 0, 0, 0, 0, 0, 0, 9,10, 0,12, 0, 0,15,16, 0,18/
C
      NLINES = 0
C     Read the three title lines
C     --------------------------
      DO 20 I = 1,3
      READ(INFIL,10,END=200) TITLE(I)
      NLINES = NLINES + 1
   10 FORMAT(A)
   20 CONTINUE
C
C     Read the calculation type
C     -------------------------
      READ(INFIL,*,END=200,ERR=210) CALC
      NLINES = NLINES + 1
      IF (CALC .LE. 0 .OR. CALC .GT. 18) THEN
       FAULT = 3
       GO TO 220
      END IF
C
C     Read the number of Mach number, Reynolds number pairs
C     -----------------------------------------------------
      READ(INFIL,*,END=200,ERR=210) NMR
      KMR = NMR
      NLINES = NLINES + 1
      IF (NMR .LE. 0 .OR. NMR .GT. 10) THEN
       FAULT = 4
       GO TO 220
      END IF
C
C     Read NMR Mach number, Reynolds number pairs
C     -------------------------------------------
      DO 30 I = 1,NMR
      READ(INFIL,*,END=200,ERR=210) MN(I),RN(I)
      NLINES = NLINES + 1
   30 CONTINUE
C
C     If CALC = 7 to 18, read A,TR,N,LDN
C     ----------------------------------
      IF (CLIST(1,CALC) .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) A,TR,N,LDN
       NLINES = NLINES + 1
      END IF
C
C     If CALC = 7,8,11,13,14,17 read EP
C     ---------------------------------
      IF (CLIST(2,CALC) .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) EP
       NLINES = NLINES +1
      END IF
C
C     If CALC = 1,2,4,5,6,7,8,11,13,14,17 read TES
C     --------------------------------------------
      IF (CLIST(3,CALC) .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) TES
       NLINES = NLINES + 1
       IF (TES .LT. 0 .OR. TES .GT. 1) THEN
        FAULT = 5
        GO TO 220
       END IF
      END IF
C
C     If CALC = 1,3,7 or 13 OR (if TES=1 and CALC = 2,5,8,11,14 or 17)
C     read TYPE, T, XTR, XUM, ZUM
C     ----------------------------------------------------------------
      IF (CLIST(4,CALC) .GT. 0 .OR.
     *    (TES .EQ. 1 .AND. CLIST(5,CALC) .GT. 0)) THEN
C
       ITYPE = 0
       READ(INFIL,10,END=200,ERR=210) TYPE
       NLINES = NLINES + 1
       IF (LLT(TYPE,'P') .OR. LGT(TYPE,'P')) GO TO 32
       ITYPE = 1
       GO TO 38
   32  IF (LLT(TYPE,'M') .OR. LGT(TYPE,'M')) GO TO 34
       ITYPE = 2
       GO TO 38
   34  IF (LLT(TYPE,'C') .OR. LGT(TYPE,'C')) GO TO 36
       ITYPE = 3
       GO TO 38
   36  FAULT = 6
       GO TO 220
C
   38  READ(INFIL,*,END=200,ERR=210) T
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) XTR
C  XTR2  SET TO XTR
       XTR2 = XTR
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) XUM,ZUM
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) TAU
       NLINES = NLINES + 1
C
       DO 40 I = 1,17
       READ(INFIL,*,END=200,ERR=210) XG(I),ZUG(I),ZLG(I)
       NLINES = NLINES + 1
   40  CONTINUE
C
      END IF
C
C     If CALC = 1 or 3, read zc92/zc50
C     --------------------------------
      IF (CLIST(6,CALC) .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) ZC92
       NLINES = NLINES + 1
      END IF
C
C     If CALC = 7,9,13 or 15, read delta2/3
C     -------------------------------------
      IF (CLIST(7,CALC) .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) D23
       NLINES = NLINES + 1
C
C     Data for root (centre-line) section
C     -----------------------------------
C
       DO 50 I = 1,15
       READ(INFIL,*,END=200,ERR=210) XRG(I),ZURG(I),ZLRG(I)
       NLINES = NLINES + 1
   50  CONTINUE
C
       READ(INFIL,*,END=200,ERR=210) Z92R
       NLINES = NLINES + 1
C
C     Data for section at eta = 2/3
C     -----------------------------
C
       DO 60 I = 1,15
       READ(INFIL,*,END=200,ERR=210) X23G(I),ZU23G(I),ZL23G(I)
       NLINES = NLINES + 1
   60  CONTINUE
C
       READ(INFIL,*,END=200,ERR=210) Z9223
       NLINES = NLINES + 1
C
      END IF
C
C     Restricted set of section data for basic aerofoil
C     -------------------------------------------------
      IF (TES .EQ. 0 .AND. CALC .EQ. 2) THEN
       READ(INFIL,*,END=200,ERR=210) T
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) XTR
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) TAU
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) TAUA
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) TAUAU
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) XUM,ZUM
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) ZU5,ZL5
       NLINES = NLINES + 1
      END IF
C
      IF (TES .EQ. 1 .AND. CLIST(8,CALC) .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) T
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) TAU
       NLINES = NLINES + 1
       READ(INFIL,*,END=200,ERR=210) TAUA
       NLINES = NLINES + 1
      END IF
C
C     Data needed when a fuselage is present (CALC = 13 to 18)
C     --------------------------------------------------------
      IF (CLIST(9,CALC) .GT. 0) THEN
C
       READ(INFIL,*,END=200,ERR=210) INT
       NLINES = NLINES + 1
       IF (INT .LT. 0 .OR. INT .GT. 1) THEN
        FAULT = 7
        GO TO 220
       END IF
C
       IF (INT .EQ. 0) THEN
        READ(INFIL,*,END=200,ERR=210) W,IW
        NLINES = NLINES + 1
       ELSE
        READ(INFIL,*,END=200,ERR=210) W,IW,H
        NLINES = NLINES + 1
       END IF
C
      END IF
C
C     User defined data that would otherwise be calculated
C     ----------------------------------------------------
      DO 70 I = 1,NMR
C
      IF (CALC .EQ. 2) THEN
       READ(INFIL,*,END=200,ERR=210) XCL0B(I),XCLMB(I)
       NLINES = NLINES + 1
      END IF
C
      IF (CALC .EQ. 4) THEN
       READ(INFIL,*,END=200,ERR=210) XCL0B(I)
       NLINES = NLINES + 1
      END IF
C
      IF (CALC .EQ. 8) THEN
       READ(INFIL,*,END=200,ERR=210) XCL0BW(I),XCLMBW(I)
       NLINES = NLINES + 1
      END IF
C
      IF (CALC .EQ. 10) THEN
       READ(INFIL,*,END=200,ERR=210) XCL0BW(I)
       NLINES = NLINES + 1
      END IF
C
      IF (CALC .EQ. 13) THEN
       READ(INFIL,*,END=200,ERR=210) XDCLMF(I)
       NLINES = NLINES + 1
      END IF
C
      IF (CALC .EQ. 14) THEN
       READ(INFIL,*,END=200,ERR=210) XCL0BF(I),XCLMBF(I)
       NLINES = NLINES + 1
      END IF
C
      IF (CALC .EQ. 16) THEN
       READ(INFIL,*,END=200,ERR=210) XCL0BF(I)
       NLINES = NLINES + 1
      END IF
C
   70 CONTINUE
C
C     Number of settings of high-lift system
C     --------------------------------------
      READ (INFIL,*,END=200,ERR=210) NDL,NDT
      KDL = NDL
      KDT = NDT
      NLINES = NLINES + 1
      IF ((NDL .LT. 0 .OR. NDL .GT. 10) .OR.
     *    (NDT .LT. 0 .OR. NDT .GT. 10)) THEN
       FAULT = 8
       GO TO 220
      END IF
C
C     High-lift system specification for aerofoil
C     ===========================================
C     If CALC = 1 to 6
C     ----------------
      IF (CLIST(10,CALC) .GT. 0 .AND. NDL .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) NL
       NLINES = NLINES + 1
C NL,NT, NLJ, NTJ MAY NOT BE ZER0
       IF (NL .LT. 0 .OR. NL .GT. 6) THEN
        FAULT = 9
        GO TO 220
       END IF
      END IF
C
      IF (CLIST(10,CALC) .GT. 0 .AND. NDT .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) NT
       NLINES = NLINES + 1
       IF (NT .LT. 0 .OR. NT .GT. 5) THEN
        FAULT = 9
        GO TO 220
       END IF
      END IF
C
C
C     Leading-edge devices.  Data for aerofoil
C     =================================================================
C
      IF (NDL .GT. 0 .AND. NL .GT. 0 .AND.
     +    (CALC .EQ. 1 .OR. CALC .EQ. 2 .OR. CALC .EQ. 5)) THEN
       DO 80 I = 1,NDL
C
C      If NL = 1 (plain flap) or NL = 2 (droop)
C      ----------------------------------------
       IF (NL .EQ. 1 .OR. NL .EQ. 2) THEN
        READ(INFIL,*,END=200,ERR=210) DL(I),RL(I),CXL(I),DCL(I)
        NLINES = NLINES + 1
       END IF
C
C      If NL = 3 (sealed slat) or NL = 4 (Kruger)
C      ------------------------------------------
       IF (NL .EQ. 3 .OR. NL .EQ. 4) THEN
        READ(INFIL,*,END=200,ERR=210) DL(I),RL(I),CXL(I),DCL(I),HL(I)
        NLINES = NLINES + 1
       END IF
C
C      If NL = 5 (slat)
C      ----------------
       IF (NL .EQ. 5) THEN
        READ(INFIL,*,END=200,ERR=210) DL(I),RL(I),CXL(I),DCL(I)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) GL(I),HL(I),LL(I),XL(I),XN(I)
        NLINES = NLINES + 1
       END IF
C
C      If NL = 6 (vented Kruger)
C      -------------------------
       IF (NL .EQ .6) THEN
        READ(INFIL,*,END=200,ERR=210) DL(I),RL(I),CXL(I),DCL(I)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) GL(I),HL(I),LL(I)
        NLINES = NLINES + 1
       END IF
C
   80  CONTINUE
      END IF
C

C READ FOR CL0 CALCS
C          IF (CALC .EQ. 3 .OR.  CALC .EQ. 4 .OR. CALC .EQ. 6) THEN
      IF (NDL .GT. 0 .AND. NL .GT. 0 .AND.
     +    (CALC .EQ. 3 .OR.  CALC .EQ. 4 .OR. CALC .EQ. 6)) THEN
       DO 81 I = 1,NDL
C
C      If NL = 1 (plain flap) or NL = 2 (droop)
C      ----------------------------------------
       IF (NL .EQ. 1 .OR. NL .EQ. 2) THEN
        READ(INFIL,*,END=200,ERR=210) DL(I),CXL(I),DCL(I)
        NLINES = NLINES + 1
       END IF
C
C      If NL = 3 (sealed slat) or NL = 4 (Kruger)
C      ------------------------------------------
       IF (NL .EQ. 3 .OR. NL .EQ. 4) THEN
        READ(INFIL,*,END=200,ERR=210) DL(I),CXL(I),DCL(I)
        NLINES = NLINES + 1
       END IF
C
C      If NL = 5 (slat)
C      ----------------
       IF (NL .EQ. 5) THEN
        READ(INFIL,*,END=200,ERR=210) DL(I),CXL(I),DCL(I)
        NLINES = NLINES + 1
       END IF
C
C      If NL = 6 (vented Kruger)
C      -------------------------
       IF (NL .EQ .6) THEN
        READ(INFIL,*,END=200,ERR=210) DL(I),CXL(I),DCL(I)
        NLINES = NLINES + 1
       END IF
C
   81  CONTINUE
       END IF
C     Trailing-edge flaps.  Data for aerofoil
C     ===============================================================
      IF (NDT .GT. 0 .AND. NT .GT. 0 .AND.
     +    (CALC .EQ. 1 .OR.  CALC .EQ. 2 .OR. CALC .EQ. 5)) THEN
C
C      Deflection angles, chord extensions and flap chords
C      ---------------------------------------------------
C      Number of elements
       NELMTS = 1
       IF (NT .EQ. 4) NELMTS = 2
       IF (NT .EQ. 5) NELMTS = 3
C
       DO 100 J = 1,NDT
       DO 90 I = 1,NELMTS
       READ(INFIL,*,END=200,ERR=210) DT(I,J),DCT(I,J)
       NLINES = NLINES + 1
   90  CONTINUE
  100  CONTINUE
C
       READ(INFIL,*,END=200,ERR=210) (CT(I), I = 1,NELMTS)
       NLINES = NLINES + 1
C
C      NT = 1 (plain)
C      ---------------
       IF (NT .EQ. 1) THEN
        READ(INFIL,*,END=200,ERR=210) RLT
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) PHIT
        NLINES = NLINES + 1
       END IF
C
C      NT = 2 (split)
C      ---------------
       IF (NT .EQ. 2) THEN
        READ(INFIL,*,END=200,ERR=210) XLM
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZLM
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZCM
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZU125
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZL125
        NLINES = NLINES + 1
       END IF
C      NT = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      -----------------------------------------------------------
       IF (NT .GE. 3 .AND. NT .LE. 5) THEN
        READ(INFIL,*,END=200,ERR=210) XTS
        NLINES = NLINES + 1
       END IF
C
      END IF
C READ FOR CL0 CALCS
      IF (NDT .GT. 0 .AND. NT .GT. 0 .AND.
     +    (CALC .EQ. 3 .OR.  CALC .EQ. 4 .OR. CALC .EQ. 6)) THEN
C
C      Deflection angles, chord extensions and flap chords
C      ---------------------------------------------------
C      Number of elements
       NELMTS = 1
       IF (NT .EQ. 4) NELMTS = 2
       IF (NT .EQ. 5) NELMTS = 3
C
       DO 101 J = 1,NDT
       DO 91 I = 1,NELMTS
       READ(INFIL,*,END=200,ERR=210) DT(I,J),DCT(I,J)
       NLINES = NLINES + 1
   91  CONTINUE
  101  CONTINUE
C
       READ(INFIL,*,END=200,ERR=210) (CT(I), I = 1,NELMTS)
       NLINES = NLINES + 1
C
C      NT = 1 (plain)
C      ---------------
       IF (NT .EQ. 1) THEN
        READ(INFIL,*,END=200,ERR=210) PHIT
        NLINES = NLINES + 1
       END IF
C
C      NT = 2 (split)
C      ---------------
       IF (NT .EQ. 2) THEN
        READ(INFIL,*,END=200,ERR=210) XLM
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZLM
        NLINES = NLINES + 1
       END IF
C      NT = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      -----------------------------------------------------------
       IF (NT .GE. 3 .AND. NT .LE. 5) THEN
        READ(INFIL,*,END=200,ERR=210) XTS
        NLINES = NLINES + 1
       END IF
C
      END IF
C
C
C     High-lift system specification for wing at mid-span of panels
C     =============================================================
C     If CALC = 7 to 18
C     -----------------
      IF (CALC .GT. 6 .AND. NDL .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) NNL
       NLINES = NLINES + 1
       IF (NNL .LE. 0 .OR. NNL .GT. 5) THEN
        FAULT = 10
        GO TO 220
       END IF
       DO 120 J = 1,NNL
       READ(INFIL,*,END=200,ERR=210) NLJ(J),EIL(J),EOL(J)
       NLINES = NLINES + 1
       IF (NLJ(J) .LE. 0 .OR. NLJ(J) .GT. 6) THEN
        FAULT = 9
        GO TO 220
       END IF
  120  CONTINUE
      END IF
C
      IF (CALC .GT. 6 .AND. NDT .GT. 0) THEN
       READ(INFIL,*,END=200,ERR=210) NNT
       NLINES = NLINES + 1
       IF (NNT .LE. 0 .OR. NNT .GT. 5) THEN
        FAULT = 10
        GO TO 220
       END IF
       DO 130 J = 1,NNT
       READ(INFIL,*,END=200,ERR=210) NTJ(J),EIT(J),EOT(J)
       NLINES = NLINES + 1
       IF (NTJ(J) .LE. 0 .OR. NTJ(J) .GT. 5) THEN
        FAULT = 9
        GO TO 220
       END IF
  130  CONTINUE
      END IF
C
C CSL CST LOGIC , USED IN EARLIER VERSION OF PROGRAM
C CSL CST NOT NOW USED BUT SET TO UNITY FOR SAFETY
       CSL = 1
       CST = 1
C
C     Section geometry of high-lift system at mid-span of device panels
C FOR CALC=7,8,11,13,14 OR 17
C
      IF (CLIST(13,CALC) .GT. 0) THEN
C     =================================================================
C     Leading-edge devices
C     --------------------
      IF (CALC .GT. 6 .AND. CSL .EQ. 1
     *    .AND. NDL .GT. 0 .AND. NNL .GT. 0) THEN
       DO 155 I = 1,NNL
       DO 145 J = 1,NDL
C
C      If NLJ(I) = 1 (plain flap) or NLJ(I) = 2 (droop)
C      ----------------------------------------
       IF (NLJ(I) .EQ. 1 .OR. NLJ(I) .EQ. 2) THEN
        READ(INFIL,*,END=200,ERR=210) DLJ(I,J),RLJ(I,J),CXLJ(I,J),
     +  DCLJ(I,J)
        NLINES = NLINES + 1
       END IF
C
C      If NLJ(I) = 3 (sealed slat) or NLJ(I) = 4 (Kruger)
C      ------------------------------------------
       IF (NLJ(I) .EQ. 3 .OR. NLJ(I) .EQ. 4) THEN
        READ(INFIL,*,END=200,ERR=210) DLJ(I,J),RLJ(I,J),CXLJ(I,J)
     +   ,DCLJ(I,J),HLJ(I,J)
        NLINES = NLINES + 1
       END IF
C
C      If NLJ(I) = 5 (slat)
C      ----------------
       IF (NLJ(I) .EQ. 5) THEN
        READ(INFIL,*,END=200,ERR=210) DLJ(I,J),RLJ(I,J),CXLJ(I,J)
     +    ,DCLJ(I,J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) GLJ(I,J),HLJ(I,J),LLJ(I,J)
     +   ,XLJ(I,J),XNJ(I,J)
        NLINES = NLINES + 1
       END IF
C
C      If NLJ(I) = 6 (vented Kruger)
C      -------------------------
       IF (NLJ(I) .EQ .6) THEN
        READ(INFIL,*,END=200,ERR=210) DLJ(I,J),RLJ(I,J),CXLJ(I,J)
     +   ,DCLJ(I,J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) GLJ(I,J),HLJ(I,J),LLJ(I,J)
        NLINES = NLINES + 1
       END IF
C
  145  CONTINUE
  155  CONTINUE
      END IF
C
C     Trailing-edge flaps
C     -------------------
      IF (CALC .GT. 6 .AND. CST .EQ. 1
     *    .AND. NDT .GT. 0 .AND. NNT .GT. 0) THEN
       DO 195 J = 1,NNT
       NELMTS = 1
       IF (NTJ(J) .EQ. 4) NELMTS = 2
       IF (NTJ(J) .EQ. 5) NELMTS = 3
C
       DO 175 K = 1,NDT
       DO 165 I = 1,NELMTS
       READ(INFIL,*,END=200,ERR=210) DTJ(I,J,K),DCTJ(I,J,K)
       NLINES = NLINES + 1
  165  CONTINUE
  175  CONTINUE
C
       READ(INFIL,*,END=200,ERR=210) (CTJ(I,J), I = 1,NELMTS)
       NLINES = NLINES + 1
C
C      If (Nt)j = 1 (plain flap)
C      -------------------------
       IF (NTJ(J) .EQ. 1) THEN
        READ(INFIL,*,END=200,ERR=210) RLTJ(J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) PHITJ(J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) LDHJ(J)
        NLINES = NLINES + 1
       END IF
C
C      If (Nt)j = 2 (split flap)
C      -------------------------
       IF (NTJ(J) .EQ. 2) THEN
        READ(INFIL,*,END=200,ERR=210) XLMJ(J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZLMJ(J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZCMJ(J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZU125J(J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZL125J(J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) LDHJ(J)
        NLINES = NLINES + 1
       END IF
C
C      If (Nt)j = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      ----------------------------------------------------------------
       IF (NTJ(J) .GE. 3) THEN
        READ(INFIL,*,END=200,ERR=210) XTSJ(J)
        NLINES = NLINES + 1
C
        READ(INFIL,*,END=200,ERR=210) LDHJ(J)
        NLINES = NLINES + 1
       END IF
C
  195  CONTINUE
      END IF
C
      END IF
C
C     Section geometry of high-lift system at mid-span of device panels
C FOR CALC=9,10,12,15,16,18
C
      IF (CLIST(14,CALC) .GT. 0) THEN
C     =================================================================
C     Leading-edge devices
C     --------------------
      IF (CALC .GT. 6 .AND. CSL .EQ. 1
     *    .AND. NDL .GT. 0 .AND. NNL .GT. 0) THEN
       DO 150 I = 1,NNL
       DO 140 J = 1,NDL
       READ(INFIL,*,END=200,ERR=210) DLJ(I,J),CXLJ(I,J),DCLJ(I,J)
       NLINES = NLINES + 1
  140  CONTINUE
  150  CONTINUE
      END IF
C
C     Trailing-edge flaps
C     -------------------
      IF (CALC .GT. 6 .AND. CST .EQ. 1
     *    .AND. NDT .GT. 0 .AND. NNT .GT. 0) THEN
       DO 190 J = 1,NNT
       NELMTS = 1
       IF (NTJ(J) .EQ. 4) NELMTS = 2
       IF (NTJ(J) .EQ. 5) NELMTS = 3
C
       DO 170 K = 1,NDT
       DO 160 I = 1,NELMTS
       READ(INFIL,*,END=200,ERR=210) DTJ(I,J,K),DCTJ(I,J,K)
       NLINES = NLINES + 1
  160  CONTINUE
  170  CONTINUE
C
       READ(INFIL,*,END=200,ERR=210) (CTJ(I,J), I = 1,NELMTS)
       NLINES = NLINES + 1
C
C      If (Nt)j = 1 (plain flap)
C      -------------------------
       IF (NTJ(J) .EQ. 1) THEN
        READ(INFIL,*,END=200,ERR=210) PHITJ(J)
        NLINES = NLINES + 1
       END IF
C
C      If (Nt)j = 2 (split flap)
C      -------------------------
       IF (NTJ(J) .EQ. 2) THEN
        READ(INFIL,*,END=200,ERR=210) XLMJ(J)
        NLINES = NLINES + 1
        READ(INFIL,*,END=200,ERR=210) ZLMJ(J)
        NLINES = NLINES + 1
       END IF
C
C      If (Nt)j = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      ----------------------------------------------------------------
       IF (NTJ(J) .GE. 3) THEN
        READ(INFIL,*,END=200,ERR=210) XTSJ(J)
        NLINES = NLINES + 1
C
       END IF
C
  190  CONTINUE
      END IF
C
      END IF
C
      GO TO 220
C
C     Unexpected end of file
C     ----------------------
  200 FAULT = 1
      GO TO 220
C
C     Unexpected data
C     ---------------
  210 FAULT = 2
      GO TO 220
C
  220 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE AC9931(OUTFIL)
C     =========================
C
C     Purpose
C     -------
C     To print the data
C
C     Input
C     -----
C     OUTFIL  - output unit number
C     The main input comes from various common blocks.
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL
C
C     Common block to contain string data
C     -----------------------------------
      CHARACTER TITLE*75,TYPE*1
      COMMON /ZA9931/TITLE(3),TYPE
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
      REAL           RLTJ,RLJ
      REAL           GLJ,HLJ,LLJ,XLJ,XNJ
      REAL           LDHJ,ZU125J,ZL125J,ZCMJ
C
      COMMON  /ZK9931/ LDHJ(5),ZU125J(5),ZL125J(5),ZCMJ(5), RLTJ(5),
     *                 RLJ(5,10),  GLJ(5,10),HLJ(5,10),LLJ(5,10),
     +                 XLJ(5,10),XNJ(5,10)
      INTEGER I,J,K,NELMTS,NLNS
C
      CHARACTER*17 LETYPE(6),TETYPE(5)
C
      INTEGER CLIST(15,18)
C
      DATA LETYPE / '(plain flap)',  ' (droop)', '(sealed slat)',
     *              '(Kruger)',      '  (slat)', '(vented Kruger)' /
C
      DATA TETYPE / ' (plain)',      ' (split)',  '(slotted)',
     *              '(double-slotted)', '(triple-slotted)' /
C
C     Multiple tests of CALC (one row per test)
C     -----------------------------------------
      DATA ((CLIST(I,J), J = 1,18), I = 1,15) /
     1  0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     2  0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     3  1, 2, 0, 4, 5, 6, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     4  1, 0, 3, 0, 0, 0, 7, 0, 0, 0, 0, 0,13, 0, 0, 0, 0, 0,
     5  0, 2, 0, 0, 5, 0, 0, 8, 0, 0,11, 0, 0,14, 0, 0,17, 0,
     6  1, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     7  0, 0, 0, 0, 0, 0, 7, 0, 9, 0, 0, 0,13, 0,15, 0, 0, 0,
     8  0, 0, 0, 4, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     9  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13,14,15,16,17,18,
     *  1, 2, 3, 4, 5, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     1  0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     2  0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     3  0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     4  0, 0, 0, 0, 0, 0, 0, 0, 9,10, 0,12, 0, 0,15,16, 0,18,
     5  0, 2, 0, 4, 0, 0, 0, 8, 0,10, 0, 0,13,14, 0,16, 0, 0/
C
      NLNS = 0
C
C     Print header and the three title lines
      WRITE(OUTFIL,1001)
 1001 FORMAT(//,1X,77('-'),/,' ESDU International plc',//,' PROGRAM ',
     1'A9931',//,' ESDUpac Number:   A9931',/,' ESDUpac Title:',4X,
     2'Computer program for estimation of lift curve  ',/,19X,'to ',
     3'maximum lift for wing-fuselage combinations with',/,19X,
     +'high-lift devices at low speeds',/,
     +/,' Data Item Number: 99031',/,
     4' Data Item Title:  Computer program for estimation of lift curve'
     5,/,19X,'to maximum lift for wing-fuselage combinations with',/,
     +19X,'high-lift devices at low speeds',/,
     6/,' ESDUpac Version:  2.1  Issued July 2002',
     7', Data Item 99031',/,' (See Data Item for full input/output ',
     8'specification and interpretation)',/,1X,77('-'),/)
C     ---------------------------
      WRITE(OUTFIL,500)
  500 FORMAT(/,
     *1X,72(1H-),//,
     *1X,'Title of run',/,
     *1X,'------------')
      DO 20 I = 1,3
      NLNS = NLNS + 1
      IF (NLNS .GT. NLINES) GO TO 220
      WRITE(OUTFIL,10) TITLE(I)
   10 FORMAT(1X,A75)
   20 CONTINUE
      WRITE(OUTFIL,505)
  505 FORMAT(/,1X,72(1H-),//,
     * 1X,'INPUT DATA',/,
     * 1X,'==========')
C
C     Print the calculation type
C     --------------------------
      NLNS = NLNS + 1
      IF (NLNS .GT. NLINES) GO TO 220
      WRITE(OUTFIL,510) CALC
  510 FORMAT(/,
     *1X,'CALC (calculation type) (see Table 3.1 or Sketch 3.1):      ',
     *    I2)
C
C     Print the number of Mach number, Reynolds number pairs
C     ------------------------------------------------------
      NLNS = NLNS + 1
      IF (NLNS .GT. NLINES) GO TO 220
      WRITE(OUTFIL,520) NMR
  520 FORMAT(
     *1X,'NMR (number of Mach and Reynolds No. pairs):                ',
     *    I2)
C
C     Print NMR Mach number, Reynolds number pairs
C     -------------------------------------------
      WRITE(OUTFIL,530)
  530 FORMAT(/,
     *1X,'Mach and Reynolds Number Pairs',/,
     *1X,'------------------------------',/,
     *1X,' Pair','   Mk       ','   Rk       ')
C
      DO 30 I = 1,NMR
      NLNS = NLNS + 1
      IF (NLNS .GT. NLINES) GO TO 220
      WRITE(OUTFIL,540) I,MN(I),RN(I)
  540 FORMAT(1X,I3,2X,2G12.4)
   30 CONTINUE
C
C     If CALC = 7 to 18, print A,TR,N,LDN
C     --------------------------------
      IF (CLIST(1,CALC) .GT. 0) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,550) A,TR,N,LDN
      END IF
C
  550 FORMAT(/,
     *1X,'A (aspect ratio):                                           ',
     *    G12.4,/,
     *1X,'lambda (taper ratio):                                       ',
     *    G12.4,/,
     *1X,'n (fractional chord line):                                  ',
     *    G12.4,/,
     *1X,'Lambda n (sweep of nth chord line):                         ',
     *    G12.4)
C
C     If CALC = 7,8,11,13,14,17 print EP
C     ---------------------------------
      IF (CLIST(2,CALC) .GT. 0) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,560) EP
      END IF
  560 FORMAT(/,
     *1X,'eta p (spanwise location of most highly loaded section):    ',
     *    G12.4)
C
C     If CALC = 1,2,4,5,6,7,8,11,13,14,17 print TES
C     --------------------------------------------
      IF (CLIST(3,CALC) .GT. 0) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (TES .EQ. 0) THEN
        WRITE(OUTFIL,570) TES
       ELSE
        WRITE(OUTFIL,580) TES
       END IF
      END IF
  570 FORMAT(
     *1X,'TES (flag for slotted flap ):                            ',
     *    I1,'  = absent')
  580 FORMAT(
     *1X,'TES (flag for slotted flap ):                             ',
     *    I1,'  = present')
C
C     If CALC = 1,3,7 or 13 OR (if TES=1 and CALC = 2,5,8,11,14 or 17)
C     print TYPE, T, XTR, XUM, ZUM
C     ----------------------------------------------------------------
      IF (CLIST(4,CALC) .GT. 0 .OR.
     *    (TES .EQ. 1 .AND. CLIST(5,CALC) .GT. 0)) THEN
C
       WRITE(OUTFIL,590)
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (ITYPE .EQ. 1) WRITE(OUTFIL,600) TYPE
       IF (ITYPE .EQ. 2) WRITE(OUTFIL,610) TYPE
       IF (ITYPE .EQ. 3) WRITE(OUTFIL,620) TYPE
C
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,630) T
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,640) XTR
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,650) XUM,ZUM
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,660) TAU
C
       WRITE(OUTFIL,670)
       DO 40 I = 1,17
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,680) I,XG(I),ZUG(I),ZLG(I)
   40  CONTINUE
C
      END IF
C
  590 FORMAT(/,
     *1X,'Section properties of basic aerofoil or wing at eta p',/,
     *1X,53(1H-))
  600 FORMAT(
     *1X,'TYPE (category of aerofoil section see Section 3):        ',
     *    A1,'   program decides')
  610 FORMAT(
     *1X,'TYPE (category of aerofoil section see Section 3):        ',
     *    A1,'   modern')
  620 FORMAT(
     *1X,'TYPE (category of aerofoil section see Section 3):        ',
     *   A1,'   conventional')
  630 FORMAT(
     *1X,'t/c (thickness to chord ratio):                             ',
     *    G12.4)
  640 FORMAT(
     *1X,'xtr/c (boundary layer transition point):                    ',
     *    G12.4)
  650 FORMAT(
     *1X,'xum/c (location of maximum upper surface ordinate)          ',
     *    G12.4,/,
     *1X,'zum/c (maximum upper surface ordinate):                     ',
     *    G12.4)
  660 FORMAT(
     *1X,'tau (trailing-edge angle in degrees in Sketch 1.1a):        ',
     *    G12.4)
  670 FORMAT(/,
     *1X,'Upper and lower surface coordinates         ',/,
     *1X,'  i  ','   (x/c)i   ','   (zu/c)i  ','  (zl/c)i   ')
  680 FORMAT(1X,I3,2X,3G12.4)
C
C     If CALC = 1 or 3, read zc92/zc50
C     --------------------------------
      IF (CLIST(6,CALC) .GT. 0) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,690) ZC92
      END IF
  690 FORMAT(/,
     *1X,'zc92/zc50 (ratio of camber ordinates at x/c = .92 and .5):  ',
     *    G12.4,/,13X,'unity for no camber')
C
C     If CALC = 7,9,13 or 15, read delta2/3
C     -------------------------------------
      IF (CLIST(7,CALC) .GT. 0) THEN
C     ------------------------------
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,700) D23
C
  700 FORMAT(/,
     *1X,'delta2/3 (twist angle at eta = 2/3 in degrees):     ',
     *    G12.4)
C
C     Data for root (centre-line) section
C     -----------------------------------
       WRITE(OUTFIL,710)
  710 FORMAT(/,
     *1X,'Data for root (centre-line) section',/,
     *1X,35(1H-))
C
       WRITE(OUTFIL,750)
       DO 50 I = 1,15
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,760) I,XRG(I),ZURG(I),ZLRG(I)
   50  CONTINUE
  750 FORMAT(/,
     *1X,'Upper and lower surface coordinates at root (centre-line)',/,
     *1X,'  i  ','  (x/c)ri   ','  (zu/c)ri  ','  (zl/c)ri  ')
  760 FORMAT(1X,I3,2X,3G12.4)
C
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,770) Z92R
  770 FORMAT(/,1X,
     *'(zc92/zc50)r (ratio of camber ordinates at x/c = .92 and .5):',
     *    G12.4,/,17X,'unity for no camber')
C
C
C     Data for section at eta = 2/3
C     -----------------------------
       WRITE(OUTFIL,780)
  780 FORMAT(/,
     *1X,'Data for section at eta = 2/3',/,
     *1X,29(1H-))
C
       WRITE(OUTFIL,820)
       DO 60 I = 1,15
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,830) I,X23G(I),ZU23G(I),ZL23G(I)
   60  CONTINUE
C
  820 FORMAT(/,
     *1X,'Upper and lower surface coordinates at eta = 2/3',/,
     *1X,'  i  ','  (x/c)2/3i ','  (zu/c)2/3i','  (zl/c)2/3i')
  830 FORMAT(1X,I3,2X,3G12.4)
C
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,840) Z9223
  840 FORMAT(/,1X,
     *'(zc92/zc50)2/3 (ratio of camber ordinates at x/c = .92 and .5):',
     * G12.4,/,19X,'unity for no camber')
C
      END IF
C     ------
C
C     Restricted set of section data for basic aerofoil
C     -------------------------------------------------
      IF (TES .EQ. 0 .AND. CALC .EQ. 2) THEN
       WRITE(OUTFIL,590)
C
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,630) T
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,640) XTR
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,660) TAU
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,860) TAUA
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,870) TAUAU
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,650) XUM,ZUM
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,880) ZU5,ZL5
      END IF
C
  860 FORMAT(
     *1X,'tau a (trailing-edge angle in degrees in Sketch 1.1b):      ',
     *    G12.4)
  870 FORMAT(
     *1X,'tau au (trailing-edge angle in degrees in Sketch 1.1c):     ',
     *    G12.4)
  880 FORMAT(
     *1X,'(zu/c)5 (upper-surface ordinate at x/c = 0.05):             ',
     *    G12.4,/,
     *1X,'(zl/c)5 (lower-surface ordinate at x/c = 0.05):             ',
     *    G12.4)
C
      IF (TES .EQ. 1 .AND. CLIST(8,CALC) .GT. 0) THEN
       WRITE(OUTFIL,590)
C
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,630) T
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,660) TAU
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,860) TAUA
      END IF
C
C
C     Data needed when a fuselage is present (CALC = 13 to 18)
C     --------------------------------------------------------
      IF (CLIST(9,CALC) .GT. 0) THEN
       WRITE(OUTFIL,900)
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (INT .EQ. 0) THEN
        WRITE(OUTFIL,910) INT
       ELSE
        WRITE(OUTFIL,920) INT
       END IF
C
       IF (INT .EQ. 0) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,930) W,IW
       ELSE
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,940) W,IW,H
       END IF
C
      END IF
C
  900 FORMAT(/,
     *1X,'Data required when a fuselage is present',/,
     *1X,40(1H-))
  910 FORMAT(
     *1X,'INT (fuselage effect on trailing-edge flap performance):    ',
     *    I1,' neglected')
  920 FORMAT(
     *1X,'INT (fuselage effect on trailing-edge flap performance):    ',
     *    I1,' included')
  930 FORMAT(
     *1X,'W/s (body width / semi-span):                               ',
     *    G12.4,/,
     *1X,'iW (setting angle of wing in degrees in Sketch 1.10):       ',
     *    G12.4)
  940 FORMAT(
     *1X,'W/s (body width / semi-span):                               ',
     *    G12.4,/,
     *1X,'iW (setting angle of wing in degrees in Sketch 1.10):       ',
     *    G12.4,/,
     *1X,'h/H (wing height / fuselage height):                        ',
     *    G12.4)
C
C     User defined data that would otherwise be calculated
C     ----------------------------------------------------
      IF (CLIST(15,CALC) .GT. 0) THEN
       WRITE(OUTFIL,950) NMR
       IF (CALC .EQ.  2) WRITE(OUTFIL,960)
       IF (CALC .EQ.  4) WRITE(OUTFIL,970)
       IF (CALC .EQ.  8) WRITE(OUTFIL,980)
       IF (CALC .EQ. 10) WRITE(OUTFIL,990)
       IF (CALC .EQ. 13) WRITE(OUTFIL,1000)
       IF (CALC .EQ. 14) WRITE(OUTFIL,1010)
       IF (CALC .EQ. 16) WRITE(OUTFIL,1020)
      END IF
C
  950 FORMAT(/,
     *1X,'User data in place of calculated data',/,
     *1X,'for ',I2,' Mach and Reynolds number pair(s)',/,
     *1X,39(1H-))
  960 FORMAT(/,
     *1X,'Pair ','    CL0B    ','  CLmB     ')
  970 FORMAT(/,
     *1X,'Pair ','    CL0B    ')
  980 FORMAT(/,
     *1X,'Pair ','   CL0Bw    ','  CLmaxB    ')
  990 FORMAT(/,
     *1X,'Pair ','   CL0Bw    ')
 1000 FORMAT(/,
     *1X,'Pair ',' Delta CLmaxf')
 1010 FORMAT(/,
     *1X,'Pair ','   CL0Bf    ','  CLmaxBf   ')
 1020 FORMAT(/,
     *1X,'Pair ','   CL0Bf    ')
 1030 FORMAT(1X,I3,2X,G12.4,G12.4)
C
      DO 70 I = 1,NMR
C
      IF (CALC .EQ. 2) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1030) I,XCL0B(I),XCLMB(I)
      END IF
C
      IF (CALC .EQ. 4) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1030) I,XCL0B(I)
      END IF
C
      IF (CALC .EQ. 8) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1030) I,XCL0BW(I),XCLMBW(I)
      END IF
C
      IF (CALC .EQ. 10) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1030) I,XCL0BW(I)
      END IF
C
      IF (CALC .EQ. 13) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1030) I,XDCLMF(I)
      END IF
C
      IF (CALC .EQ. 14) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1030) I,XCL0BF(I),XCLMBF(I)
      END IF
C
      IF (CALC .EQ. 16) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1030) I,XCL0BF(I)
      END IF
C
   70 CONTINUE
C
C     Number of settings of high-lift system
C     --------------------------------------
      NLNS = NLNS + 1
      IF (NLNS .GT. NLINES) GO TO 220
      WRITE(OUTFIL,1040) NDL,NDT
 1040 FORMAT(/,
     *1X,'High-Lift System',/,
     *1X,'================',//,
     *1X,'Ndl (number of leading-edge device settings):         ',
     *    I2,/,
     *1X,'Ndt (number of trailing-edge device settings):        ',
     *    I2)
C
C     High-lift system specification for aerofoil
C
      IF (CLIST(10,CALC) .GT. 0 ) THEN
C     ===========================================
C     If CALC = 1 to 6
C     ----------------
C
      IF (CLIST(10,CALC) .GT. 0 .AND. NDL .GT. 0) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1060) NL,LETYPE(NL)
      END IF
C
      IF (CLIST(10,CALC) .GT. 0 .AND. NDT .GT. 0) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1070) NT,TETYPE(NT)
      END IF
C
 1060 FORMAT(
     *1X,'Nl (leading-edge device type):                              ',
     *    I2,1X,A17)
 1070 FORMAT(
     *1X,'Nt (trailing-edge device type):                             ',
     *    I2,1X,A17)
C
C
C     Leading-edge devices.  Data for aerofoil
C     =================================================================
      IF (NDL .GT. 0 .AND. NL .GT. 0 .AND.
     +    (CALC .EQ. 1 .OR. CALC .EQ. 2 .OR. CALC .EQ. 5)) THEN
       IF (NL .EQ. 1 .OR. NL .EQ. 2) WRITE(OUTFIL,1110)
       IF (NL .EQ. 3 .OR. NL .EQ. 4) WRITE(OUTFIL,1810)
       IF (NL .EQ. 5 )               WRITE(OUTFIL,1820)
       IF (NL .EQ. 6 )               WRITE(OUTFIL,1830)
C
       DO 80 I = 1,NDL
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
C
C      If NL = 1 (plain flap) or NL = 2 (droop)
C      ----------------------------------------
       IF (NL .EQ. 1 .OR. NL .EQ. 2)
     * WRITE(OUTFIL,1120) I,DL(I),RL(I),CXL(I),DCL(I)

C
C      If NL = 3 (sealed slat) or NL = 4 (Kruger)
C      ------------------------------------------
       IF (NL .EQ. 3 .OR. NL .EQ. 4)
     * WRITE(OUTFIL,1130) I,DL(I),RL(I),CXL(I),DCL(I),HL(I)
C
C      If NL = 5 (slat)
C      ----------------
       IF (NL .EQ. 5)
     * WRITE(OUTFIL,1140) I,DL(I),RL(I),CXL(I),DCL(I),
     *                      GL(I),HL(I),LL(I),XL(I),XN(I)
C
C      If NL = 6 (vented Kruger)
C      -------------------------
       IF (NL .EQ .6)
     * WRITE(OUTFIL,1150) I,DL(I),RL(I),CXL(I),DCL(I),
     *                      GL(I),HL(I),LL(I)
C
   80  CONTINUE
      END IF
C
 1110 FORMAT(/,
     *1X,'Leading-edge device geometry on aerofoil (See Table 4.1)    ',
     */,
     *1X,65(1H-),//,
     +1X,'Deflection angles,leading edge, chords and chord extensions/c'
     +,/,1X,'                    radius/c                             ')
 1810 FORMAT(/,
     *1X,'Leading-edge device geometry on aerofoil (See Table 4.1)    ',
     */,
     *1X,65(1H-),//,
     +1X,'Deflection angles, leading edge, chords/c, chord extensions',
     +' and trailing edge',/,
     +1X,'                    radius/c                              ',
     +1X,'       heights/c'  )
 1820 FORMAT(/,
     *1X,'Leading-edge device geometry on aerofoil (See Table 4.1)    ',
     */,
     *1X,65(1H-),//,
     +1X,'Deflection angles, leading edge, chords and chord extensions',
     +'/c',/,1X,'                     radius/c                   ',
     +//,1X,'         gap/c,     trailing edge, overlap/c, trailing',
     +1X,'edge and fixed nose ',/,
     +1X,'                       height/c                       positi',
     +'ons/c')
 1830 FORMAT(/,
     *1X,'Leading-edge device geometry on aerofoil (See Table 4.1)    ',
     */,
     *1X,65(1H-),//,
     +1X,'Deflection angles, leading edge, chords and chord extensions',
     +'/c',1X,/,'                      radius/c                       ',
     +1X,//,'           gap/c,   trailing edge, overlap/c',
     +1X,/,'                      height/c' )
 1120 FORMAT(/,
     *1X,'Setting','   delta l  ','   rho l/c  ','   cxl/c    ',
     *             '   Delta cl/c',/,
     *1X,I4,3X,4G12.4)
 1130 FORMAT(/,
     *1X,'Setting','   delta l  ','   rho l/c  ','   cxl/c    ',
     *             '   Delta cl/c','  Hl/c      ',/,
     *1X,I4,3X,5G12.4)
 1140 FORMAT(/,
     *1X,'Setting','   delta l  ','   rho l/c  ','   cl/c     ',
     *             '   Delta cl/c',/,
     *1X,I4,3X,4G12.4,//,
     *1X,'       ','   Gl/c     ','   Hl/c     ','   Ll/c     ',
     *             '   xl/c     ','   xn/c     ',/,
     *1X,7X,5G12.4)
 1150 FORMAT(/,
     *1X,'Setting','   delta l  ','   rho l/c  ','   cl/c     ',
     *             '   Delta cl/c',/,
     *1X,I4,3X,4G12.4,//,
     *1X,'       ','   Gl/c     ','   Hl/c     ','   Ll/c     ',/,
     *1X,7X,3G12.4)
C
C     Trailing-edge flaps.  Data for aerofoil
C     ===============================================================
      IF (NDT .GT. 0 .AND. NT .GT. 0 .AND.
     +     (CALC .EQ. 1 .OR. CALC .EQ. 2 .OR. CALC .EQ. 5)) THEN
C
C      Deflection angles, chord extensions and flap chords
C      ---------------------------------------------------
C      Number of elements
       NELMTS = 1
       IF (NT .EQ. 4) NELMTS = 2
       IF (NT .EQ. 5) NELMTS = 3
C
       WRITE(OUTFIL,1160) NELMTS
 1160 FORMAT(/,
     *1X,'Trailing-edge device geometry on aerofoil (See Table 4.1)   ',
     */,
     *1X,66(1H-),//,
     *1X,'Deflection angles and chord extensions for ',I1,
     *   ' flap element(s)',//,
     *1X,'Setting ',' Element','   delta t  ','   Delta ct/c')
C
       DO 100 J = 1,NDT
       DO 90 I = 1,NELMTS
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (I .EQ. 1) THEN
        WRITE(OUTFIL,1170) J,I,DT(I,J),DCT(I,J)
       ELSE
        WRITE(OUTFIL,1180)   I,DT(I,J),DCT(I,J)
       END IF
C
 1170 FORMAT(1X,I4,4X,I4,4X,2G12.4)
 1180 FORMAT(1X,8X,I4,4X,2G12.4)
   90  CONTINUE
       WRITE (OUTFIL,1182)
 1182 FORMAT (1X)
  100  CONTINUE
C
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (NELMTS .EQ. 1) WRITE(OUTFIL,1200) CT(1)
       IF (NELMTS .EQ. 2) WRITE(OUTFIL,1210) CT(1),CT(2)
       IF (NELMTS .EQ. 3) WRITE(OUTFIL,1220) CT(1),CT(2),CT(3)
C
 1200 FORMAT(
     *1X,'ct/c (flap chord / wing chord):                             ',
     *    G12.4)
 1210 FORMAT(1X,'Flap chords ct1/c =',G12.4,5X,'ct2/c =',G12.4)
 1220 FORMAT(1X,'Flap chords ct1/c =',G12.4,5X,'ct2/c =',G12.4,5X,
     *          'ct3/c =',G12.4)
C
C      NT = 1 (plain)
C      ---------------
       IF (NT .EQ. 1) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1230) RLT
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1240) PHIT
       END IF
C
 1230 FORMAT(
     *1X,'rho l/t (leading edge radius / thickness):                  ',
     *    G12.4)
 1240 FORMAT(1X,
     *'phi t (angle from aerofoil datum to tangent to upper surface',/,
     *1X,'      at trailing edge in degrees in Sketch 1.7):           ',
     *    G12.4)
C
C      NT = 2 (split)
C      ---------------
       IF (NT .EQ. 2) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1250) XLM
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1260) ZLM
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1270) ZCM
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1280) ZU125
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1290) ZL125
       END IF
C
 1250 FORMAT(
     *1X,'xlm/c (location of maximum lower surface ordinate):         ',
     *    G12.4)
 1260 FORMAT(
     *1X,'zlm/c (maximum lower surface ordinate):                     ',
     *    G12.4)
 1270 FORMAT(
     *1X,'zcm/c (maximum camber height):                              ',
     *    G12.4)
 1280 FORMAT(
     *1X,'(zu/c)1.25 (upper surface ordinate at x=0.0125c):           ',
     *    G12.4)
 1290 FORMAT(
     *1X,'(zl/c)1.25 (lower surface ordinate at x=0.0125c):           ',
     *     G12.4)
C
C      NT = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      -----------------------------------------------------------
       IF (NT .GE. 3 .AND. NT .LE. 5) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1300) XTS
       END IF
 1300 FORMAT(
     *1X,'xts/c (location of flap shroud trailing edge):              ',
     *    G12.4)
C
      END IF
C
      IF (NDL .GT. 0 .AND. NL .GT. 0 .AND.
     +    (CALC .EQ. 3 .OR. CALC .EQ. 4 .OR. CALC .EQ. 6)) THEN
       WRITE(OUTFIL,1112)
C
       DO 81 I = 1,NDL
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
C
C      If NL = 1 (plain flap) or NL = 2 (droop)
C      ----------------------------------------
       IF (NL .EQ. 1 .OR. NL .EQ. 2)
     * WRITE(OUTFIL,1123) I,DL(I),CXL(I),DCL(I)

C
C      If NL = 3 (sealed slat) or NL = 4 (Kruger)
C      ------------------------------------------
       IF (NL .EQ. 3 .OR. NL .EQ. 4)
     * WRITE(OUTFIL,1133) I,DL(I),CXL(I),DCL(I)
C
C      If NL = 5 (slat)
C      ----------------
       IF (NL .EQ. 5)
     * WRITE(OUTFIL,1143) I,DL(I),CXL(I),DCL(I)
C
C      If NL = 6 (vented Kruger)
C      -------------------------
       IF (NL .EQ .6)
     * WRITE(OUTFIL,1153) I,DL(I),CXL(I),DCL(I)
C
   81  CONTINUE
      END IF
C
 1112 FORMAT(/,
     *1X,'Leading-edge device geometry on aerofoil (See Table 4.1)    ',
     */,
     *1X,65(1H-),//,
     +1X,'Deflection angles, chords and chord extensions')
 1123 FORMAT(/,
     *1X,'Setting','   delta l  ','   cxl/c    ',
     *             '   Delta cl/c',/,
     *1X,I4,3X,3G12.4)
 1133 FORMAT(/,
     *1X,'Setting','   delta l  ','   cxl/c    ',
     *             '   Delta cl/c',/,
     *1X,I4,3X,3G12.4)
 1143 FORMAT(/,
     *1X,'Setting','   delta l  ','   cl/c     ',
     *             '   Delta cl/c',/,
     *1X,I4,3X,3G12.4)
 1153 FORMAT(/,
     *1X,'Setting','   delta l  ','   cl/c     ',
     *             '   Delta cl/c',/,
     *1X,I4,3X,4G12.4)
C
C     Trailing-edge flaps.  Data for aerofoil
C     ===============================================================
      IF (NDT .GT. 0 .AND. NT .GT. 0 .AND.
     +     (CALC .EQ. 3 .OR. CALC .EQ. 4 .OR. CALC .EQ. 6)) THEN
C
C      Deflection angles, chord extensions and flap chords
C      ---------------------------------------------------
C      Number of elements
       NELMTS = 1
       IF (NT .EQ. 4) NELMTS = 2
       IF (NT .EQ. 5) NELMTS = 3
C
       WRITE(OUTFIL,1161) NELMTS
 1161 FORMAT(/,
     *1X,'Trailing-edge device geometry on aerofoil (See Table 4.1)   ',
     */,
     *1X,66(1H-),//,
     *1X,'Deflection angles and chord extensions for ',I1,
     *   ' flap element(s)',//,
     *1X,'Setting ',' Element','   delta t  ','   Delta ct/c')
C
       DO 101 J = 1,NDT
       DO 91 I = 1,NELMTS
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (I .EQ. 1) THEN
        WRITE(OUTFIL,1171) J,I,DT(I,J),DCT(I,J)
       ELSE
        WRITE(OUTFIL,1181)   I,DT(I,J),DCT(I,J)
       END IF
C
 1171 FORMAT(1X,I4,4X,I4,4X,2G12.4)
 1181 FORMAT(1X,8X,I4,4X,2G12.4)
   91  CONTINUE
       WRITE (OUTFIL,1183)
 1183 FORMAT (1X)
  101  CONTINUE
C
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (NELMTS .EQ. 1) WRITE(OUTFIL,1201) CT(1)
       IF (NELMTS .EQ. 2) WRITE(OUTFIL,1211) CT(1),CT(2)
       IF (NELMTS .EQ. 3) WRITE(OUTFIL,1221) CT(1),CT(2),CT(3)
C
 1201 FORMAT(
     *1X,'ct/c (flap chord / wing chord):                             ',
     *    G12.4)
 1211 FORMAT(1X,'Flap chords ct1/c =',G12.4,5X,'ct2/c =',G12.4)
 1221 FORMAT(1X,'Flap chords ct1/c =',G12.4,5X,'ct2/c =',G12.4,5X,
     *          'ct3/c =',G12.4)
C
C      NT = 1 (plain)
C      ---------------
       IF (NT .EQ. 1) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1242) PHIT
       END IF
C
 1242 FORMAT(1X,
     *'phi t (angle from aerofoil datum to tangent to upper surface',/,
     *1X,'      at trailing edge in degrees in Sketch 1.7):           ',
     *    G12.4)
C
C      NT = 2 (split)
C      ---------------
       IF (NT .EQ. 2) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1252) XLM
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1262) ZLM
       END IF
C
 1252 FORMAT(
     *1X,'xlm/c (location of maximum lower surface ordinate):         ',
     *    G12.4)
 1262 FORMAT(
     *1X,'zlm/c (maximum lower surface ordinate):                     ',
     *    G12.4)
C
C      NT = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      -----------------------------------------------------------
       IF (NT .GE. 3 .AND. NT .LE. 5) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1302) XTS
       END IF
 1302 FORMAT(
     *1X,'xts/c (location of flap shroud trailing edge):              ',
     *    G12.4)
C
      END IF
C
      END IF
C
C     High-lift system specification for wing at mid-span of panels
C     =============================================================
C     If CALC = 7 to 18
C     -----------------
      IF (CALC .GT. 6 .AND. NDL + NDT .GT. 0)
     *WRITE(OUTFIL,1320)
C
      IF (CALC .GT. 6 .AND. NDL .GT. 0) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1330) NNL
C
       DO 120 J = 1,NNL
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1340) J,NLJ(J),EIL(J),EOL(J),LETYPE(NLJ(J))
  120  CONTINUE
      END IF
C
      IF (CALC .GT. 6 .AND. NDT .GT. 0) THEN
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1350) NNT
C
       DO 130 J = 1,NNT
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       WRITE(OUTFIL,1340) J,NTJ(J),EIT(J),EOT(J),TETYPE(NTJ(J))
  130  CONTINUE
      END IF
C
 1320 FORMAT(/,
     *1X,'High-lift system specification for wing at mid-span of ',
     *   'device panels',/,
     *1X,'-------------------------------------------------------',
     *   '-------------')
 1330 FORMAT(/,
     *1X,'Nnl (number of leading-edge device panels):          ',
     *    I3,/,
     */,1X,'Device','  Type   ','  Inboard   ','  Outboard  ',
     */,1X,'Number','         ','  Limit     ','  Limit     ',
     */,1X,'  j   ','  (Nl)j  ','  (eta il)j ','  (eta ol)j ')
 1340 FORMAT(1X,I3,3X,I6,3X,2G12.4,/,1X,6X,A17,/)
 1350 FORMAT(/,
     *1X,'Nnt (number of trailing-edge device panels):         ',
     *    I3,/,
     */,1X,'Device','  Type   ','  Inboard   ','  Outboard  ',
     */,1X,'Number','         ','  Limit     ','  Limit     ',
     */,1X,'  j   ','  (Nt)j  ','  (eta it)j ','  (eta ot)j ')
C
C     Section geometry of high-lift system at mid-span of device panels
C     =================================================================
C
      IF (CLIST(13,CALC) .GT. 0) THEN
C
C     Leading-edge devices
C     --------------------
      IF (NDL .GT. 0  ) THEN
       WRITE(OUTFIL,1111)
C
C
       DO 151 I = 1,NNL
       DO 141 J = 1,NDL
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
C
C      If NLJ(I) = 1 (plain flap) or NLJ(I) = 2 (droop)
C      ----------------------------------------
       IF ((NLJ(I) .EQ. 1 .OR. NLJ(I) .EQ. 2) .AND. J .EQ. 1)  THEN
         WRITE(OUTFIL,1121) I,J,DLJ(I,J),RLJ(I,J),CXLJ(I,J),DCLJ(I,J)
       END IF
       IF ((NLJ(I) .EQ. 1 .OR. NLJ(I) .EQ. 2) .AND. J .NE. 1)  THEN
        WRITE(OUTFIL,1122)    J,DLJ(I,J),RLJ(I,J),CXLJ(I,J),DCLJ(I,J)
       END IF
C
C      If NLJ(I) = 3 (sealed slat) or NLJ(I) = 4 (Kruger)
C      ------------------------------------------
       IF ((NLJ(I) .EQ. 3 .OR. NLJ(I) .EQ. 4 ) .AND. J .EQ. 1)  THEN
        WRITE(OUTFIL,1131) I,J,DLJ(I,J),RLJ(I,J),CXLJ(I,J),DCLJ(I,J),
     *                                                         HLJ(I,J)
       END IF
       IF ((NLJ(I) .EQ. 3 .OR. NLJ(I) .EQ. 4 ) .AND. J .NE. 1)  THEN
        WRITE(OUTFIL,1132)   J,DLJ(I,J),RLJ(I,J),CXLJ(I,J),DCLJ(I,J),
     *                                                         HLJ(I,J)
       END IF
C
C      If NLJ(I) = 5 (slat)
C      ----------------
       IF (NLJ(I) .EQ. 5 .AND. J .EQ. 1) THEN
        WRITE(OUTFIL,1141) I,J,DLJ(I,J),RLJ(I,J),CXLJ(I,J),DCLJ(I,J),
     *                      GLJ(I,J),HLJ(I,J),LLJ(I,J),XLJ(I,J),XNJ(I,J)
       END IF
       IF (NLJ(I) .EQ. 5 .AND. J .NE. 1) THEN
        WRITE(OUTFIL,1142)     J,DLJ(I,J),RLJ(I,J),CXLJ(I,J),DCLJ(I,J),
     *                      GLJ(I,J),HLJ(I,J),LLJ(I,J),XLJ(I,J),XNJ(I,J)
       END IF
C
C      If NLJ(I) = 6 (vented Kruger)
C      -------------------------
       IF (NLJ(I) .EQ. 6 .AND. J .EQ. 1)  THEN
         WRITE(OUTFIL,1151) I,J,DLJ(I,J),RLJ(I,J),CXLJ(I,J),DCLJ(I,J),
     *                      GLJ(I,J),HLJ(I,J),LLJ(I,J)
       END IF
       IF (NLJ(I) .EQ. 6 .AND. J .NE. 1)  THEN
         WRITE(OUTFIL,1152)   J,DLJ(I,J),RLJ(I,J),CXLJ(I,J),DCLJ(I,J),
     *                      GLJ(I,J),HLJ(I,J),LLJ(I,J)
       END IF
C
  141  CONTINUE
  151 CONTINUE
      END IF
C
 1111 FORMAT(/,
     *1X,'Geometry of leading-edge devices at their mid-span',/,
     *1X,'--------------------------------------------------',//,
     +1X,'                              (See Table 4.1)     ',/,
     *1X,' Device ',' Setting','            ','            ',
     *   '            ',/,
     *1X,' Number ',' Number ','            ','            ')
 1121 FORMAT(/,
     +1X,'                 Deflection, leading edge, chords',
     +1X,'and chord extensions/c',/,
     +1X,'                 angles        radius/c         ',//,
     *1X,'   j    ','  n    ','  (delta l)j','  (rho l/c)j',
     *             '   (cxl/c)j ','  (Delta cl/c)j', /,
     *1X,2(I4,3X),4G12.4)
 1122 FORMAT(/,
     *1X,7X,I4,3X,4G12.4)
 1131 FORMAT(/,
     +1X,'                Deflection, leading edge, chords/c,',
     +1X,'chord extensions and ',/,
     +1X,'                angles        radius/c          ',
     +1X,' trailing edge heights/c',
     +1X//,
     *1X,'   j    ','  n    ','  (delta l)j','  (rho l/c)j',
     *          '  (cxl/c)j ','  (Delta cl/c)j ',' (Hl/c)j    ',/,
     *1X,2(I4,3X),5G12.4)
 1132 FORMAT(/,
     *1X,7X,I4,3X,5G12.4)
 1141 FORMAT(/,
     +1X,'                 Deflection, leading edge, chords',
     +1X,'and chord extensions/c',/,
     +1X,'                 angles        radius/c        ',//,
     +1X,'                 gap/c,   trailing edge, overlap/c,',
     +1X,'trailing edge and ',/,
     +1X,'                             height/c             ',
     +1X,'  fixed nose positions/c',
     +1X ,//,
     *1X,'   j    ','  n    ','  (delta l)j','  (rho l/c)j',
     *            '   (cl/c)j  ','  (Delta cl/c)j ',/,
     *1X,2(I4,3X),4G12.4,//,
     *1X,'       ','       ','   (Gl/c)j   ','  (Hl/c)j   ',
     *        '  (Ll/c)j   ',     '  (cl/c)j   ','  (xn/c)j   ',/,
     *1X,7X,7X,5G12.4)
 1142 FORMAT(/,
     *1X,'       ','       ','   (delta l)j','  (rho l/c)j',
     *      '   (cl/c)j  ', '  (Delta cl/c)j',/,
     *1X,8X,I4,3X,4G12.4,//,
     *1X,'       ','       ','   (Gl/c)j   ','  (Hl/c)j   ',
     *    '  (Ll/c)j   ',         '  (xl/c)j   ','  (xn/c)j   ',/,
     *1X,8X,7X,5G12.4)
 1151 FORMAT(/,
     +1X,'                 Deflection, leading edge, chords',
     +1X,'and chord extensions/c',/,
     +1X,'                 angles        radius/c ',//,
     +1X,'                 gap/c,    trailing edge, overlap/c',/,
     +1X,'                             height/c ',//,
     *1X,'   j    ','  n    ','  (delta l)j ',' (rho l/c)j',
     *          '  (cl/c)j    ','  Delta cl/c',/,
     *1X,2(I4,3X),4G12.4,//,
     *1X,'       ','        ','  (Gl/c)j   ','  (Hl/c)j  ',
     +1X,'  (Ll/c)j     ',/,
     *1X,7X,7X,3G12.4)
 1152 FORMAT(/,
     *1X,'        ','       ','  (delta l)j  ','(rho l/c)j',
     *1X,                          ' (xl/c)j   ','  (Delta cl/c)j',/,
     *1X,7X,I4,3X,4G12.4,//,
     *1X,'       ','       ','   (Gl/c)j   ','  (Hl/c)j   ',
     +1X,' (Ll/c)j   ',/,
     *1X,7X,7X,3G12.4)
C
C     Trailing-edge flaps.  Data for aerofoil
C     ===============================================================
C
C     Trailing-edge flaps
C     -------------------
C
      IF (NDT .GT. 0 ) THEN
C
       WRITE(OUTFIL,1431)
C
       DO 191 J = 1,NNT
       NELMTS = 1
       IF (NTJ(J) .EQ. 4) NELMTS = 2
       IF (NTJ(J) .EQ. 5) NELMTS = 3
C
       WRITE(OUTFIL,1436)
       DO 171 K = 1,NDT
       DO 161 I = 1,NELMTS
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (I .EQ. 1 .AND. K .EQ. 1) THEN
        WRITE(OUTFIL,1441) J,K,I,DTJ(I,J,K),DCTJ(I,J,K)
       ELSE
         WRITE(OUTFIL,1451)   K,I,DTJ(I,J,K),DCTJ(I,J,K)
       END IF
  161  CONTINUE
C
      WRITE (OUTFIL,77)
   77 FORMAT (1X)
  171  CONTINUE
C
 1431 FORMAT(/,
     *1X,'Geometry of trailing-edge devices at their mid-span',/,
     *1X,'---------------------------------------------------',//,
     +1X,'                                (See Table 4.1)    ')
 1436 FORMAT(/,
     *1X,' Device ',' Setting',' Element',' Deflection ',
     *   '    Chord    ',/,
     *1X,' Number ',' Number ',' Number ',' Angle      ',
     *   ' Extension  ',/,
     *1X,'   j    ','   n    ','   i    ',' (delta ti)j',
     *   ' (Delta cti/c)j')
 1441 FORMAT(1X,3(I4,4X),2G12.4)
 1451 FORMAT(1X,8X,2(I4,4X),2G12.4)
C
       WRITE(OUTFIL,1471)
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       DO 181 I = 1,NELMTS
       IF (I .EQ. 1) THEN
        WRITE(OUTFIL,1481) J,I,CTJ(I,J)
       ELSE
        WRITE(OUTFIL,1491)   I,CTJ(I,J)
       END IF
  181  CONTINUE
C
 1471 FORMAT(/,
     *1X,' Device ',' Element','   Flap     ',/,
     *1X,' Number ',' Number ','   Chord    ',/,
     *1X,'   j    ','   i    ','  (cti/c)j  ')
 1481 FORMAT(1X,2(I4,4X),G12.4)
 1491 FORMAT(1X,8X,I4,4X,G12.4)
C
C      If (Nt)j = 1 (plain flap)
C      -------------------------
C
       IF (NTJ(J) .EQ. 1) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1231) RLTJ(J)
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1241) PHITJ(J)
       END IF
C
 1231 FORMAT(
     *1X,'rho l/t (leading edge radius / thickness):                  ',
     *    G12.4)
 1241 FORMAT(1X,
     *'phi t (angle from aerofoil datum to tangent to upper surface',/,
     *1X,'      at trailing edge in degrees in Sketch 1.7):           ',
     *    G12.4)
C
C      (NT)J = 2 (split)
C      ---------------
       IF (NTJ(J) .EQ. 2) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1251) XLMJ(J)
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1261) ZLMJ(J)
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1271) ZCMJ(J)
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1281) ZU125J(J)
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1291) ZL125J(J)
       END IF
C
 1251 FORMAT(
     *1X,'xlm/c (location of maximum lower surface ordinate):         ',
     *    G12.4)
 1261 FORMAT(
     *1X,'zlm/c (maximum lower surface ordinate):                     ',
     *    G12.4)
 1271 FORMAT(
     *1X,'zcm/c (maximum camber height):                              ',
     *    G12.4)
 1281 FORMAT(
     *1X,'(zu/c)1.25 (upper surface ordinate at x=0.0125c):           ',
     *    G12.4)
 1291 FORMAT(
     *1X,'(zl/c)1.25 (lower surface ordinate at x=0.0125c):           ',
     *     G12.4)
C
C      (NT)J = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      -----------------------------------------------------------
       IF (NTJ(J) .GE. 3 .AND. NTJ(J) .LE. 5) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1301) XTSJ(J)
       END IF
 1301 FORMAT(
     *1X,'xts/c (location of flap shroud trailing edge):              ',
     *    G12.4)

C      Hinge-line sweep for all types of trailing edge device
C      but for wing only (omit for aerofoil; i.e. CALC > 6)
C      ------------------------------------------------------
       IF (CLIST(12,CALC) .GT. 0) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1311) LDHJ(J)
       END IF
 1311 FORMAT(
     *1X,'Lambda h (hinge-line sweep):                                ',
     *    G12.4,//,4X,' ------')
  191  CONTINUE
      END IF
C
      END IF
C
      IF (CLIST(14,CALC) .GT. 0) THEN
C     Section geometry of high-lift system at mid-span of device panels
C     =================================================================
C     Leading-edge devices
C     --------------------
      IF (CALC .GT. 6 .AND. CSL .EQ. 1
     *    .AND. NDL .GT. 0 .AND. NNL .GT. 0) THEN
       WRITE(OUTFIL,1400)
 1400 FORMAT(/,
     *1X,'Geometry of leading-edge devices at their mid-span',/,
     *1X,'--------------------------------------------------',//,
     +1X,'                                 (See Table 4.1)   ',//,
     *1X,' Device ',' Setting',' Deflection ','   Chords    ',
     *   '    Chord   ',/,
     *1X,' Number ',' Number ',' Angle      ','            ',
     *   '   Extension  ',/,
     *1X,'   j    ','   n    ',' (delta l)j ','(cxl or cl/c)j',
     *   ' (Delta cl/c)j')
C
 1410 FORMAT(1X,2(I4,4X),3G12.4)
 1420 FORMAT(1X,8X,I4,4X,3G12.4)
C
       DO 150 I = 1,NNL
       DO 140 J = 1,NDL
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (J .EQ. 1) THEN
        WRITE(OUTFIL,1410) I,J,DLJ(I,J),CXLJ(I,J),DCLJ(I,J)
       ELSE
        WRITE(OUTFIL,1420)   J,DLJ(I,J),CXLJ(I,J),DCLJ(I,J)
       END IF
  140  CONTINUE
  150  CONTINUE
      END IF
C
C     Trailing-edge flaps
C     -------------------
      IF (CALC .GT. 6 .AND. CST .EQ. 1
     *    .AND. NDT .GT. 0 .AND. NNT .GT. 0) THEN
       WRITE(OUTFIL,1430)
C
       DO 190 J = 1,NNT
       NELMTS = 1
       IF (NTJ(J) .EQ. 4) NELMTS = 2
       IF (NTJ(J) .EQ. 5) NELMTS = 3
C
       WRITE(OUTFIL,1435)
       DO 170 K = 1,NDT
       DO 160 I = 1,NELMTS
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       IF (I .EQ. 1 .AND. K .EQ. 1) THEN
        WRITE(OUTFIL,1440) J,K,I,DTJ(I,J,K),DCTJ(I,J,K)
       ELSE
         WRITE(OUTFIL,1450)   K,I,DTJ(I,J,K),DCTJ(I,J,K)
       END IF
  160  CONTINUE
  170  CONTINUE
C
 1430 FORMAT(/,
     *1X,'Geometry of trailing-edge devices at their mid-span',/,
     *1X,'---------------------------------------------------',//,
     +1X,'                                (See Table 4.1)    ')
 1435 FORMAT(/,
     *1X,' Device ',' Setting',' Element',' Deflection ',
     *   '   Chord   ',/,
     *1X,' Number ',' Number ',' Number ',' Angle      ',
     *   '   Extension  ',/,
     *1X,'   j    ','   n    ','   i    ',' (delta ti)j',
     *   ' (Delta cti/c)j')
 1440 FORMAT(1X,3(I4,4X),2G12.4)
 1450 FORMAT(1X,8X,2(I4,4X),2G12.4)
C
       WRITE(OUTFIL,1470)
       NLNS = NLNS + 1
       IF (NLNS .GT. NLINES) GO TO 220
       DO 180 I = 1,NELMTS
       IF (I .EQ. 1) THEN
        WRITE(OUTFIL,1480) J,I,CTJ(I,J)
       ELSE
        WRITE(OUTFIL,1490)   I,CTJ(I,J)
       END IF
  180  CONTINUE
C
 1470 FORMAT(/,
     *1X,' Device ',' Element','   Flap     ',/,
     *1X,' Number ',' Number ','   Chord    ',/,
     *1X,'   j    ','   i    ','  (cti/c)j  ')
 1480 FORMAT(1X,2(I4,4X),G12.4)
 1490 FORMAT(1X,8X,I4,4X,G12.4)
C
C      If (Nt)j = 1 (plain flap)
C      -------------------------
       IF (NTJ(J) .EQ. 1) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1500) PHITJ(J)
       END IF
C
 1500 FORMAT(/,1X,
     *'(phi t)j (angle from aerofoil datum to tangent to upper surface',
     */,
     *1X,'          at trailing edge in degrees in Sketch 1.7):       ',
     *    G12.4,//,4X,' ------')
C
C      If (Nt)j = 2 (split flap)
C      -------------------------
       IF (NTJ(J) .EQ. 2) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1510) XLMJ(J)
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1520) ZLMJ(J)
       END IF
C
 1510 FORMAT(
     *1X,'(xlm/c)j (location of maximum lower-surface ordinate):      ',
     *    G12.4)
 1520 FORMAT(
     *1X,'(zlm/c)j (maximum lower-surface ordinate):                  ',
     *    G12.4,//,4X,' ------')
C
C      If (Nt)j = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      ----------------------------------------------------------------
       IF (NTJ(J) .GE. 3) THEN
        NLNS = NLNS + 1
        IF (NLNS .GT. NLINES) GO TO 220
        WRITE(OUTFIL,1530) XTSJ(J)
       END IF
C
 1530 FORMAT(
     *1X,'(xts/c)j (location of flap shroud trailing edge):           ',
     *    G12.4,//,4X,' ------')
C
  190  CONTINUE
      END IF
C
      END IF
C
  220 WRITE(OUTFIL,1570)
 1570 FORMAT(/,1X,72(1H-))
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE AD9931(OUTFIL,NFLTS,FAULTS)
C     ======================================
C
C     Purpose
C     -------
C     To print faults
C
C     Input
C     -----
C     OUTFIL     - output unit number
C     NFLTS      - number of faults
C     FAULTS(60) - list of up to 60 fault numbers
C               Faults 1 to 11 are found on input
C               Faults 101 to 154 are found in the data check
C               Faults 1001 to 104? are found by Sections AA to l
C               Faults 2001 to 204? are found by Subroutines 1 to 15
C               Faults 3000 to 3040 are found while reading a plot
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,NFLTS,FAULTS(60)
C
      IF (FAULTS(1) .LT. 100) THEN
C      Input error
C      -----------
       CALL INPER1(OUTFIL,FAULTS(1))
      ELSE
       IF (FAULTS(1) .LT. 1000) THEN
C       Faults found by data check
C       --------------------------
        CALL DATER1(OUTFIL,NFLTS,FAULTS)
       ELSE
        IF (FAULTS(1) .LT. 2000) THEN
C        Error found in Sections AA to l
C        ---------------------------------
         CALL PARERR(OUTFIL,FAULTS(1))
        ELSE
         IF (FAULTS(1) .LT. 3000) THEN
C         Error found in Subroutines 1 to 15
C         ----------------------------------
          CALL SUBERR(OUTFIL,FAULTS(1))
         ELSE
C         Error found while reading a plot
C         --------------------------------
          CALL PLERR2(OUTFIL,FAULTS(1))
         END IF
        END IF
       END IF
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE INPER1(OUTFIL,FAULT)
C     ===============================
C
C     Purpose
C     -------
C     To print a fault in the data
C
C     Input
C     -----
C     OUTFIL  - output unit number
C     FAULT   - error number (0 means none)
C
C     Local
C     -----
C     COMMON /ERTXT1/ TXT(11,2) - text supplied by block data INPER2
C
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,FAULT
C
      CHARACTER*60 TXT
      COMMON /ERTXT1/ TXT(11,2)
C
      IF (FAULT .NE. 0) THEN
       IF (FAULT .LE. 11) THEN
        WRITE(OUTFIL,10) TXT(FAULT,1),TXT(FAULT,2)
       ELSE
        WRITE(OUTFIL,20) FAULT
       END IF
      END IF
C
   10 FORMAT(/,
     *1X,'ERROR',/,
     *1X,'=====',/,
     *1X,A60,/,
     *1X,A60)
C
   20 FORMAT(/,
     *1X,'Program Error',/,
     *1X,'=============',/,
     *1X,'FAULT ',I3,' has not been catered for.')
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA INPER2
C     =================
C
C     Purpose
C     -------
C     To supply text for messages about errors found on input
C
C     -----------------------------------------------------------------
C
      CHARACTER*60 TXT
      COMMON /ERTXT1/ TXT(11,2)
C
      INTEGER I,J
C
      DATA ((TXT(I,J), J = 1,2), I = 1,11) /
     1'The data ended at this stage.',' ',
     2'Unrecognisable data was found at this stage',' ',
     3'CALC should be in the range 1 to 18.',' ',
     4'The number of pairs of Mach and Reynolds numbers',
     *'should range from 1 to 10 (inclusive)',
     5'TES should be 0 or 1',' ',
     6'TYPE should be P or M or C.',' ',
     7'INT should be 0 or 1',' ',
     8'The number of device settings should be in the range',
     *'0 to 10 (inclusive)',
     9'Leading edge device types range from 1 to 6 (inclusive) and',
     *'trailing edge device types range from 1 to 5 (inclusive)',
     *'Allowance has been made for 5 leading edge device panels',
     *'and 5 trailing edge device panels.',
     1'CSL should be 0 or 1',' '/
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE DATER1(OUTFIL,NFLTS,FAULTS)
C     ======================================
C
C     Purpose
C     -------
C     To print errors found by the data check
C
C     Input
C     -----
C     OUTFIL     - output unit number
C     NFLTS      - number of errors found
C     FAULTS(60) - list of up to 60 error numbers
C
C     Local
C     -----
C     COMMON /ERTXT2/ TXT(54,2) - the text of 54 error messages
C     I,N                       - array indices
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,NFLTS,FAULTS(60)
C
      CHARACTER*64 TXT
      COMMON /ERTXT2/ TXT(54,2)
C
      INTEGER I,N
C
      IF (NFLTS .GT. 0) THEN
       DO 30 I = 1,NFLTS
       N = FAULTS(I) - 100
       IF (N .GE. 1 .AND. N .LE. 54) THEN
        WRITE(OUTFIL,10) TXT(N,1),TXT(N,2)
   10   FORMAT(1X,'Error - ',A64,/,1X,8X,A64)
       ELSE
        WRITE(OUTFIL,20)
   20   FORMAT(1X,'Program error - Error number ',I5,'does not exist.')
       END IF
   30  CONTINUE
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA DATER2
C     =================
C
C     Text of error messages for data check
C     -------------------------------------
C
      CHARACTER*64 TXT
      COMMON /ERTXT2/ TXT(54,2)
C
      INTEGER I,J
C
C SOME MESSAGES ARE NOT USED
      DATA ((TXT(I,J), J = 1,2), I = 1,10) /
     *'Mach numbers should be in the range 0.0 <= Mk <= 0.25',' ',
     *'Reynolds numbers should be in the range 0.7E6 <= Rk <= 9E6',' ',
     *'Reynolds numbers should be in the range 0.7E6 <= Rk <= 12E6',' ',
     *'The aspect ratio should be in the range 2 <= A <= 10',' ',
     *'The taper ratio should be in the range  0 <= lambda <= 1',' ',
     *'Fractional chord line should be in the range 0 <= n <= 1',' ',
     +'The leading edge sweep must be >=0 and <= 50, the mid-chord',
     + 'sweep >=0 and <=45, and the trailing edge sweep >=-12 and <=50',
     *'The location of the most highly loaded section',
     *'should be in the range 0.0 <= (eta p) <= 1.0',
     *'The thickness to chord ratio should be in the range',
     *'0.06 <= (t/c) <= 0.24',
     *'The location of the boundary layer transition point',
     *'should be in the range 0.0 <= (xtr/c) <= 0.5' /
C
      DATA ((TXT(I,J), J = 1,2), I = 11,20) /
     *'The location of the maximum upper surface height',
     *'should be in the range 0.0 <= (xum/c) <= 1.0',
     *'The maximum upper surface height (zum/c) should be >= 0.0',' ',
     *'Trailing edge angle should be in the range 0 <= tau <= 25',' ',
     *'Upper and lower surface ordinates (zu/c)i and (zl/c)i',
     *'should be at 17 standard positions (x/c)i',
     *'Lower surface ordinates (zl/c)i should not exceed',
     *'upper surface ordinates (zu/c)i',
     *'The sealed slat or Kruger flap trailing edge height above chord',
     *'line should be in the range -0.25 <= Hl <= 0.50',
     *'The slat should have geometry in the ranges 0.01<= Gl <=0.06,',
     *'-0.03<= Hl <=0.1,-0.035<= Ll <=0.14, 0<=xl<=0.35,0.01<=xn<=0.06',
     *'The ratio (zc92/zc50)r should be in the range               ',
     *'0.1 <=  (zc92/zc50)r  <= 10   ',
     *'Upper and lower surface ordinates (zu/c)ri and (zl/c)ri',
     *'should be at 15 standard positions (x/c)ri',
     *'Lower surface ordinates (zl/c)ri should not exceed',
     *'upper surface ordinates (zu/c)ri' /
C
      DATA ((TXT(I,J), J = 1,2), I = 21,30) /
     *'The vented Kruger should have geometry in the ranges',
     *'0.01 <=Gl < =0.06,-0.03 <= Hl < =0.1,-0.035= Ll <= .14',
     *'The maximum depth of the bottom surface zlm/c',
     *'should not be positive',
     *'The ratio (zc92/zc50)2/3 should be in the range               ',
     *'0.1 <= (zc92/zc50)2/3  <= 10   ',
     *'Upper and lower surface ordinates (zu/c)2/3i and (zl/c)2/3i',
     *'should be at 15 standard positions (x/c)22/3i',
     *'Lower surface ordinates (zl/c)2/3i should not exceed',
     *'upper surface ordinates (zu/c)2/3i',
     *'The trailing-edge angle should be in the range',
     *'0 <= (tau a) <= 25 degrees',
     *'The trailing-edge angle should be in the range',
     *'0 <= (tau au) <= 25 degrees',
     *'(zu/c)5 should exceed (zl/c)5',' ',
     *'The ratio of body width to semi-span (W/s)',
     *'should not be less than zero.',
     *'There may be only a single leading edge panel, with inner limit',
     *'in the range 0 <= (eta il)1 < 1.0 and (eta ol)1 = 1.0 (tip)   ' /
C
      DATA ((TXT(I,J), J = 1,2), I = 31,40) /
     *'The inner limit of the trailing-edge panel that contains',
     *'(eta p) should be in the range 0 <= (eta it)p <= 1.0',
     *'The outer limit of the trailing-eading-edge panel that contains',
     *'(eta p) should be in the range (eta it)p <= (eta ot)p <= 1.0',
     *'Leading-edge device leading-edge radius should be in the range',
     +' 0 <= rho l/c <= 0.02 ',
     *'The extended chord of a leading-edge device (c~l/c)',
     *'should not be less than zero or greater than 0.35',
     *'The chord extension given by a leading-edge device (Delta cl/c)',
     *'should not be less than zero',
     *'The chord extension given by each element of the trailing-edge',
     *'device (Delta cl/c) should not be less than zero',
     *'Each flap chord element (cti/c) should be >=0',' ',
     *'The plain flap leading-edge radius should be in the range',
     *'0.04 <= (rho l/t) <= 0.14',
     *'The location of the maximum lower surface ordinate should be',
     *'in the range 0.0 <= (xlm/c) <= 1.0',
     *'The upper surface (zu/c)1.25 must not be below',
     *'the lower surface (zl/c)1.25' /
C
      DATA ((TXT(I,J), J = 1,2), I = 41,49) /
     *'The coordinate of the flap shroud trailing edge (xts/c)',
     *'should exceed zero',
     *'The hinge-line sweep-back should be in the range',
     *'-8 <= (Lambda h)j <= 50 degrees',
     *'The inner and outer limits of each leading-edge device',
     *'should be 0.0 <= (eta il)j <= (eta ol)j <= 1.0',
     *'The inner and outer limits of each trailing-edge device',
     *'should be 0.0 <= (eta it)j <= (eta ot)j <= 1.0',
     *'The extended chord of a leading-edge device (c~l/c)',
     *'should not be less than zero or greater than 0.35',
     *'The chord extension given by each leading-edge device',
     *'(Delta cl/c)j should nt be less than zero',
     *'The chord extension given by each element of each trailing-edge',
     *'device (Delta cti)j should not be less than zero',
     *'The flap chord of each element of each trailing-edge device',
     *'(cti/c)j should not be less than zero',
     *'The location of the maximum lower surface ordinate should be',
     *'in the range 0.0 <= (xlm/c)j <= 1.0' /
C
      DATA ((TXT(I,J), J = 1,2), I = 50,54) /
     *'The maximum depth of the bottom surface (zlm/c)j ',
     *'should not be positive',
     *'The coordinate of the flap shroud trailing edge (xts/c)j',
     *'should not be less than zero',
     *'The plain flap leading-edge radius should be in the range ',
     *'0.04 <= (rho l/t) <= 0.14',
     *'The upper surface ((zu/c)125)j must not be below ',
     *'the lower surface ((zl/c)125)j ',
     *'Leading-edge device leading-edge radius should be in the range',
     *'0 <= (rho l/c)j <= 0.020 ' /
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE AG9931(K)
C     ====================
C
C     Purpose
C     -------
C     To copy any user supplied data to CL0B etc
C
C     Input
C     -----
C     K      - current Mach number, Reynolds number pair
C
C     -----------------------------------------------------------------
C
      INTEGER K
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
C
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
      CL0B = XCL0B(K)
      CLMB = XCLMB(K)
      CL0BW = XCL0BW(K)
      CLMXB = XCLMBW(K)
      CL0BF = XCL0BF(K)
      CLMXBF = XCLMBF(K)
      DCLMXF = XDCLMF(K)
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE DATCHK(NFLTS,FAULTS)
C     ===============================
C
C     Purpose
C     -------
C     To check the data
C
C     Output
C     ------
C     NFLTS      - number of faults
C     FAULT(50)  - fault numbers
C
C     Method
C     ------
C     This subroutine follows the pattern of Subroutine AB9931
C     which reads the data.
C
C     -----------------------------------------------------------------
C
      INTEGER NFLTS,FAULTS(50)
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
      REAL           RLTJ,RLJ
      REAL           GLJ,HLJ,LLJ,XLJ,XNJ
      REAL           LDHJ,ZU125J,ZL125J,ZCMJ
      REAL           Z
C
      COMMON  /ZK9931/ LDHJ(5),ZU125J(5),ZL125J(5),ZCMJ(5), RLTJ(5),
     *                 RLJ(5,10),  GLJ(5,10),HLJ(5,10),LLJ(5,10),
     +                 XLJ(5,10),XNJ(5,10)
      INTEGER I,J,K,NELMTS
C
      INTEGER CLIST(14,18)
C
      REAL CHKLDX(4),TNN,TN,SN,X(4)
      DATA X / 0.0 , 1.0 , 2.0 , 4.0 /
C
C
C     Multiple tests of CALC (one row per test)
C     -----------------------------------------
      DATA ((CLIST(I,J), J = 1,18), I = 1,14) /
     1  0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     2  0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     3  1, 2, 0, 4, 5, 6, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     4  1, 0, 3, 0, 0, 0, 7, 0, 0, 0, 0, 0,13, 0, 0, 0, 0, 0,
     5  0, 2, 0, 0, 5, 0, 0, 8, 0, 0,11, 0, 0,14, 0, 0,17, 0,
     6  1, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     7  0, 0, 0, 0, 0, 0, 7, 0, 9, 0, 0, 0,13, 0,15, 0, 0, 0,
     8  0, 0, 0, 4, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     9  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13,14,15,16,17,18,
     *  1, 2, 3, 4, 5, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     1  0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     2  0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     3  0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     4  0, 0, 0, 0, 0, 0, 0, 0, 9,10, 0,12, 0, 0,15,16, 0,18/
C
C SET ZEROES
      DO 11 I = 1,4
      CHKLDX(I) = 0.0
   11 CONTINUE
      NFLTS = 0
      DO 10 I = 1,50
      FAULTS(I) = 0
   10 CONTINUE
C
C     Check NMR Mach number, Reynolds number pairs
C     --------------------------------------------
      DO 20 I = 1,NMR
      IF (MN(I) .LT. 0.0 .OR. MN(I) .GT. 0.25) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 101
       GO TO 25
      END IF
   20 CONTINUE
C
   25 DO 30 I = 1,NMR
      IF (CALC .LE. 6) THEN
       IF (RN(I) .LT. 0.7E6 .OR. RN(I) .GT. 9.0E6) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 102
        GO TO 35
       END IF
      ELSE
          IF ((CALC .EQ. 7) .OR. (CALC .EQ. 8) .OR. (CALC .EQ. 13)
     +        .OR. (CALC .EQ. 14))   THEN
       IF (RN(I) .LT. 0.7E6 .OR. RN(I) .GT. 12.0E6) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 103
        GO TO 35
       END IF
          END IF
      END IF
   30 CONTINUE
C
C     If CALC = 7 to 18, check A,TR,N,LDN
C     -----------------------------------
   35 IF (CLIST(1,CALC) .GT. 0) THEN
C
       IF (A .LT. 2.0 .OR. A .GT. 10.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 104
       END IF
C
       IF (TR .LT. 0.1 .OR. TR .GT. 1.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 105
       END IF
C
       IF ( N .LT. 0.0 .OR. N .GT. 1.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 106
       END IF
C
C      Calculate TNN = tan[(Lambda n) * pi / 180)
       TNN = TAN(.017453293 * LDN)
C      Calculate Z = (1 / A) * (1 - lambda) / (1 + lambda)
       Z = (1.0 / A) * (1 - TR) / (1 + TR)
C
C      Calculate Lambda0, Lambda1/4, Lambda1/2 and Lambda1
C      ---------------------------------------------------
       DO 1001 I = 1,4
C      Calculate TN = tan(Lambda i)
       TN = TNN + (4.0 * N - X(I)) * Z
C      Calculate SN = sin(Lambda i)
       SN = TN / SQRT(1.0 + TN * TN)
C    CHKLDX(i) = (Lambda i) = (180 / pi) * arc sin(sin(Lambda i))
       CHKLDX(I) = 57.29577951 * ASIN(SN)
 1001  CONTINUE
C
C CHECKS ON
C      0 <=CHKLDX(1) <=50 , 0 <=CHKLDX(3) <= 45,
C      -12 <= CHKLDX(4) <= 50
        IF (CHKLDX(1) .LT. 0.0 .OR. CHKLDX(1) .GT. 50
     + .OR. CHKLDX(3) .LT. 0.0 .OR. CHKLDX(3) .GT. 45
     + .OR.  CHKLDX(4) .LT. -12.0 .OR. CHKLDX(4) .GT. 50 )  THEN
C
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 107
       END IF
C
      END IF
C
C     If CALC = 7,8,11,13,14,17 check EP
C     ----------------------------------
      IF (CLIST(2,CALC) .GT. 0) THEN
       IF (EP .LT. 0.0 .OR. EP .GT. 1.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 108
       END IF
      END IF
C
C     If CALC = 1,3,7 or 13 OR (if TES=1 and CALC = 2,5,8,11,14 or 17)
C     read TYPE, T, XTR, XUM, ZUM
C     ----------------------------------------------------------------
      IF (CLIST(4,CALC) .GT. 0 .OR.
     *    (TES .EQ. 1 .AND. CLIST(5,CALC) .GT. 0)) THEN
C
       IF (T .LT. 0.06 .OR. T .GT. 0.24) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 109
       END IF
C
       IF (XTR .LT. 0.0 .OR. XTR .GT. 0.5) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 110
       END IF
C
       IF (XUM .LT. 0.0 .OR. XUM .GT. 1.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 111
       END IF
C
       IF (ZUM .LT. 0.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 112
       END IF
C
       IF (TAU .LT. 0.0 .OR. TAU .GT. 25.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 113
       END IF
C
C      Check (x/c)g, (zu/c)g and (zl/c)g
C      (Possible fault numers are 114 and 115)
       CALL CHKXG(XG,ZUG,ZLG,NFLTS,FAULTS)
C
      END IF
C
C     Data for root (centre-line) section FOR calc = 7, 9, 13, 15
C     -----------------------------------------------------------
      IF (CLIST(7,CALC) .GT. 0) THEN
C
        IF ( Z92R .GT. 10.0 .OR. Z92R .LT. 0.1) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 118
        END IF
C      Check (x/c)rg, (zu/c)rg and (zl/c)rg
C      (Possible fault numers are 119 and 120)
       CALL CHKXRG(XRG,ZURG,ZLRG,NFLTS,FAULTS)
C
C     Data for section at eta = 2/3
C     -----------------------------
C
        IF ( Z9223 .GT. 10.0 .OR. (Z9223) .LT. 0.1 ) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 123
        END IF
C
C      Check (x/c)2/3g, (zu/c)2/3g and (zl/c)2/3g
C      (Possible fault numers are 124 and 125)
       CALL CHK23G(X23G,ZU23G,ZL23G,NFLTS,FAULTS)
C
      END IF
C
C     Restricted set of section data for basic aerofoil
C     -------------------------------------------------
      IF (TES .EQ. 0 .AND. CALC .EQ. 2) THEN
C
       IF (T  .LT. 0.06 .OR. T .GT. 0.24) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 109
       END IF
C
       IF (XTR .LT. 0.0 .OR. XTR .GT. 0.5) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 110
       END IF
C
       IF (TAU .LT. 0.0 .OR. TAU .GT. 25.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 113
       END IF
C
       IF (TAUA .LT. 0.0 .OR. TAUA .GT. 25.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 126
       END IF
C
       IF (TAUAU .LT. 0.0 .OR. TAUAU .GT. 25.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 127
       END IF
C
       IF (XUM .LT. 0.0 .OR. XUM .GT. 1.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 111
       END IF
C
       IF (ZUM .LT. 0.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 112
       END IF
C
       IF (ZU5 .LE. ZL5) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 128
       END IF
C
      END IF
C
      IF (TES .EQ. 1 .AND. CLIST(8,CALC) .GT. 0) THEN
C
       IF (T  .LT. 0.06 .OR. T .GT. 0.24) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 109
       END IF
C
       IF (TAU .LT. 0.0 .OR. TAU .GT. 25.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 113
       END IF
C
       IF (TAUA .LT. 0.0 .OR. TAUA .GT. 25.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 126
       END IF
C
      END IF
C
C     Data needed when a fuselage is present (CALC = 13 to 18)
C     --------------------------------------------------------
      IF (CLIST(9,CALC) .GT. 0) THEN
C
       IF (W .LT. 0.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 129
       END IF
C
      END IF
C
C
      IF (CLIST(10,CALC) .GT. 0 ) THEN
C     Leading-edge devices.  Data for aerofoil
C     =================================================================
      IF (NDL .GT. 0 .AND. NL .GT. 0) THEN
C
C
             IF (CALC .EQ. 1 .OR. CALC .EQ. 3 .OR. CALC .EQ. 5) THEN
       DO 60 I = 1,NDL
       IF (RL(I) .LT. 0.0 .OR. RL(I) .GT. 0.02) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 133
        GO TO 65
       END IF
   60  CONTINUE
             END IF
C
   65  DO 70 I = 1,NDL
       IF (CXL(I) .LT. 0.0 .OR. CXL(I) .GT. 0.35) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 134
        GO TO 75
       END IF
   70  CONTINUE
C
   75  DO 80 I = 1,NDL
       IF (DCL(I) .LT. 0.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 135
        GO TO 64
       END IF
   80  CONTINUE
C
   64 CONTINUE
C
             IF (CALC .EQ. 1 .OR. CALC .EQ. 3 .OR. CALC .EQ. 5) THEN
      IF (NL .EQ. 3 .OR. NL .EQ. 4) THEN
       DO 61 I = 1,NDL
       IF (HL(I) .LT. -0.025 .OR. HL(I) .GT. 0.050) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 116
        GO TO 85
       END IF
   61 CONTINUE
       END IF
C
      IF (NL .EQ. 5 ) THEN
       DO 62 I = 1,NDL
       IF   (   GL(I) .LT.  0.01   .OR.  GL(I) .GT. 0.06
     +     .OR. HL(I) .LT. -0.03   .OR.  HL(I) .GT. 0.1
     +     .OR. LL(I) .LT. -0.035  .OR.  LL(I) .GT. 0.14
     +     .OR. XL(I) .LT.  0.0    .OR.  XL(I) .GT. 0.35
     +     .OR. XN(I) .LT.  0.01   .OR.  XN(I) .GT. 0.06  ) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 117
        GO TO 85
       END IF
   62  CONTINUE
       END IF
C   67  CONTINUE
C
      IF (NL .EQ. 6 ) THEN
       DO 63 I = 1,NDL
       IF   (   GL(I) .LT.  0.01   .OR.  GL(I) .GT. 0.06
     +     .OR. HL(I) .LT. -0.03   .OR.  HL(I) .GT. 0.1
     +     .OR. LL(I) .LT. -0.035  .OR.  LL(I) .GT. 0.14  ) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 121
        GO TO 85
       END IF
   63  CONTINUE
       END IF
             END IF
C
C
      END IF
C
C     Trailing-edge flaps.  Data for aerofoil
C     ===============================================================
   85 IF (NDT .GT. 0 .AND. NT .GT. 0) THEN
C
C      Deflection angles, chord extensions and flap chords
C      ---------------------------------------------------
C      Number of elements
       NELMTS = 1
       IF (NT .EQ. 4) NELMTS = 2
       IF (NT .EQ. 5) NELMTS = 3
C
       DO 100 J = 1,NDT
       DO 90 I = 1,NELMTS
C these loops once held a test, now deleted
   90  CONTINUE
  100  CONTINUE
C
       DO 106 I = 1,NELMTS
       IF (CT(I) .LT. 0.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 137
        GO TO 107
       END IF
  106  CONTINUE
C
C      NT = 1 (plain)
C      ---------------
  107  IF (NT .EQ. 1) THEN
        IF (RLT .LT. 0.04 .OR. RLT .GT. 0.14) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 138
        END IF
       END IF
C
C      NT = 2 (split)
C      ---------------
       IF (NT .EQ. 2) THEN
C
        IF (XLM .LT. 0.0 .OR. XLM .GT. 1.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 139
        END IF
C
        IF (ZLM .GT. 0.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 122
        END IF
C
        IF (ZU125 .LT. ZL125) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 140
        END IF
C
       END IF
C
C      NT = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      -----------------------------------------------------------
       IF (NT .GE. 3 .AND. NT .LE. 5) THEN
        IF (XTS .LE. 0.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 141
        END IF
       END IF
       END IF
C
C      Hinge-line sweep for all types of trailing edge device
C      but for wing only (omit for aerofoil; i.e. CALC > 6)
C      ------------------------------------------------------
C       IF (CLIST(12,CALC) .GT. 0) THEN
C        IF (LDH .LT. -8.0 .OR. LDH .GT. 50.0) THEN
C         NFLTS = NFLTS + 1
C         FAULTS(NFLTS) = 142
C        END IF
C       END IF
C
      END IF
C
C     High-lift system specification for wing at mid-span of panels
C     =============================================================
C TESTS ON PANELS
C
C      If CALC = 7,8,11,13,14 or 17
C      ----------------------------
C TEST FOR 1 ONLY LE PANEL EXTENDING TO TIP ONLY
      IF (CLIST(11,CALC) .GT. 0 .AND. NDL .GT. 0) THEN
C
        IF (NNL . NE. 1 .OR. EIL(1) .LT. 0.0 .OR. EOL(1) .GT. 1.0
     +    .OR. EOL(1) .LT. 0.999999 ) THEN
C        IF (EILP .LT. 0.0 .OR. EILP .GT. 1.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 130
         GO TO 125
        END IF
C      END IF
      END IF
C
C     If CALC = 9,10,12,15,16 or 18
C     -----------------
      IF (CLIST(14,CALC) .GT. 0 .AND. NDL .GT. 0) THEN
       DO 120 J = 1,NNL
       IF (EIL(J) .LT. 0.0 .OR. EOL(J) .LE. EIL(J)
     *     .OR. EOL(J) .GT. 1.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 143
        GO TO 125
       END IF
  120  CONTINUE
      END IF
C
  125 IF (CALC .GT. 6 .AND. NDT .GT. 0) THEN
       DO 130 J = 1,NNT
       IF (EIT(J) .LT. 0.0 .OR. EOT(J) .LT. EIT(J)
     *     .OR. EOT(J) .GT. 1.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 144
        GO TO 132
       END IF
  130  CONTINUE
      END IF
C
C     Section geometry of high-lift system at mid-span of device panels
C     =================================================================
C     Leading-edge devices
C     --------------------
C
  132 CONTINUE
C
      IF (CLIST(11,CALC) .GT. 0 .AND. NDL .GT. 0) THEN
       DO 901 I = 1,NNL
       DO 601 J = 1,NDL
       IF (RLJ(I,J) .LT. 0.0 .OR. RLJ(I,J) .GT. 0.02) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 154
        GO TO 651
       END IF
  601  CONTINUE
  901  CONTINUE
C
  651 DO 902 I = 1,NNL
       DO 701 J = 1,NDL
       IF (CXLJ(I,J) .LT. 0.0 .OR. CXLJ(I,J) .GT. 0.35) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 134
        GO TO 751
       END IF
  701  CONTINUE
  902 CONTINUE
C
  751 DO 903 I = 1,NNL
       DO 801 J = 1,NDL
       IF (DCLJ(I,J) .LT. 0.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 135
        GO TO 641
       END IF
  801  CONTINUE
  903 CONTINUE
C
  641 CONTINUE
C
      DO 904 I = 1,NNL
      IF (NLJ(I) .EQ. 3 .OR. NLJ(I) .EQ. 4) THEN
       DO 611 J = 1,NDL
       IF (HLJ(I,J) .LT. -0.025 .OR. HLJ(I,J) .GT. 0.050) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 116
        GO TO 851
       END IF
  611 CONTINUE
       END IF
C
C
      IF (NLJ(I) .EQ. 5 ) THEN
       DO 621 J = 1,NDL
       IF   (   GLJ(I,J) .LT.  0.01   .OR.  GLJ(I,J) .GT. 0.06
     +     .OR. HLJ(I,J) .LT. -0.03   .OR.  HLJ(I,J) .GT. 0.1
     +     .OR. LLJ(I,J) .LT. -0.035  .OR.  LLJ(I,J) .GT. 0.14
     +     .OR. XLJ(I,J) .LT.  0.0    .OR.  XLJ(I,J) .GT. 0.35
     +     .OR. XNJ(I,J) .LT.  0.01   .OR.  XNJ(I,J) .GT. 0.06  ) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 117
        GO TO 851
       END IF
  621  CONTINUE
       END IF
C   67  CONTINUE
C
      IF (NLJ(I) .EQ. 6 ) THEN
       DO 631 J = 1,NDL
       IF   (   GLJ(I,J) .LT.  0.01   .OR.  GLJ(I,J) .GT. 0.06
     +     .OR. HLJ(I,J) .LT. -0.03   .OR.  HLJ(I,J) .GT. 0.1
     +     .OR. LLJ(I,J) .LT. -0.035  .OR.  LLJ(I,J) .GT. 0.14  ) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 121
        GO TO 851
       END IF
  631  CONTINUE
       END IF
  904 CONTINUE
      END IF
C
      IF (CLIST(14,CALC) .GT. 0 .AND. NDL .GT. 0) THEN
C
       DO 136 I = 1,NNL
       DO 134 J = 1,NDL
       IF (CXLJ(I,J) .LT. 0.0 .OR. CXLJ(I,J) .GT. 0.35) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 145
        GO TO 138
       END IF
  134  CONTINUE
  136  CONTINUE
C
  138  DO 150 I = 1,NNL
       DO 140 J = 1,NDL
       IF (DCLJ(I,J) .LT. 0.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 146
        GO TO 155
       END IF
  140  CONTINUE
  150  CONTINUE
      END IF
C
C     Trailing-edge flaps
C     -------------------
C
  851 IF (CLIST(11,CALC) .GT. 0 .AND. NDT .GT. 0) THEN
       DO 290 J = 1,NNT
       NELMTS = 1
       IF (NTJ(J) .EQ. 4) NELMTS = 2
       IF (NTJ(J) .EQ. 5) NELMTS = 3
C
       DO 270 K = 1,NDT
       DO 260 I = 1,NELMTS
C these loops once held a test, now deleted
  260  CONTINUE
  270  CONTINUE
C
       DO 274 I = 1,NELMTS
        IF (CTJ(I,J) .LT. 0.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 148
        GO TO 276
       END IF
  274  CONTINUE
C
C
C      If (Nt)j = 1 (plain flap)
C      -------------------------
  276  IF (NTJ(J) .EQ. 1) THEN
        IF (RLTJ(J) .LT. 0.04 .OR. RLTJ(J) .GT. 0.14) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 152
        END IF
       END IF

C      If (Nt)j = 2 (split flap)
C      -------------------------
       IF (NTJ(J) .EQ. 2) THEN
        IF (XLMJ(J) .LT. 0.0 .OR. XLMJ(J) .GT. 1.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 149
        END IF
        IF (ZLMJ(J) .GT. 0.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 150
        END IF
        IF (ZU125J(J) .LT. ZL125J(J)) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 153
        END IF
       END IF
C
C      If (Nt)j = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      ----------------------------------------------------------------
       IF (NTJ(J) .GE. 3) THEN
        IF (XTSJ(J) .LT. 0.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 151
        END IF
C      Hinge-line sweep for all types of trailing edge device
C      but for wing only (omit for aerofoil; i.e. CALC > 6)
C      ------------------------------------------------------
C       IF (CLIST(12,CALC) .GT. 0) THEN
        IF (LDHJ(J) .LT. -8.0 .OR. LDHJ(J) .GT. 50.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 142
        END IF
C       END IF
       END IF
C
  290  CONTINUE
      END IF
C
 155  IF (CLIST(14,CALC) .GT. 0 .AND. NDT .GT. 0) THEN
       DO 190 J = 1,NNT
       NELMTS = 1
       IF (NTJ(J) .EQ. 4) NELMTS = 2
       IF (NTJ(J) .EQ. 5) NELMTS = 3
C
       DO 170 K = 1,NDT
       DO 160 I = 1,NELMTS
C these loops once held a test, now deleted
  160  CONTINUE
  170  CONTINUE
C
       DO 174 I = 1,NELMTS
        IF (CTJ(I,J) .LT. 0.0) THEN
        NFLTS = NFLTS + 1
        FAULTS(NFLTS) = 148
        GO TO 176
       END IF
  174  CONTINUE
C
C      If (Nt)j = 2 (split flap)
C      -------------------------
  176  IF (NTJ(J) .EQ. 2) THEN
        IF (XLMJ(J) .LT. 0.0 .OR. XLMJ(J) .GT. 1.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 149
        END IF
        IF (ZLMJ(J) .GT. 0.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 150
        END IF
       END IF
C
C      If (Nt)j = 3 (slotted), 4 (double-slotted) or 5 (triple-slotted)
C      ----------------------------------------------------------------
       IF (NTJ(J) .GE. 3) THEN
        IF (XTSJ(J) .LT. 0.0) THEN
         NFLTS = NFLTS + 1
         FAULTS(NFLTS) = 151
        END IF
C
       END IF
C
C
  190  CONTINUE
      END IF
C
C
      CONTINUE
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE CHKXG(XG,ZUG,ZLG,NFLTS,FAULTS)
C     =========================================
C
C     Purpose
C     -------
C     To check the dimensionless upper-surface and lower-surface
C     coordinates (x/c)g, (zu/c)g, (zl/c)g at the 17 standard
C     chordwise locations
C
C     Input
C     -----
C     XG(17)    - dimensionless chord-wise locations (x/c)g supplied
C                 by the user
C     ZUG(17),  - upper and lower surface ordinates (zu/c)g and (zl/c)g
C     ZLg(17)
C
C     Output
C     ------
C     NFLTS      - total number of faults found so far
C     FAULTS(50) - list of fault numbers of faults found
C
C     Local
C     -----
C     XX(17)     - standard dimensionless chord-wise locations
c     TOL        - tolerance
C     I          - array index
C
C     -----------------------------------------------------------------
C
      INTEGER NFLTS,FAULTS(50)
      REAL XG(17),ZUG(17),ZLG(17)
C
      INTEGER I
      REAL XX(17),TOL
C
      DATA XX /
     * 0.0, 0.01, 0.0125, 0.025, 0.05,
     * 0.1,  0.2,    0.3,   0.4,  0.5,
     * 0.6,  0.7,    0.8,   0.9, 0.95,
     * 0.99, 1.0 /
C
      TOL = 1.0E-8
C
      DO 10 I = 1,17
      IF (ABS(XG(I) - XX(I)) .GT. TOL) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 114
       GO TO 20
      END IF
   10 CONTINUE
C
   20 DO 30 I = 1,17
      IF (ZUG(I) .LT. ZLG(I)) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 115
       GO TO 40
      END IF
   30 CONTINUE
C
   40 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE CHKXRG(XRG,ZURG,ZLRG,NFLTS,FAULTS)
C     =============================================
C
C     Purpose
C     -------
C     To check the dimensionless upper-surface and lower-surface
C     coordinates (x/c)rg, (zu/c)rg, (zl/c)rg at the 15 standard
C     chordwise locations
C
C     Input
C     -----
C     XRG(15)    - dimensionless chord-wise locations (x/c)rg supplied
C                 by the user
C     ZURG(15),  - upper and lower surface ordinates (zu/c)rg
C     ZLRG(15)     and (zl/c)rg
C
C     Output
C     ------
C     NFLTS      - total number of faults found so far
C     FAULTS(50) - list of fault numbers of faults found
C
C     Local
C     -----
C     XX(15)     - standard dimensionless chord-wise locations
c     TOL        - tolerance
C     I          - array index
C
C     -----------------------------------------------------------------
C
      INTEGER NFLTS,FAULTS(50)
      REAL XRG(15),ZURG(15),ZLRG(15)
C
      INTEGER I
      REAL XX(15),TOL
C
      DATA XX /
     * 0.0, 0.025, 0.05,   0.1,  0.2,
     * 0.3,   0.4,  0.5,   0.6,  0.7,
     * 0.8,   0.9, 0.95,  0.99,  1.0 /
C
      TOL = 1.0E-8
C
      DO 10 I = 1,15
      IF (ABS(XRG(I) - XX(I)) .GT. TOL) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 119
       GO TO 20
      END IF
   10 CONTINUE
C
   20 DO 30 I = 1,15
      IF (ZURG(I) .LT. ZLRG(I)) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 120
       GO TO 40
      END IF
   30 CONTINUE
C
   40 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE CHK23G(X23G,ZU23G,ZL23G,NFLTS,FAULTS)
C     ================================================
C
C     Purpose
C     -------
C     To check the dimensionless upper-surface and lower-surface
C     coordinates (x/c)23g, (zu/c)23g, (zl/c)23g at the 15 standard
C     chordwise locations
C
C     Input
C     -----
C     X23G(15)    - dimensionless chord-wise locations (x/c)23g supplied
C                 by the user
C     ZU23G(15),  - upper and lower surface ordinates (zu/c)23g
C     ZL23G(15)     and (zl/c)23g
C
C     Output
C     ------
C     NFLTS      - total number of faults found so far
C     FAULTS(50) - list of fault numbers of faults found
C
C     Local
C     -----
C     XX(15)     - standard dimensionless chord-wise locations
c     TOL        - tolerance
C     I          - array index
C
C     -----------------------------------------------------------------
C
      INTEGER NFLTS,FAULTS(50)
      REAL X23G(15),ZU23G(15),ZL23G(15)
C
      INTEGER I
      REAL XX(15),TOL
C
      DATA XX /
     * 0.0, 0.025, 0.05,   0.1,  0.2,
     * 0.3,   0.4,  0.5,   0.6,  0.7,
     * 0.8,   0.9, 0.95,  0.99,  1.0 /
C
      TOL = 1.0E-8
C
      DO 10 I = 1,15
      IF (ABS(X23G(I) - XX(I)) .GT. TOL) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 124
       GO TO 20
      END IF
   10 CONTINUE
C
   20 DO 30 I = 1,15
      IF (ZU23G(I) .LT. ZL23G(I)) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 125
       GO TO 40
      END IF
   30 CONTINUE
C
   40 RETURN
      END

