C *********************************************************************
C ESDU International plc
C
      PROGRAM B9931
C
C     ESDUpac Number:   B9931
C     ESDUpac Title:    COMPUTER PROGRAM FOR ESTIMATION OF
C                       SPANWISE POSITION OF PEAK LOADING
C
C     Data Item Number: 99031
C     Data Item Title:  COMPUTER PROGRAM FOR ESTIMATION OF LIFT CURVE
C                       TO MAXIMUM LIFT FOR WING-FUSELAGE COMBINATIONS
C                       WITH HIGH-LIFT DEVICES AT LOW SPEEDS
C
C     ESDUpac Status
C     --------------
C     Version:    2.0   Issued September 2000
C
C
c                       The changes are to source codes
C                       to satisfy compiler options
C
C                       FL /4Ys /4Yd /Fs
C
c                       The calculation routines are unchanged
C
C
C     Version:    1.0   Issued October 1999
C
C
C
C
C     Calculation of dimensionless spanwise locations
C     of most highly loaded sections (eta p)
C     ===============================================
C
C     Data
C     ====
C     TITLE(3)   - three lines of up to 72 characters
C     A          - aspect ratio (2.0 <= A <= 12.0)
C     TR         - taper ratio (0.0 <= lambda <= 1.0)
C     N          - fractional chord line (0.0 <= n <= 1.0)
C     LDN        - sweep of nth chord line (Lambda n) in degrees
C                  (0.0 <= Lambda 1/2 <= 45 degrees)
C     NMR        - number of Mach numbers (1 <= NMR <= 10)
C     MK(10)     - NMR Mach numbers (0.0 <= Mk <= 0.25)
C
C     Working Parameters and Results
C     ==============================
C     LD50       - half chord sweep-back angle (Lambda 1/2)
C     ATLD50     - A tan(Lambda 1/2)
C     KAPPA      - parameter kappa = (1+2*lambda)/(3*(1+lambda))
C     BA(10)     - NMR parameters Beta*A = sqrt(1-Mk**2)*A
C     EB(10)     - NMR spanwise centres of pressure (eta bar)
C     EP(10)     - MRR dimensionless spanwise locations of most highly
C                  loaded sections (eta p)
C
C     Working Integers
C     ----------------
C     INFIL      - input unit number
C     OUTFIL     - output unit number
C     NLNS       - number of lines to be printed
C     NFLTS      - number of faults found
C     FAULTS(10) - list of fault numbers
C
C     -----------------------------------------------------------------
C
      CHARACTER *75 TITLE
      COMMON/YA9931/TITLE(3)
C
      INTEGER INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS
      COMMON/YB9931/INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS(10)
C
      REAL A,TR,N,LDN,MK,LD50,ATLD50,KAPPA,BA,EB,EP
      COMMON/YC9931/A,TR,N,LDN,MK(10),LD50,ATLD50,KAPPA,
     *              BA(10),EB(10),EP(10)
C
      INFIL = 5
      OUTFIL = 6
C
C     Read the data
C     -------------
      CALL BB9931
C
C     Print the data with any error message
C     -------------------------------------
      CALL BC9931
      IF (NFLTS .NE. 0) GO TO 100
C
C     Check the data and print any error messages
C     -------------------------------------------
      CALL BD9931
      IF (NFLTS .NE. 0) THEN
       CALL BE9931
       GO TO 100
      END IF
C
C     Calculate centres of pressure eta p for the NMR Mach numbers
C     ------------------------------------------------------------
      CALL BF9931
C
C     Print the results and any error messages
C     ----------------------------------------
      CALL BG9931
C
  100 STOP'NORMAL END'
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE BB9931
C     =================
C
C     Purpose
C     -------
C     To read the data
C
C     Input
C     -----
C     INFIL      - input unit number
C
C     Output to common blocks
C     -----------------------
C     TITLE(3)   - three lines of up to 72 characters
C     A          - aspect ratio (2.0 <= A <= 12.0)
C     TR         - taper ratio (0.0 <= lambda <= 1.0)
C     N          - fractional chord line (0.0 <= n <= 1.0)
C     LDN        - sweep of nth chord line (Lambda n) in degrees
C                  (0.0 <= Lambda 1/2 <= 45 degrees)
C     NMR        - number of Mach numbers (1 <= NMR <= 10)
C     MK(10)     - NMR Mach numbers (0.0 <= Mk <= 0.25)
C     NLNS       - number of lines to be printed
C     NFLTS      - number of faults found
C     FAULTS(10) - list of fault numbers
C
C     -----------------------------------------------------------------
C
      CHARACTER *75 TITLE
      COMMON/YA9931/TITLE(3)
C
      INTEGER INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS
      COMMON/YB9931/INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS(10)
C
      REAL A,TR,N,LDN,MK,LD50,ATLD50,KAPPA,BA,EB,EP
      COMMON/YC9931/A,TR,N,LDN,MK(10),LD50,ATLD50,KAPPA,
     *              BA(10),EB(10),EP(10)
C
      INTEGER I
C
C     Set data and results to zero
C     ----------------------------
      NMR = 0
      NLNS = 0
      NFLTS = 0
      A = 0.0
      TR = 0.0
      N = 0.0
      LDN = 0.0
      LD50 = 0.0
      ATLD50 = 0.0
      KAPPA = 0.0
C
      DO 10 I = 1,10
      FAULTS(I) = 0
      MK(I) = 0.0
      BA(I) = 0.0
      EB(I) = 0.0
      EP(I) = 0.0
   10 CONTINUE
C
C     Read the three title lines
C     --------------------------
      DO 40 I = 1,3
      READ(INFIL,30,END=200) TITLE(I)
   30 FORMAT(A)
      NLNS = NLNS + 1
   40 CONTINUE
C
C     Read A, lambda, n, Lambda n and NMR
C     -----------------------------------
      READ(INFIL,*,END=200,ERR=210) A
      NLNS = NLNS + 1
      READ(INFIL,*,END=200,ERR=210) TR
      NLNS = NLNS + 1
      READ(INFIL,*,END=200,ERR=210) N
      NLNS = NLNS + 1
      READ(INFIL,*,END=200,ERR=210) LDN
      NLNS = NLNS + 1
      READ(INFIL,*,END=200,ERR=210) NMR
      NLNS = NLNS + 1
C     Check that NMR is in range
      IF (NMR .LT. 0 .OR. NMR .GT. 10) GO TO 220
C
C     Read the list of Mach numbers
C     -----------------------------
      DO 50 I = 1,NMR
      READ(INFIL,*,END=200,ERR=210) MK(I)
      NLNS = NLNS + 1
   50 CONTINUE
      GO TO 230
C
C     Unexpected end of file
C     ----------------------
  200 NFLTS = 1
      FAULTS(1) = 1
      GO TO 230
C
C     Unexpected data
C     ---------------
  210 NFLTS = 1
      FAULTS(1) = 2
      GO TO 230
C
C     Error in NMR
C     ------------
  220 NFLTS = 1
      FAULTS(1) = 3
      GO TO 230
C
  230 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE BC9931
C     =================
C
C     Purpose
C     -------
C     To print the data (and an error if there is one)
C
C     Input from common blocks
C     ------------------------
C     OUTFIL     - output unit number
C     TITLE(3)   - three lines of up to 72 characters
C     A          - aspect ratio (2.0 <= A <= 12.0)
C     TR         - taper ratio (0.0 <= lambda <= 1.0)
C     N          - fractional chord line (0.0 <= n <= 1.0)
C     LDN        - sweep of nth chord line (Lambda n) in degrees
C                  (0.0 <= Lambda 1/2 <= 45 degrees)
C     NMR        - number of Mach numbers (1 <= NMR <= 10)
C     MK(10)     - NMR Mach numbers (0.0 <= Mk <= 0.25)
C     NLNS       - number of lines to be printed
C     NFLTS      - number of faults found
C     FAULTS(10) - list of fault numbers
C
C     Local
C     -----
C     I          - array index
C     NLINES     - number of lines printed
C
C     -----------------------------------------------------------------
C
      CHARACTER *75 TITLE
      COMMON/YA9931/TITLE(3)
C
      INTEGER INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS
      COMMON/YB9931/INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS(10)
C
      REAL A,TR,N,LDN,MK,LD50,ATLD50,KAPPA,BA,EB,EP
      COMMON/YC9931/A,TR,N,LDN,MK(10),LD50,ATLD50,KAPPA,
     *              BA(10),EB(10),EP(10)
C
      INTEGER I,NLINES
C
      NLINES = 0
C
C     Print header and the three title lines
      WRITE(OUTFIL,1001)
 1001 FORMAT(//,1X,77('-'),/,' ESDU International plc',//,' PROGRAM ',
     1'B9931',//,' ESDUpac Number:   B9931',/,' ESDUpac Title:',4X,
     2'Computer program for estimation of spanwise ',/,19X,'',
     3'position of peak loading.',/,
     +/,' Data Item Number: 99031',/,
     4' Data Item Title:  Computer program for estimation of lift curve'
     5,/,19X,'to maximum lift for wing-fuselage combinations with',/,
     +19X,'high-lift devices at low speeds.',/,
     6/,' ESDUpac Version:  2.0  Issued September 2000',
     7', Data Item 99031',/,' (See Data Item for full input/output ',
     8'specification and interpretation)',/,1X,77('-'),/)
C     ---------------------------
      WRITE(OUTFIL,505)
  505 FORMAT(
     * 1X,'INPUT DATA',/,
     * 1X,'==========')
C
C     Print the title lines
C     ---------------------
      WRITE(OUTFIL,10)
   10 FORMAT(/,
     *1X,
     *'Title',/,
     *1X,'=====')
C
      DO 40 I = 1,3
      NLINES = NLINES + 1
      IF (NLINES .GT. NLNS) GO TO 200
      WRITE(OUTFIL,30) TITLE(I)
   30 FORMAT(1X,A75)
   40 CONTINUE
C
c      WRITE(OUTFIL,50)
c   50 FORMAT(/,1X,72(1H-),//,
c     *1X,'Data',/,
c     *1X,'====')
C
C     Print A, lambda, n, Lambda n and NMR
C     ------------------------------------
      NLINES = NLINES + 1
      IF (NLINES .GT. NLNS) GO TO 200
      WRITE(OUTFIL,60) A
   60 FORMAT(/,
     *1X,'A (aspect ratio):                              ',G12.4)
C
      NLINES = NLINES + 1
      IF (NLINES .GT. NLNS) GO TO 200
      WRITE(OUTFIL,70) TR
   70 FORMAT(
     *1X,'lambda (taper ratio)                           ',G12.4)
C
      NLINES = NLINES + 1
      IF (NLINES .GT. NLNS) GO TO 200
      WRITE(OUTFIL,80) N
   80 FORMAT(
     *1X,'n (nth chord line)                             ',G12.4)
C
      NLINES = NLINES + 1
      IF (NLINES .GT. NLNS) GO TO 200
      WRITE(6,90) LDN
   90 FORMAT(
     *1X,'Lambda n (sweep of nth chord line in degrees): ', G12.4)
C
      NLINES = NLINES + 1
      IF (NLINES .GT. NLNS) GO TO 200
      WRITE(OUTFIL,100) NMR
  100 FORMAT(
     *1X,'NMR (number of Mach numbers):                  ',1X,I3)
C
C     Print the Mach numbers
C     ----------------------
      WRITE(OUTFIL,110)
  110 FORMAT(/,
     *1X,'Number',5X,'Mach Number',/,
     *1X,'  k   ',5X,'    Mk     ',/,
     *1X,'------',5X,'-----------')
C
      DO 130 I = 1,NMR
      NLINES = NLINES + 1
      IF (NLINES .GT. NLNS) GO TO 200
      WRITE(OUTFIL,120) I, MK(I)
  120 FORMAT(1X,I3,8X,G12.4)
  130 CONTINUE
C
C     If one gets to here, all the data were read
C     -------------------------------------------
      GO TO 300
C
C     Otherwise print an error message
C     --------------------------------
  200 WRITE(OUTFIL,205)
  205 FORMAT(/,
     *1X,'Error',/,
     *1X,'=====')
C
      GO TO (210,220,230), FAULTS(1)
C
  210 WRITE(OUTFIL,215)
  215 FORMAT(1X,'The data ended at this stage.')
      GO TO 300
C
  220 WRITE(OUTFIL,225)
  225 FORMAT(1X,'Unrecognisable data was found at this stage.')
      GO TO 300
C
  230 WRITE(OUTFIL,235)
  235 FORMAT(1X,
     *'The program needs at least 1, but no more than 10 Mach numbers')
      GO TO 300
C
  300 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE BD9931
C     =================
C
C     Purpose
C     -------
C     To check the data
C
C     Input from common blocks
C     ------------------------
C     A          - aspect ratio (2.0 <= A <= 12.0)
C     TR         - taper ratio (0.0 <= lambda <= 1.0)
C     N          - fractional chord line (0.0 <= n <= 1.0)
C     LDN        - sweep of nth chord line (Lambda n) in degrees
C                  (0.0 <= Lambda 1/2 <= 45 degrees)
C     NMR        - number of Mach numbers (1 <= NMR <= 10)
C     MK(10)     - NMR Mach numbers (0.0 <= Mk <= 0.25)
C
C     Output to common block
C     ----------------------
C     NFLTS      - number of faults found
C     FAULTS(10) - list of fault numbers
C
C     Local
C     -----
C     I          - array index
C     FOUND      - flag (0 = failure,  1 = success)
C
C     -----------------------------------------------------------------
C
      INTEGER INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS
      COMMON/YB9931/INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS(10)
C
      REAL A,TR,N,LDN,MK,LD50,ATLD50,KAPPA,BA,EB,EP
      COMMON/YC9931/A,TR,N,LDN,MK(10),LD50,ATLD50,KAPPA,
     *              BA(10),EB(10),EP(10)
C
      INTEGER I,FOUND
C
      NFLTS = 0
C
      IF (A .LT. 2.0 .OR. A .GT. 12.0) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 1
      END IF
C
      IF (TR .LT. 0.1 .OR. TR .GT. 1.0) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 2
      END IF
C
      IF (N .LT. 0.0 .OR. N .GT. 1.0) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 3
      END IF
C
      FOUND = 1
      DO 10 I = 1,NMR
      IF (MK(I) .LT. 0.0 .OR. MK(I) .GT. 0.25) FOUND = 0
   10 CONTINUE
      IF (FOUND .NE. 1) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 4
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE BE9931
C     =================
C
C     Purpose
C     -------
C     To print errors found by the data check
C
C     Input from common blocks
C     ------------------------
C     OUTFIL     - output unit number
C     NFLTS      - number of faults found
C     FAULTS(10) - list of fault numbers
C
C     Output to common block
C     ----------------------
C
C     Local
C     -----
C     I          - array index
C
C     -----------------------------------------------------------------
C
      INTEGER INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS
      COMMON/YB9931/INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS(10)
C
      INTEGER I
C
      WRITE(OUTFIL,5)
    5 FORMAT(/,
     *1X,'Errors',/,
     *1X,'======')
C
      DO 50 I = 1,NFLTS
C
      GO TO (10,20,30,40), FAULTS(I)
C
   10 WRITE(OUTFIL,15)
   15 FORMAT(/,
     *1X,'Aspect ratio A should be in the range (2.0 <= A <= 12.0)')
      GO TO 50
C
   20 WRITE(OUTFIL,25)
   25 FORMAT(/,
     *1X,'Taper ratio lambda should be in the range ',
     *'(0.1 <= lambda <= 1.0)')
      GO TO 50
C
   30 WRITE(OUTFIL,35)
   35 FORMAT(/,
     *1X,'The nth chord line n  should be in the range ',
     *'(0.0 <= n <= 1.0)')
      GO TO 50
C
   40 WRITE(OUTFIL,45)
   45 FORMAT(/,
     *1X,'Mach numbers Mk should be in the range (0.0 <= Mk <= 0.25)')
      GO TO 50
C
   50 CONTINUE
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE BF9931
C     =================
C
C     Purpose
C     -------
C     To calculate  eta p
C
C     Input from common blocks
C     ------------------------
C     A          - aspect ratio (2.0 <= A <= 12.0)
C     TR         - taper ratio (0.0 <= lambda <= 1.0)
C     N          - fractional chord line (0.0 <= n <= 1.0)
C     LDN        - sweep of nth chord line (Lambda n) in degrees
C                  (0.0 <= Lambda 1/2 <= 45 degrees)
C     NMR        - number of Mach numbers (1 <= NMR <= 10)
C     MK(10)     - NMR Mach numbers (0.0 <= Mk <= 0.25)
C
C     Output to common blocks
C     -----------------------
C     LD50       - half chord sweep-back angle (Lambda 1/2)
C     ATLD50     - A tan(Lambda 1/2)
C     KAPPA      - parameter kappa = (1+2*lambda)/(3*(1+lambda))
C     BA(10)     - NMR parameters Beta*A = sqrt(1-Mk**2)*A
C     EB(10)     - NMR spanwise centres of pressure (eta bar)
C     EP(10)     - MRR dimensionless spanwise locations of most highly
C                  loaded sections (eta p)
C     NLNS       - number of lines to be printed
C     NFLTS      - number of faults found
C     FAULTS(10) - list of fault numbers
C
C     Local
C     -----
C     SN,TN      - sine and tangent of an angle
C     I          - array index
C     FOUND      - flag (0=failure  1=success)
C
C     -----------------------------------------------------------------
C
      INTEGER INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS
      COMMON/YB9931/INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS(10)
C
      REAL A,TR,N,LDN,MK,LD50,ATLD50,KAPPA,BA,EB,EP
      COMMON/YC9931/A,TR,N,LDN,MK(10),LD50,ATLD50,KAPPA,
     *              BA(10),EB(10),EP(10)
C
      INTEGER I,FOUND
      REAL SN,TN
C
      NFLTS = 0
      NLNS = 0
C
C     Calculate and check A*tan(Lambda 1/2) and Lambda 1/2
C     ----------------------------------------------------
C     A tan(Lambda 1/2) = A * tan(Lambda n * pi / 180)
C                       + (4*n-1)*(1-lambda)/(1+lambda)
      ATLD50 = A * TAN(LDN * 3.141593 / 180.0)
     *       + (4.0 * N - 2.0) * (1.0 - TR) / (1.0 + TR)
C
      TN = ATLD50 / A
C     N.B. A is in the range (2.0 <= A <= 12.0)
      SN = TN / SQRT(1.0 + TN * TN)
      LD50 = (180.0 / 3.141593) * ASIN(SN)
C
      IF (LD50 .LT. 0.0 .OR. LD50 .GT. 45.0) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 1
      END IF
C
      IF (ATLD50 .LT. 0.0 .OR. ATLD50 .GT. 6.0) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 2
      END IF
C
C     Calculate and check kappa
C     -------------------------
C     kappa = (1 + 2 * lambda)/[3 * (1 + lambda)]
      KAPPA = (1.0 + 2.0 * TR) / (3.0 * (1.0 + TR))
C
      IF (KAPPA .LT. 0.3333 .OR. KAPPA .GT. 0.5) THEN
       NFLTS = NFLTS + 1
       FAULTS(NFLTS) = 3
      END IF
C
      NLNS = 3
C
C     Stop here if an error was found
      IF (NFLTS .NE. 0) GO TO 20
C     (Any mistake after this is a programming error.)
C
C     Calculate eta p for each Mach number
C     ====================================
      DO 10 I = 1,NMR
C
C     Calculate beta*A = sqrt(1 - Mk^2) * A
C     -------------------------------------
      BA(I) = SQRT(1.0 - MK(I) * MK(I)) * A
C
C     Read eta bar from Figures 1 to 5 of Item 83040
C     ----------------------------------------------
      CALL FIG01B(BA(I),KAPPA,ATLD50,EB(I),FOUND)
C
      IF (FOUND .NE. 1) THEN
       NFLTS = 1
       FAULTS(1) = 4
       GO TO 20
      END IF
C
      NLNS = NLNS + 1
C
C     Read eta p from Figure 1 of Item 89034
C     --------------------------------------
      CALL FIG41B(TR,EB(I),EP(I),FOUND)
C
      IF (FOUND .NE. 1) THEN
       NFLTS = 1
       FAULTS(1) = 5
       GO TO 20
      END IF
C
      NLNS = NLNS + 1
C
   10 CONTINUE
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE BG9931
C     =================
C
C     Purpose
C     -------
C     To print the results
C
C     Input from common blocks
C     ------------------------
C     OUTFIL     - output unit number
C     NMR        - number of Mach numbers (1 <= NMR <= 10)
C     MK(10)     - NMR Mach numbers (0.0 <= Mk <= 0.25)
C     LD50       - half chord sweep-back angle (Lambda 1/2)
C     ATLD50     - A tan(Lambda 1/2)
C     KAPPA      - parameter kappa = (1+2*lambda)/(3*(1+lambda))
C     BA(10)     - NMR parameters Beta*A = sqrt(1-Mk**2)*A
C     EB(10)     - NMR spanwise centres of pressure (eta bar)
C     EP(10)     - MRR dimensionless spanwise locations of most highly
C                  loaded sections (eta p)
C     NLNS       - number of lines to be printed
C     NFLTS      - number of faults found
C     FAULTS(10) - list of fault numbers
C
C     Local
C     -----
C     I          - array index
C     MN         - number of current Mach number
C     NLINES     - number of lines printed
C
C     -----------------------------------------------------------------
C
      INTEGER INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS
      COMMON/YB9931/INFIL,OUTFIL,NMR,NLNS,NFLTS,FAULTS(10)
C
      REAL A,TR,N,LDN,MK,LD50,ATLD50,KAPPA,BA,EB,EP
      COMMON/YC9931/A,TR,N,LDN,MK(10),LD50,ATLD50,KAPPA,
     *              BA(10),EB(10),EP(10)
C
      INTEGER I,NLINES,MN
C
C     Print Lambda 1/2, A*tan(Lambda 1/2) and kappa
C     ---------------------------------------------
      WRITE(OUTFIL,10)
   10 FORMAT(/,1X,72(1H-),//,
     *1X,'Results',/,
     *1X,'=======')
c     *1X,'Lambda 1/2 (sweep-back of 1/2 chord line in degrees) =',
c     *   F8.2,/,
c     *1X,'Parameter A tan(Lambda 1/2) =                         ',
c     *   G12.4,/,
c     *1X,'Parameter kappa =                                     ',
c     *   G12.4)
C
C     Were Lambda 1/2, A*tan(Lambda 1/2) and kappa valid?
C     ---------------------------------------------------
      IF (NFLTS .EQ. 0) GO TO 20
C     Fault numbers 4 and 5 would occur in the interpolations.
      IF (FAULTS(NFLTS) .LT. 4) GO TO 100
      GO TO 200
C
   20 WRITE(OUTFIL,30)
   30 FORMAT(/,
     *1X,1X,' k  ','  Mach Number  ',
     *      '      eta p    ',/,
     *1X,1X,'--- ','  -----------  ',
     *      '      -----    ')
C
C     Print the result for each Mach number
C     -------------------------------------
      NLINES = 3
      DO 50 I = 1,NMR
      MN = I
      NLINES = NLINES + 1
      IF (NLINES .GT. NLNS) GO TO 200
      WRITE(OUTFIL,40) I,MK(I),EP(I)
   40 FORMAT(1X,I3,2X,2G15.4)
   50 CONTINUE
C
C     If one gets to here, no faults were found.
      GO TO 300
C
C     Lambda 1/2, A*tan(Lambda 1/2) or kappa were wrong
C     -------------------------------------------------
  100 WRITE(OUTFIL,105)
  105 FORMAT(/,
     *1X,'Errors',/,
     *1X,'======')
C
      DO 140 I = 1,NFLTS
C
      GO TO (110,120,130), FAULTS(I)
C
  110 WRITE(OUTFIL,115)
  115 FORMAT(1X,'Lambda 1/2 should be in the range 0 to 45 degrees')
      GO TO 140
C
  120 WRITE(OUTFIL,125)
  125 FORMAT(1X,'A tan(Lambda 1/2) should be in the range 0 to 6')
      GO TO 140
C
  130 WRITE(OUTFIL,135)
  135 FORMAT(1X,'Parameter kappa should be in the range 1/3 to 1/2')
      GO TO 140
C
  140 CONTINUE
C
      GO TO 300
C
C     A parameter was out of range of the plots
C     -----------------------------------------
  200 WRITE(OUTFIL,205) MK(MN)
  205 FORMAT(/,
     *1X,'Program error in calculation for Mach number ',G12.4,/,
     *1X,'=========================================================')
C
      IF (FAULTS(1) .EQ. 4) THEN
       WRITE(OUTFIL,210) BA(MN),KAPPA,ATLD50
  210  FORMAT(
     *1X,'Figures 1 to 5 of Item 83040 require:',/,
     *1X,'beta A in the range 1.5 to 12 [beta A =',G12.4,']',/,
     *1X,'kappa in the range 1/3 to 1/2 [kappa  =',G12.4,']',/,
     *1X,'A tan(Lambda1/2) from 0 to 6  [A tan(Lambda1/2) =',G12.4,']')
      ELSE
       WRITE(OUTFIL,220) TR,EB(MN)
  220  FORMAT(
     *1X,'Figure 1 of Item 89034 requires:',/,
     *1X,'lambda in the range 0 to 1        [lambda  =',G12.4,']',/,
     *1X,'eta bar in the range 0.36 to 0.48 [eta bar =',G12.4,']')
      END IF
      GO TO 300
C
  300 WRITE(OUTFIL,310)
  310 FORMAT(/,1X,72(1H-),/)
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG01B(W,X,Y,Z,FOUND)
C     ===============================
C
C     Purpose
C     -------
C     Figures 1 to 5
C     Item 83040
C
C     Input
C     -----
C     W     - Beta A
C     X     - kappa
C     Y     - A tan(Lambda1/2)
C
C     Output
C     ------
C     Z     - eta bar (EB)
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C     XX      - usually just X but ensures that if X is just below
C               0.333333 it is not treated as out of range
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER,I,NW
      REAL W,X,Y,Z
      REAL XX,ZZ(5)
C
      REAL WW,XMN,XMX,YMN,YMX,C
      COMMON /PLTB01/ WW(5),XMN,XMX,YMN,YMX,C(78,5)
C
      DATA NW,ORDER/5, 12/
C
C     Calculate Z for the given X and Y and each WW
C     ---------------------------------------------
      XX = X
      IF (X .GE. 0.333) XX = AMAX1(X,0.3333333)
      DO 10 I = 1,5
      CALL A9E799(XX,Y,XMN,XMX,YMN,YMX,ORDER,C(1,I),ZZ(I),FOUND)
      IF (FOUND .NE. 1) GO TO 20
   10 CONTINUE
C
C     Use a spline fit to interpolate Z for the given W
C     -------------------------------------------------
      CALL A9G799(NW,WW,ZZ,W,Z,FOUND)
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB01
C     =================
C
C     Data for Item 83040 Figures 1 to 5
C     ----------------------------------
C
      REAL WW,XMN,XMX,YMN,YMX,C
      COMMON /PLTB01/ WW(5),XMN,XMX,YMN,YMX,C(78,5)
C
      INTEGER I
C
      DATA WW / 1.5, 3.0, 5.0, 8.0, 12.0 /
C
      DATA XMN,XMX,YMN,YMX/0.333333,0.5,0.0,6.0/
C
      DATA (C(I,1),I=1,40) /
     *.43544112E+00 ,.15853311E-01 ,-.11080262E-02,-.14261079E-02,
     *-.51008650E-04,.25195965E-04 ,.14088044E-04 ,.48296331E-04 ,
     *-.33261533E-05,-.35935188E-04,-.23844372E-06,.17668421E-04 ,
     *.18264952E-01 ,.13866546E-01 ,.20910898E-02 ,-.13437002E-02,
     *.12498161E-03 ,.16391592E-04 ,-.34104268E-04,.48914909E-04 ,
     *.77691968E-05 ,-.34607271E-04,.82445616E-06 ,-.33605975E-02,
     *-.16098932E-02,.16047652E-04 ,.25313197E-03 ,.15032788E-03 ,
     *-.26318190E-06,-.40134423E-04,-.10512199E-04,.85308082E-05 ,
     *.67884512E-05 ,.13542208E-02 ,.67406733E-03 ,-.68777936E-04,
     *-.12416348E-03,-.47925370E-04,.20476369E-05 ,.12826899E-04 /
C
      DATA (C(I,1),I=41,78) /
     *.42701041E-05 ,-.27488966E-05,-.39173329E-03,-.34705311E-03,
     *.57029913E-04 ,.82352030E-04 ,-.20246799E-04,-.30683311E-05,
     *.55280913E-05 ,-.20416417E-05,.15028437E-03 ,.18488217E-03 ,
     *-.10348917E-04,-.43718358E-04,.39129630E-04 ,.89281674E-06 ,
     *-.10928871E-04,-.10106806E-03,-.11273580E-03,.10487190E-04 ,
     *.24540730E-04 ,-.20498739E-04,-.11002393E-05,.95705355E-04 ,
     *.39335854E-04 ,-.16884966E-04,-.26913401E-04,.61172032E-06 ,
     *-.44986666E-04,-.30970427E-04,.28390443E-04 ,.24980715E-04 ,
     *.10443366E-04 ,.71871676E-05 ,-.29892122E-04,-.64422987E-05,
     *.68365364E-05 ,.12764248E-04/
C
      DATA (C(I,2),I=1,40) /
     *.43335968E+00 ,.14260419E-01 ,-.15578704E-02,-.27427202E-03,
     *-.65676151E-04,.28087767E-05 ,.18210988E-04 ,.10229355E-04 ,
     *-.43486614E-05,-.71126972E-05,-.26529931E-06,.32300062E-05 ,
     *.24285579E-01 ,.10058923E-01 ,.14274817E-02 ,-.65424013E-03,
     *-.20329628E-04,.13635037E-04 ,.56066308E-05 ,.21189229E-04 ,
     *-.13181195E-05,-.16268531E-04,-.99783853E-07,-.38708656E-02,
     *-.97287939E-03,.63915154E-04 ,.15741453E-03 ,.37683365E-04 ,
     *-.60733789E-05,-.96936105E-05,-.38042798E-05,.18012993E-05 ,
     *.36322620E-05 ,.12677718E-02 ,.13586535E-03 ,-.10764921E-03,
     *-.10378012E-04,.46464851E-04 ,.13689693E-05 ,-.12256216E-04/
C
      DATA (C(I,2),I=41,78) /
     *-.19719617E-06,.24999881E-05 ,-.10980261E-03,.18821840E-03 ,
     *.55446126E-04 ,-.10615836E-03,-.11495513E-06,.44750060E-05 ,
     *-.29825125E-06,.23906094E-05 ,-.72900025E-04,-.15079521E-03,
     *.23374287E-04 ,.76941128E-04 ,-.19951289E-04,-.44941865E-05,
     *.52931850E-05 ,-.17900544E-05,.45953554E-04 ,.16904260E-04 ,
     *-.27924408E-04,.66029095E-05 ,.24556743E-05 ,.67924897E-04 ,
     *-.12704606E-04,.50290670E-05 ,.58491703E-05 ,.92426834E-06 ,
     *-.50897844E-04,-.23104779E-04,-.63604013E-05,.72431419E-05 ,
     *.18518146E-04 ,.59760820E-05 ,-.74102404E-05,.12223770E-04 ,
     *.21039188E-04 ,-.14480142E-04/
C
      DATA (C(I,3),I=1,40) /
     *.43025328E+00 ,.12873271E-01 ,-.12863173E-02,-.10500042E-03,
     *-.23259141E-04,.72626497E-06 ,.62267828E-05 ,.40774236E-05 ,
     *-.13355936E-05,-.27576087E-05,-.22302998E-06,.12078544E-05 ,
     *.31182755E-01 ,.61448720E-02 ,.76466792E-03 ,-.17116048E-03,
     *-.27590437E-04,.89048642E-07 ,.75619852E-05 ,.71533961E-05 ,
     *-.17456505E-05,-.46050616E-05,-.16271704E-06,-.40401696E-02,
     *-.42351333E-03,.77332341E-04 ,.67995865E-04 ,-.12822503E-04,
     *-.36700894E-05,.34093267E-05 ,-.11590354E-05,-.71477804E-06,
     *.14643038E-05 ,.11323172E-02 ,.76027295E-04 ,.54872360E-04 ,
     *-.34506224E-04,-.25584163E-05,-.20884370E-06,.42638585E-06 /
C
      DATA (C(I,3),I=41,78) /
     *.15471010E-05 ,.90560259E-07 ,.18683020E-03 ,.96731288E-04 ,
     *-.57747338E-04,.86677369E-05 ,-.42505493E-05,-.58836439E-06,
     *.15724004E-05 ,-.91947364E-07,-.20023811E-03,.56503590E-04 ,
     *.54663458E-04 ,-.23001924E-04,-.48221981E-05,.24906786E-05 ,
     *.81037533E-06 ,-.24509544E-04,.97500479E-05 ,.23974332E-04 ,
     *-.25272981E-04,-.31901231E-05,.32441617E-05 ,.75181162E-04 ,
     *.11461705E-04 ,-.63935238E-04,.98408867E-05 ,.15418496E-05 ,
     *-.11745627E-04,-.13944954E-04,.28696991E-05 ,-.35340122E-05,
     *-.29803362E-04,-.17069759E-04,.25394535E-04 ,.73661355E-05 ,
     *-.72098672E-05,.15711122E-04/
C
      DATA (C(I,4),I=1,40) /
     *.42691159E+00 ,.10691110E-01 ,-.86030610E-03,-.27300408E-04,
     *-.13449177E-04,-.28542769E-06,.37184302E-05 ,.12797180E-05 ,
     *-.88058143E-06,-.76464210E-06,-.60601531E-07,.27562449E-06 ,
     *.38261711E-01 ,.33352608E-02 ,.37317157E-03 ,-.12210828E-03,
     *-.40526996E-05,.21137167E-05 ,.15909003E-05 ,.41541429E-05 ,
     *-.69742926E-06,-.30793349E-05,.25448113E-06 ,-.37771182E-02,
     *-.18687483E-03,.80999186E-04 ,.57363507E-04 ,.67960947E-05 ,
     *-.30028495E-05,-.18324537E-05,-.10210355E-05,.40223261E-06 ,
     *.12447332E-05 ,.15018776E-02 ,.49843799E-04 ,.86334398E-05 ,
     *.58523905E-04 ,-.92620614E-06,-.26791256E-05,.32109104E-06 /
C
      DATA (C(I,4),I=41,78) /
     *-.12196647E-05,-.12035918E-06,-.38305804E-03,-.21139414E-04,
     *-.25270982E-04,-.81973019E-04,-.58790009E-05,.36246419E-05 ,
     *.17484031E-05 ,.17675973E-05 ,.13540884E-03 ,.10817561E-04 ,
     *.43736676E-04 ,-.16255722E-04,-.72438789E-05,.16736194E-05 ,
     *.14045269E-05 ,-.63013755E-04,.20808609E-04 ,-.50233634E-05,
     *.34893820E-04 ,.54595768E-05 ,-.15392497E-05,.17004365E-04 ,
     *-.31023767E-04,-.37505723E-06,.10472548E-04 ,.44351879E-05 ,
     *-.12618268E-04,-.88210583E-05,.16446286E-04 ,-.27371381E-04,
     *-.75089830E-05,.15153612E-04 ,-.16295102E-04,.13107186E-04 ,
     *-.31466327E-05,.20273640E-04/
C
      DATA (C(I,5),I=1,40) /
     *.42373026E+00 ,.90364788E-02 ,.27557371E-04 ,.74262229E-04 ,
     *.17053869E-04 ,-.13324494E-05,-.47349298E-05,-.25046442E-05,
     *.11348525E-05 ,.18679914E-05 ,.65321149E-07 ,-.92052974E-06,
     *.45270093E-01 ,.49423978E-03 ,.64317453E-03 ,.24883235E-03 ,
     *.55641273E-04 ,-.75554025E-05,-.16332760E-04,-.69615459E-05,
     *.45148222E-05 ,.59487577E-05 ,-.29954226E-06,-.41627312E-02,
     *-.16060941E-02,.50217359E-03 ,.67660989E-04 ,.25200340E-04 ,
     *-.20215187E-05,-.78891927E-05,-.19081563E-05,.24966760E-05 ,
     *.16208308E-05 ,.20024320E-02 ,.59757021E-03 ,-.18292751E-03,
     *-.10003305E-04,-.33461824E-05,.48306693E-06 ,.13478177E-05 /
C
      DATA (C(I,5),I=41,78) /
     *.19685700E-06 ,-.60731588E-06,-.10629581E-02,-.21943690E-03,
     *.27141955E-04 ,.37758209E-04 ,-.13073573E-05,-.33130167E-05,
     *-.40202602E-06,-.53332692E-07,.55495941E-03 ,.28198642E-03 ,
     *.79993613E-06 ,-.61354280E-04,-.18003198E-04,.68204182E-05 ,
     *.58291512E-05 ,-.39335996E-03,-.50602102E-04,-.77088742E-04,
     *-.15904579E-04,.11057874E-05 ,-.12511428E-05,.21925672E-03 ,
     *.82506719E-04 ,-.19820279E-04,.66834827E-05 ,.89065230E-05 ,
     *-.11307715E-03,-.61887952E-04,.84353078E-05 ,-.98148032E-05,
     *.71292861E-04 ,.13711481E-04 ,.36546492E-04 ,-.77277434E-04,
     *-.36959603E-04,.73870941E-04/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG41B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 89034
C     Figure 1
C     etap vs. eta bar and lambda
C
C     Input
C     -----
C     X     - lambda
C     Y     - eta bar
C
C     Output
C     ------
C     Z     - eta p
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER     - order of polynomial
C     I         - array index
C                 For Left Hand Side of Plot
C                 --------------------------
C     C1( )     - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN1,XMX1 - minimum and maximum X
C     YMN1,YMX1 - minimum and maximum Y
C                 For Right Hand Side of Plot
C                 ---------------------------
C     C2( )     - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN2,XMX2 - minimum and maximum X
C     YMN2,YMX2 - minimum and maximum Y
C
C     Method
C     ------
C     The routine tries the left hand side of the plot.  If X or Y
C     is out of range, it tries the right hand side of the plot.
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER,I
      REAL X,Y,Z
      REAL XMN1,XMX1,YMN1,YMX1,C1(120)
      REAL XMN2,XMX2,YMN2,YMX2,C2(120)
C
      DATA ORDER/15/
C
      DATA XMN1,XMX1,YMN1,YMX1/0.0,0.2,0.36,0.48/
C
      DATA XMN2,XMX2,YMN2,YMX2/0.2,1.0,0.36,0.48/
C
      DATA (C1(I),I=1,40) /
     *.82011833E+00 ,.16942846E+00 ,-.64360790E-01,.14316961E-01 ,
     *.18875558E-02 ,-.13293601E-02,-.11130346E-02,.92492895E-03 ,
     *.99737872E-04 ,-.46428557E-03,.23965697E-03 ,.72852750E-04 ,
     *-.15738602E-03,.32779320E-04 ,.39628936E-04 ,-.15080784E+00,
     *.11734038E+00 ,-.23648853E-01,-.14413554E-01,.17528442E-01 ,
     *-.68036326E-02,-.12504494E-03,.13920658E-02 ,-.73258883E-03,
     *.16108041E-03 ,-.30729135E-05,.40038724E-04 ,.38266582E-05 ,
     *-.18840106E-03,.22082027E-01 ,-.35968489E-01,.25897095E-01 ,
     *-.16315399E-01,.61362373E-02 ,-.25052274E-03,-.44832208E-03,
     *-.17549657E-03,.15402216E-03 ,.17420240E-03 ,-.22945948E-03/
C
      DATA (C1(I),I=41,80) /
     *.49301974E-04 ,.59322327E-04 ,-.57310382E-02,.12017467E-01 ,
     *-.12013157E-01,.11144354E-01 ,-.83648676E-02,.41007860E-02 ,
     *-.89681845E-03,-.83434890E-03,.95035960E-03 ,-.17032708E-03,
     *-.25286657E-03,.60925357E-04 ,.32130796E-02 ,-.57493238E-02,
     *.46052436E-02 ,-.30929145E-02,.19929159E-02 ,-.17301033E-02,
     *.91752087E-03 ,-.17534147E-03,-.16335444E-03,.36285207E-03 ,
     *-.27619064E-03,.19206740E-03 ,.51821728E-03 ,-.42547759E-03,
     *.32296931E-03 ,-.39173443E-03,.23894294E-03 ,.20189973E-04 ,
     *.45181976E-05 ,.18280432E-04 ,-.87219859E-04,-.10729302E-02,
     *.12444676E-02 ,-.12592829E-02,.11900445E-02 ,-.63278023E-03/
C
      DATA (C1(I),I=81,120) /
     *.45673464E-03 ,-.30930715E-03,.30647960E-04 ,.14876153E-03 ,
     *.79075864E-03 ,-.10705045E-02,.11760709E-02 ,-.13150243E-02,
     *.86430377E-03 ,-.50268740E-03,.11826159E-03 ,.52945826E-04 ,
     *-.49216336E-03,.59503461E-03 ,-.54790448E-03,.40492060E-03 ,
     *-.16768498E-03,.11686954E-03 ,.63605972E-04 ,.10075776E-04 ,
     *.39452298E-04 ,-.85258492E-04,.30813419E-03 ,-.27360329E-03,
     *.12871971E-03 ,.42114248E-03 ,-.54430661E-03,.51752237E-03 ,
     *-.44258694E-03,.18634636E-03 ,-.40661622E-03,.46280603E-03 ,
     *-.44635499E-03,.24301670E-03 ,.11410753E-03 ,-.76952646E-04,
     *.64924861E-04 ,.15320481E-03 ,-.17775976E-03,-.23442174E-03/
C
      DATA (C2(I),I=1,40) /
     *.42596371E+00 ,.29841107E+00 ,.37201244E-01 ,-.16396240E-01,
     *-.11820256E-01,-.56591540E-02,-.17811360E-02,.86407394E-03 ,
     *.18057337E-02 ,.73771479E-04 ,-.81616429E-03,.28873268E-03 ,
     *.55819604E-03 ,-.24541281E-03,-.50994978E-03,-.24833635E+00,
     *.20270854E-01 ,.11239198E+00 ,.18567667E-01 ,-.31773316E-01,
     *-.16395584E-01,.15464631E-02 ,.46219060E-02 ,.40832375E-03 ,
     *-.88777653E-03,.11453202E-03 ,.36590444E-03 ,.35004864E-03 ,
     *-.22139542E-03,.46960535E-02 ,-.22982513E-01,.58139292E-02 ,
     *.24470454E-01 ,.39702271E-02 ,-.12789717E-01,-.24334874E-02,
     *.39736058E-02 ,.14475139E-02 ,-.74002711E-03,-.84257302E-03/
C
      DATA (C2(I),I=41,80) /
     *.81362303E-05 ,.50453811E-03 ,-.93796726E-02,-.58685856E-02,
     *-.10230114E-02,-.12098330E-02,.47121585E-02 ,.36422378E-02 ,
     *-.29732538E-02,-.27947898E-03,.22737375E-02 ,-.43349284E-03,
     *-.14490373E-02,.18140330E-03 ,-.42308803E-03,-.29927484E-02,
     *-.13961250E-02,.15568492E-02 ,.19284314E-03 ,.30561361E-03 ,
     *.18416580E-02 ,.11561258E-03 ,-.93229270E-03,-.89684063E-04,
     *.23037121E-03 ,-.81402719E-03,-.35110562E-03,.12493303E-02 ,
     *.45678785E-03 ,.83953937E-03 ,.76485946E-03 ,.99213616E-04 ,
     *-.67989486E-03,-.28264547E-03,.65494264E-03 ,-.67548408E-04,
     *.12665036E-03 ,-.11765157E-04,.35581026E-03 ,.53647161E-03 /
C
      DATA (C2(I),I=81,120) /
     *.25402778E-03 ,-.50761905E-03,-.72892995E-04,.19553349E-03 ,
     *.27931077E-03 ,.10594026E-03 ,-.30376713E-03,.11820744E-03 ,
     *.23845095E-04 ,-.35298153E-03,.23251039E-03 ,.18699586E-03 ,
     *-.43753268E-04,-.33424225E-03,.30634580E-03 ,.76896213E-04 ,
     *-.47301492E-03,-.32388522E-04,-.84265858E-04,-.12608367E-04,
     *.24537209E-03 ,-.30672849E-04,-.28628928E-03,.68900546E-04 ,
     *.11828538E-05 ,.91166149E-04 ,.30840402E-03 ,-.15805678E-04,
     *.41164648E-04 ,.12366605E-03 ,-.17473896E-04,-.13052793E-03,
     *-.14019066E-04,.51648993E-04 ,.84456803E-05 ,-.79315507E-04,
     *-.11416502E-05,.16564932E-04 ,-.12662333E-04,-.71445151E-04/
C

C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN1,XMX1,YMN1,YMX1,ORDER,C1,Z,FOUND)
      IF (FOUND .NE. 1)
     *CALL A9E799(X,Y,XMN2,XMX2,YMN2,YMX2,ORDER,C2,Z,FOUND)
C
C     0.0 <= eta p <= 1.0
C     -------------------
      Z = AMAX1(0.0,Z)
      Z = AMIN1(1.0,Z)
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C     =====================================================
C
C     Purpose
C     -------
C     To interpolate Z for a given X and Y using a complete double
C     Chebyschev polynomial
C
C     Input
C     -----
C     X,Y     - coordinates of the required point
C     XMN,XMX - range of X
C     YMN,YMX - range of Y
C     ORDER   - order of polynomial
C     C(M)    - coefficients of polynomial
C               where M = (ORDER*(ORDER+1))/2
C
C     Output
C     ------
C     Z       - Z for a given (XMN <= X <= XMX) and (YMN <= Y <= YMX)
C               otherwise zero
C     FOUND   - flag    0 = out of range
C                       1 = success
C
C     Local
C     -----
C     I,J,K   - multipliers and index in cos(I*S)*cos(J*T)*C(K)
C     JF      - upper limit of J
C     CX(),CY() - cos((I-1)*S) and cos((J-1)*T)
C                 for I = 1 to ORDER and J = 1 to ORDER
C
C     Method
C     ------
C     For example if ORDER = 4, the formula for Z is:
C     Z = cos(0) * (cos(0)*C(1)+cos(T)*C(2)+cos(2*T)*C(3)+cos(3*T)*C(4))
C       + cos(S) * (cos(0)*C(5)+cos(T)*C(6)+cos(2*T)*C(7))
C       + cos(2*S)*(cos(0)*C(8)+cos(T)*C(9))
C       + cos(3*S)* cos(0)*C(10)
C     where S and T are parameters given by:
C     cos(S) = xx where xx = (2*X-XMX-XMN)/(XMX-XMN)
C     cos(T) = yy where yy = (2*Y-YMX-YMN)/(YMX-YMN)
C     so that when X = XMN, xx = -1.0 and S = -pi
C         and when X = XMX, xx = +1.0 and S = 0.0
C     and similarly for Y, yy and T.
C
C     Subroutines Called
C     ------------------
C     none
C
C     -----------------------------------------------------------------
C
      REAL X,Y,XMN,XMX,YMN,YMX,C(*),Z
      INTEGER ORDER,FOUND
      INTEGER I,J,K,JF
      REAL CX(16),CY(16)
C
C     Calculate cos(I*S) and cos(I*T) for I=1 to ORDER
C     ------------------------------------------------
      CX(1) = 1.0
      CX(2) = (2.0 * X - XMX - XMN) / (XMX - XMN)
      CY(1) = 1.0
      CY(2) = (2.0 * Y - YMX - YMN) / (YMX - YMN)
      DO 10 I = 3, ORDER
      CX(I) = 2.0 * CX(2) * CX(I-1) - CX(I-2)
      CY(I) = 2.0 * CY(2) * CY(I-1) - CY(I-2)
   10 CONTINUE
C
C     Check that X and Y are in range
C     -------------------------------
      Z = 0.0
      FOUND = 0
      IF (ABS(CX(2)) .GT. 1.0 .OR. ABS(CY(2)) .GT. 1.0) GO TO 40
C
C     Calculate the polynomial
C     ------------------------
      K = 0
      DO 30 I = 1, ORDER
      JF = ORDER - I + 1
      DO 20 J = 1, JF
      K = K + 1
      Z = Z + C(K) * CX(I) * CY(J)
   20 CONTINUE
   30 CONTINUE
C
      FOUND = 1
C
   40 RETURN
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE A9G799(N,XX,ZZ,X,Z,FOUND)
C     ====================================
C
C     Purpose
C     -------
C     Interpolation based on a cubic spline fit
C
C     Input
C     -----
C     N           - number of data points
C     XX(N),ZZ(N) - coordinates of the N data points
C     X           - position at which Z is to be found
C
C     Output
C     ------
C     Z           - height of curve at X
C     FOUND       - flag (0=failure  1=success)
C
C     Local
C     -----
C     S()         - slopes dZ/dX at the N data points
C     I           - array index
C     K           - spline that contains X
C     XL,ZL,SL    - X, Z and S at lhs. of spline K
C     XR,ZR,SR    - X, Z and S at rhs. of spline K
C     XRXL,ZRZL   - (XR-XL) and (ZR-ZL)
C     XXL,XXR     - (X-XL) and (X-XR)
C
C     Method
C     ------
C     1. The routine fits a curve to the data.  This curve fit favours
C        large radii of curvature.  The curve fit supplies slopes dZ/dX
C        at each data point.
C     2. The routine finds the spline, K, that contains X.
C     3. The routine uses the following formula to interpolate Z for
C        the given X:
C        Z =   A * (X-XL) / (XR-XL) + B * (X-XR) / (XR-XL)
C            + C * (X-XL)**2 * (X-XR) / (XR-XL)**3
C            + D * (X-XL) * (X-XR)**2 / (XR-XL)**3
C        where:
C        A =  ZR
C        B = -ZL
C        C = (XR-XL) * SR - (ZR-ZL)
C        D = (XR-XL) * SL - (ZR-ZL)
C        The subroutine substitutes A, B, C and D into the above
C        equation to get the formula at the end of the subroutine.
C
C     Subroutine Called
C     -----------------
C     A9H799 - spline fit
C
C     -----------------------------------------------------------------
C
      INTEGER N,FOUND
      REAL XX(N),ZZ(N),X,Z
C
      INTEGER I,K
      REAL S(20),XL,ZL,SL,XR,ZR,SR,XRXL,ZRZL,XXL,XXR
C
C     Calculate the slope S = dZ/dX at each data point
C     ------------------------------------------------
      CALL A9H799(N,XX,ZZ,S)
C
C     Find the spline, K, that contains X
C     -----------------------------------
      FOUND = 0
      IF (x .LT. XX(1) .OR. X .GT. XX(N)) GO TO 30
      FOUND = 1
      K = 1
      DO 10 I = 2,N
      IF (X .LE. XX(I)) GO TO 20
      K = I
   10 CONTINUE
C
C     Interpolate Z at the given X
C     ----------------------------
   20 XL = XX(K)
      ZL = ZZ(K)
      SL = S(K)
      XR = XX(K+1)
      ZR = ZZ(K+1)
      SR = S(K+1)
      XRXL = XR - XL
      ZRZL = ZR - ZL
      XXL = X - XL
      XXR = X - XR
C
      Z = (ZR * XXL - ZL * XXR + XXL * XXR * (SR * XXL + SL * XXR
     *    - ZRZL * (XXL + XXR) / XRXL) / XRXL) / XRXL
C
   30 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE A9H799(N,X,Z,S)
C     ==========================
C
C     Purpose
C     -------
C     Slopes for a spline fit that favours large radii of curvature
C
C     Input
C     -----
C     N         - number of data points
C     X(N),Z(N) - coordinates of the N points
C
C     Output
C     ------
C     S(N)      - slopes at tne N points
C
C     Local
C     -----
C     I,J,L          - array indices
C     NS(20)         - count of estimates of slope and curvature
C                      at each point
C     SS(20,3)       - up to three estimates of slope
C     KK(20,3)         and curvature at each data point
C     SX(3),KX(3)    - three estimates of slope and curvature
C     TOP,BOT,TOL    - dividend, divisor and tolerance
C     K1K2,K1K3,K2K3 - KX(1)*KX(2), KX(1)*KX(3) and KX(2)*KX(3)
C
C     -----------------------------------------------------------------
C
      INTEGER N
      REAL X(N),Z(N),S(N)
      INTEGER I,J,L,NS(20)
      REAL SS(20,3),KK(20,3),SX(3),KX(3),TOP,BOT,TOL,
     *                 K1K2,K1K3,K2K3
C
      TOL = 1.0E-10
      IF (N .GT. 3) GO TO 10
C
C     Only Two or Three Points
C     ========================
      CALL A9J799(N,X,Z,S)
      GO TO 80
C
C     Four or More Points
C     ===================
   10 DO 20 I=1,N
      NS(I) = 0
   20 CONTINUE
C
C     Take successive sets of three points.  Fit a quadratic to each
C     set.  This gives up to three estimates of the slope and curvature
C     at each point.
C     -----------------------------------------------------------------
      DO 40 I = 1,N-2
      CALL A9I799(X(I),Z(I),SX,KX)
C
      L = I
      DO 30 J = 1,3
      NS(L) = NS(L) + 1
      SS(L,NS(L)) = SX(J)
      KK(L,NS(L)) = KX(J)
      L = L + 1
   30 CONTINUE
C
   40 CONTINUE
C
C     Points 2 to N-1 have two or three estimates.
C     Calculate the slopes at these points.
C     --------------------------------------------
      DO 70 I=2,N-1

      DO 50 J = 1,NS(I)
      SX(J) = SS(I,J)
      KX(J) = KK(I,J)
   50 CONTINUE
C
      IF (NS(I) .GT. 2) GO TO 60
C
C     Two Estimates (Points 2 and N-1)
C     -------------
C     Favour the larger radius of curvature.
      TOP = KX(1) * SX(2) + KX(2) * SX(1)
      BOT = KX(1) + KX(2)
      S(I) = 0.5 * (SX(1) + SX(2))
      IF (BOT .GT. TOL * ABS(TOP)) S(I) = TOP / BOT
      GO TO 70
C
C     Three Estimates (Points 3 to N-2)
C     ---------------
C     Favour the larger radii of curvature.
   60 K1K2 = KX(1) * KX(2)
      K1K3 = KX(1) * KX(3)
      K2K3 = KX(2) * KX(3)
      BOT = K1K2 + K1K3 + K2K3
      TOP = SX(3) * K1K2 + SX(2) * K1K3 + SX(1) * K2K3
      S(I) = (SX(1) + SX(2) + SX(3)) / 3.0
      IF (BOT .GT. TOL * ABS(TOP)) S(I) = TOP / BOT
C
   70 CONTINUE
C
C     Make the second derivative constant in the first and last splines.
C     ------------------------------------------------------------------
      S(1) = 2.0 * (Z(2) - Z(1)  ) / (X(2) - X(1)  ) - S(2)
      S(N) = 2.0 * (Z(N) - Z(N-1)) / (X(N) - X(N-1)) - S(N-1)
C
   80 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE A9I799(X,Z,S,K)
C     ==========================
C
C     Purpose
C     -------
C     Slopes and curvatures at three given points on a quadratic
C
C     Input
C     -----
C     X(3),Z(3) - coordinates
C
C     Output
C     ------
C     S(3)      - slopes at the three points
C     K(3)      - curvatures at the three points
C
C     Local
C     -----
C     X1X2      - X(1) - X(2)
C     X1X3      - X(1) - X(3)
C     X2X3      - X(2) - X(3)
C     Q1        - Z(1) / (X1X2 * X1X3)
C     Q2        - Z(2) / (X1X2 * X2X3)
C     Q3        - Z(3) / (X1X3 * X2X3)
C     C         - |d2Z / dX2|
C     B         - 1 + (dZ/dX)**2
C
C     Method
C     ------
C     The quaddratic can be written:
C     Z = (X-X2)*(X-X3)*Q1 - (X-X1)*(X-X3)*Q2 + (X-X1)*(X-X2)*Q3
C     Then:
C     S(1) = (X1-X2)*(Q1+Q3) + (X1-X3)*(Q1-Q2)
C     S(2) = (X2-X3)*(Q1-Q2) + (X2-X1)*(Q3-Q2)
C     S(3) = (X1-X3)*(Q2-Q3) - (X2-X3)*(Q1+Q3)
C     and the second derivative is constant and is:
C     (d2Z/dX2) = 2 * (Q1 - Q2 + Q3)
C     and the curvatures are given by:
C     K = ABS(d2Z/dX2) / [1 + (dZ/dX)**2]**1.5
C
C     -----------------------------------------------------------------
C
      REAL X(3),Z(3),S(3),K(3)
      INTEGER I
      REAL X1X2,X1X3,X2X3,Q1,Q2,Q3,C,B
C
      X1X2 = X(1) - X(2)
      X1X3 = X(1) - X(3)
      X2X3 = X(2) - X(3)
C
      Q1 = Z(1) / (X1X2 * X1X3)
      Q2 = Z(2) / (X1X2 * X2X3)
      Q3 = Z(3) / (X1X3 * X2X3)
C
      C = 2.0 * ABS(Q1 - Q2 + Q3)
C
      S(1) = X1X2 * (Q1 + Q3) + X1X3 * (Q1 - Q2)
      S(2) = X2X3 * (Q1 - Q2) + X1X2 * (Q2 - Q3)
      S(3) = X1X3 * (Q2 - Q3) - X2X3 * (Q1 + Q3)
C
      DO 10 I = 1,3
      B = 1.0 + S(I) * S(I)
      K(I) = C / (B * SQRT(B))
   10 CONTINUE
C
      RETURN
      END
C     ------------------------------------------------------------------
      SUBROUTINE A9J799(N,X,Z,S)
C     ==========================
C
C     Purpose
C     -------
C     Slopes on a straight line or quadratic
C
C     Input
C     -----
C     N        - number of data points (2 or 3)
C     X(),Z()  - coordinates of data points
C
C     Output
C     ------
C     S()      - slopes at the data points
C
C     Local
C     -----
C     I        - array index
C
C     -----------------------------------------------------------------
C
      INTEGER N
      REAL X(N),Z(N),S(N)
      INTEGER I
C
      IF (N .GT. 2) GO TO 10
C
C     Just Two Points
C     ===============
      S(1) = (Z(2) - Z(1)) / (X(2) - X(1))
      S(2) = S(1)
      GO TO 30
C
C     Just Three Points
C     =================
   10 DO 20 I = 1,3
      S(I) =
     * (  Z(1) * (2.0 * X(I) - X(2) - X(3)) * (X(3) - X(2))
     *  - Z(2) * (2.0 * X(I) - X(1) - X(3)) * (X(3) - X(1))
     *  + Z(3) * (2.0 * X(I) - X(1) - X(2)) * (X(2) - X(1)) )
     * / ((X(2) - X(1)) * (X(3) - X(1)) * (X(3) - X(2)) )
   20 CONTINUE
C
   30 RETURN
      END


