C     -----------------------------------------------------------------
      SUBROUTINE SUBRAA
C     =================
C     this subroutine is not used
C     Purpose
C     -------
C     Section AA:
C     to duplicate device data :- copies data from section at etap
C     to mid-span of each device panel.
C
C     Input from Common Block
C     -----------------------
C     CSL       - flag on geometry of leading-edge devices:
C                 0 means always the same as at ETAP
C                 1 means different
C     NDL       - number of leading edge device settings (0<=NDL<=10)
C     DL(10)    - NDL deflection angles (deg)       [delta l]
C     CXL(10)   - NDL leading edge extended chords  [c'l/c]
C     DCL(10)   - NDL chord extensions due to deployment of leading
C                 edge device                       [Delta cl / c]
C     CST       - flag on geometry of trailing-edge devices:
C                 0 means always the same as at ETAP
C                 1 means different
C     NDT       - number of trailing-edge device settings (0<=NDT<=10)
C     DT(3,10)  - NDT deflection angles (deg) of up to 3 elements
C                                                        [delta t]
C     DCT(3,10) - NDT chord extensions due to deployment of up to 3
C                 elements                               [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements     [ct/c]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)                 [phit]
C     XLM,ZLM   - coordinates of section maximum lower surface ordinate
C                                                        [xlm/c, zlm/c]
C     XTS       - location of flap shroud trailing edge  [xts/c]
C     T         - thickness to chord ratio [t/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17),    coordinates at each of 17 standard chordwise
C     ZLG(17)     locations [(x/c)g, (zu/c)g and (zl/c)g]
C     NNL       - number of leading-edge device panels (0<=NNL<=5)
C     NNT       - number of trailing-edge device panels (0<=NNT<=5)
C     NTJ(5)     - trailing-edge device types
C
C     Output to Common Block
C     ----------------------
C     DLJ(5,10)    - NDL*NNL deflection angles [(delta l)j]
C     CXLJ(5,10)   - NDL*NNL extended chords   [(c'l / c)j]
C     DCLJ(5,10)   - NDL*NNL extensions on deployment [(Delta cl / c)j]
C     DTJ(3,5,10)  - deflection angles for up to 3 elements, for NDT
C                    device settings, for NNT trailing edge devices
C                    [(delta t)j]
C     DCTJ(3,5,10) - chord extensions for up to 3 elements, for NDT
C                    device settings, for NNT trailing edge devices
C                    [(Delta ct / c)j]
C     CTJ(3,5)     - flap chords for up to 3 elements, for NNT devices
C                    [(ct/c)j]
C     PHITJ(5)     - angle from aerofoil datum to tangent to upper
C                    surface at trailing edge  [(phi t)j]
C     XLMJ(5)      - chordwise location of section maximum lower surface
C                    coordinate  [(xlm/c)j]
C     ZLMJ(5)      - section maximum (negative) lower surface ordinate
C                    [(zlm/c)j]
C     TJ(5)        - section thicknesses (t/c)j of NNT devices
C     TAUJ(5)      - NNT trailing edge angles in Sketch 1.1a
C     TAUAJ(5)     - NNT trailing edge angles in Sketch 1.1b
C     XTSJ(5)      - chordwise location of flap shroud trailing edge
C                    angle  [(xts/c)j]
C
C     Local
C     -----
C     I,J,K        - array indices
C     TN,SN        - tan and sin of an angle
C
C     -----------------------------------------------------------------
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
      INTEGER I,J,K
      REAL TN,SN
C
C     Leading-edge data
C     =================
      IF (CSL .EQ. 0 .AND. NDL .GT. 0 .AND. NNL .GT. 0) THEN
C      Take each leading-edge panel in turn
       DO 20 I = 1,NNL
C      Take each leading-edge device setting in turn
       DO 10 J = 1,NDL
C      (delta l)j = (elta l)
       DLJ(I,J) = DL(J)
C      (c'l/c)j = (c'l/c)
       CXLJ(I,J) = CXL(J)
C      (Delta cl/c)j = (Delta cl/c)
       DCLJ(I,J) = DCL(J)
   10  CONTINUE
   20  CONTINUE
      END IF
C
C     Trailing-edge data
C     ==================
      IF (CST .EQ. 0 .AND. NDT .GT. 0 .AND. NNT .GT. 0) THEN
C      Take each trailing edge panel.
       DO 50 J = 1,NNT
C      Take all three (possible) elements.
       DO 40 I = 1,3
C      Take each trailing-edge device setting.
       DO 30 K = 1,NDT
C      (delta ti)j = (delta ti)
       DTJ(I,J,K) = DT(I,K)
C      (Delta cti/c)j = (Delta ct/c)j
       DCTJ(I,J,K) = DCT(I,K)
   30  CONTINUE
C      (cti/c)j = (cti/c)
       CTJ(I,J) = CT(I)
   40  CONTINUE
C      (phi t)j = (phi t)
       PHITJ(J) = PHIT
C      (xlm/c)j = (xlm/c)
       XLMJ(J) = XLM
C      (zlm/c)j = (zlm/c)
       ZLMJ(J) = ZLM
C      (t/c)j = (t/c)
       TJ(J) = T
C      (xts/c)j = (xts/c)
       XTSJ(J) = XTS
C      (tau)j = tau
       TAUJ(J) = TAU
C      Calculate (tau a)j for (Nt)j >= 3
       IF (NTJ(J) .GE. 3) THEN
C       tan[ ] = {[(zu/c)g=14 - (zl/c)g=14]
C                 - [(zu/c)g=16 - (zl/c)g=16]} / 0.18
        TN = ((ZUG(14) - ZLG(14)) - (ZUG(16) - ZLG(16))) / 0.18
C       sin[] = tan[ ] / sqrt{1 + tan^2[ ]}
        SN = TN / SQRT(1.0 + TN * TN)
C       (tau a)j = 2 * arc sin (sin[ ]) converted to degrees
        TAUAJ(J) = 2.0 * (180.0 / 3.141593) * ASIN(SN)
       END IF
   50  CONTINUE
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRA
C     ================
C
C     Purpose
C     -------
C     To supply data for and store the results of Section a:
C     calculation of wing geometric parameters,that are independent
C     of Mk and high-lift device settings
C
C     Input from Common Block
C     -----------------------
C     CALC- calculation type (1 to 18)
C     A         - aspect ratio of wing    [A]
C     TR        - taper ratio of wing     [lambda]
C     N         - fractional chord line   [n]
C     LDN        - sweep of nth chord line [Lambda n]
C     EP        - dimensionless spanwise location of most highly
C                 loaded section [eta p]
C
C     Output to Common Block
C     ----------------------
C     LDX(4)    - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     KAPPA     - pasrameter (1+2*lambda)/(3*(1+lambda))
C     CPCBB,    - chord ratios cp/cbb, cr/cbb, (c2/3)/cbb
C     CRCBB,      where cbb is (c double bar)
C     C23CBB
C
C     -----------------------------------------------------------------
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
C     Calculate LDX(4),KAPPA,CPCBB,CRCBB,Z23CBB by Section a
C     --------------------------------------------------------
      CALL SUBRA0(CALC,A,TR,N,LDN,EP,LDX,KAPPA,CPCBB,CRCBB,C23CBB)
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRA0(CALC,A,TR,N,LDN,EP,LDX,KAPPA,CPCBB,CRCBB,C23CBB)
C     ==================================================================
C
C     Purpose
C     -------
C     Section a :- calculation of wing geometric parameters
C     that are independent of Mk and high-lift device settings
C
C     Input
C     -----
C     CALC      - calculation type (1 to 18)
C     A         - aspect ratio of wing    [A]
C     TR         - taper ratio of wing     [lambda]
C     N         - fractional chord line   [n]
C     LDN       - sweep of nth chord line [Lambda n]
C     EP        - dimensionless spanwise location of most highly
C                 loaded section [eta p]
C
C     Output
C     ------
C     LDX(4)    - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     KAPPA     - pasrameter (1+2*lambda)/(3*(1+lambda))
C     CPCBB,    - chord ratios cp/cbb, cr/cbb, (c2/3)/cbb
C     CRCBB,      where cbb is (c double bar)
C     C23CBB
C
C     Local
C     -----
C     LIST(18,5) - array of flags on each of the 5 calculations
C                  that each of the 18 calculations might need
C     RTOD       - radians to degrees conversion factor
C     DTOR       - degrees to radians conversion factor
C     CX         - (3/2)*(1+TR)/(1+TR+TR^2)
C     X(4)       - X in (4*n-X)/A in the equations for LDX()
C                  O.0, 1.0, 2.0, 4.0
C     TNN        - tan(LDN * pi /180.0)
C     SN,TN      - sin and tangent of LDX(I)
C     Z          - (1/A)*(1-TR)/(1+TR)
C
C     -----------------------------------------------------------------
C
      INTEGER CALC
      REAL A,TR,N,LDN,EP,LDX(4),KAPPA,CPCBB,CRCBB,C23CBB
      REAL Z
C
      INTEGER LIST(18,5),I
      REAL X(4),DTOR,RTOD,CX,TNN,TN,SN
C
C     Data for the list of flags LIST(18,5)
C     -------------------------------------
C     CALC = 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,16,17,18
      DATA LIST /
     1       0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     2       0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     3       0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     4       0, 0, 0, 0, 0, 0, 7, 0, 9, 0, 0, 0,13, 0,15, 0, 0, 0,
     5       0, 0, 0, 0, 0, 0, 7, 0, 9, 0, 0, 0,13, 0,15, 0, 0, 0/
C
C
C     Data for X
C     ----------
      DATA X / 0.0, 1.0, 2.0, 4.0 /
C
      DTOR = 3.141593 / 180.0
      RTOD = 180.0 / 3.141593
C
      IF (CALC .GT. 6) THEN
C      Calculate CX = (3/2) * [(1 + lambda) / (1 + lambda + lambda^2)]
C      for use later in the routine.
       CX = 1.5 * (1.0 + TR) / (1.0 + TR + TR * TR)
      END IF
C
C     Section a1 - calculate the various sweeps if required
C     =======================================================
      IF (LIST(CALC,1) .GT. 0) THEN
C      Calculate TNN = tan[(Lambda n) * pi / 180)
       TNN = TAN(DTOR * LDN)
C      Calculate Z = (1 / A) * (1 - lambda) / (1 + lambda)
       Z = (1.0 / A) * (1 - TR) / (1 + TR)
C
C      Calculate Lambda0, Lambda1/4, Lambda1/2 and Lambda1
C      ---------------------------------------------------
       DO 10 I = 1,4
C      Calculate TN = tan(Lambda i)
       TN = TNN + (4.0 * N - X(I)) * Z
C      Calculate SN = sin(Lambda i)
       SN = TN / SQRT(1.0 + TN * TN)
C      LDX(i) = (Lambda i) = (180 / pi) * arc sin(sin(Lambda i))
       LDX(I) = RTOD * ASIN(SN)
   10  CONTINUE
      END IF
C
C     Section a2 - calculate KAPPA if required
C     ==========================================
C
      IF (LIST(CALC,1) .GT. 0) THEN
C      Kappa = (1/3) * (1 + 2 * lambda) / (1 + lambda)
       KAPPA = (1.0/3.0) * (1.0 + 2.0 * TR) / (1.0 + TR)
      END IF
C
C     Calculate chord ratios that are needed
C     ======================================
C     Section a3
C     ------------
C     (cp/c double bar) =
C                     (3/2) * [(1 + lambda) / (1 + lambda + lambda^2)]
C     *               * [1 - (eta p) + lambda * (eta p)
      IF (LIST(CALC,2) .GT. 0) CPCBB = CX * ( 1.0 - EP + TR * EP)
C
C     Section a4
C     ------------
C     (cr/c double bar) =
C                     (3/2) * [(1 + lambda) / (1 + lambda + lambda^2)]
      IF (LIST(CALC,4) .GT. 0) CRCBB = CX
C
C     Section a5
C     ------------
C     ((c2/3)/c double bar) =
C                     (3/2) * [(1 + lambda) / (1 + lambda + lambda^2)]
C                     (1/3 + 2/3 * lambda)
      IF (LIST(CALC,5) .GT. 0) C23CBB = CX * (1.0 + 2.0 * TR) / 3.0
C
C     Aerofoils - CALC = 1 to 6
C     =========================
C     The following statements are true for aerofoils:
      IF (CALC .LE. 6) THEN
       KAPPA = 0.5
       CPCBB = 1.0
       CRCBB = 1.0
       C23CBB = 1.0
      END IF
C     and VX(I) = 0.0 for I = 1 to 4 and was set thus at the start.
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRBB(K,FAULT)
C     ==========================
C
C     Purpose
C     -------
C     To supply data for and store the results of Sections b:
C     calculation of wing parameters for the current Mach and
C     Reynolds numbers
C
C     Input
C     -----
C     K    - curent Mach and Reynolds number pair
C
C     Output
C     ------
C     FAULT  - fault number (0 means "none")
C
C     Input from Common Blocks
C     ------------------------
C     CALC      - calculation type (1 to 18)
C     MN(10)    - Mach numbers M(K)
C     RN(10)    - Reynolds numbers R(K)
C     A         - aspect ratio of wing    [A]
C     TR        - taper ratio of wing     [lambda]
C     LDX(4)    - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     KAPPA     - parameter (1+2*lambda)/(3*(1+lambda))
C     CPCBB,    - chord ratios cp/cbb, cr/cbb, (c2/3)/cbb
C     CRCBB,      where cbb is (c double bar)
C     C23CBB
C
C     Output to Common Block
C     ----------------------
C     LCS       - lift-curve slope  [a1]
C     EB        - spanwise centre of pressure [eta bar]
C     RXK,RXKR  - Reynolds numbers based on Cp, Cr and C2/3
C     RXK23       [R'k, R'kr and R'k2/3]
C     MUP       - peak loading   [mu p]
C
C     -----------------------------------------------------------------
C
      INTEGER K,FAULT
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
C     Calculate LCS,EB,RXK,RXKR,RXK23,MUP by Sections b1 to b5
C     ----------------------------------------------------------
      CALL SUBRB0(CALC,MN(K),RN(K),A,TR,LDX,KAPPA,CPCBB,CRCBB,C23CBB,
     *                  LCS,EB,RXK,RXKR,RXK23,MUP,FAULT)
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRB0(CALC,MK,RK,A,TR,LDX,KAPPA,CPCBB,CRCBB,C23CBB,
     *                  LCS,EB,RXK,RXKR,RXK23,MUP,FAULT)
C     =============================================================
C
C     Purpose
C     -------
C     Calculation of wing parameters for the current Mach and
C     Reynolds numbers
C
C     Input
C     -----
C     CALC      - calculation type (1 to 18)
C     MK        - current Mach number M(K)
C     RK        - current Reynolds number R(K)
C     A         - aspect ratio of wing    [A]
C     TR        - taper ratio of wing     [lambda]
C     LDX(4)    - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     KAPPA     - parameter (1+2*lambda)/(3*(1+lambda))
C     CPCBB,    - chord ratios cp/cbb, cr/cbb, (c2/3)/cbb
C     CRCBB,      where cbb is (c double bar)
C     C23CBB
C
C     Output
C     ------
C     LCS       - lift-curve slope  [a1]
C     EB        - spanwise centre of pressure [eta bar]
C     RXK,RXKR  - Reynolds numbers based on Cp, Cr and C2/3
C     RXK23       [R'k, R'kr and R'k2/3]
C     MUP       - peak loading   [mu p]
C     FAULT     - fault number (0 means none)
C     RK2     - value of RK
C
C     Local
C     -----
C     LIST(18,5) - array of flags on each of the 5 calculations
C                  that each of the 18 calculations might need
C     DTOR       - degrees to radians conversion factor
C     WW,XX,YY   - parameters (W,X,Y) and reading Z in an Item plot
C     ZZ
C     B          - beta = sqrt(1-M*M)
C     BA         - beta * A
C     ATLD50     - A * tan(Lambda1/2)
C
C     -----------------------------------------------------------------
C
      INTEGER CALC,FAULT
      REAL MK,RK,A,TR,LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,
     *     LCS,EB,RXK,RXKR,RXK23,MUP
C
      INTEGER LIST(18,5)
      REAL DTOR,WW,XX,YY,ZZ,B,BA,ATLD50
C
C     Next lines get RK down to call SUBR14 in Subroutine KK
C
      REAL RK2
      COMMON /ZJ9931/ RK2
      RK2 = RK
C
      DATA LIST /
     1          0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     2          0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     3          0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     4          0, 0, 0, 0, 0, 0, 7, 0, 9, 0, 0, 0,13, 0,15, 0, 0, 0,
     5          0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0/
C
      DTOR = 3.141593 / 180.0
C
      FAULT = 0
C
      IF (CALC .GT. 6) THEN
C      Calculate beta, beta*A and A*tan(Lambda1/2)
C      -------------------------------------------
C      Calculate beta = sqrt(1 - Mk^2)
       B = SQRT(1.0 - MK * MK)
C      Calculate BA = beta * A
       BA = B * A
C      Calculate ATLD50 = A * Lambda1/2
       ATLD50 = A * TAN(DTOR * LDX(3))
      END IF
C
C     Section b1:
C     Find lift-curve slope, LCS (= a1) in Figure 1 of Item 70011
C     -----------------------------------------------------------
      IF (LIST(CALC,1) .GT. 0) THEN
       WW = TR
       XX = ATLD50
       YY = BA
C      Read LCS from Figures 1(a) to 1(e) of Item 70011
       CALL FIG00A(WW,XX,YY,ZZ,FAULT)
C
       LCS = ZZ*A
       IF (FAULT .NE. 0) GO TO 10
      END IF
C
C     Section b2;
C     Find the spanwise centre of pressure, EB = (eta bar)
C     ----------------------------------------------------
      IF (LIST(CALC,2) .GT. 0) THEN
       WW = BA
       XX = KAPPA
       YY = ATLD50
C      Read EB from Figures 1 to 5 of Item 83040
       CALL FIG01A(WW,XX,YY,ZZ,FAULT)
       EB = ZZ
       IF (FAULT .NE. 0) GO TO 10
      END IF
C
C     Section b3:
C     Reynolds number based on Cp; i.e. R'k = Rk * (Cp/Cbb)
C     -----------------------------------------------------
C
      IF (LIST(CALC,5) .GT. 0)  RXK = RK * CPCBB
C
C     Section b4:
C     Reynolds numbers for the root and 2/3 chords (R'kr) and (R'k2/3)
C     ----------------------------------------------------------------
      IF (LIST(CALC,4) .GT. 0) THEN
       RXKR = RK * CRCBB
       RXK23 = RK * C23CBB
      END IF
C
C     Section b5: Peak loading, Mup
C     -------------------------------
      IF (LIST(CALC,5) .GT. 0) THEN
C      Read Mup from Figure 2 of Item 89034
       CALL FIG02A(TR,EB,MUP,FAULT)
       IF (FAULT .NE. 0) GO TO 10
      END IF
C
C     The following statements are true for aerofoils (CALC = 1 to 6)
C     ---------------------------------------------------------------
      IF (CALC .LE. 6) THEN
       RXK = RK
       RXKR = RK
       RXK23 = RK
      END IF
C     Note: Subroutine SUBRC4 will supply LCS for CALC = 1, 2 and 3
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRCC(K,FAULT)
C     ==========================
C
C     Purpose
C     -------
C     To manage the calculations of Section c:
C     calculation of CL0Bf for the basic wing-fuselage
C
C     Input
C     -----
C     K         - current Mach and Reynolds number pair
C
C     Output
C     ------
C     FAULT     - fault number (0 means "none")
C
C     Input from Common Blocks
C     ------------------------
C     CALC      - calculation type (1 to 18)
C     MN(10),   - NMR pairs of Mach and Reynolds numbers
C     RN(10)
C     A         - aspect ratio of wing    [A]
C     TR        - taper ratio of wing     [lambda]
C     T         - thickness to chord ratio [t/c]
C     XTR       - dimensionless chordwise location of boundary layer
C                 transition point [xtr/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17),  - dimensionless upper-surface and lower-surface
C     ZLG(17)     coordinates at each of 17 standard chordwise
C                 locations [(zu/c)g and (zl/c)g]
C     ZC92      - ratio of camber ordinate at x=0.92c to camber
C                 ordinate at x=0.5c  [zc92/zc50]
C     D23       - geometric twist angle (deg) at eta = 2/3, relative
C                 to root chord, positive nose up   [delta 2/3]
C     ZURG(15), - dimensionless upper and lower surface coordinates
C     ZLRG(15)    at 15 standard dimensionless locations along root
C                 chord   [(zu/c)rg, (zl/c)rg]
C     Z92R      - ratio of camber ordinate at x=0.92c to that at x=0.5c
C                 on root chord  [(zc92/zc50)r]
C     ZU23G(15),- dimensionless upper and lower surface coordinates
C     ZU23G(15)   at 15 standard dimensionless locations
C                 [(zu/c)2/3g, (zl/c)2/3g]
C     Z9223     - ratio of camber ordinate at x=0.92c to that at x=0.5c
C                 [(zc92/zc50)2/3]
C     W         - ratio of body width to semi-span  [W/s]
C     IW        - setting angle of wing centre-line chord relative
C                 to fulselage centre linen (deg)   [iW]
C     LDX(4)   - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     LCS      - lift-curve slope in Section b1 [a1]
C     RXKR     - Reynolds number based on cr in Section b4 [R'kr]
C     RXK23    - Reynolds number based on c2/3 in Section b4 [R'k23]
C
C     Output to Common Blocks
C     -----------------------
C     CL0B        - lift coefft. at zero angle of attack for basic
C                   aerofoil (high-lift devices not deployed) [CL0B]
C     CL0BW       - lift coefft. at zero angle of attack for basic wing
C                   (high-lift devices not deployed)
C     CL0BF       - lift coefft. at zero angle of attack for basic
C                   wing-fuselage combination [CL0Bf]
C     A0BW     - zero lift angle (rad) of basic wing in Section c1
C                [alpha 0Bw]
C     A0BF     - wing-fuselage zer0-lift angle (rad) in Section c2
C     A0BT     - zero-lift angle (rad) of basic aerofoil in Section c4
C                [alpha 0BT]
C     LCS0T    - theoretical lift-curve slope of basic aerofoil
C                in Section c4 [(a1)0T]
C     LCS      - lift-curve slope for aerofoils only (CALC = 1, 2, 3)
C
C     Local
C     -----
C     A0BT1    - root zero-lift angle (rad) in Section c1
C                [(aplha 0BT)1]
C     RA01     - zero-lift angle conversion factor at root in para. c1
C                [alpha 0BV / alpha 0BT]1
C     DTE      - effective twist angle (deg) in paragrah c1 [delta te]
C     RA0      - zero-lift angle conversion factor for basic aerofoil
C                in Section c4  [alpha 0BV / alpha 0BT]
C
C     ----------------------------------------------------------------
C
      INTEGER K,FAULT
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
      REAL   TN,RTOD,SN
C
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
      REAL A0BT1,RA01,DTE,RA0
C     Next line to take DTE from here into SUBRDD
      COMMON /ZI9931/ DTE
C
      INTEGER LIST(18,5)
C
      DATA LIST /
     * 0, 0, 0, 0, 0, 0, 7, 0, 9, 0, 0, 0,13, 0,15, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0,13, 0,15, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0,13, 0,15, 0, 0, 0,
     * 1, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     * 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0/
C
      FAULT = 0
C
C     Calculation of zero-lift angle for basic wing [alpha 0Bw]
C     =========================================================
C     Paragrah c1
C     -----------
      IF (LIST(CALC,1) .GT. 0)
     *CALL SUBRC1(MN(K),A,TR,ZURG,ZLRG,Z92R,D23,ZU23G,ZL23G,Z9223,
     *            LDX,LCS,RXKR,RXK23,CL0BW,A0BW,A0BT1,RA01,DTE,
     *            FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Section c2
C     ------------
      IF (LIST(CALC,2) .GT. 0) CALL SUBRC2(W,IW,A0BW,A0BT1,RA01,A0BF)
C
C     Section c3
C     ------------
      IF (LIST(CALC,3) .GT. 0) CALL SUBRC3(LCS,A0BF,CL0BF)
C
C     Section c4
C     ------------
      IF (LIST(CALC,4) .GT. 0)
     *CALL SUBRC4(MN(K),RN(K),T,XTR,TAU,ZUG,ZLG,ZC92,
     *            TAUA,TAUAU,A0BT,RA0,LCS0T,LCS,CL0B,FAULT)
C
C     Next lines are for a CALC=2 TES=1 run
C
      IF (TES .EQ. 1 .AND. CALC .EQ. 2) ZU5 = ZUG(5)
      IF (TES .EQ. 1 .AND. CALC .EQ. 2) ZL5 = ZLG(5)
C
C     Next lines a repeat of calcs in SUBR06 needed before CALL SUBRC5
C     Calculate trailing edge angles [tau a] and [tau au] in degrees
C     --------------------------------------------------------------
C     (tau a) = 2 *
C     arc tan[{[(zu/c)14 - (zl/c)14] - [(zu/c)16 - (zl/c)16]} / 0.18]
      IF (TES.EQ.1 .AND. CALC .EQ. 2)
     +     TN =((ZUG(14) - ZLG(14)) - (ZUG(16) - ZLG(16)))/0.18
C
      IF (TES.EQ.1 .AND. CALC .EQ. 2) RTOD = 180.0 / 3.141493
      IF (TES.EQ.1 .AND. CALC .EQ. 2) SN = TN / SQRT(1.0 + TN * TN)
      IF (TES.EQ.1 .AND. CALC .EQ. 2) TAUA = 2.0 * RTOD * ASIN(SN)
C
C     (tau au) = arc tan[[(zu/c)14 - (zu/c)16] / 0.09]
      IF (TES.EQ.1 .AND. CALC .EQ. 2) TN = (ZUG(14) - ZUG(16)) / 0.09
      IF (TES.EQ.1 .AND. CALC .EQ. 2) SN = TN / SQRT(1.0 + TN * TN)
      IF (TES.EQ.1 .AND. CALC .EQ. 2) TAUAU = RTOD * ASIN(SN)
C
C
      IF (LIST(CALC,5) .GT. 0)
     *CALL SUBRC5(MN(K),RN(K),T,XTR,TAU,ZU5,ZL5,TAUA,TAUAU,
     *                  LCS0T,LCS,FAULT)
C
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRC1(MK,A,TR,ZURG,ZLRG,Z92R,D23,ZU23G,ZL23G,Z9223,
     *                  LDX,LCS,RXKR,RXK23,CL0BW,A0BW,A0BT1,RA01,DTE,
     *                  FAULT)
C     ===============================================================
C
C     Purpose
C     -------
C     Section c1 of the notes:
C     Calculation of the zero lift angle and zero angle lift coefft.
C     for the basic wing
C
C     Input
C     -----
C     MK        - current Mach number
C     A         - aspect ratio of wing [A]
C     TR        - taper ratio of wing     [lambda]
C     ZURG(15), - dimensionless upper and lower surface coordinates
C     ZLRG(15)    at 15 standard dimensionless locations along root
C                 chord   [(zu/c)rg, (zl/c)rg]
C     Z92R      - ratio of camber ordinate at x=0.92c to that at x=0.5c
C                 on root chord  [(zc92/zc50)r]
C     D23       - geometric twist angle (deg) at eta = 2/3, relative
C                 to root chord, positive nose up   [delta 2/3]
C     ZU23G(15) - dimensionless upper and lower surface coordinates
C     ZL23G(15)   at 15 standard dimensionless locations
C                 [(zu/c)2/3g, (zl/c)2/3g]
C     RXKR,     - Reynolds numbers based on Cr and C2/3
C     RXK23       [R'kr and R'k2/3]
C     Z9223     - ratio of camber ordinate at x=0.92c to that at x=0.5c
C                 [(zc92/zc50)2/3]
C     LDX(4)    - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     LCS       - lift curve slope [a1]

C     Output
C     ------
C     CL0BW      - lift-coefft. at zero angle of attack for basic wing
C                  (high-lift devices not deployed) [CL 0Bw]
C     A0BW       - zero lift angle of basic wing [alpha 0Bw] (rad)
C     A0BT1      - root (centre-line) zero lift angle [(alpha 0BT)1]
C                  (rad)
C     RA01       - zero lift angle conversion factor at root
C                  [alpha 0BV / alpha 0BT]1
C     DTE        - effective twist angle [delta te]
C     FAULT      - fault number (0 means "none")
C
C     Local
C     -----
C     A0BT23     - zero lift angle at eta = 2/3  [(alpha 0BT)2/3]
C     RA02       - zero lift angle conversion factor at eta = 2/3
C                  [alpha 0BV / alpha 0BT]2/3
C     AOR2       - effective twist conversion factor
C                  [(alpha or)2 / delta te]
C     YY         - A tan(Lambda1/4)
C     DTOR       - (radians) = DTOR * (degrees)
C     RTOD       - (degrees) = RTOD * (radians)
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL MK,A,TR,ZURG(15),ZLRG(15),Z92R,D23,ZU23G(15),ZL23G(15),Z9223,
     *     LDX(4),LCS,RXKR,RXK23,CL0BW,A0BW,A0BT1,RA01,DTE
C
      REAL A0BT23,RA02,AOR2,YY,DTOR,RTOD
C
      DTOR = 3.141593 / 180.0
      RTOD = 180.0 / 3.141493
      FAULT = 0
C
C     Subroutine 9 calculates the root (centre-line) zero lift angle
C     A0BT1 = (alpha 0Bt)1 (rad)
C     --------------------------------------------------------------
      CALL SUBR09(ZURG,ZLRG,A0BT1)
C
C     Subroutine 9 calculates the zero lift angle
C     A0BT23 = (alpha 0BT)2/3 at eta = 2/3 in radians
C     -----------------------------------------------
      CALL SUBR09(ZU23G,ZL23G,A0BT23)
C
C
C     Subroutine 1 calculates the zero lift angle conversion factor
C     RA01 = [(alpha 0BV)/(alpha 0BT)]1 at the root.
C     -------------------------------------------------------------
      CALL SUBR01(MK,RXKR,Z92R,RA01,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Subroutine 1 calculate the zero lift angle conversion factor
C     RA02 = [(alpha 0BV)/(alpha 0BT)]2/3 at eta = 2/3
C     ------------------------------------------------------------
      CALL SUBR01(MK,RXK23,Z9223,RA02,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Find the effective twist conversion factor AOR2 =
C     [(alpha or)2/(delta te)] from Figures 1a to 1d of Item 87031
C     ------------------------------------------------------------
C     YY = A * tan(Lambda1/4)
      YY = A * TAN(DTOR * LDX(2))
      CALL FIG03A(TR,A,YY,AOR2,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     The effective twist angle DTE is given (in degrees) by a formula
C     (delta te) = (3/2) {(delta 2/3)
C                   + [ (alpha 0BT)1 * [(alpha 0BV)/(alpha 0BT)]1
C                      - (alpha 0BT)2/3 * [(alpha 0BV)/(alpha 0BT)]2/3]
C                   * (180 / pi)}
C     ------------------------------------------------------------
      DTE = 1.5 * (D23 + RTOD * ( A0BT1 * RA01 - A0BT23 * RA02))
C
C     The zero lift angle for the basic wing is given (in radians) by:
C     (alpha 0BW) = (alpha 0BT)1 *[(alpha 0BV)/(alpha 0BT)]1
C                   +[(alpha or)2/(delta te)] * (delta te) * (pi/180)
C     ----------------------------------------------------------------
      A0BW = A0BT1 * RA01 + AOR2 * DTE * DTOR
C
C     The zero angle lift coefficient of the basic wing is given by:
C     CL0BW = - (alpha 0BW) * (a1)
C     --------------------------------------------------------------
      CL0BW = - A0BW * LCS
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRC2(W,IW,A0BW,A0BT1,RA01,A0BF)
C     ============================================
C
C     Purpose
C     -------
C     Section c2 of the notes - calculation of zero-lift angle
C     for wing-fuselage combination
C
C     Input
C     -----
C     W          - ratio of body width to semi-span  [W/s]
C     IW         - setting angle of wing centre-line chord relative
C                 to fulselage centre linen (deg)   [iW]
C     A0BW       - zero lift angle of basic wing [alpha 0Bw] (rad)
C     A0BT1      - root (centre-line) zero lift angle [(alpha 0BT)1]
C                  (rad)
C     RA01       - zero lift angle conversion factor at root
C                  [alpha 0BV / alpha 0BT]1
C
C     Output
C     ------
C     A0BF       - wing-fuselage zero-lift angle (alpha 0Bf) (rad)
C
C     Local
C     -----
C     DA0F       - fuselage correction angle (rad) [Delta alpha 0f]
C     DTOR       - (radians) = DTOR * (degrees)
C
C     -----------------------------------------------------------------
C
      REAL W,IW,A0BW,A0BT1,RA01,A0BF
C
      REAL DA0F,DTOR
C
      DTOR = 3.141593 / 180.0
C
C     Calculate the fuselage correction angle in radians
C     (Delta alpha 0f) =
C          [1 - (1 + 0.35 * (W/s)) / (1.03 + 1.075 * (W/s))]
C         *[(pi/180) * (iW) - (alpha 0BT)1 * (alpha 0BV)/(alpha 0BT)]1]
C     -----------------------------------------------------------------
      DA0F = (1.0 - (1.0 + 0.35 * W) / (1.03 + 1.075 * W))
     *     * (DTOR * IW - A0BT1 * RA01)
C
C     Calculate the wing-fuselage zero-lift angle
C     (alpha 0Bf) = (alpha 0BW) + (Delta alpha 0f)
C     --------------------------------------------
      A0BF = A0BW + DA0F
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRC3(LCS,A0BF,CL0BF)
C     =================================
C
C     Purpose
C     -------
C     Section c3 of the notes - lift at zero angle of attack
C     for basic wing-fuselage
C
C     Input
C     -----
C     LCS    - lift-curve slope [a1]
C     A0BF   - wing-fuselage zero-lift angle (rad) [alpha 0Bf]
C
C     Output
C     ------
C     CL0BF  - lift at zero angle of attack for basic wing-fuselage
C              [CL0Bf]
C
C     -----------------------------------------------------------------
C
      REAL LCS,A0BF,CL0BF
C
      CL0BF = - A0BF * LCS
C
      RETURN
      END
C     -----------------------------------------------------------------
C
      SUBROUTINE SUBRC4(MK,RK,T,XTR,TAU,ZUG,ZLG,ZC92,
     *                  TAUA,TAUAU,A0BT,RA0,LCS0T,LCS,CL0B,FAULT)
C     ===========================================================
C
C
C     Purpose
C     -------
C     Section c4 of the notes - calculation of CL0B for basic aerofoil
C
C     Input
C     -----
C     MK        - current Mach number
C     RK        - current Reynolds number
C     T         - thickness to chord ratio [t/c]
C     XTR       - dimensionless chordwise location of boundary layer
C                 transition point [xtr/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17),  - dimensionless upper-surface and lower-surface
C     ZLG(17)     coordinates at each of 17 standard chordwise
C                 locations [(zu/c)g and (zl/c)g]
C
C     Output
C     ------
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C     TAUAU     - trailing edge angle (deg) in Sketch 1.1c  [tau au]
C     A0BT     - zero-lift angle (rad) of basic aerofoil in Section c4
C                [alpha 0BT]
C     LCS0T    - theoretical lift-curve slope of basic aerofoil
C                in Section c4 [(a1)0T]
C     RA0      - zero-lift angle conversion factor for basic aerofoil
C                in Section c4  [alpha 0BV / alpha 0BT]
C     LCS      - lift-curve slope
C     CL0B     - lift coefft. at zero angle of attack for basic
C                aerofoil (high-lift devices not deployed) [CL0B]
C     FAULT    - fault number
C
C     Local
C     -----
C     F1       - factor in formula for (a1)0T
C     BETA     - sqrt(1.0 - MK**2)
C     RLCS     - ratio of lift- curve slopes [(a1)0V / (a1)0T]
C     TN,SN    - tangent and sine of an angle
C     RTOD     - (degrees) = RTOD * (radians)
C     TOL      - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL MK,RK,T,XTR,TAU,ZUG(17),ZLG(17),ZC92,
     *     TAUA,TAUAU,A0BT,RA0,LCS0T,LCS,CL0B
C
      REAL F1,BETA,RLCS,TN,SN,RTOD,TOL
C
      TOL = 1.0E-8
      RTOD = 180.0 / 3.141593
C
C     Subroutine 6 calculates the zero-lift angle (alpha 0BT)
C     using the arrays (zu/c)g and (zl/c)g where g = 1 to 17
C     -------------------------------------------------------
      CALL SUBR06(ZUG,ZLG,A0BT)
C
C     Calculate trailing edge angles [tau a] and [tau au] in degrees
C     --------------------------------------------------------------
C     (tau a) = 2 *
C     arc tan[{[(zu/c)14 - (zl/c)14] - [(zu/c)16 - (zl/c)16]} / 0.18]
C
      TN = ((ZUG(14) - ZLG(14)) - (ZUG(16) - ZLG(16))) / 0.18
C
      SN = TN / SQRT(1.0 + TN * TN)
      TAUA = 2.0 * RTOD * ASIN(SN)
C
C     (tau au) = arc tan[[(zu/c)14 - (zu/c)16] / 0.09]
      TN = (ZUG(14) - ZUG(16)) / 0.09
      SN = TN / SQRT(1.0 + TN * TN)
      TAUAU = RTOD * ASIN(SN)
C
C     Calculate the theoretical lift-curve slope
C     ==========================================
      IF (T .LE. TOL) FAULT = 1001
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate F1 =
C     0.551 + 0.3967 * [[(zu/c)5 + (zl/c)5] / (t/c)] +0.0021 * tau
C     ------------------------------------------------------------
      F1 = 0.551 + 0.3967 * (ZUG(5) + ZLG(5)) / T + 0.0021 * TAU
C
      IF (MK .GE. 1.0) FAULT = 1002
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate beta = sqrt(1 - Mk^2)
C     -------------------------------
      BETA = SQRT(1.0 - MK * MK)
      IF (BETA .LE. TOL) FAULT = 1002
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate the theoretical lift curve slope (per radian)
C     (a1)0T = 2 * pi * (1 + F1 * (t/c)) * (1 / beta + 0.0429 * Mk)
C     -------------------------------------------------------------
      LCS0T = 2.0 * 3.141593 * (1.0 + F1 * T)*(1.0 / BETA + 0.0429 * MK)
C
C     Subroutine 1 calculates RA0 = [alpha 0BV / alpha 0BT]
C     -----------------------------------------------------
      CALL SUBR01(MK,RK,ZC92,RA0,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Subroutine 2 calculates RLCS = [(a1)0V/(a1)0T]
C     ----------------------------------------------
      CALL SUBR02(MK,RK,XTR,TAUA,TAUAU,RLCS,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate CL0B = - (alpha 0BT) * [(alpha 0BV)/(alpha 0BT)]
C                        * (a1)0T * [(a1)0V/(a1)0T]
C     ----------------------------------------------------------
      CL0B = - A0BT * RA0 *LCS0T * RLCS
C
C     Calculate the lift-curve slope as (a1)0T [(a1)0V / (a1))T]
C     ----------------------------------------------------------
      LCS = LCS0T * RLCS
C
   10 RETURN
      END
C     -----------------------------------------------------------------
C
      SUBROUTINE SUBRC5(MK,RK,T,XTR,TAU,ZU5,ZL5,TAUA,TAUAU,
     *                  LCS0T,LCS,FAULT)
C     =====================================================
C
C     Purpose
C     -------
C     Modification of Section c4 of the notes to give lift-curve slope
C     of aerofoil for CALC = 2
C
C     Input
C     -----
C     MK        - current Mach number
C     RK        - current Reynolds number
C     T         - thickness to chord ratio [t/c]
C     XTR       - dimensionless chordwise location of boundary layer
C                 transition point [xtr/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZU5,ZL5   - ordinates at x/c = 0.05 [(zu/c)5 and (zl/c)5]
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C     TAUAU     - trailing edge angle (deg) in Sketch 1.1c  [tau au]
C
C     Output
C     ------
C     LCS0T    - theoretical lift-curve slope of basic aerofoil
C                in Section c4 [(a1)0T]
C     LCS      - lift-curve slope
C     FAULT    - fault number
C
C     Local
C     -----
C     F1       - factor in formula for (a1)0T
C     BETA     - sqrt(1.0 - MK**2)
C     RLCS     - ratio of lift- curve slopes [(a1)0V / (a1)0T]
C     TOL      - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL MK,RK,T,XTR,TAU,ZU5,ZL5,TAUA,TAUAU,LCS0T,LCS
C
      REAL F1,BETA,RLCS,TOL
C
      TOL = 1.0E-8
C
C     Calculate the theoretical lift-curve slope
C     ==========================================
      IF (T .LE. TOL) FAULT = 1001
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate F1 =
C     0.551 + 0.3967 * [[(zu/c)5 + (zl/c)5] / (t/c)] +0.0021 * tau
C     ------------------------------------------------------------
      F1 = 0.551 + 0.3967 * (ZU5 + ZL5) / T + 0.0021 * TAU
C
      IF (MK .GE. 1.0) FAULT = 1002
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate beta = sqrt(1 - Mk^2)
C     -------------------------------
      BETA = SQRT(1.0 - MK * MK)
      IF (BETA .LE. TOL) FAULT = 1002
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate the theoretical lift curve slope (per radian)
C     (a1)0T = 2 * pi * (1 + F1 * (t/c)) * (1 / beta + 0.0429 * Mk)
C     -------------------------------------------------------------
      LCS0T = 2.0 * 3.141593 * (1.0 + F1 * T)*(1.0 / BETA + 0.0429 * MK)
C
C     Subroutine 2 calculates RLCS = [(a1)0V/(a1)0T]
C     ----------------------------------------------
      CALL SUBR02(MK,RK,XTR,TAUA,TAUAU,RLCS,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate the lift-curve slope as (a1)0T [(a1)0V / (a1))T]
C     ----------------------------------------------------------
      LCS = LCS0T * RLCS
C
   10 RETURN
      END
C
C     -----------------------------------------------------------------
      SUBROUTINE SUBRDD(K,FAULT)
C     ==========================
C
C     Purpose
C     -------
C     To manage the calculations of Section d of the notes:
C     Calculation of maximum lift coefficient of basic wing or aerofoil
C
C     Input and Output via Parameter List
C     ===================================
C     K     - current Mach and Reynolds number pair - input
C     FAULT - fault number (0 means "none")         - output
C
C     Input and Output via Common Blocks
C     ==================================
C     CALC      - calculation type (1 to 18)
C     ITYPE     - integer version of TYPE:
C                 1 = 'P' = program decides
C                 2 = 'M' = modern
C                 3 = 'C' = conventional
C     MSG       - message number for printout
C     MN(10),   - NMR pairs of Mach and Reynolds numbers
C     RN(10)
C     A         - aspect ratio of wing    [A]
C     TR        - taper ratio of wing     [lambda]
C     T         - thickness to chord ratio [t/c]
C     XUM,ZUM   - dimensionless chordwise location and height
C                 maximum height [xum/c and zum/c]
C     TAU       - trailing edge angle (deg) [tau]
C               - dimensionless upper-surface and lower-surface
C     ZUG(17),    coordinates at each of 17 standard chordwise
C     ZLG(17)     locations [(x/c)g, (zu/c)g and (zl/c)g]
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C     CLMB      - max. lift coefft. of basic aerofoil
C                 (high-lift devices not deployed) [CLmB]
C     CLMXB     - max. lift coefft. of basic wing (high-lift devices
C                 not deployed) [CL max B]
C                 deployed [CL0wf]
C     DCLMXF    - increment in max. lift coefft. due to fuselage
C                 [Delta CL max f]
C     CLMXBF    - max. lift coefft. of basic wing-fuselage combination
C                 [CL max Bf]
C     LDX(4)   - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     KAPPA    - kappa in Section a2
C     RXK      - Reynolds number based on cp in Section b3 [R'k]
C     RXKR     - Reynolds number based on cr in Section b4 [R'kr]
C     MUP      - peak loading in Section b5 [mu p]
C     DTE      - effective twist angle (deg) in paragrah c1 [delta te]
C     A0BTP    - zero-lift angle for section at eta p in Section d1
C                [(alpha 0BT)p]
C     LCS0P    - lift-curve slope for section at eta p in Section d1
C                ((a1)0p]
C
C     DTE      - effective twist angle
C     -----------------------------------------------------------------
C
      INTEGER K,FAULT
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      REAL           DTE
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Next line to get DTE into SUBRDD from SUBRCC
      COMMON /ZI9931/ DTE
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
C
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
      INTEGER LIST(18,3)
C
      DATA LIST /
     * 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0,13, 0, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13, 0, 0, 0, 0, 0,
     * 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 /
C
      FAULT = 0
C
C     Section d1 - calculation of CLmaxB for basic wing
C     ---------------------------------------------------
      IF (LIST(CALC,1) .GT. 0)
     *CALL SUBRD1(ITYPE,MN(K),A,TR,T,XUM,ZUM,TAU,ZUG,ZLG,
     *            LDX,RXK,RXKR,DTE,MUP,TAUA,CLMXB,A0BTP,LCS0P,
     *            MSG,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Section d2 - calculation of CLmaxBf for basic wing fuselage
C     -------------------------------------------------------------
      IF (LIST(CALC,2) .GT. 0) CALL SUBRD2(CLMXB,DCLMXF,CLMXBF)
C
C     Section d3 - calculation of CLmB for basic aerofoil
C     -----------------------------------------------------
      IF (LIST(CALC,3) .GT. 0)
     *CALL SUBRD3(ITYPE,MN(K),RN(K),T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,CLMB,
     *            MSG,FAULT)
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRD1(ITYPE,MK,A,TR,T,XUM,ZUM,TAU,ZUG,ZLG,
     *                  LDX,RXK,RXKR,DTE,MUP,TAUA,CLMXB,A0BTP,LCS0P,
     *                  MSG,FAULT)
C     =======================================================
C
C     Purpose
C     -------
C     Section d1 of the notes:
C     Calculation of maximum lift coefficient of the basic wing
C     (high-lift devices not deployed)
C
C     Input
C     -----
C     ITYPE    - integer version of TYPE (1 = 'P', 2 = 'M', 3 = 'C')
C     MK       - current Mach number
C     A        - aspect ratio [A]
C     TR        - taper ratio [lambda]
C     T        - thickness to chord ratio [t/c]
C     XUM,ZUM  - dimensionless maximum height and its location
C                [xum/c and zum/c]
C     TAU      - trailing edge angle (deg) [tau]
C     ZUG(17), - upper and lower surface heights at 17 chordwise
C     ZLG(17)    stations [(zu/c)g and (zl/c)g]
C     LDX(4)   - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     RXK,     - Reynolds numbers based on Cp and Cr
C     RXKR       [R'k and R'kr]
C     DTE      - effective twist angle (deg) [delta te]
C     MUP      - peak loading [mu p]
C     XTR2   - value of xtr
C
C     Output
C     ------
C     TAUA     - trailing edge angle (deg) in Sketch 1.1b [tau a]
C     CLMXB    - maximum lift coefft. of basic wing
C                (high-lift devices not deployed) [CL max B]
C     MSG      - message number for printout
C     FAULT    - fault number (0 means "none")
C
C     Local
C     -----
C     A0BTP    - zero lift angle for section at eta p    [(alpha 0BT)p]
C     LCS0P    - lift-curve slope for section at eta p   [(a1)0p]
C     TNTAUU   - angle of tangent to upper surface       [tan(tau u)]
C     DCLP     - lift increment at eta p                 [(Delta CL)p]
C     FS       - section type factor                     [Fs]
C     ZUSEC    - (zu/c)3 sec(Lambda0)
C     MKCOS    - Mk cos(Lambda0)
C     SWCF     - sweep correction factor  [Delta CLM / cos(Lambda0)**4]
C     RXKCOS   - R'k cos(Lambda0)**2
C     DCLR     - Reynolds number correction term         [Delta CLR]
C     DCLV     - sweep correction term                 [Delta CL Lambda]
C     TNLD50   - tan(Lambda1/2)
C     TWCF     - twist correction factor          [Delta CLt / delta te]
C     TN       - tan of an angle
C     SN       - sine of an angle
C     CS,CS2,  - cos(Lambda0), CS**2 and CS**4
C     CS4
C     DTOR,    - (degrees to radians) and (radians to degrees)
C     RTOD       conversion factors
C     TOL      - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER ITYPE,FAULT,MSG
      REAL MK,A,TR,T,XUM,ZUM,TAU,ZUG(17),ZLG(17),
     *     LDX(4),RXK,RXKR,DTE,MUP,TAUA,CLMXB
C
      REAL A0BTP,LCS0P,TNTAUU,DCLP,FS,ZUSEC,MKCOS,SWCF,
     *     RXKCOS,DCLR,DCLV,TNLD50,TWCF,TN,SN,CS,CS2,CS4,DTOR,RTOD,TOL
C
C     Next two lines bring in XTR2
      REAL XTR2
      COMMON /ZH9931/XTR2
      TOL = 1.0E-8
      DTOR = 3.141593 / 180.0
      RTOD = 180.0 / 3.141593
      FAULT = 0
C
C     Use Subroutine 6 to calculate the zero lift angle (alpha 0BT)p
C     for the section at eta p using the arrays (zu/c)g and (zl/c)g
C     with g = 1 to 17
C     --------------------------------------------------------------
      CALL SUBR06(ZUG,ZLG,A0BTP)
C
C     Calculate the trailing edge angle (tau a) in degrees
C     for the section at eta p
C     (tau a) = 2 *
C     arc tan[{[(zu/c)14 - (zl/c)14] - [(zu/c)16 - (zl/c)16]} / 0.18]
C     ---------------------------------------------------------------
C
      TN = ((ZUG(14) - ZLG(14)) - (ZUG(16) - ZLG(16))) / 0.18
C
      SN = TN / SQRT(1.0 + TN * TN)
      TAUA = 2.0 * RTOD * ASIN(SN)
C
C     Use Subroutine 5 to calculate the lift-curve slope LCS0P = (a1)0p
C     for the section at eta p using R'kr, (t/c), tau and (tau a)
C     -----------------------------------------------------------------
      CALL SUBR05(RXK,T,TAU,TAUA,LCS0P,FAULT,XTR2)
      IF (FAULT .NE. 0) GO TO 10
C
C     Next line to 'use' RXKR and avoid warning
      RXKR = RXKR + 0.
C     Calculate the upper surface angle tangent
C     TNTAUU = tan(tau u) = (zum/c) / (1 - xum/c)
C     -------------------------------------------
      IF (ABS(1.0 - XUM) .LE. TOL * ABS(ZUM)) FAULT = 1003
      IF (FAULT .NE. 0) GO TO 10
      TNTAUU = ZUM / (1.0 - XUM)
C
C     Use Subroutine 7 to calculate the lift increment
C     DCLP = (delta CL)p for the CLmax calculation using
C     R'k, (zu/c)3, (Lambda 0),tan(tau u), (Lambda 1)
C     --------------------------------------------------
      CALL SUBR07(RXK,ZUG(3),LDX(1),TNTAUU,LDX(4),DCLP,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Use Subroutine 8 to calculate the section type factor Fs
C     using R'k, (Lambda 0), (the integer version of TYPE),
C     (zu/c)14, (zl/c)14, (zu/c)17, (zl/c)17.
C     The subroutine returns Fs plus a message number MSG.
C     --------------------------------------------------------
      CALL SUBR08(RXK,LDX(1),ITYPE,ZUG(14),ZLG(14),ZUG(17),ZLG(17),FS,
     *            MSG,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Read the sweep correction factor
C     SWCF = [(Delta CLM)/cos^4(Lambda0)] from Figure 3 of Item 89034
C     using [(zu/c)3 * sec(Lambda 0)] and [Mk * cos(Lambda 0)]
C     ---------------------------------------------------------------
      CS = COS(DTOR * LDX(1))
      IF (ABS(CS) .LE. TOL) FAULT = 1004
      IF (FAULT .NE. 0) GO TO 10
      ZUSEC = ZUG(3) / CS
      MKCOS = MK * CS
      CALL FIG09A(ZUSEC,MKCOS,SWCF,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Read the Reynolds number correction term
C     DCLR = (Delta CLR) from Figure 4 of Item 89034
C     using (Lambda 0) and [R'k * cos^2(Lambda 0)]
C     ----------------------------------------------
      RXKCOS = RXK * CS * CS
      CALL FIG10A(RXKCOS,LDX(1),DCLR,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Read the sweep correction term
C     DCLV = (Delta CL Lambda) f0rom Figures 5a and 5b of Item 89034
C     using (Lambda 0) and [(zu/c)3 * sec(Lambda 0)]
C     -------------------------------------------------------------
      CALL FIG11A(LDX(1),ZUSEC,DCLV,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Read the twist correction factor TWCF = [(Delta CLt)/(delta te)]
C     from Figures 6a to 6d of Item 89034 using
C     lambda, A and tan(Lambda1/2)
C     ----------------------------------------------------------------
      TNLD50 = TAN(DTOR * LDX(3))
      CALL FIG12A(TR,A,TNLD50,TWCF,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate CLmaxB for the basic wing
C     CLmaxB = {[-(alpha 0BT)p * (a1)0p * sec(Lambda 0)
C               + (Delta CL)] * FS} / mup
C            + [(Delta CLM)/cos^4(Lambda 0)] * cos^4(Lambda 0)
C            + (Delta CLR) + (Delta CL Lambda)
C            + {(Delta CLT)/(delta et)] * (delta et)
C     --------------------------------------------------------
      IF (MUP .LE. TOL) FAULT = 1005
      IF (FAULT .NE. 0) GO TO 10
      CS2 = CS * CS
      CS4 = CS2 * CS2
      CLMXB = ( - A0BTP * LCS0P / CS + DCLP) * FS / MUP
     *      + SWCF * CS4 + DCLR + DCLV + TWCF * DTE
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRD2(CLMXB,DCLMXF,CLMXBF)
C     ======================================
C
C     Purpose
C     -------
c     Section d2 of the notes:
C     Calculation of maximum lift coefft. of basic wing-fuselage
C     combination
C
C     Input
C     -----
C     CLMXB   - max. lift coefft. of basic wing
C               (high-lift devices not deployed)             [CL max B]
C     DCLMXF  - increment in max. lift coefft. due to fuselage
C               [Delta CL max f]
C
C     Output
C     ------
C     CLMXBF  - maximum lift coefft. of basic wing-fuselage combination
C               (high-lift devices not deployed)            [CL max Bf]
C
C     -----------------------------------------------------------------
C
      REAL CLMXB,DCLMXF,CLMXBF
C
C     CLmaxBf = CLmaxB + (Delta CLmaxf)
C     ---------------------------------
      CLMXBF = CLMXB + DCLMXF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRD3(ITYPE,MK,RK,T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,CLMB,
     *                  MSG,FAULT)
C     =============================================================
C
C     Purpose
C     -------
C     Section d3 of the notes:
C     Calculation of maximum lift coefft. of basic aerofoil
C     (high-lift devices not deployed)
C
C     Input
C     -----
C     ITYPE    - integer version of TYPE (1 = 'P', 2 = 'M', 3 = 'C')
C     MK       - current Mach number
C     RK       - current Reynolds number
C     T        - thickness to chord ratio [t/c]
C     XUM,ZUM  - dimensionless maximum height and its location
C                [xum/c and zum/c]
C     TAU      - trailing edge angle (deg) [tau]
C     ZUG(17), - upper and lower surface heights at 17 chordwise
C     ZLG(17)    stations [(zu/c)g and (zl/c)g]
C     TAUA     - trailing edge angle (deg) in Sketch 1.1b [tau a]
C
C     Output
C     ------
C     CLMB     - maximum lift coefft. of basic aerofoil
C                (high-lift devices not deployed) [CLmB]
C     MSG      - message number for printout
C     FAULT    - fault number (0 means "none")
C
C     Local
C     -----
C     A0BT     - zero lift angle                         [alpha 0BT]
C     SN       - sine of an angle
C     TN       - tangent of an angle
C     LCS0G    - lift-curve slope                        [(a1)0g]
C     TNTAUU   - angle of tangent to upper surface       [tan(tau u)]
C     DCL      - lift increment                          [Delta CL]
C     FS       - section type factor                     [Fs]
C     F1,F2    - factors from Figures 6 and 7 of Item 84026
C     FM       - 1.0 - F1 * F2
C     X        - dummy parameter [either zero or (zu/c)5 - (zu/c)2]
C     RTOD     - (degrees) = RTOD * (radians)
C     TOL      -tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER ITYPE,MSG,FAULT
      REAL MK,RK,TAU,ZUG(17),ZLG(17),TAUA,CLMB,ZUM,XUM,T
C
      REAL A0BT,LCS0G,TNTAUU,DCL,FS,F1,F2,FM,X,TOL,SN,TN,RTOD
C
C     Next two lines added  to bring in XTR2
C
      REAL XTR2
      COMMON /ZH9931/XTR2
C
      RTOD = 180.0 / 3.141593
      TOL = 1.0E-8
      FAULT = 0
C
C     Use Subroutine 6 to calculate the zero lift angle (alpha 0BT)
C     for the section using the arrays (zu/c)g and (zl/c)g
C     with g = 1 to 17
C     -------------------------------------------------------------
      CALL SUBR06(ZUG,ZLG,A0BT)
C
C     Calculate the trailing edge angle (tau a) in degrees
C     (tau a) = 2 *
C     arc tan[{[(zu/c)14 - (zl/c)14] - [(zu/c)16 - (zl/c)16]} / 0.18]
C     ---------------------------------------------------------------
C
      TN = ((ZUG(14) - ZLG(14)) - (ZUG(16) - ZLG(16))) / 0.18
C
      SN = TN / SQRT(1.0 + TN * TN)
      TAUA = 2.0 * RTOD * ASIN(SN)
C
C     Use Subroutine 5 to calculate the lift-curve slope
C     LCS0G = (a1)og using Rk, (t/c), tau and (tau a)
C     --------------------------------------------------
      CALL SUBR05(RK,T,TAU,TAUA,LCS0G,FAULT,XTR2)
      IF (FAULT .NE. 0) GO TO 10
C
C     The upper surface angle TNTAUU = tan(tau u)is given by
C     tan(tau u) = (zum/c) / (1 - xum/c)
C     ------------------------------------------------------
      IF (ABS(1.0 - XUM) .LE. TOL * ABS(ZUM)) FAULT = 1006
      IF (FAULT .NE. 0) GO TO 10
      TNTAUU = ZUM / (1.0 - XUM)
C
C     Subroutine 7 gives the correction (Delta CL) using the parameters
C     Rk, (zu/c)3, 0, tan(tau u) and 0
C     -----------------------------------------------------------------
      X = 0.0
      CALL SUBR07(RK,ZUG(3),X,TNTAUU,X,DCL,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Subroutine 8 gives the factor Fs and a message number MSG
C     for the parameters Rk, 0, (the integer version of TYPE),
C     (zu/c)14, (zl/c)14, (zu/c)17 and (zl/c)17)
C     ---------------------------------------------------------
      X = 0.0
      CALL SUBR08(RK,X,ITYPE,ZUG(14),ZLG(14),ZUG(17),ZLG(17),FS,
     *            MSG,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Read F1 from Figure 6 of Item 84026
C     -----------------------------------
      CALL FIG08A(MK,F1,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Read F2 from Figure 7 of Item 84026
C     -----------------------------------
      X = ZUG(5) - ZUG(2)
      CALL FIG07A(X,F2,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Fm is given by:
C     ---------------
      FM = 1.0 - F1 * F2
C
C     CLmB is given by the formula
C     CLmB = [- (alpha 0BT) * (a1)og + (Delta CL)] * Fs * FM
C     ------------------------------------------------------
      CLMB = (DCL - A0BT * LCS0G) * FS * FM
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBREE(JL,JT,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Section e
C     Calculation of additional geometric parameters for high-lift
C     systems, including fuselage interference
C
C     Input
C     -----
C     JL          - current leading-edge device setting number
C     JT          - current trailing-edge device setting number
C
C     Output
C     ------
C     FAULT       - fault number
C
C     Input from Common Blocks
C     ------------------------
C     CALC        - calculation type
C     INT         - flag on fuselage effect on trailing edge
C                   (0 means "neglect", 1 means "include")
C     NDL         - number of leading-edge device settings  [N delta l]
C     NDT         - number of trailing-edge device settings [N delta t]
C     NNL         - number of leading-edge devices
C     NNT         - number of trailing-edge devices
C     NTJ(5)      - trailing-edge device types  [(Nt)j]
C     NL          - device type of leading edge panel [Nl]
C     NT          - device type of trailing-edge panel [Nt]
C     CSL         - flag = 1
C     CST         - flag = 1
C     W           - ratio of body width to semi-span [W/s]
C     H           - (wing height) / (fuselage height)  [h/H]
C     EILP        - inboard edge of leading-edge panel
C                   as a fraction of semi-span [(eta il)p] NOT USED
C     EITP        - outboard edge of leading-edge panel
C                   as a fraction of semi-span [(eta it)p] NOT USED
C     CXL(10)     - leading-edge extended chord [c'l/c]
C     DCL(10)     - chord extension of leading-edge device
C                   [Delta cl / c]
C     DCT(3,10)   - chord extensions of up to 3 elements of trailing
C                   edge device [Delta ct / c]
C     CT(3)       - flap chord / c of up to 3 elements of trailing-edge
C                   device  [cti/c]
C     XTS         - location of flap shroud trailing edge [xts/c]
C     DCLJ(5,10)  - leading-edge extensions  [(Delta cl / c)j]
C     DCTJ(3,5,10)- trailing-edge extensions [(Delta ct / c)j]
C     CTJ(3,5)    - flap chords for up to 3 elements in 5 devices
C                   [(ct/c)j]
C     XTSJ(5)     - chordwise locations of flap shroud trailing edges
C                   [(xts/c)j]
C     EIL(5)      - spanwise positions of leading-edge panels
C                   as fractions of semi-span  [(eta il)j]
C     EIT(5)      - spanwise positions of trailing-edge panels
C                   as fractions of semi-span  [(eta it)j]
C
C     Output to Common Blocks
C     -----------------------
C     CXCL        - extended chord / chord with leading edge
C                   extended  [(c'/c)l]
C     CXCT        - extended chord / chord with trailing edge
C                   extended  [(c'/c)t]
C     CXC         - extended chord / chord  with both leading
C                   and trailing edges extended [c'/c]
C     CXCLJ(5)    - extended chords / chords with leading edges
C                   extended [((c'/c)l)j]
C     CXCTJ(5)    - extended chords / chords with trailing edges
C                   extended [((c'/c)t)j]
C     CXCTMJ(5)   - extended chord /chord for trailing edge maximum lift
C                   calculation [(c'/c)m]
C     CXCM        - extended chord /chord for leading edge maximum lift
C                   calculation [(c'/c)m]
C     CELCXM      - (cel/c')m for maximum lift calculation
C     EILPEF      - effective spanwise position of inboard edge
C                   of leading-edge device
C                   as a proportion of semi-span [(eta il)p eff]
C     EITPEF      - effective spanwise position of inboard edge
C                   of trailing-edge device
C                   as a proportion of semi-span [(eta it)p eff]
C     EIL1EF      - effective spanwise position of inboard edge
C                   of innermost leading-edge device as a proportion
C                   of semi-span [(eta il)1 eff]
C     EIT1EF      - effective spanwise position of inboard edge
C                   of innermost trailing-edge device as a proportion
C                   of semi-span [(eta it)1 eff]
C     NTLJ(5)     - integer denoting trailing edge flap type
C                   aft of leading edge device [(Ntl)j]
C     NLTJ(5)     - integer denoting leading edge flap type
C                   forward of trailing edge device [(Ntt)j]
C     -----------------------------------------------------------------
C
      INTEGER JL,JT,FAULT
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
      INTEGER NTLJ ,NLTJ
C     to get NTLJ into  SUBRHH
      COMMON /ZL9931/ NTLJ(5)
C     to get NLTJ into SUBRII
      COMMON /ZM9931/ NLTJ(5)
C
      REAL    CXCTMJ
C     to get CXCTMJ into SUBRII
      COMMON /ZN9931/ CXCTMJ(5)
C
C
      FAULT = 0
C
C     Section e1: calculation of extended chords for aerofoil
C     -----------------------------------------------------------------
      IF (CALC .LE. 6) THEN
      CALL SUBRE1(NDL,NDT,NL,NT,DCL(JL),DCT(1,JT),CT,XTS,CXCL,CXCT,CXC)
      END IF
C
C     Section e2: calculation of extended chords
C     --------------------------------------------

      IF (CALC .GT. 6) THEN
C
      CALL SUBRE2(CALC,NDL,NDT,NNL,NNT,NTJ,NLJ,CSL,CST,CXLJ(1,JL),
     *                  DCLJ(1,JL),DCTJ(1,1,JT),CTJ,XTSJ,CXCL,CXCT,
     *                  CXCLJ,CXCTJ,CXCM,CELCXM,FAULT,EIL,EOL,EIT,EOT,
     +                  CXCTMJ,NTLJ,NLTJ)
      IF (FAULT .NE. 0) GO TO 10
      END IF
C~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
C
C     Section e3: calculation of extended chords for maximum lift calc
C     -----------------------------------------------------------------
C
      CALL SUBRE3(CALC,INT,W,H,EIL,EIT,
     *            EILPEF,EITPEF,EIL1EF,EIT1EF)
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRE1(NDL,NDT,NL,NT,DCL,DCT,CT,XTS,CXCL,CXCT,CXC)
C     =============================================================
C
C     Purpose
C     -------
C     Section e1 of the notes:
C     calculation of extended chords for basic
C     aerofoil
C     (These chords are used in calculation of Delta CL0, Delta CLm,
C      Delta CLmax (but NOT Delta CL0W))
C
C     Input
C     -----
C     NDL         - number of leading-edge device settings  [N delta l]
C     NDT         - number of trailing-edge device settings [N delta t]
C     NL          - device type of leading edge panel that contains
C                   [Nl]
C     NT          - device type of trailing-edge panel that contains
C                   [Nt]
C     DCL         - current chord extension of leading-edge device
C                   [delta Cl]
C     DCT(3)      - current chord extensions of 3 elements of trailing
C                   edge device [Delta cti]
C     CT(3)       - flap chord / c of up to 3 elements of trailing-edge
C                   device  [cti/c]
C     XTS         - location of flap shroud trailing edge [xts/c]
C
C     Output
C     ------
C     CXCL        - extended chord / chord with leading edge
C                   extended  [(c'/c)l]
C     CXCT        - extended chord / chord with trailing edge
C                   extended  [(c'/c)t]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     Local
C     -----
C     J           - trailing flap element number
C     NELTS       - number of trailing flap elements
C
C     Method
C     ------
C     The subroutine follows the notes in Section e1
C
C     -----------------------------------------------------------------
C
      INTEGER NDL,NDT,NL,NT
      REAL DCL,DCT(3),CT(3),XTS,CXCL,CXCT,CXC
C
      INTEGER J,NELTS
C
C     Calculate (c'/c)l
C     -----------------
C     (c'/c)l is at least 1.0
      CXCL = 1.0
C     But if (N delta l) exceeds 0 and Nl exceeds 0 then
C     (c'/c)l = 1.0 + (Delta Cl/c)
      IF (NDL .NE. 0 .AND. NL .NE. 0) CXCL = 1.0 + DCL
C
C     Calculate (c'/c)t
C     -----------------
C     (c'/c)t is at least 1.0
      CXCT = 1.0
C     But if (N delta t) exceeds 0 and Nt exceeds 0 then
      IF (NDT .NE. 0 .AND. NT .NE. 0) THEN
       IF (NT .LE. 2) THEN
C       If Nt is 1 or 2, (c'/c)t = 1.0 + (Delta ct/c)
        CXCT = 1.0 + DCT(1)
       ELSE
C       Otherwise (i.e. If Nt = 3 or 4 or 5) the trailing edge device
C       has Nelts = Nt - 2 elements and (c'/c)t is given by
C       (c'/c)t = (xts/c) + Sigma(ctj/c) for j = 1 to Nelts
        NELTS = NT - 2
        CXCT = XTS
        DO 10 J = 1,NELTS
        CXCT = CXCT + CT(J) + DCT(J)
   10   CONTINUE
       END IF
      END IF
C
C      Calculate CXC = (c'/c)
C      (c'/c) = (c'/c)l + (c'/c)t - 1.0
C      --------------------------------
      CXC = CXCL + CXCT - 1.0
C
      RETURN
      END
C     -----------------------------------------------------------------
C
      SUBROUTINE SUBRE2(CALC,NDL,NDT,NNL,NNT,NTJ,NLJ,CSL,CST,CXLJ,
     *                  DCLJ,DCTJ,CTJ,XTSJ,CXCL,CXCT,
     *                  CXCLJ,CXCTJ,CXCM,CELCXM,FAULT,EIL,EOL,EIT,EOT,
     *                  CXCTMJ,NTLJ,NLTJ)
C     ==========================================================
C
C     Purpose
C     -------
C     Section e2 - calculation of extended chords
C
C     Input
C     -----
C     CALC        - calculation type
C     NDL         - number of leading-edge device settings  [N delta l]
C     NDT         - number of trailing-edge device settings [N delta t]
C     NNL         - number of leading-edge devices
C     NNT         - number of trailing-edge devices
C     NTJ(5)      - trailing-edge device types  [(Nt)j]
C     NL          - device type of leading edge panel [Nl]
C     CSL         - flag = 1
C     CST         - flag = 1
C     CXL         - current leading-edge extended chord [c'l/c]
C     DCLJ(5)     - current leading-edge extensions  [(Delta cl / c)j]
C     DCTJ(3,5)   - current trailing-edge extensions [(Delta ct / c)j]
C     CTJ(3,5)    - flap chords for up to 3 elements in 5 devices
C                   [(ct/c)j]
C     XTSJ(5)     - chordwise locations of flap shrout trailing edges
C                   [(xts/c)j]
C     CXCL        - extended chord / chord  with leading edge
C                   extended  [(c'/c)l]
C     CXCT        - extended chord / chord  with trailing edge
C                   extended  [(c'/c)t]
C     CXC         - extended chord / chord  with both leading
C                   and trailing edges extended [c'/c]
C
C     Output
C     ------
C     CXCLJ(5)    - extended chords / chords with leading edges
C                   extended [((c'/c)l)j]
C     CXCTJ(5)    - extended chords / chords with trailing edges
C                   extended [((c'/c)t)j]
C     CXCM        - extended chord / chord for leading edge maximum lift
C                   calculation [(c'/c)m]
C     CXCTMJ(5)   - extended chord / chord in trailing edge maximum lift
C                   calculation
C     CELCXM      - (cel/c')m for maximum lift calculation
C     FAULT       - fault number
C
C     Local
C     -----
C     NE          - number of elements in trailing-edge device
C     I           - element number
C     J           - trailing-edge panel number
C     LIST(18,2)  - flags on calculations to be performed for
C                   various calculation types
C     TOL         - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER CALC,NDL,NDT,NNL,NNT,NTJ(5),NLJ(5),CSL,CST,FAULT
C
      REAL CXLJ(5),DCLJ(5),DCTJ(3,5),CTJ(3,5),XTSJ(5),
     *     CXCL,CXCT,CXCLJ(5),CXCTJ(5),CXCM,CELCXM
C
      INTEGER I,J,NE,LIST(18,2)
      REAL TOL
      REAL EIL(5),EOL(5),EIT(5),EOT(5),DCLTJ(5),DCTLJ(5),CXCTMJ(5)
      INTEGER NTLJ(5),NLTJ(5)
C
      DATA LIST /
     * 0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0 /
C
      FAULT = 0
      TOL = 1.0E-8
C
      IF (LIST(CALC,1) .LE. 0) GO TO 40
C
C     Section e2i
C     =============
C     Calculation of extended chords at mid-span of each flap panel
C     for the calculation of Delta CL0w
C     -------------------------------------------------------------
C
C     If CSL = 0 then ((c'/c)l)1 = (c'/c)l
      IF (CSL .EQ. 0) CXCLJ(1) = CXCL
C     If CST = 0 then ((c'/c)l)1 = (c'/c)t
      IF (CST .EQ. 0) CXCTJ(1) = CXCT
C
      IF (CSL .NE. 0 .AND. NDL .GT. 0 .AND. NNL .GT. 0) THEN
C      If CSL > 0 and (N delta l) > 0 and Nnl > 0 then
C      ((c'/c)l)j = 1 + (Delta Cl/c)j for j = 1 to Nnl
       DO 10 J = 1,NNL
       CXCLJ(J) = 1.0 + DCLJ(J)
   10  CONTINUE
      END IF
C
      IF (CST .NE. 0 .AND. NDT .GT. 0 .AND. NNT .GT. 0) THEN
C      If CST > 0 and (N delta t) > 0 and Nnt > 0 then
C      take each trailing-edge device in turn
       DO 30 J = 1,NNT
       IF (NTJ(J) .LE. 2) THEN
C       For (Nt)j = 1 or 2
C       ((c'/c)t)j = 1 + (Delta ct/c)j
        CXCTJ(J) = 1.0 + DCTJ(1,J)
       ELSE
C       For (Nt)j = 3 or 4 or 5
C       The trailing-edge device has NE = (Nt)j - 2 elements
C       and ((c'/c)t)j = (xts/c)j + Sigma[(cti/c)j + (Delta cti/c)j]
C       for i = 1 to NE
        NE = NTJ(J) - 2
        CXCTJ(J) = XTSJ(J)
        DO 20 I = 1,NE
        CXCTJ(J) = CXCTJ(J) + CTJ(I,J) + DCTJ(I,J)
   20   CONTINUE
       END IF
   30  CONTINUE
      END IF
C
   40 IF (LIST(CALC,2) .LE. 0) GO TO 50
C
C     Section e2ii
C     ==============
C     Calculation of extended chords for maximum lift calculations
C     ------------------------------------------------------------
C     (Note only one l.e.device possible,
C      although some variables are set as arrays)
C
      IF (NDT .EQ. 0) THEN
          CXCM = CXCLJ(1)
      END IF
C
      IF (NDL .EQ. 0) THEN
         DO 555 J = 1,NNT
          CXCTMJ(J) = CXCTJ(J)
          NLTJ(J) = 0
  555 CONTINUE
      END IF
C
      DCLTJ(1) = 0.0
      NTLJ(1)  = 0
C
      IF (NDT .NE. 0 .AND. NDL .NE. 0) THEN
      DO 551 I=1,NNT
         IF ( (EIL(1) + EOL(1))/2.0 .GT. EIT(I)
     +  .AND.  (EIL(1) + EOL(1))/2.0  .LT. EOT(I) ) THEN
                  DCLTJ(1) = CXCTJ(I) - 1.0
                  NTLJ(1) = NTJ(I)
C             ELSE
C                   DCLTJ(1) = 0.0
C                   NTLJ(1) = 0
           END IF
  551 CONTINUE
      CXCM = CXCLJ(1) + DCLTJ(1)
C
      DO 556 I = 1,NNT
          DCTLJ(I) = 0.0
  556 CONTINUE
      DO 552 I = 1,NNT
      DO 553 J = 1,NNL
         IF ( (EIT(I) + EOT(I))/2.0 .GT. EIL(J)
     +  .AND.  (EIT(I) + EOT(I))/2.0  .LT. EOL(J) ) THEN
                  DCTLJ(I) = CXCLJ(J) - 1.0
                  NLTJ(I) = NLJ(J)
         END IF
  553 CONTINUE
  552 CONTINUE
      DO 554 I = 1,NNT
          CXCTMJ(I) = CXCTJ(I) + DCTLJ(I)
  554 CONTINUE
      END IF
C
C
      IF (NDL .NE. 0) THEN
        IF (ABS(CXCM) .LE. TOL) FAULT = 1007
C
      IF (NLJ(1) .LE. 4) THEN
C      For Nl = 1 to 4
C      (c'/c)m = (c'/c) and
C      (cel/c')m = (c'l/c) / (c'/c)
C
        CELCXM = CXLJ(1) / CXCM
      ELSE
C
C      For Nl = 5 or 6
C      (c'/c)m = (c'/c) and
C      (cel/c')m = [(cl/c) / (c'/c)
C      For Nl = 5 or 6, CXL = (cl/c)
C       CELCXM = CXL / CXC
        CELCXM = CXLJ(1) / CXCM
C
      END IF
C
      END IF
C
   50 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRE3(CALC,INT,W,H,EIL,EIT,
     *                  EILPEF,EITPEF,EIL1EF,EIT1EF)
C     =================================================
C
C     Purpose
C     -------
C     Section e3
C     Calculation of fuselage effect on device effectiveness
C     (The fuselage effect is modelled by adding an inboard
C      extension to the innermost panels.)
C
C     Input
C     -----
C     CALC        - calculation type
C     INT         - flag on fuselage effect on trailing edge
C                   (0 means "neglect", 1 means "include")
C     W           - ratio of body width to semi-span [W/s]
C     H           - (wing height) / (fuselage height)  [h/H]
C     EILP        - inboard edge of leading-edge panel
C                   as a fraction of semi-span [(eta il)p] NOT USED
C     EITP        - outboard edge of leading-edge panel
C                   as a fraction of semi-span [(eta it)p] NOT USED
C     EIL(5)      - spanwise positions of leading-edge panels
C                   as fractions of semi-span  [(eta il)j]
C     EIT(5)      - spanwise positions of trailing-edge panels
C                   as fractions of semi-span  [(eta it)j]
C
C     Output
C     ------
C     EILPEF      - effective spanwise position of inboard edge
C                   of leading-edge device
C                   as a proportion of semi-span [(eta il)p eff]
C     EITPEF      - effective spanwise position of inboard edge
C                   of trailing-edge device
C                   as a proportion of semi-span [(eta it)p eff]
C     EIL1EF      - effective spanwise position of inboard edge
C                   of innermost leading-edge device as a proportion
C                   of semi-span [(eta il)1 eff]
C     EIT1EF      - effective spanwise position of inboard edge
C                   of innermost trailing-edge device as a proportion
C                   of semi-span [(eta it)1 eff]
C
C     Local
C     -----
C     DEI         - effective inward shift of inner edge of device
C                   as a proportion of semi-span
C                   [(Delta eta il)p or (Delta eta it)p or
C                    (Delta eta il)p or (Delta eta it)p]
C     LIST(18,4)  - flags on calculations to be performed for
C                   the various calculation types
C
C     -----------------------------------------------------------------
C
      INTEGER CALC,INT
      REAL W,H,EIL(5),EIT(5),EILPEF,EITPEF,EIL1EF,EIT1EF
C
      INTEGER LIST(18,4)
      REAL DEI
C
      DATA LIST /
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     * 0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18 /
C
      IF (LIST(CALC,3) .GT. 0) THEN
C      Section e3iii - innermost leading edge panel
C      ----------------------------------------------
C      Assume that DEI = (Delta eta il)1 = 0.0
       DEI = 0.0
C      But if CALC > 12, Subroutine 12 gives DEI = (Delta eta il)1
       IF (CALC .GT. 12) CALL SUBR12(EIL(1),W,DEI)
C      then (eta il)1eff = (eta il)1 - (Delta eta il)1
       EIL1EF = EIL(1) - DEI
C      Set for later calls
       EILPEF = EIL1EF
      END IF
C
      IF (LIST(CALC,4) .GT. 0) THEN
C      Section e3iv - innermost trailing edge panel
C      ----------------------------------------------
C      Assume that DEI = (Delta eta it)1 = 0.0
       DEI = 0.0
C      But if CALC > 12 and INT = 1 then Subroutine 13 gives
C      DEI = (Delta eta it)1
       IF (CALC .GT. 12 .AND. INT .EQ. 1) CALL SUBR13(EIT(1),W,H,DEI)
C      then (eta it)1eff = (eta it)1 - (Delta eta it)1
       EIT1EF = EIT(1) - DEI
C      Set for later calls
       EITPEF = EIT1EF
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRFF(JL,FAULT)
C     ===========================
C
C     Purpose
C     -------
C     Sections f and F2 of the notes:
C     Calculation of leading-edge device increments in CL0
C
C     Input
C     -----
C     JL     - current leading edge device setting number
C
C     Output
C     ------
C     FAULT  - fault number (0 means "none")
C
C     Input from Common Blocks
C     ------------------------
C     CALC   - calculation type (1 to 18)
C     NDL    - number of leading edge device settings (0<=NDL<=10)
C     NNL    - number of leading-edge device panels (0<=NNL<=5)
C     NLJ(5) - leading-edge device types   [(Nl)j]
C     NL     - device type of leading-edge panel containing ETAP    [Nl]
C     DL(10)     - NDL deflection angles (deg)       [delta l]
C     CXL(10)    - NDL leading edge extended chords  [c'l/c]
C     EIL(5),    - positions of inner and outer edges of NNL leading
C     EOL(5)       edge panels                 [(eta il)j and (eta ol)j]
C     DLJ(5,10)  - NNL*NDL deflection angles [(delta l)j]
C     CXLJ(5,10) - NNL*NDL extended chords   [(c'l / c)j]
C     LCS        - lift-curve slope in Section b1 [a1]
C     EB         - spanwise centre of pressure in Section b2 [eta bar]
C     CXC        - extended chord / chord with both leading
C                  and trailing edges extended [c'/c]
C     CXCLJ(5)   - extended chords / chords with leading edges
C                  extended [((c'/c)l)j]
C     EIL1EF     - effective spanwise position of inboard edge
C                  of innermost leading-edge device as a proportion
C                  of semi-span [(eta il)1 eff]
C
C     Output to Common Blocks
C     -----------------------
C     DCL0L       - increment in aerofoil lift coefficient at zero angle
C                   of attack due to deployment of leading-edge device
C                   [Delta CL0l]
C     DC0LWJ(NNL) - increments in wing lift coefft. at zero angle of
C                   attack due to NNL leading-edge devices
C                   [(Delta CL0lw)j]
C     DCL0LW      - increment in wing lift coefft. at zero angle of
C                   attack due to leading-edge devices [Delta CL0lw]
C
C     -----------------------------------------------------------------
C
      INTEGER JL,FAULT
      INTEGER J
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
C
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
      FAULT = 0
C
      DCL0L = 0.0
      DCL0LW = 0.0
      DO 10 J = 1,5
      DC0LWJ(J) = 0.0
   10 CONTINUE
      IF (NDL .EQ. 0) GO TO 20
C
      IF (CALC .GT. 6) THEN
       CALL SUBRF1(NNL,NLJ,EIL,EOL,DLJ(1,JL),CXLJ(1,JL),
     *             LCS,EB,CXCLJ,EIL1EF,DC0LWJ,DCL0LW,FAULT)
      ELSE
       CALL SUBRF2(NL,DL(JL),CXL(JL),CXC,DCL0L,FAULT)
      END IF
C
   20 RETURN
      END
C     -----------------------------------------------------------------
C
      SUBROUTINE SUBRF1(NNL,NLJ,EIL,EOL,DLJ,CXLJ,
     *                  LCS,EB,CXCLJ,EIL1EF,DC0LWJ,DCL0LW,FAULT)
C     ==========================================================
C
C
C     Purpose
C     -------
C     Section f:
C     Calculation of leading-edge device increments [Delta CL0lw]
C     for wings
C     (This is the summation of the contribution of Nnl panels)
C
C     Input
C     -----
C     NNL        - number of leading-edge device panels (0<=NNL<=5)
C     NLJ(5)     - leading-edge device types   [(Nl)j]
C     EIL(5),    - positions of inner and outer edges of NNL leading
C     EOL(5)       edge panels                 [(eta il)j and (eta ol)j]
C     DLJ(5)     - NNL deflection angles [(delta l)j]
C     CXLJ(5)    - NNL extended chords   [(c'l / c)j]
C     LCS        - lift-curve slope in Section b1 [a1]
C     EB         - spanwise centre of pressure in Section b2 [eta bar]
C     CXCLJ(5)   - extended chords / chords with leading edges
C                  extended [((c'/c)l)j]
C     EIL1EF     - effective spanwise position of inboard edge
C                  of innermost leading-edge device as a proportion
C                  of semi-span [(eta il)1 eff]
C
C     Output
C     ------
C     DC0LWJ(NNL) - increments in wing lift coefft. at zero angle of
C                   attack due to NNL leading-edge devices
C                   [(Delta CL0lw)j]
C     DCL0LW      - increment in wing lift coefft. at zero angle of
C                   attack due to leading-edge devices [Delta CL0lw]
C     FAULT       - fault number (0 means "none")
C
C     Local
C     -----
C     J           - device number
C     CXC0        - ((c'/c)l)j
C     CELCX0      - fraction of CXC0 in accordance with the notes
C     K0          - factor given in the notes
C     DCL0L2      - [Delta C'L0l]2 given in the notes as 0.0
C     DCL0LG      - [Delta CL0l]gen output Subroutine 3
C     PHIOJ       - reading from Figure 3 of Item 93019 [Phi oj]
C     PHIIJ       - reading from Figure 3 of Item 93019 [Phi ij]
C     ETA         - fraction of semi-span [eta]
C     TOL         - tolerance
C     CLCJ        - for Nl = 5 or 6 (c'l/c)j = (cl/c)j = CLCJ
C
C     -----------------------------------------------------------------
C
      INTEGER NNL,NLJ(5),FAULT
      REAL EIL(5),EOL(5),DLJ(5),CXLJ(5),LCS,EB,CXCLJ(5),EIL1EF,
     *     DC0LWJ(5),DCL0LW
C
      INTEGER J
      REAL CXC0,CELCX0,K0,DCL0L2,DCL0LG,PHIOJ,PHIIJ,ETA,TOL,CLCJ
C
      TOL = 1.0E-8
      FAULT = 0
C
      DCL0LW = 0.0
      DO 5 J = 1,5
      DC0LWJ(J) = 0.0
    5 CONTINUE
C
      IF (NNL .EQ. 0) GO TO 60
C
C     Take each leading-edge device in turn
C     =====================================
      DO 50 J = 1,NNL
C
C     (c'/c)0 = ((c'/c)l)j and [Delta C'L0l]2 = 0 are always the same.
C     ----------------------------------------------------------------
      CXC0 = CXCLJ(J)
      DCL0L2 = 0.0
      IF (ABS(CXC0) .LE. TOL) FAULT = 1008
      IF (FAULT .NE. 0) GO TO 60
C
C     The other parameters of Subroutine 3 depend on the device type.
C     ---------------------------------------------------------------
      GO TO (10,10,20,20,30,30), NLJ(J)
C
C     Device types 1 and 2
C     --------------------
C     (cel/c')0 = (c'l/c)j / ((c'/c)l)j
   10 CELCX0 = CXLJ(J) / CXCLJ(J)
      K0 = 1.0
      GO TO 40
C
C     Device  types 3 and 4
C     ---------------------
C     (cel/c')0 = (c'l/c)j / ((c'/c)l)j
   20 CELCX0 = CXLJ(J) / CXCLJ(J)
      K0 = 1.8
      GO TO 40
C
C
C     Device types 5 and 6
C     --------------------
C     (cel/c')0 = (cl/c)j / (c'/c)l)j
   30 CLCJ = CXLJ(J)
      CELCX0 = CLCJ / CXCLJ(J)
      K0 = 1.35
      GO TO 40
C
C
C     Subroutine 3 gives [Delta CL0l]gen for the governing parameters
C     (c'/c)0, (cel/c')0, K0, [Delta C'L0l]2 and (delta l)j
C     ---------------------------------------------------------------
   40 CALL SUBR03(CXC0,CELCX0,K0,DCL0L2,DLJ(J),DCL0LG,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Figure 3 of Item 93019 with eta = (eta ol)j gives Phi oj
C     --------------------------------------------------------
      ETA = EOL(J)
      CALL FIG13A(EB,ETA,PHIOJ,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Figure 3 of Item 93019 also gives Phi ij but with an eta
C     that treats the innermost device specially
C     --------------------------------------------------------
      IF (J .EQ. 1) THEN
C      eta = (eta il)1eff
       ETA = EIL1EF
      ELSE
C      eta = (eta il)j
       ETA = EIL(J)
      END IF
C
      CALL FIG13A(EB,ETA,PHIIJ,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Calculate (Delta CL0lw)j =
C     (a1)/(2*pi) * [Delta CL0l]gen * [(Phi oj) -(Phi ij)]
C     ----------------------------------------------------
      DC0LWJ(J) = (0.5 / 3.141593) * LCS * DCL0LG * (PHIOJ - PHIIJ)
C
C     Accumulate (Delta CL0lw)j in Delta CL0lw
C     (Delta CL0lw) = Sigma(Delta CL0lw)j for j = 1 to Nnl
C     ---------------------------------------------------
      DCL0LW = DCL0LW + DC0LWJ(J)
C
   50 CONTINUE
C
   60 RETURN
      END
C     -----------------------------------------------------------------
C
      SUBROUTINE SUBRF2(NL,DL,CXL,CXC,DCL0L,FAULT)
C     ============================================
C~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
C
C     Purpose
C     -------
C     Section F2:
C     Calculation of leading-edge device increment for aerofoil
C     [Delta CL0l]
C
C     Input
C     -----
C     NL        - device type of leading-edge panel containing ETAP [Nl]
C     DL        - deflection angle (deg)       [delta l]
C     CXL       - leading edge extended chord  [c'l/c]
C     CXC       - extended chord / chord with both leading
C                 and trailing edges extended [c'/c]
C
C     Output
C     ------
C     DCL0L     - increment in aerofoil lift coefficient at zero angle
C                 of attack due to deployment of leading-edge device
C                 [Delta CL0l]
C     FAULT     - fault number (0 means "none")
C
C     Local
C     -----
C     CXC0        - (c'/c)
C     CELCX0      - fraction of CXC0 in accordance with the notes
C     LAMBDA      - sweep-back Lambda = 0.0
C     DLCOS       - [(delta l)*cos(Lambda)]]
C     KL          - factor Kl read from Figure 1a of Item 94027
C     K0          - factor given in the notes
C     DCL0L2      - [Delta C'L0l]2 given in the notes as 0.0
C     DCL0LG      - [Delta CL0l]gen output Subroutine 3
C     TOL         - tolerance
C     CLC         - for Nl = 5 and 6 CXL = (cl/c) = CLC
C
C     -----------------------------------------------------------------
C
      INTEGER NL,FAULT
      REAL DL,CXL,CXC,DCL0L
C
      REAL CXC0,CELCX0,LAMBDA,DLCOS,KL,K0,DCL0L2,DCL0LG,TOL,CLC
C
      TOL = 1.0E-8
      FAULT = 0
      DCL0L = 0.0
C
C     (c'/c)0 = (c'/c) is always the same
C     -----------------------------------
      CXC0 = CXC
      IF (ABS(CXC) .LE. TOL) FAULT = 1009
      IF (FAULT .NE. 0) GO TO 50
C
C     Other parameters of Subroutine 3 depend on the device type
C     ==========================================================
      GO TO (10,10,20,20,30,30), NL
C
C     Device types 1 and 2
C     --------------------
C     (cel/c')0 = (c'l/c) / (c'/c)
   10 CELCX0 = CXL / CXC
C     Lambda = 0.0
      LAMBDA = 0.0
      LAMBDA = LAMBDA + 0.0
C     (delta l)*cos(Lambda) = (delta l)
      DLCOS = DL
C     Figure 1a of Item 94027 gives Kl
      CALL FIG14A(DLCOS,KL,FAULT)
      IF (FAULT .NE. 0) GO TO 50
C     then
      K0 = 1.0 / KL
C     [Delta C'L0l]2 = 0.0
      DCL0L2 = 0.0
      GO TO 40
C
C     Device types 3 and 4
C     --------------------
C     (cel/c')0 = (c'l/c) / (c'/c)
   20 CELCX0 = CXL / CXC
      K0 = 1.8
C     [Delta C'L0l]2 = 0.0
      DCL0L2 = 0.0
      GO TO 40
C
C
C     Device types 5 and 6
C     --------------------
C     (cel/c')0 = (cl/c) / (c'/c)
   30 CLC = CXL
      CELCX0 = CLC / CXC
      K0 = 1.35
C     [Delta C'L0l]2 = 0.03
      DCL0L2 = 0.03
      GO TO 40
C
C
C     Subroutine 3 gives [Delta CL0l]gen for the governing parameters
C     (c'/c)0, (cel/c')0, K0, [Delta C'L0l]2 and (delta l)
C     ===============================================================
C
   40 CALL SUBR03(CXC0,CELCX0,K0,DCL0L2,DL,DCL0LG,FAULT)
C
C
C     In all cases (Delta CL0l) = [Delta CL0l]gen
      DCL0L = DCL0LG
C
   50 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRGG(K,JT,FAULT)
C     =============================
C
C     Purpose
C     -------
C     To supply data for and store the results of Sections g and G2:
C     Calculation of trailing-edge flap increments,
C     Delta CL0tw or Delta CL0t
C
C     Input
C     -----
C     K       - current Mach and Reynolds number pair
C     JT      - current trailing-edge device setting
C
C     Output
C     ------
C     FAULT   - fault number (0 means "none")
C
C     Input from Common Blocks
C     ------------------------
C     CALC   - calculation type (1 to 18)
C     NDT    - number of trailing-edge device settings (0<=NDT<=10)
C     NNL    - number of leading-edge device panels (0<=NNL<=5)
C     NNT    - number of trailing-edge device panels (0<=NNT<=5)
C     NTJ(5) - trailing-edge device types [(Nt)j]
C     NT     - device type of trailing-edge panel [Nt]
C     MN(10),   - NMR pairs of Mach and Reynolds numbers
C     RN(10)
C     A         - aspect ratio of wing [A]
C     TR        - taper ratio of wing lambda]
C     T         - thickness to chord ratio [t/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17)   - dimensionless upper-surface and lower-surface
C     ZLG(17)     coordinates at each of 17 standard chordwise
C                 locations [(zu/c)g and (zl/c)g]
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C     DT(3,10)  - NDT deflection angles (deg) of up to 3 elements
C                                                        [delta t]
C     DCT(3,10) - NDT chord extensions due to deployment of up to 3
C                 elements                               [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements     [ct/c]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)                 [phit]
C     XLM,ZLM   - coordinates of section maximum lower surface ordinate
C                                                        [xlm/c, zlm/c]
C     EIT(5),   - positions of inner and outer edges of NNT trailing
C     EOT(5)      edge panels                 [(eta il)j and (eta ol)j]
C     DTJ(3,5,10)  - deflection angles for up to 3 elements, for NNT
C                    trailing edge devices, for NDT device settings
C                    [(delta t)j]
C     DCTJ(3,5,10) - chord extensions for up to 3 elements, for NNT
C                    trailing edge devices, for NDT device settings
C                    [(Delta ct / c)j]
C     CTJ(3,5)     - flap chords for up to 3 elements, for NNT devices
C                    [(ct/c)j]
C     PHITJ(5)     - angle from aerofoil datum to tangent to upper
C                    surface at trailing edge [(phi t)j]
C     XLMJ(5)      - chordwise location of section maximum lower surface
C                    coordinate  [(xlm/c)j]
C     ZLMJ(5)      - section maximum (negative) lower surface ordinate
C                    [(zlm/c)j]
C     TJ(5)        - section thicknesses (t/c)j of NNT devices
C     TAUJ(5)    - NNT trailing edge angles in Sketch 1.1a
C     TAUAJ(5)   - NNT trailing edge angles in Sketch 1.1b
C     XTSJ(5)    - chordwise location of flap shroud trailing edge
C                    [(xts/c)j]
C     LDX(4)   - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     LCS      - lift-curve slope in Section b1  [a1]
C     EB       - spanwise centre of pressure in Section b2 [eta bar]
C     RXK      - Reynolds number based on cp in Section b3 [R'k]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     EIT1EF      - effective spanwise position of inboard edge
C                   of innermost trailing-edge device as a proportion
C                   of semi-span [(eta it)1 eff]
C
C     Results to Common Blocks
C     ------------------------
C     CXCTJ(5)   - extended chords / chords with trailing edges
C                  extended [((c'/c)t)j]
C     DCL0T      - increment in aerofoil lift coefficient at zero angle
C                  of attack due to deployment of trailing-edge device
C                  [Delta CL0t]
C     DC0TWJ(NNt) - increments in wing lift coefft. at zero angle of
C                   attack due to NNT trailing-edge devices
C                   [(Delta CL0tw)j]
C     DCL0TW      - increment in wing lift coefft. at zero angle of
C                   attack due to trailing-edge devices [Delta CL0tw]
C
C     -----------------------------------------------------------------
C
      INTEGER K,JT,FAULT
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
C
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
      IF (NDT .EQ. 0) GO TO 10
C
      IF (CALC .GT. 6) THEN
C      Calculation for a wing
C      ----------------------
       CALL SUBRG1(NNT,NTJ,A,TR,EIT,EOT,DTJ(1,1,JT),DCTJ(1,1,JT),CTJ,
     *             PHITJ,XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,LDX,LCS,EB,
     *             RXK,CXCTJ,EIT1EF,DC0TWJ,DCL0TW,FAULT)
      ELSE
C      Calculation for an aerofoil
C      ---------------------------
       CALL SUBRG2(CALC,NT,RN(K),T,TAU,ZUG,ZLG,TAUA,DT(1,JT),DCT(1,JT),
     *             CT,PHIT,XLM,ZLM,CXC,DCL0T,FAULT)
      END IF
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRG1(NNT,NTJ,A,TR,EIT,EOT,DTJ,DCTJ,CTJ,PHITJ,
     *                  XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,LDX,LCS,EB,
     *                  RXK,CXCTJ,EIT1EF,DC0TWJ,DCL0TW,FAULT)
C     ======================================================
C
C     Purpose
C     -------
C     Section g:
C     Calculation of trailing-edge flap increments, Delta CL0tw
C     for CALC = 7 to 18 as the sum of the contributions of Nnt panels
C
C     Input
C     -----
C     NNT          - number of trailing-edge device panels (0<=NNT<=5)
C     NTJ(5)       - trailing-edge device types  [(Nt)j]
C     A            - aspect ratio of wing [A]
C     TR           - taper ratio of wing [lambda]
C     EIT(5),      - positions of inner and outer edges of NNT trailing
C     EOT(5)         edge panels[(eta il)j and (eta ol)j]
C     DTJ(3,5)     - deflection angles for up to 3 elements, for NNT
C                    trailing edge devices, for current device setting
C                    [(delta t)j]
C     DCTJ(3,5)    - chord extensions for up to 3 elements, for NNT
C                    trailing edge devices, for current device setting
C                    [(Delta ct / c)j]
C     CTJ(3,5)     - flap chords for up to 3 elements, for NNT devices
C                    [(ct/c)j]
C     PHITJ(5)     - angle from aerofoil datum to tangent to upper
C                    surface at trailing edge [(phi t)j]
C     XLMJ(5)      - chordwise location of section maximum lower surface
C                    coordinate  [(xlm/c)j]
C     ZLMJ(5)      - section maximum (negative) lower surface ordinate
C                    [(zlm/c)j]
C     TJ(5)        - section thicknesses (t/c)j of NNT devices
C     TAUJ(5)      - NNT trailing edge angles in Sketch 1.1a
C     TAUAJ(5)     - NNT trailing edge angles in Sketch 1.1b
C     XTSJ(5)      - chordwise location of flap shroud trailing edge
C                    angle  [(xts/c)j]
C     LDX(4)       - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     LCS          - lift-curve slope in Section b1  [a1]
C     EB           - spanwise centre of pressure in Section b2 [eta bar]
C     RXK          - Reynolds number based on cp in Section b3 [R'k]
C     CXCTJ(5)     - extended chords / chords with trailing edges
C                     extended [((c'/c)t)j]
C     EIT1EF       - effective spanwise position of inboard edge
C                    of innermost trailing-edge device as a proportion
C                    of semi-span [(eta it)1 eff]
C
C     Output
C     ------
C     DC0TWJ(NNt) - increments in wing lift coefft. at zero angle of
C                   attack due to NNT trailing-edge devices
C                   [(Delta CL0tw)j]
C     DCL0TW      - increment in wing lift coefft. at zero angle of
C                   attack due to trailing-edge devices [Delta CL0tw]
C     FAULT       - fault number (0 means "none")
C
C     Local
C     -----
C     J          - panel number j
C     DCL0TJ     - [Delta CL0t / (Phi o - Phi i)] for current panel
C     KF0J       - (Kf0)j for current panel
C     PHIOJ      - Phi oj for current panel
C     PHIIJ      - Phi ij for current panel
C
C     -----------------------------------------------------------------
C
      INTEGER NNT,NTJ(5),FAULT
      REAL A,TR,EIT(5),EOT(5),DTJ(3,5),DCTJ(3,5),CTJ(3,5),PHITJ(5),
     *     XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),LDX(4),LCS,
     *     EB,RXK,CXCTJ(5),EIT1EF,DC0TWJ(5),DCL0TW
C
      INTEGER J
      REAL DCL0TJ,KF0J,PHIOJ,PHIIJ
C
      FAULT = 0
      DCL0TW = 0.0
      DO 5 J = 1,5
      DC0TWJ(J) = 0.0
    5 CONTINUE
      IF (NNT .LE. 0) GO TO 80
C
C     Calculate and accumulate the contributions of each of the panels
C     ================================================================
      DO 70 J = 1,NNT
C
C     Choose the calculation appropriate to the type of this panel
C     ------------------------------------------------------------
      GO TO (10, 20, 30, 30, 30), NTJ(J)
C
C     (Nt)j = 1
C     ---------
   10 CALL SUBRG3(J,A,TR,EIT(J),EOT(J),DTJ(1,J),DCTJ(1,J),CTJ(1,J),
     *            PHITJ(J),LDX,CXCTJ(J),EIT1EF,DCL0TJ,KF0J,PHIOJ,PHIIJ,
     *            FAULT)
      GO TO 60
C
C     (Nt)j = 2
C     ---------
   20 CALL SUBRG4(J,A,TR,EIT(J),EOT(J),DTJ(1,J),DCTJ(1,J),CTJ(1,J),
     *            XLMJ(J),ZLMJ(J),LDX,CXCTJ(J),EIT1EF,DCL0TJ,KF0J,
     *            PHIOJ,PHIIJ,FAULT)
      GO TO 60
C
C     (Nt)j = 3, 4 or 5
C     -----------------
   30 CALL SUBRG5(J,NTJ(J),EIT(J),EOT(J),DTJ(1,J),DCTJ(1,J),
     *            CTJ(1,J),TJ(J),TAUJ(J),TAUAJ(J),XTSJ(J),
     *            EB,RXK,CXCTJ(J),EIT1EF,DCL0TJ,KF0J,
     *            PHIOJ,PHIIJ,FAULT)
      GO TO 60
C
C     Calculate (Delta CL0tw)j and accumulate Delta CL0tw
C     ===================================================
   60 IF (FAULT .NE. 0) GO TO 80
C
C     Calculate (Delta CL0tw)j = 1/(2 * pi) * (a1) * (kf0)j
C                                * [(Delta CL0t)/((Phi o)-(phi i))]j
C                                * [(Phi oj) - (Phi ij)]
C     --------------------------------------------------------------
      DC0TWJ(J) = (0.5 / 3.141593) * LCS * KF0J * DCL0TJ
     *            * (PHIOJ - PHIIJ)
C
C     Accumulate Delta CL0tw
C     (Delta CL0tw) = Sigma[Delta CL0tw]j for j = 1 to Nnt
C     ----------------------
      DCL0TW = DCL0TW + DC0TWJ(J)
C
   70 CONTINUE
C
   80 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRG2(CALC,NT,RK,T,TAU,ZUG,ZLG,TAUA,DT,DCT,CT,
     *                  PHIT,XLM,ZLM,CXC,DCL0T,FAULT)
C     ==========================================================
C
C     Purpose
C     -------
C     Section G2:
C     Calculation of trailing-edge device increments Delta CL0t
C     for aerofoils
C
C     Input
C     -----
C     CALC      - calculation type (1 to 6)
C     NT        - device type of trailing-edge panel
C     RK        - Reynolds number
C     T         - thickness to chord ratio [t/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17)   - dimensionless upper-surface and lower-surface
C     ZLG(17)     coordinates at each of 17 standard chordwise
C                 locations [(zu/c)g and (zl/c)g]
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C     DT(3)     - deflection angles (deg) of up to 3 elements
C                 [delta t]
C     DCT(3)    - chord extensions due to deployment of up to 3
C                 elements  [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements  [ct/c]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)  [phit]
C     XLM,ZLM   - coordinates of section maximum lower surface ordinate
C                 [xlm/c, zlm/c]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C
C     Output
C     ------
C     DCL0T      - increment in aerofoil lift coefficient at zero angle
C                  of attack due to deployment of trailing-edge device
C                  [Delta CL0t]
C     FAULT      - fault number (0 means "none")
C
C     Local
C     -----
C     SN,TN      - sine and tan of an angle
C
C     -----------------------------------------------------------------
C
      INTEGER CALC,NT,FAULT
      REAL RK,T,TAU,ZUG(17),ZLG(17),TAUA,DT(3),DCT(3),CT(3),
     *     PHIT,XLM,ZLM,CXC,DCL0T
C
      REAL SN,TN
C
      FAULT = 0
      DCL0T = 0.0
C
C     If CALC = 2 or 5, TAUA needs to be calculated (in degrees)
C     ---------------------------------------------
C     (It was data for CALC = 4 or 6 and calculated for Calc = 1 or 3)
      IF (CALC .EQ. 2 .OR. CALC .EQ. 5) THEN
C      (tau a) = 2 *
C      arc tan[{[(zu/c)14 - (zl/c)14] - [(zu/c)16 - (zl/c)16]} / 0.18]
       TN = ((ZUG(14) - ZLG(14)) - (ZUG(16) - ZLG(16))) / 0.18
       SN = TN / SQRT(1.0 + TN * TN)
       TAUA = 2.0 * ASIN(SN) * 180.0 / 3.141593
      END IF
C
      IF (NT .EQ. 0) GO TO 40
C
C     Choose the calculation appropriate to the panel
C     -----------------------------------------------
      GO TO (10, 20, 30, 30, 30), NT
C
C     NT = 1
C     ------
   10 CALL SUBRG6(DT(1),CT(1),PHIT,CXC,DCL0T,FAULT)
      GO TO 40
C
C     NT = 2
c     ------
   20 CALL SUBRG7(DT(1),CT(1),XLM,ZLM,CXC,DCL0T,FAULT)
      GO TO 40
C
C     NT = 3, 4 or 5
C     --------------
   30 CALL SUBRG8(NT,RK,T,TAU,TAUA,DT,DCT,CT,CXC,DCL0T,FAULT)
      GO TO 40
C
   40 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRG3(J,A,TR,EITJ,EOTJ,DTJ,DCTJ,CTJ,PHITJ,LDX,
     *                  CXCTJ,EIT1EF,DCL0TJ,KF0J,PHIOJ,PHIIJ,FAULT)
C     =============================================================
C
C     Purpose
C     -------
C     Calculation of [Delta CL0t / (Phi o - Phi i)]j, (Kf0)j,
C     (Phi oj) and (Phi ij) for a device of type Ntj = 1
C     (see Section g)
C
C     Input
C     -----
C     J            - device number
C     A            - aspect ratio of wing [A]
C     TR           - taper ratio of wing [lambda]
C     EITJ,        - positions of inner and outer edges of NNT trailing
C     EOTJ           edge panels [(eta il)j and (eta ol)j]
C     DTJ          - deflection angles for up to 3 elements, for NNT
C                    trailing edge devices, for current device setting
C                    [(delta t)j]
C     DCTJ         - chord extensions for up to 3 elements, for NNT
C                    trailing edge devices, for current device setting
C                    [(Delta ct / c)j]
C     CTJ          - flap chords for up to 3 elements, for NNT devices
C                    [(ct/c)j]
C     PHITJ        - angle from aerofoil datum to tangent to upper
C                    surface at trailing edge [(phi t)j]
C     LDX(4)       - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     EIT1EF       - effective spanwise position of inboard edge
C                    of innermost trailing-edge device as a proportion
C                    of semi-span [(eta it)1 eff]
C
C     Output
C     ------
C     CXCTJ        - extended chords / chords with trailing edges
C                    extended [((c'/c)t)j]
C     DCL0TJ       - [Delta CL0t / (Phi o - Phi i)] for current panel
C     KF0J         - (Kf0)j for current panel
C     PHIOJ        - (Phi oj) for current panel
C     PHIIJ        - (Phi ij) for current panel
C     FAULT        - fault number (0 means "none")
C
C     Local
C     -----
C     ATLD50       - A tan(Lambda1/2)
C     KT0          - Kt0 in Section g
C     X1           - (delta t)j + (phi t)j
C     X2           - A tan(Lambda1/2) - 8 lambda
C     JP0, JPJ     - Jp0 and (Jp)j in Section g
C     ATJ          - (at)j in Section g
C     DTOR         - (radians) = DTOR * (degrees)
C
C     -----------------------------------------------------------------
C
      INTEGER J,FAULT
      REAL A,TR,EITJ,EOTJ,DTJ,DCTJ,CTJ,PHITJ,LDX(4),
     *     CXCTJ,EIT1EF,DCL0TJ,KF0J,PHIOJ,PHIIJ
C
      REAL ATLD50,KT0,X1,X2,JP0,JPJ,ATJ,DTOR
C
      DTOR = 3.141593 / 180.0
      FAULT = 0
C
C     Calculate ((c'/c)t)j = 1 + (Delta ct/c)j
C     ----------------------------------------
      CXCTJ = 1.0 + DCTJ
C
C     Read Jp0 from Figure 1 of Item 97011
C     using the parameter (delta t)j + (phi t)j
C     -----------------------------------------
      X1 = DTJ + PHITJ
      CALL FIG15A(X1,JP0,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate Kt0
C     -------------
C     ATLD50 = A * tan(Lambda1/2)
      ATLD50 = A * TAN(DTOR * LDX(3))
C     (Kt0) = 0 for [A * tan(Lambda1/2)] <= 2.0
C     Otherwise (Kt0) = 0.03 * [A * tan(Lambda1/2) - 2.0]
      IF (ATLD50 .LE. 2.0) THEN
       KT0 = 0.0
      ELSE
       KT0 = 0.03 * (ATLD50 - 2.0)
      END IF
C
C     Calculate Jpj
C     -------------
      JPJ = JP0 * (1.0 - KT0)
C
C     Subroutine 11 calculates (at)j
C     using the parameters (ct/c)j and ((c'/c)t)j
C     -------------------------------------------
      CALL SUBR11(CTJ,CXCTJ,ATJ,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate [Delta CL0t / (Phi o - Phi i)]j  =
C     ((c'/c)t)j * (Jp)j * (delta t)j * (pi/180) * (at)j
C     --------------------------------------------------
      DCL0TJ = CXCTJ * JPJ * DTJ * DTOR * ATJ
C
C     (Kf0)j is simply:
C     -----------------
      KF0J = 1.02
C
C     Read Phi oj and Phi ij from Figure 3a of Item 91014
C     ---------------------------------------------------
C     X2 is [A tan(Lambda1/2) - 8 * lambda]
      X2 = ATLD50 - 8.0 * TR
C     Use Figure 3a of Item 91014 with the governing parameters
C     [A tan(Lambda1/2) - 8 * lambda] and (eta ot)j
      CALL FIG17A(X2,EOTJ,PHIOJ,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
      IF (J .EQ. 1) THEN
C      Use Figure 3a of Item 91014 with the governing parameters
C      [A tan(Lambda1/2) - 8 * lambda] and (eta it)1eff
       CALL FIG17A(X2,EIT1EF,PHIIJ,FAULT)
      ELSE
C      otherwise use Figure 3a of Item 91014 with the governing parameters
C      parameters [A tan(Lambda1/2) - 8 * lambda] and (eta it)j
       CALL FIG17A(X2,EITJ,PHIIJ,FAULT)
      END IF
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRG4(J,A,TR,EITJ,EOTJ,DTJ,DCTJ,CTJ,XLMJ,ZLMJ,LDX,
     *                  CXCTJ,EIT1EF,DCL0TJ,KF0J,PHIOJ,PHIIJ,FAULT)
C     =============================================================
C
C     Purpose
C     -------
C     Calculation of [Delta CL0t / (Phi o - Phi i)]j, (Kf0)j,
C     Phi oj and Phi ij for a device of type Ntj = 2
C     (see Section g)
C
C     Input
C     -----
C     J         - device number
C     A         - aspect ratio of wing    [A]
C     TR         - taper ratio of wing     [lambda]
C     EITJ,     - positions of inner and outer edges of NNT trailing
C     EOTJ        edge panels                 [(eta il)j and (eta ol)j]
C     DTJ          - deflection angles for up to 3 elements, for NNT
C                    trailing edge devices, for current device setting
C                    [(delta t)j]
C     DCTJ         - chord extensions for up to 3 elements, for NNT
C                    trailing edge devices, for current device setting
C                    [(Delta ct / c)j]
C     CTJ          - flap chords for up to 3 elements, for NNT devices
C                    [(ct/c)j]
C     XLMJ         - chordwise location of section maximum lower surface
C                    coordinate  [(xlm/c)j]
C     ZLMJ         - section maximum (negative) lower surface ordinate
C                    [(zlm/c)j]
C     LDX(4)       - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     EIT1EF       - effective spanwise position of inboard edge
C                    of innermost trailing-edge device as a proportion
C                    of semi-span [(eta it)1 eff]
C
C     Output
C     ------
C     CXCTJ        - extended chords / chords with trailing edges
C                    extended [((c'/c)t)j]
C     DCL0TJ       - [Delta CL0t / (Phi o - Phi i)] for current panel
C     KF0J         - (Kf0)j for current panel
C     PHIOJ        - Phi oj for current panel
C     PHIIJ        - Phi ij for current panel
C     FAULT        - fault number (0 means "none")
C
C     Local
C     -----
C     KT0          - Kt0 in Section g
C     X1           - (- zlm / c)j (with zlm negative)
C     X2           - A tan(Lambda1/2) - 8 lambda
C     DCL0TD       - (Delta C'L0t)d in Figure 1 of Item 94029
C     JSPJ         - factor (Jsp)j in formula for
C                    [Delta CL0t / (Phi o - Phi i)]
C     ATJ          - (at)j in Section g
C     DTOR         - (radians) = DTOR * (degrees)
C
C     -----------------------------------------------------------------
C
      INTEGER J,FAULT
      REAL A,TR,EITJ,EOTJ,DTJ,DCTJ,CTJ,XLMJ,ZLMJ,LDX(4),
     *     CXCTJ,EIT1EF,DCL0TJ,KF0J,PHIOJ,PHIIJ
C
      REAL KT0,X1,X2,DCL0TD,JSPJ,ATJ,DTOR
C
      DTOR = 3.141593 / 180.0
      FAULT = 0
C
C     Calculate ((c'/c)t)j = 1 + (Delta ct/c)j
C     ----------------------------------------
      CXCTJ = 1.0 + DCTJ
C
C     Calculate Kt0 = 0.41 - 0.00227 * (delta t)j
C     -------------------------------------------
      KT0 = 0.41 - 0.00227 * DTJ
C
C     Read (Delta C'L0t)d from Figure 1 of Item 94029
C     using the parameters (xlm/c)j and |(zlm/c)j|
C     -----------------------------------------------
      X1 = ABS(ZLMJ)
      CALL FIG16A(XLMJ,X1,DCL0TD,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate (Jsp)j = (Delta C'L0t)d * Kt0
C     ---------------------------------------
      JSPJ = DCL0TD * KT0
C
C     Subroutine 11 gives (at)j for the governing parameters
C     (ct/c)j and ((c'/ct)j
C     ------------------------------------------------------
      CALL SUBR11(CTJ,CXCTJ,ATJ,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate [Delta CL0t / (Phi o - Phi i)] =
C     ((c'/c)t)j * (Jsp)j * (delta t)j * (pi/180) * (at)j
C     ---------------------------------------------------
      DCL0TJ = CXCTJ * JSPJ * DTJ * DTOR * ATJ
C
C     (Kf0)j is simply:
C     -----------------
      KF0J = 0.98
C
C     Read Phi oj and Phi ij from Figure 3a of Item 91014
C     ---------------------------------------------------
C     X2 is [A tan(Lambda1/2) - 8 * lambda]
      X2 = A * TAN(DTOR * LDX(3)) - 8.0 * TR
C     Use Figure 3a of Item 91014 with the governing parameters
C     [A tan(Lambda1/2) - 8 * lambda] and (eta ot)j
      CALL FIG17A(X2,EOTJ,PHIOJ,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
      IF (J .EQ. 1) THEN
C      Use Figure 3a of Item 91014 with the governing parameters
C      [A tan(Lambda1/2) - 8 * lambda] and (eta it)1eff
       CALL FIG17A(X2,EIT1EF,PHIIJ,FAULT)
      ELSE
C     otherwise use Figure 3a of Item 91014 with the governing parameters
C     parameters [A tan(Lambda1/2) - 8 * lambda] and (eta it)j
       CALL FIG17A(X2,EITJ,PHIIJ,FAULT)
      END IF
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRG5(J,NTJ,EIT,EOT,DTJ,DCTJ,CTJ,TJ,TAUJ,TAUAJ,
     *                  XTSJ,EB,RXK,CXCTJ,EIT1EF,DCL0TJ,KF0J,
     *                  PHIOJ,PHIIJ,FAULT)
C     ===========================================================
C
C     Purpose
C     -------
C     Calculation of [Delta CL0t / (Phi o - Phi i)]j, (Kf0)j,
C     Phi oj and Phi ij for a device of types Ntj = 3, 4 and 5
C
C     Input
C     -----
C     J         - device number
C     NTJ       - device type
C     EIT,      - positions of inner and outer edges of NNT trailing
C     EOT         edge panels              [(eta it)j and (eta ot)j]
C     DTJ(3)       - deflection angles for up to 3 elements, for NNT
C                    trailing edge devices, for current device setting
C                    [(delta t)j]
C     DCTJ(3)      - chord extensions for up to 3 elements, for NNT
C                    trailing edge devices, for current device setting
C                    [(Delta ct / c)j]
C     CTJ(3)       - flap chords for up to 3 elements, for NNT devices
C                    [(ct/c)j]
C     TJ           - section thickness (t/c)j
C     TAUJ         - trailing edge angle in Sketch 1.1a (tau)j
C     TAUAJ        - trailing edge angle in Sketch 1.1b (tau a)j
C     XTSJ         - chordwise location of flap shroud trailing edge
C                    [(xts/c)j]
C     EB           - spanwise centre of pressure in Section b2
C                    [eta bar]
C     RXK          - Reynolds number based on cp in Section b3 [R'k]
C     EIT1EF       - effective spanwise position of inboard edge
C                    of innermost trailing-edge device as a proportion
C                    of semi-span [(eta it)1 eff]
C
C     Output
C     ------
C     CXCTJ        - extended chord / chord with trailing edge
C                    extended [((c'/c)t)j]
C     DCL0TJ       - [Delta CL0t / (Phi o - Phi i)] for current panel
C     KF0J         - (Kf0)j for current panel
C     PHIOJ        - Phi oj for current panel
C     PHIIJ        - Phi ij for current panel
C     FAULT        - fault number (0 means "none")
C
C     Local
C     -----
C     NE           - number of elements
C     I,L          - element numbers
C     A10J         - ((a1)0)j in the notes
C     CETCX(3)     - (ceti/c') in the notes
C     LD2          - dummy Lambda supplied as 0.0
C     DTSEC(3)     - (delta ti) sec(Lambda2) in the notes
C     DCXLJ(3)     - (Delta C'Li)j in the notes
C     JT(1)        - J factors (Jt1), (Jt2) and (Jt3)
C     SUM          - sum of terms (Jti)j * (Delta C'Li)j
C     DTOR         - (radians) = DTOR * (degrees)
C     TOL          - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER J,NTJ,FAULT
      REAL EIT,EOT,DTJ(3),DCTJ(3),CTJ(3),TJ,TAUJ,TAUAJ,
     *     XTSJ,EB,RXK,CXCTJ,EIT1EF,DCL0TJ,KF0J,
     *     PHIOJ,PHIIJ
C
      INTEGER NE,I,L
      REAL A10J,CETCX(3),LD2,DTSEC(3),DCXLJ(3),JT(3),SUM,DTOR,TOL
C
      TOL = 1.0E-8
      DTOR = 3.141593 / 180.0
      DTOR = DTOR
      FAULT = 0
      LD2 = 0.0
C
C     Number of elements
      NE = NTJ - 2
C
C     Subroutine 5 gives ((a1)0)j for the governing parameters
C     R'k, (t/c)j, (tau)j, and (tau a)j
C     --------------------------------------------------------
C     next line to take XTR2 = 0.0 into subroutine
      CALL SUBR05(1.0E6,TJ,TAUJ,TAUAJ,A10J,FAULT,0.0)
      IF (FAULT .NE. 0) GO TO 50
C     In this version of program there is no need to call subr05,
C     left in to avoid 'use' warnings, as is next line
       RXK = RXK
C
C     Calculate ((c'/c)t)j = (xts/c)j + Sigma[(cti/c)j + (Delta cti/c)j]
C     for i = 1 to tne number of elements (Ne)
C     --------------------
      CXCTJ = XTSJ
      DO 10 I = 1,NE
      CXCTJ = CXCTJ + CTJ(I) + DCTJ(I)
   10 CONTINUE
      IF (ABS(CXCTJ) .LE. TOL) FAULT = 1013
      IF (FAULT .NE. 0) GO TO 50
C
C     Calculate  [(delta ti) * sec(Lambda2)] and
C     (cet1/c'), (cet2/c') and (cet3/c')
C     for the appropriate number of elements
C     ------------------------------------------
      DO 30 I = 1,NE
C
C     DTSEC(i) = [(delta ti) * sec(Lambda2)] = (delta ti)j
C     because Lambda2 = 0.0
      DTSEC(I) = DTJ(I)
C
C     (ceti/c') = Sigma[(ctl/c)j + (Delta ctl/c)j] / ((c'/c)t)j
C                 for l = i to Ne
      CETCX(I) = 0.0
      DO 20 L = I,NE
      CETCX(I) = CETCX(I) + CTJ(L) + DCTJ(L)
   20 CONTINUE
      CETCX(I) = CETCX(I) / CXCTJ
C
   30 CONTINUE
C
C     For all three types calculate Jt1 and (Delta C'L1)j
C     ===================================================
C     Subroutine SUBJT1 gives Jt1
C     for the parameters (detla t1)j and Lambda2
C     ------------------------------------------
      CALL SUBJT1(DTJ(1),LD2,JT(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Read DCXLJ(1) = (Delta C'L1)j from Figure 4 of Item 94031
C     with the governing parameters (cet1/c') and
C     [(delta t1) * sec(Lambda2)]
C     ---------------------------------------------------------
      CALL FIG18A(CETCX(1),DTSEC(1),DCXLJ(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     For types 4 and 5 calculate Jt2 and (Delta C'L2)j
C     =================================================
      IF (NTJ .GE. 4) THEN
C
C      Subroutine SUBJT2 gives Jt2
C      ---------------------------
C      for the parameters (detla t1)j and Lambda2
       CALL SUBJT2(DTJ(1),LD2,JT(2),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C      Read DCXLJ(2) = (Delta C'L2)j from Figure 5 of Item 94031
C      with the governing parameters (cet2/c') and
C      [(delta t2) * sec(Lambda2)]
C      ---------------------------------------------------------
       CALL FIG19A(CETCX(2),DTSEC(2),DCXLJ(2),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
      END IF
C
C     For type 5 calculate Jt3 and (Delta C'L3)j
C     ==========================================
      IF (NTJ .EQ. 5) THEN
C
C      Subroutine SUBJT3 gives Jt3
C      ---------------------------
C      for the parameters (delta t3)j and Lambda2
       CALL SUBJT3(DTJ(3),LD2,JT(3),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C      Read DCXLJ(3) = (Delta C'L3)j from Figure 6 of Item 94031
C      with the governing parameters (cet3/c') and
C      [(delta t3) * sec(Lambda2)]
C      ---------------------------------------------------------
       CALL FIG20A(CETCX(3),DTSEC(3),DCXLJ(3),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
      END IF
C
C     Calculate DCL0TJ = [Delta CL0t / (Phi o - Phi i)]j =
C     ((c'/c)t)j * Sigma[(Jti) * (Delta c'Li)j] * ((a1)0)j / (2 * pi)
C     for i = 1 to Ne (the number of elements)
C     =========================================
      SUM = 0.0
      DO 40 I = 1,NE
      SUM = SUM + JT(I) * DCXLJ(I)
   40 CONTINUE
C
      DCL0TJ = CXCTJ * SUM
C
C     For type 3 (Kf0)j is 1.05 and for types 4 and 5 it is 1.0
C     ---------------------------------------------------------
      IF (NTJ .EQ. 3) THEN
       KF0J = 1.05
      ELSE
       KF0J = 1.0
      END IF
C
C     Read Phi oj and Phi ij from Figure 3 of Item 93019
C     --------------------------------------------------
C     The parameters (eta bar) and (eta ot)j give (Phi oj)
      CALL FIG13A(EB,EOT,PHIOJ,FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
      IF (J .EQ. 1) THEN
C      For the innermost panel (eta bar) and (eta it)1eff give (Phi ij)
       CALL FIG13A(EB,EIT1EF,PHIIJ,FAULT)
      ELSE
C      For the other panels (eta bar) and (eta it)j give (Phi ij)
       CALL FIG13A(EB,EIT,PHIIJ,FAULT)
      END IF
      IF (FAULT .NE. 0) GO TO 50
C
   50 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRG6(DT,CT,PHIT,CXC,DCL0T,FAULT)
C     =============================================
C
C     Purpose
C     -------
C     Calculation of Delta CL0t for Nt = 1 for an aerofoil
C
C     Input
C     -----
C     DT        - deflection angle (deg) [delta t]
C     CT        - flap chord / c  [ct/c]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)  [phit]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C
C     Output
C     ------
C     DCL0T      - increment in aerofoil lift coefficient at zero angle
C                  of attack due to deployment of trailing-edge device
C                  [Delta CL0t]
C     FAULT      - fault number (0 means "none")
C
C     Local
C     -----
C     AT         - lift-curve slope [at]
C     JP         - J factor
C     X          - (delta t + phi t) sec(Lambda2) with Lambda2 = 0.0
C     DTOR       - (radians) = DTOR * (degrees)
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL DT,CT,PHIT,CXC,DCL0T
C
      REAL AT,JP,X,DTOR
C
      DTOR = 3.141593 / 180.0
      FAULT = 0
      DCL0T = 0.0
C
C     Subroutine 11 with the governing parameters
C     (ct/c) and (c'/c) gives (at)
C     -------------------------------------------
      CALL SUBR11(CT,CXC,AT,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Figure 1 of Item 94028 gives Jp as a function of
C     X = [(delta t) + (phi t)] * sec(Lambda2) with Lambda2 = 0.0
C     -----------------------------------------------------------
      X = DT + PHIT
      CALL FIG28A(X,JP,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Delta DCL0T = (Delta CL0t) =
C     (c'/c) * Jp * (delta t) * (pi / 180) * (at)
C     -------------------------------------------
      DCL0T = CXC * JP * DT * DTOR * AT
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRG7(DT,CT,XLM,ZLM,CXC,DCL0T,FAULT)
C     ================================================
C
C     Purpose
C     -------
C     Calculation of Delta CL0t for Nt = 2 for an aerofoil
C
C     Input
C     -----
C     DT        - deflection angle (deg)  [delta t]
C     CT        - flap chord / c  [ct/c]
C     XLM,ZLM   - coordinates of section maximum lower surface ordinate
C                 [xlm/c, zlm/c]
C     CXC       - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C
C     Output
C     ------
C     DCL0T      - increment in aerofoil lift coefficient at zero angle
C                  of attack due to deployment of trailing-edge device
C                  [Delta CL0t]
C     FAULT      - fault number (0 means "none")
C
C     Local
C     -----
C     AT         - lift-curve slope [at]
C     JSP        - J factor
C     ABSZLM     - |zlm/c|
C     DCL0TD     - (Delta C'L0t)d
C     DTOR       - (radians) = DTOR * (degrees)
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL DT,CT,XLM,ZLM,CXC,DCL0T
C
      REAL AT,JSP,ABSZLM,DTOR,DCL0TD
C
      DTOR = 3.141593 / 180.0
      FAULT = 0
      DCL0T = 0.0
C
C     Subroutine 11 with the governing parameters
C     (ct/c) and (c'/c) gives (at)
C     -------------------------------------------
      CALL SUBR11(CT,CXC,AT,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Figure 1 of Item 94029 with the governing parameters
C     (xlm/c) and |(zlm/c)| gives DCL0TD = (Delta C'L0t)d
C     ----------------------------------------------------
      ABSZLM = ABS(ZLM)
C     N.B. The graph requires a positive ( - zlm / c )
      CALL FIG16A(XLM,ABSZLM,DCL0TD,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate Jsp =
C     [0.41 - 0.13 * (delta t) * (pi/180)] * (Delta C'L0t)d
C     -----------------------------------------------------
      JSP = (0.41 - 0.13 * DT * DTOR) * DCL0TD
C
C     (Delta CL0t) = (c'/c) * Jsp * (delta t) * (pi/180) * (at)
C     ---------------------------------------------------------
      DCL0T = CXC * JSP * DT * DTOR * AT
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRG8(NT,RK,T,TAU,TAUA,DT,DCT,CT,CXC,DCL0T,FAULT)
C     =============================================================
C
C     Purpose
C     -------
C     Calculation of Delta CL0t for types Nt = 3, 4 and 5 for aerofoils
C
C     Input
C     -----
C     NT        - device type of trailing-edge panel
C     RK        - Reynolds number
C     T         - thickness to chord ratio [t/c]
C     TAU       - trailing edge angle (deg) [tau]
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C     DT(3)     - deflection angles (deg) of up to 3 elements
C                 [delta t]
C     DCT(3)    - chord extensions due to deployment of up to 3
C                 elements  [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements  [ct/c]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C
C     Output
C     ------
C     DCL0T      - increment in aerofoil lift coefficient at zero angle
C                  of attack due to deployment of trailing-edge device
C                  [Delta CL0t]
C     FAULT      - fault number (0 means "none")
C
C     Local
C     -----
C     NE           - number of elements
C     I,L          - element numbers
C     AT           - at in the notes
C     CETCX(3)     - (ceti/c') in the notes
C     LD2          - dummy Lambda supplied as 0.0
C     DTSEC(3)     - (delta ti) sec(Lambda2) in the notes
C     DCXL(3)      - (Delta C'Li) in the notes
C     JT(3)        - J factors Jt1, Jt2 and Jt3
C     SUM          - sum of terms Jti * Delta C'Li
C     TOL          - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER NT,FAULT
      REAL RK,T,TAU,TAUA,DT(3),DCT(3),CT(3),CXC,DCL0T
C
      INTEGER NE,I,L
C
      REAL AT,CETCX(3),LD2,DTSEC(3),DCXL(3),JT(3),SUM,TOL
C
      TOL = 1.0E-8
      FAULT = 0
      LD2 = 0.0
C
      IF (ABS(CXC) .LE. TOL) FAULT = 1014
      IF (FAULT .NE. 0) GO TO 50
C
C     Number of elements
      NE = NT - 2
C
C     Subroutine 5 gives (at) for the parameters
C     Rk, (t/c), tau and (tau a)
C     ------------------------------------------
C     Next line to take XTR2 = 0.0 into subroutine
      CALL SUBR05(RK,T,TAU,TAUA,AT,FAULT,0.0)
      IF (FAULT .NE. 0) GO TO 50
C
C     Calculate (delta ti) * sec(Lambda2) and
C     (cet1/c'), (cet2/c') and (cet3/c')
C     for the appropriate number of elements
C     ---------------------------------------
      DO 30 I = 1,NE
C
C     (delta ti) * sec(Lambda2) = (delta ti) because Lambda2 = 0.0
      DTSEC(I) = DT(I)
C
C     (ceti/c') = Sigma[(ctl/c) + (Delta ctl/c)] / (c'/c)
C     for l = 1 to Ne (the number of elements)
      CETCX(I) = 0.0
C
      DO 20 L = I,NE
      CETCX(I) = CETCX(I) + CT(L) + DCT(L)
   20 CONTINUE
      CETCX(I) = CETCX(I) / CXC
C
   30 CONTINUE
C
C     For all three types calculate Jt1 and Delta C'L1
C     ================================================
C     Subroutine SUBJT1 gives Jt1
C     for the parameters (delta t1) and Lambda2
C     -----------------------------------------
      CALL SUBJT1(DT(1),LD2,JT(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Read DCXL(1) = Delta C'L1 from Figure 4 of Item 94031
C     for the parameters (cet1/c') and [(delta t1) * sec(Lambda2)]
C     ------------------------------------------------------------
      CALL FIG18A(CETCX(1),DTSEC(1),DCXL(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     For types 4 and 5 calculate Jt2 and Delta C'L2
C     ==============================================
      IF (NT .GE. 4) THEN
C
C      Subroutine SUBJT2 gives Jt2
C      for the parameters (delta t1) and Lambda2
C      -----------------------------------------
       CALL SUBJT2(DT(1),LD2,JT(2),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C      Read Delta C'L2 from Figure 5 of Item 94031
C      for the parameters (cet2/c') and [(delta t2)*sec(Lambda2)]
C      ----------------------------------------------------------
       CALL FIG19A(CETCX(2),DTSEC(2),DCXL(2),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
      END IF
C
C     For type 5 calculate Jt3 and Delta C'L3
C     =======================================
      IF (NT .EQ. 5) THEN
C
C      Subroutine SUBJT3 gives Jt3
C      for the parameters (delta t3) and Lambda2
C      -----------------------------------------
       CALL SUBJT3(DT(3),LD2,JT(3),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C      Read (Delta C'L3) from Figure 6 of Item 94031
C      for the parameters (cet3/c') and [(delta t3)*sec(Lambda2)]
C      ----------------------------------------------------------
       CALL FIG20A(CETCX(3),DTSEC(3),DCXL(3),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
      END IF
C
C     Calculate (Delta CL0t) =
C     (c'/c) * Sigma[(Jti) * (Delta C'Li)] * (at) / (2 * pi)
C     ======================================================
      SUM = 0.0
      DO 40 I = 1,NE
      SUM = SUM + JT(I) * DCXL(I)
   40 CONTINUE
      DCL0T = (0.5 / 3.141593) * CXC * SUM * AT
C
   50 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBJT1(DT1,LD2,JT1,FAULT)
C     ====================================
C
C     Purpose
C     -------
C     To calculate J factor Jt1
C
C     Input
C     -----
C     DT1     - delta t1
C     LD2     - Lambda2 (with |Lambda2| < pi / 2 assumed)
C
C     Output
C     ------
C     JT1     - Jt1
C     FAULT   - fault number
C
C     Local
C     -----
C     DTOR    - (radians) = DTOR * (degrees)
C     X       - (delta t1) * sec(Lambda2)
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL DT1,LD2,JT1
C
      REAL DTOR,X
C
      DTOR = 3.141593 / 180.0
C
      FAULT = 0
      JT1 = 0.0
C
C     X = (delta t1) * sec(Lambda2)
      X = DT1 / COS(DTOR * LD2)
C
      IF (X .LT. 0.0) THEN
       FAULT = 1010
      ELSE
       IF (X .LE. 23.5) THEN
C       For 0.0 <= [(delta t1)*sec(Lambda2)] <= 23.5
C       Jt1 = 1.17 * sqrt[3.83 * (delta t1) * sec(Lambda2)]
        JT1 = 1.17 * SQRT(SIN(3.83 * X * DTOR))
       ELSE
C       For [(delta t1)*sec(Lambda2)] > 23.5, Jt1 = 1.17
        JT1 = 1.17
       END IF
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBJT2(DT1,LD2,JT2,FAULT)
C     ====================================
C
C     Purpose
C     -------
C     To calculate J factor Jt2
C
C     Input
C     -----
C     DT1     - delta t1
C     LD2     - Lambda2 (with |Lambda2| < pi / 2 assumed)
C
C     Output
C     ------
C     JT2     - Jt2
C     FAULT   - fault number
C
C     Local
C     -----
C     DTOR    - (radians) = DTOR * (degrees)
C     X       - (delta t1) * sec(Lambda2)
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL DT1,LD2,JT2
C
      REAL DTOR,X
C
      DTOR = 3.141593 / 180.0
C
      FAULT = 0
      JT2 = 0.0
C
C     X = [(delta t1)*sec(Lambda2)]
      X = DT1 / COS(DTOR * LD2)
C
      IF (X .LT. -10.0) THEN
       FAULT = 1011
      ELSE
       IF (X .LE. 30.0) THEN
C      If (-10) <=[(delta t1)*sec(Lambda2)] <= 30
C       Jt2 = 2.2 - 0.04 * |(delta t1)*sec(Lambda2)|
        JT2 = 2.2 - 0.04 * ABS(X)
       ELSE
C       If [(delta t1)*sec(Lambda2)] >= 30
        JT2 = 1.0
       END IF
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBJT3(DT3,LD2,JT3,FAULT)
C     ====================================
C
C     Purpose
C     -------
C     To calculate J factor Jt3
C
C     Input
C     -----
C     DT3     - delta t3
C     LD2     - Lambda2 (with |Lambda2| < pi / 2 assumed)
C
C     Output
C     ------
C     JT3     - Jt3
C     FAULT   - fault number
C
C     Local
C     -----
C     DTOR    - (radians) = DTOR * (degrees)
C     X       - (delta t3) * sec(Lambda2)
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL DT3,LD2,JT3
C
      REAL DTOR,X
C
      DTOR = 3.141593 / 180.0
C
      FAULT = 0
      JT3 = 0.0
C
C     X = [(delta t3)*sec(Lambda2)]
      X = DT3 / COS(DTOR * LD2)
C
      IF (X .LT. 0.0) THEN
       FAULT = 1012
      ELSE
       IF (X .LE. 20.0) THEN
C      If 0.0 <= [(delta t3)*sec(Lambda2)] <= 20, Jt3 = 1.42
        JT3 = 1.42
       ELSE
C      If [(delta t3)*sec(Lambda2)] > 20
C      Jt3 = 1.42  - 0.004 * [(delta t1) * sec(Lambda2) - 20]^(1.79)
        JT3 = 1.42 - 0.004 * (X - 20.0)**1.79
       END IF
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRHH(K,JL,FAULT)
C     =============================
C
C     Purpose
C     -------
C     To supply data for and store results of Sections h and H2:
C     Calculation of Delta CLmaxl and Delta CLml
C
C     Input
C     -----
C     K      - current Reynolds number and Mach number pair
C     JL     - current leading edge device setting
C
C     Output
C     ------
C     FAULT  - fault number (0 means "none")
C
C     Input from common blocks
C     ------------------------
C     CALC   - calculation type (1 to 18)
C     TES    - slotted trailing-edge flap at ETAP flag
C              0 means absent, 1 means present
C     NDL    - number of leading edge device settings (0<=NDL<=10)
C     NL     - device type of leading-edge panel containing ETAP    [Nl]
C     RN(10) - Reynolds numbers
C     DL(10)    - NDL deflection angles (deg)       [delta l]
C     RL(10)    - NDL leading edge radii / c        [rhol/c]
C     CXL(10)   - NDL leading edge extended chords  [c'l/c]
C     DCL(10)   - NDL chord extensions due to deployment of leading
C                 edge device                       [Delta cl / c]
C     GL(10)    - NDL normal distances between slat trailing edge and
C                 section surface                   [Gl / c]
C     HL(10)    - NDL heights of slat trailing edge above chord line
C                                                   [Hl / c]
C     LL(10)    - NDL overlaps between deployed slat and fixed-section
C                 nose                              [Ll / c]
C     XL(10)    - NDL chordwise locations of undeployed slat trailing
C                 edge                              [xl / c]
C     XN(10)    - NDL chordwise locations of fixed section nose
C                                                   [xn / c]
C     LDX(4)   - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     RXK      - Reynolds number based on cp in Section b3 [R'k]
C     MUP      - peak loading in Section b5 [mu p]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     EILPEF      - effective spanwise position of inboard edge
C                   of leading-edge device
C                   as a proportion of semi-span [(eta il)p eff]
C     NTLJ(5)     - integer denoting trailing edge flap type
C                   aft of leading edge device [(Ntl)j]
C
C     Input/Output
C     ------------
C     CXCM        - extended chord / chord for maximum lift calculation
C                   [(c'/c)m]
C     CELCXM      - (cel/c')m for maximum lift calculation
C
C     Output to common blocks
C     -----------------------
C     DCLML      - increment in aerofoil max. lift coefft. due to
C                  leading-edge device [Delta CLml]
C     DCLMXL     - increment in max. lift coefft. of wing due to
C                  deployment of leading-edge hig-lift devices
C                  [(Delta CLmaxl)]
C
C     -----------------------------------------------------------------
C
      INTEGER K,JL,FAULT
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
C
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
      INTEGER NTLJ
C     To get NTLJ from SUBREE
      COMMON /ZL9931/ NTLJ(5)
C
      REAL           RLTJ,RLJ
      REAL           GLJ,HLJ,LLJ,XLJ,XNJ
      REAL           LDHJ,ZU125J,ZL125J,ZCMJ
C     To get extra panel data in from read
      COMMON  /ZK9931/ LDHJ(5),ZU125J(5),ZL125J(5),ZCMJ(5),RLTJ(5),
     *                 RLJ(5,10),GLJ(5,10),HLJ(5,10),LLJ(5,10),
     +                 XLJ(5,10),XNJ(5,10)
C
      INTEGER LIST(18,2)
C
      DATA LIST /
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     * 1, 2, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 /
C
      FAULT = 0
      DCLML = 0.0
      DCLMXL = 0.0
C
C     If N delta l = 0 or Nl = 0, Delta CLmaxl and Delta CLml
C     can not be calculated.
C     -------------------------------------------------------
C
      IF (NDL .EQ. 0 ) GO TO 10
C
C     Section h calculates Delta CLmaxl
C     for CALC = 7, 8, 11, 13, 14, 17
C     -----------------------------------
      IF (LIST(CALC,1) .NE. 0)
     * CALL SUBRH1(NTLJ(1),NLJ(1),DLJ(1,JL),RLJ(1,JL),GLJ(1,JL),
     *               HLJ(1,JL)  ,LLJ(1,JL),
     *             XLJ(1,JL),XNJ(1,JL),LDX(1),LDX(2),RXK,MUP,CXCM,
     *             CELCXM,EILPEF,DCLMXL,FAULT)
C
C     Section H2 calculates Delta CLml
C     for CALC = 1, 2 and 5
C     ----------------------------------
C
      IF (LIST(CALC,2) .NE. 0)
     * CALL SUBRH2(TES,NL,RN(K),DL(JL),RL(JL),CXL(JL),
     *             GL(JL),HL(JL),LL(JL),XL(JL),XN(JL),CXC,CXCM,
     *             CELCXM,DCLML,FAULT)
C
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRH1(NTLJ,NLJ,DLJ,RLJ,GLJ,HLJ,LLJ,
     *             XLJ,XNJ,LD0,LD25,RXK,MUP,CXC,
     *             CELCXM,EILPEF,DCLMXL,FAULT)
C     ========================================
C
C     Purpose
C     -------
C     Section h:
C     Calculation of Delta CLmaxl due to leading-edge devices
C
C     Input
C     -----
C     TES    - slotted trailing-edge flap at ETAP flag
C              0 means absent, 1 means present
C     NL     - device type of leading-edge panel containing ETAP    [Nl]
C     DL        - deflection angle (deg)       [delta l]
C     RL        - leading edge radius / c        [rhol/c]
C     GL        - normal distance between slat trailing edge and
C                 section surface                   [Gl / c]
C     HL        - height of slat trailing edge above chord line
C                                                   [Hl / c]
C     LL        - overlap between deployed slat and fixed-section
C                 nose                              [Ll / c]
C     XL        - chordwise location of undeployed slat trailing
C                 edge                              [xl / c]
C     XN        - chordwise location of fixed section nose
C                                                   [xn / c]
C     LD0       - Lambda0
C     LD25      - Lambda1/4
C     RXK      - Reynolds number based on cp in Section b3 [R'k]
C     MUP      - peak loading in Section b5 [mu p]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     CELCXM      - (cel/c')m for maximum lift calculation
C     EILPEF      - effective spanwise position of inboard edge
C                   of leading-edge device
C                   as a proportion of semi-span [(eta il)p eff]
C
C     Output
C     ------
C     DCLMXL      - increment in max. lift coefft. of wing due to
C                   deployment of leading-edge high-lift devices
C                   [(Delta CLmaxl)]
C     FAULT       - fault number (0 means "none")
C
C     Local
C     -----
C     FIG1B       - flag on Figure 1b  (0 or 1)
C     DTOR        - (radians) = DTOR * (degrees)
C     LD          - Lambda
C     CS          - cos(Lambda)
C     FR          - factor FR in the notes
C     KVL         - factor [K Lambda l] in the notes
C     PSII        - factor [Psi i] from Figure 3 of Item 92031
C     KE          - factor Ke in the notes
C     KG          - factor Kg in the notes
C     KL          - factor Kl in the notes
C     D0          - [delta 0] in the notes
C     X,Y         - coordinates in data item plots
C     DCLMLG      - [(Delta CLml)/(Fr Psi i)]gen in the notes
C     TOL         - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER NTLJ(5),NLJ(5),FAULT
      REAL DLJ(5),RLJ(5),GLJ(5),HLJ(5),LLJ(5),XLJ(5),XNJ(5),LD0,LD25
     *      ,RXK,MUP, CXC,CELCXM,EILPEF,DCLMXL
C
C     CXC is read in as CXCM
      INTEGER FIG1B
      REAL DTOR,LD,CS,FR,KVL,PSII,KE,KG,KL,D0,X,Y,DCLMLG,TOL
C
      TOL = 1.0E-8
      DTOR = 3.141593 / 180.0
      FAULT = 0
C     Lambda = Lambda0
      LD = LD0
C
C     Calculate FR and KVL = (K Lambda l)
C     --------------------
      CS = COS(DTOR * LD)
      IF (CS .LE. TOL) FAULT = 1015
      IF (RXK .LE. 0.0) FAULT = 1016
      IF (FAULT .NE. 0) GO TO 60
C
C     FR = 0.153 * log10[R'k * cos^2(Lambda)]
      FR = 0.153 * LOG10(RXK * CS * CS)
C
C     (K Lambda l) = cos(Lambda1/4)
      KVL = COS(DTOR * LD25)
C
C     Figure 3 of Item 92031 gives (Psi i) for eta = (eta il)p eff
C     ------------------------------------------------------------
      CALL FIG21A(EILPEF,PSII,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Ke, Kg, Kl and delta0 depend on the device type
C     ===============================================
      GO TO (10, 10, 20, 20, 30, 30), NLJ(1)
C
C     Nl = 1 or 2
C     ===========
   10 KE = 1.0
      D0 = 0.0
C
C     Figure 2a of Item 94027 gives Kg
C     as a function of X = (rho l/c) * sec(Lambda)
C     --------------------------------------------
      X = RLJ(1) / CS
      CALL FIG22A(X,KG,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Figure 1a of Item 94027 gives Kl
C     as a function of X = (delta l) * cos(Lambda)
C     --------------------------------------------
      X = DLJ(1) * CS
      CALL FIG14A(X,KL,FAULT)
      IF (FAULT .NE. 0) GO TO  60
      GO TO 50
C
C     Nl = 3 or 4
C     ===========
   20 KE = 1.0
      D0 = 0.0
C
C     Figure 2a of Item 94027 gives Kg
C     as a function of X = (rho l/c) * sec(Lambda)
C     --------------------------------------------
      X = RLJ(1) / CS
      CALL FIG22A(X,KG,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Figure 1c of Item 94027 gives Kl
C     as a function of X = (delta l) * cos(Lambda)
C     and Y = (Hl/c) * sec(Lambda)
C     --------------------------------------------
      X = DLJ(1) * CS
      Y = HLJ(1) / CS
      CALL FIG23A(X,Y,KL,FAULT)
      IF (FAULT .NE. 0) GO TO 60
      GO TO 50
C
C     Nl = 5 or 6
C     ===========
C
C     Types 5 and 6 receive the same treatment except for Ke.
C     If Nl = 5, Figure 3 of Item 94027 gives Ke,
C     but if Nl = 6, Ke = 1.0
C     -------------------------------------------------------
   30 IF (NLJ(1) .EQ. 5) THEN
C      Read Ke from Figure 3 of Item 94027
C      as a function of X = (Ll/c) / [(xl/c) - (xn/c)]
       IF (ABS(XLJ(1) - XNJ(1)) .LE. TOL * ABS(LLJ(1))) FAULT = 1017
       IF (FAULT .NE. 0) GO TO 60
       X = LLJ(1) / (XLJ(1) - XNJ(1))
       CALL FIG24A(X,KE,FAULT)
       IF (FAULT .NE. 0) GO TO 60
      ELSE
       KE = 1.0
      END IF
C
C     Figure 2b of Item 94027 gives Kg
C     as a function of X = (rho l/c) * sec(Lambda)
C     --------------------------------------------
      X = RLJ(1) / CS
      CALL FIG25A(X,KG,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Kl is affected by the type of trailing-edge flap
C     ------------------------------------------------
C     Decide whether Figure 1b of Item 94027 or Figure 5 of Item 94030
C     should be used.
C
C     X = (delta l) * cos(Lambda
      X = DLJ(1) * CS
C     Y = (Gl/c) * sec(Lambda)
      Y = GLJ(1) / CS
C
C
C     Next line equivalent to IF (TES .EQ. 0) THEN
      IF (NTLJ(1) .LE. 2) THEN
C      Use Figure 1b of Item 94027
       FIG1B = 1
      ELSE
C     Otherwise TES = 1 and then if [(Gl/c)*sec(Lambda)]
C     is out of the range 0.02 to 0.05 use Figure 1b
       IF (Y .LT. 0.02 .OR. Y .GT. 0.05) THEN
        FIG1B = 1
       ELSE
C      Otherwise 0.02 <= [(Gl/c) * sec(Lambda)] <= 0.05
C      and therefore use Figure 5 of Item 94030
        FIG1B = 0
       END IF
      END IF
C
      IF (FIG1B .EQ. 1) THEN
C      Figure 1b of Item 94027 gives Kl
C      as a function of X = [(delta l)*cos(Lambda]
C      and Y = [(Gl/c)*sec(Lambda)]
C      -------------------------------------------
       CALL FIG26A(X,Y,KL,FAULT)

      ELSE
C      Figure 5 of Item 94030 gives Kl
C      as a function of X = [(delta l)*cos(Lambda]
C      -------------------------------------------
       CALL FIG27A(X,KL,FAULT)
      END IF
      IF (FAULT .NE. 0) GO TO 60
C
C
      D0 = 0.25
C
      GO TO 50
C
C     Subroutine 4 gives [(Delta CLml)/(Fr Psi i)]gen
C     as a function of (cel/c')m, Ke, Kg, Kl,
C     (delta 0), (delta l)
C     -----------------------------------------------
   50 CALL SUBR04(CELCXM,KE,KG,KL,D0,DLJ(1),DCLMLG,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Finally (Delta CLmaxl) =
C                              (c'/c) * [(Delta CLml)/(Fr Psi i)]gen *
C                              FR * (K Lambda l) * (Psi i) / mup
C     ----------------------------------------------------------------
      IF (ABS(MUP) .LE. TOL) FAULT = 1018
      IF (FAULT .NE. 0) GO TO 60
      DCLMXL = CXC * DCLMLG * FR * KVL * PSII / MUP
C
   60 RETURN
      END
C     -----------------------------------------------------------------
C
      SUBROUTINE  SUBRH2(TES,NL,RK,DL,RL,CXL,GL,HL,LL,XL,XN,CXC,
     *                 CXCM,CELCXM,DCLML,FAULT)
C     =========================================================
C
C     Purpose
C     -------
C     Section H2:
C     Calculation of [Delta CLml] due to leading-edge devices
C     on an aerofoil
C
C     Input
C     -----
C     TES    - slotted trailing-edge flap at ETAP flag
C              0 means absent, 1 means present
C     NL     - device type of leading-edge panel containing ETAP    [Nl]
C     RK     - current Reynolds number
C     DL        - deflection angle (deg)       [delta l]
C     RL        - leading edge radius / c        [rhol/c]
C     CXL       - leading edge extended chord  [c'l/c]
C     GL        - normal distance between slat trailing edge and
C                 section surface                   [Gl / c]
C     HL        - height of slat trailing edge above chord line
C                                                   [Hl / c]
C     LL        - overlap between deployed slat and fixed-section
C                 nose                              [Ll / c]
C     XL        - chordwise location of undeployed slat trailing
C                 edge                              [xl / c]
C     XN        - chordwise location of fixed section nose
C                                                   [xn / c]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     EILPEF      - effective spanwise position of inboard edge
C                   of leading-edge device
C                   as a proportion of semi-span [(eta il)p eff]
C
C     Output
C     ------
C     CXCM        - extended chord / chord for maximum lift calculation
C                   [(c'/c)m]
C     CELCXM      - (cel/c')m for maximum lift calculation
C     DCLML      - increment in aerofoil max. lift coefft. due to
C                  leading-edge device [Delta CLml]
C     FAULT       - fault number (0 means "none")
C
C     Local
C     -----
C     FIG1B       - flag on Figure 1b  (0 or 1)
C     LD          - Lambda (taken as zero)
C     CS          - cos(Lambda)
C     FR          - factor FR in the notes
C     KE          - factor Ke in the notes
C     KG          - factor Kg in the notes
C     KL          - factor Kl in the notes
C     D0          - [delta 0] in the notes
C     X,Y         - coordinates in data item plots
C     DCLMLG      - [(Delta CLml)/(Fr Psi i)]gen in the notes
C     TOL         - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER TES,NL,FAULT
      REAL RK,DL,RL,CXL,GL,HL,LL,XL,XN,CXC,CXCM,CELCXM,DCLML
C
      INTEGER FIG1B
      REAL LD,CS,FR,KE,KG,KL,D0,X,Y,DCLMLG,TOL
C
      TOL = 1.0E-8
      FAULT = 0
      DCLML = 0.0
C
C     To allow the use of the subroutines for wings, set Lambda = 0.0
C     and cos(Lambda = 1.0
      LD = 0.0
      LD = LD
      CS = 1.0
C
      IF (ABS(CXC) .LE. TOL) FAULT = 1019
      IF (FAULT .NE. 0) GO TO 60
C
C     Ke, Kg, Kl and delta0 depend on the device type
C     ===============================================
      GO TO (10, 10, 20, 20, 30, 30), NL
C
C     Nl = 1 or 2
C     ===========
C     (c'/c)m = (c'/c)
   10 CXCM = CXC
C     (cel/c')m = (c'l/c) / (c'/c)
      CELCXM = CXL / CXC
C     Ke = 1
      KE = 1.0
C     (delta 0) = 0
      D0 = 0.0
C
C     Figure 2a of Item 94027 gives Kg
C     as a function of X = (rho l/c) * sec(Lambda)
C     --------------------------------------------
      X = RL / CS
      CALL FIG22A(X,KG,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Figure 1a of Item 94027 gives Kl
C     as a function of X = (delta l) * cos(Lambda)
C     --------------------------------------------
      X = DL * CS
      CALL FIG14A(X,KL,FAULT)
      IF (FAULT .NE. 0) GO TO  60
      GO TO 50
C
C     Nl = 3 or 4
C     ===========
C     (c'/c)m = (c'/c)
   20 CXCM = CXC
C     (cel/c')m = (c'l/c) * (c'/c)
      CELCXM = CXL / CXC
C     Ke = 1
      KE = 1.0
C     (delta 0) = 0
      D0 = 0.0
C
C     Figure 2a of Item 94027 gives Kg
C     as a function of X = (rho l/c) * sec(Lambda)
C     --------------------------------------------
      X = RL / CS
      CALL FIG22A(X,KG,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Figure 1c of Item 94027 gives Kl
C     as a function of X = (delta l) * cos(Lambda)
C     and Y = (Hl/c) * sec(Lambda
C     --------------------------------------------
      X = DL * CS
      Y = HL / CS
      CALL FIG23A(X,Y,KL,FAULT)
      IF (FAULT .NE. 0) GO TO 60
      GO TO 50
C
C     Nl = 5 or 6
C     ===========
C
C     Types 5 and 6 get much the same treatment as each other
C     -------------------------------------------------------
C     (c'/c)m = (c'/c)
   30 CXCM = CXC
C
C     For Nl = 5 or 6, CXL = (cl/c)
C     (Cel/c')m = [(cl/c) / (c'/c)
      CELCXM = CXL / CXC
C
C     Ke depends on the device type
C     -----------------------------
      IF (NL .EQ. 5) THEN
C      For Nl = 5 read Ke from Figure 3 of Item 94027
C      as a function of X = (Ll/c) / [(xl/c) - (xn/c)]
       X = LL / (XL - XN)
       CALL FIG24A(X,KE,FAULT)
       IF (FAULT .NE. 0) GO TO 60
      ELSE
C      For Nl = 6, Ke = 1
       KE = 1.0
      END IF
C
C     Figure 2b of Item 94027 gives Kg
C     as a function of X = (rho l/c) * sec(Lambda)
C     --------------------------------------------
      X = RL / CS
      CALL FIG25A(X,KG,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
C     Kl is affected by the type of trailing-edge flap
C     ------------------------------------------------
C     X = (delta l/c) * cos(Lambda)
      X = DL * CS
C     Y = (Gl/c) * sec(Lambda)
      Y = GL / CS
C
C     Decide whether to use Figure 1b of Item 94027
C     or Figure 5 of Item 94030
C     ---------------------------------------------
      IF (TES .EQ. 0) THEN
C      If TES = 0 use Figure 1b
       FIG1B = 1
      ELSE
C     Otherwise TES = 1 and if Y = [(Gl/c) * sec(Lambda)]
C     is out of the range 0.02 to 0.05 use Figure 1b
       IF (Y .LT. 0.02 .OR. Y .GT. 0.05) THEN
        FIG1B = 1
       ELSE
C      Otherwise 0.02 <= [(Gl/c) * sec(Lambda)] <= 0.05
C      and use Figure 5
        FIG1B = 0
       END IF
      END IF
C
      IF (FIG1B .EQ. 1) THEN
C      Figure 1b of Item 94027 gives Kl
C      as a function of X = [(delta l/c) * cos(Lambda)]
C      and Y = (Gl/c) * sec(Lambda)
C      ------------------------------------------------
       CALL FIG26A(X,Y,KL,FAULT)
      ELSE
C      Otherwise, for both device types, Figure 5 ofItem 94030 gives Kl
C      as a function of X = [(delta l/c) * cos(Lambda)]
C      ------------------------------------------------
       CALL FIG27A(X,KL,FAULT)
C
      END IF
      IF (FAULT .NE. 0) GO TO 60
C
      D0 = 0.25
C
      GO TO 50
C
C     Subroutine 4 gives [(Delta CLml)/(Fr Psi i)]gen
C     as a function of (cel/c')m, Ke, Kg, Kl,
C     (delta 0), (delta l)
C     -----------------------------------------------
   50 CALL SUBR04(CELCXM,KE,KG,KL,D0,DL,DCLMLG,FAULT)
      IF (FAULT .NE. 0) GO TO 60
C
      IF (RK .LE. 0.0) FAULT = 1020
      IF (FAULT .NE. 0) GO TO 60
C
C     FR is given by FR = 0.153 * log10(Rk)
C     ---------------
      FR = 0.153 * LOG10(RK)
C
C     Finally (Delta CLml) is given by
C     (Delta CLml) = [(Delta CLml)/(Fr Psi i)]gen * FR
C     ------------------------------------------------
C
      DCLML = DCLMLG * FR * CXCM
C
C
   60 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRII(K,JL,JT,FAULT)
C     ================================
C
C     Purpose
C     -------
C     To supply data for and store results of Sections i and i2:
C     Calculation of Delta CLmaxt and Delta CLmt
C
C     Input
C     -----
C     K      - Reynolds number, Mach number pair
C     JL     - leading-edge device setting number (may be zero)
C     JT     - trailing-edge device setting number
C
C     Output
C     ------
C     FAULT  - fault number (0 means none)
C
C     Input from common blocks
C     ------------------------
C     CALC   - calculation type (1 to 18)
C     NDL    - number of leading edge device settings (0<=NDL<=10)
C     NDT    - number of trailing-edge device settings (0<=NDT<=10)
C     NL     - device type of leading-edge panel containing ETAP    [Nl]
C     NT     - device type of trailing-edge panel containing EATP   [Nt]
C     RN(1)     - Reynolds numbers
C     A         - aspect ratio of wing    [A]
C     TR         - taper ratio of wing     [lambda]
C     T         - thickness to chord ratio [t/c]
C     XUM,ZUM   - dimensionless chordwise location and height
C                 maximum height [xum/c and zum/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17),  - dimensionless upper-surface and lower-surface
C     ZLG(17)     coordinates at each of 17 standard chordwise
C                 locations [(zu/c)g and (zl/c)g]
C     EOTP      - outboard limit of trailing-edge flap
C                 panel which contains ETAP  [(eta ol)p]
C     CXL(10)   - NDL leading edge extended chords  [c'l/c]
C     DCL(10)   - NDL chord extensions due to deployment of leading
C                 edge device                       [Delta cl / c]
C     DT(3,10)  - NDT deflection angles (deg) of up to 3 elements
C                                                        [delta t]
C     DCT(3,10) - NDT chord extensions due to deployment of up to 3
C                 elements                               [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements     [ct/c]
C     RLT       - leading edge radius of section or of deployed leading
C                 edge device / thickness                [rhol/t]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)                 [phit]
C     XLM,ZLM   - coordinates of section maximum lower surface ordinate
C                                                        [xlm/c, zlm/c]
C     ZCM       - section maximum camber height          [zcm/c]
C     ZU125,    - section upper and lower surface ordinates
C     ZL125       at x=0.0125c                 [(zu/c)1.25, (zl/c)1.25]
C     LDH        - hinge-line sweep (deg)                 [Lambda h]
C     LDX(4)    - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     RXK      - Reynolds number based on cp in Section b3 [R'k]
C     MUP      - peak loading in Section b5 [mu p]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     EITPEF      - effective spanwise position of inboard edge
C                   of trailing-edge device
C                   as a proportion of semi-span [(eta it)p eff]
C     (EITPEF comming through as EIT1EF)
C     NLTJ(5)     - integer denoting leading edge flap type
C                   forward of trailing edge device [(Ntt)j]
C     CXCTMJ(5)   - extended chord /chord for trailing edge maximum lift
C                   calculation [(c'/c)m]
C     Input/Output
C     ------------
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C
C     Output to common blocks
C     -----------------------
C     DCLMT      - increment in aerofoil max. lift coefft. due to
C                  trailing-edge device [Delta CLmt]
C     DCLMXT     - increment in max. lift coefft. of wing due to
C                  deployment of trailing-edge high-lift devices
C                  [(DCL max t)]
C     DCLMTJ(5)  - increment in (DCL max t) j  for NNT panels
C     Local
C     -----
C     IL          - (1 max JL) to guard against CXL(0) etc
C     LIST(18,2)  - list of flags that decides the action for each CALC
C
C     -----------------------------------------------------------------
C
      INTEGER K,JL,JT,FAULT
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
C
      REAL   DCLMTJ
C
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
      COMMON /ZP9931/ DCLMTJ(5)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL   LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ,D,P
C
      REAL   RLTJ,RLJ
      REAL   GLJ,HLJ,LLJ,XLJ,XNJ
      REAL   LDHJ,ZU125J,ZL125J,ZCMJ
C     To get in extra panel data from read
      COMMON  /ZK9931/ LDHJ(5),ZU125J(5),ZL125J(5),ZCMJ(5), RLTJ(5),
     *                 RLJ(5,10),  GLJ(5,10),HLJ(5,10),LLJ(5,10),
     +                 XLJ(5,10),XNJ(5,10)
      INTEGER NLTJ
C     To get NLTJ from SUBREE
      COMMON /ZM9931/ NLTJ(5)
C
      REAL    CXCTMJ
C     To get CXCTMJ from SUBREE
      COMMON /ZN9931/ CXCTMJ(5)
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
      INTEGER IL,LIST(18,2)
C
      INTEGER JJJ
C
      DATA LIST /
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     * 1, 2, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 /
C
      FAULT = 0
      DCLMT = 0.0
      DCLMXT = 0.0
C
      DO 5 JJJ = 1,5
          DCLMTJ(JJJ) = 0.0
    5 CONTINUE
C
      IF (NDL .EQ .0) NL = 0
C
      IF (NDT .EQ. 0 ) GO TO 10
C
C     Avoid "CXL(0)" and "DCL(0)" when JL = 0
C     in calls to SUBRI1 and SUBRI2
C     ---------------------------------------
      IL = MAX0(1,JL)
C
C     Calculation of Delta CLmaxt
C     ---------------------------
C    EOTP set to zero not used
      EOTP = 0.0
      IF (LIST(CALC,1) .GT. 0)
     * CALL SUBRI1(NLJ,NTJ,A,TR,T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,EOTP,
     *           CXLJ(1,IL),DCLJ(1,IL),DTJ(1,1,JT),DCTJ(1,1,JT),CTJ
     *           ,RLTJ,PHITJ,ZCMJ,ZU125J,ZL125J,LDHJ,LDX,RXK,MUP,CXC,
     *           EITPEF,DCLMXT,FAULT,NNL,NNT,CXCTMJ,NLTJ,EIT,EOT,DCLMTJ)
C
C     Calculation of Delta CLmt
C     -------------------------
      IF (LIST(CALC,2) .GT. 0)
     * CALL SUBRI2(NL,NT,RN(K),T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,
     *           CXL(IL),DCL(IL),DT(1,JT),DCT(1,JT),CT,RLT,PHIT,
     *             ZCM,ZU125,ZL125,CXC,DCLMT,FAULT)
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRI1(NLJ,NTJ,A,TR,T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,EOTP,
     *                  CXLJ,DCLJ,DTJ,DCTJ,CTJ,RLTJ,PHITJ,
     *                  ZCMJ,ZU125J,ZL125J,LDHJ,LDX,RXK,MUP,CXC,EITPEF,
     *                  DCLMXT,FAULT,NNL,NNT,CXCTMJ,NLTJ,EIT,EOT,DCLMTJ)
C     ==================================================================
C
C     Purpose
C     -------
C     Section i:
C     Calculation of Delta CLmaxt due to trailing-edge devices
C
C     Input
C     -----
C     NL     - device type of leading-edge panel containing ETAP    [Nl]
C     NT     - device type of trailing-edge panel containing EATP   [Nt]
C     A         - aspect ratio of wing    [A]
C     TR        - taper ratio of wing     [lambda]
C     T         - thickness to chord ratio [t/c]
C     XUM,ZUM   - dimensionless chordwise location and height
C                 maximum height [xum/c and zum/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17),  - dimensionless upper-surface and lower-surface
C     ZLG(17)     coordinates at each of 17 standard chordwise
C                 locations [(zu/c)g and (zl/c)g]
C     EOTP      - outboard limit of trailing-edge flap
C                 panel which contains ETAP  [(eta ol)p]
C     CXL       - leading edge extended chord  [c'l/c]
C     DCL       - chord extension due to deployment of leading
C                 edge device                       [Delta cl / c]
C     DT(3)     - deflection angles (deg) of up to 3 elements
C                                                        [delta t]
C     DCT(3)    - chord extensions due to deployment of up to 3
C                 elements                               [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements     [ct/c]
C     RLT       - leading edge radius of section or of deployed leading
C                 edge device / thickness                [rhol/t]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)                 [phit]
C     ZCM       - section maximum camber height          [zcm/c]
C     ZU125,    - section upper and lower surface ordinates
C     ZL125       at x=0.0125c                 [(zu/c)1.25, (zl/c)1.25]
C     LDH        - hinge-line sweep (deg)                 [Lambda h]
C     LDX(4)   - sweep of 0, 1/4, 1/2 and 1.0 chord lines
C     RXK      - Reynolds number based on cp in Section b3 [R'k]
C     MUP      - peak loading in Section b5 [mu p]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     EITPEF      - effective spanwise position of inboard edge
C                   of trailing-edge device
C                   as a proportion of semi-span [(eta it)p eff]
C
C     Input/Output
C     ------------
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C
C     Output
C     ------
C     DCLMXT      - increment in max. lift coefft. of wing due to
C                   deployment of trailing-edge high-lift devices
C                   (DCL max t)
C     FAULT       - fault number
C
C     Local
C     -----
C     DTOR        - (radians) = DTOR * (degrees)
C     LD          - Lambda0
C     LD25        - Lambda1/4
C     CS          - cosine of LD or LD25
C     FR,KVT,KF   - factors in final formula for Delta CLmaxt
C     PHIO,PHII   - Phi o and Phi i
C     DCLMTG      - [Delta CLmt / FR (Phi o - Phi i)]gen
C     TOL         - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER NLJ(5),NTJ(5),FAULT,NNL,NNT,NLTJ(5) ,J
      INTEGER NT
      REAL A,TR,T,XUM,ZUM,TAU,ZUG(17),ZLG(17),TAUA,EOTP,
     *     CXL,DCL,DT(3),DCT(3),CT(3),RLT,PHIT,
     *     ZCM,ZU125,ZL125,LDH,LDX(4),RXK,MUP,CXC,EITPEF,DCLMXT
C
      REAL DTOR,LD,LD25,CS,FR,KVT,KF,PHIO,PHII,DCLMTG,TOL
C
      REAL CXLJ(5),DCLJ(5),DTJ(3,5),DCTJ(3,5), CTJ(3,5),
     +RLTJ(5),PHITJ(5),ZCMJ(5),ZU125J(5),ZL125J(5),LDHJ(5)
C
      REAL EIT(5),EOT(5)
      REAL CXCTMJ(5)
      REAL DCLMTJ(5)
C     Next 22 lines avoid use warnings from earlier versions
      DCT(1) =  0
      DCT(1) = DCT(1) +0
      CT(1)  =  0
      CT(1)  = CT(1) + 0
      DT(1)  =  0
      DT(1)  = DT(1) + 0
      DCT(2) =  0
      DCT(2) = DCT(2) + 0
      CT(2)  =  0
      CT(2)  = CT(2) + 0
      DT(2)  =  0
      DT(2)  = DT(2) + 0
      DCT(3) =  0
      DCT(3) = DCT(3) + 0
      CT(3)  =  0
      CT(3)  = CT(3) + 0
      DT(3)  =  0
      DT(3)  = DT(3) + 0
      NLJ(1) =  NLJ(1) + 0
      NNL    =  NNL + 0
      NT = 0
      NT = NT + 0
C
C
      CONTINUE
      FAULT = 0
      DTOR = 3.141593 / 180.0
      TOL = 1.0E-8
C     Lambda = Lambda0 = LDX(1)
      LD = LDX(1)
C     LD25 = Lambda1/4 = LDX(2)
      LD25 = LDX(2)
C
C     Calculate FR = 0.153 * log10[(R'k) * cos^2(Lambda)]
C     ------------
      CS = COS(DTOR * LD)
      IF (RXK * CS * CS .LE. TOL) FAULT = 1021
      IF (FAULT .NE. 0) GO TO 50
      FR = 0.153 * LOG10(RXK * CS * CS)
C
C     Calculate KVT = (K Lambda t) = [cos(Lambda1/4)]^2.5
C     -------------
      CS = COS(DTOR * LD25)
      IF (CS .LE. 0.0) FAULT = 1022
      IF (FAULT .NE. 0) GO TO 50
      KVT = CS**2.5
C
C     Choose the subroutine appropriate to the device type
C     ----------------------------------------------------
      CXL = CXLJ(1)
      DCL = DCLJ(1)
      DO 70 J = 1,NNT
      CXC = CXCTMJ(J)
      RLT = RLTJ(J)
      PHIT = PHITJ(J)
      ZCM = ZCMJ(J)
      ZU125 = ZU125J(J)
      ZL125 = ZL125J(J)
      LDH = LDHJ(J)
      EOTP = EOT(J)
      NT = NTJ(J)
      IF (J .NE. 1) EITPEF = EIT(J)
      GO TO (10, 20, 30, 30, 30), NTJ(J)
C
C     NT = 1
C     ------
C     Kf = 1.0
   10 KF = 1.0
      CALL SUBRI3(NLTJ(J),A,TR,EOTP,CXL,DCL,DTJ(1,J),CTJ(1,J)
     *            ,RLT,PHIT,
     *           LDHJ(J),LDX(3),
     +           CXC,EITPEF,PHIO,PHII,DCLMTG,FAULT)
      GO TO 40
C
C     NT = 2
C     ------
C     Kf = 1.0
   20 KF = 1.0
      CALL SUBRI4(A,TR,EOTP,DTJ(1,J),CTJ(1,J),ZCM,ZU125,ZL125,LDHJ(J)
     *           ,LDX(1),LDX(3),CXC,EITPEF,PHIO,PHII,DCLMTG,FAULT)
      GO TO 40
C
C     NT = 3, 4 or 5
C     --------------
C     Kf = 1.1
   30 KF = 1.1
C
      CALL SUBRI5(NTJ(J),A,TR,T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,EOTP,
     *            DTJ(1,J),DCTJ(1,J),CTJ(1,J),ZUG(3),LDHJ(J),LDX(1)
     *            ,LDX(3),LDX(4),CXC,EITPEF,PHIO,PHII,DCLMTG,FAULT)
C
      GO TO 40
C
   40 IF (FAULT .EQ. 0) THEN
C
C       (DCL max t) = Kf * (K Lambda t) * cos(Lambda h)
C       * FR * [Delta CLmt / FR (Phi o - Phi i)]gen
C       * [(Phi o) - (Phi i)] / (mu p)
C      ================================================
       IF (ABS(MUP) .LE. TOL) FAULT = 1023
       IF (FAULT .NE. 0) GO TO 50
C       DCLMXT = KF * KVT * COS(DTOR * LDH) * FR * DCLMTG
C               * (PHIO - PHII) / MUP
       DCLMTJ(J) = KF * KVT * COS(DTOR * LDH) * FR * DCLMTG
     *          * (PHIO - PHII) / MUP
       DCLMXT = DCLMXT + DCLMTJ(J)
C
      END IF
C
   70 CONTINUE
   50 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRI2(NL,NT,RK,T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,
     *                  CXL,DCL,DT,DCT,CT,RLT,PHIT,
     *                  ZCM,ZU125,ZL125,CXC,DCLMT,FAULT)
C     ============================================================
C
C     Purpose
C     -------
C     Section i2:
C     Calculation of Delta CLmt due to trailing-edge devices
C     on aerofoils
C
C     Input
C     -----
C     NL     - device type of leading-edge panel containing ETAP    [Nl]
C     NT     - device type of trailing-edge panel containing EATP   [Nt]
C     RK        - Reynolds number
C     T         - thickness to chord ratio [t/c]
C     XUM,ZUM   - dimensionless chordwise location and height
C                 maximum height [xum/c and zum/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17),  - dimensionless upper-surface and lower-surface
C     ZLG(17)     coordinates at each of 17 standard chordwise
C                 locations [(zu/c)g and (zl/c)g]
C     CXL       - leading edge extended chord  [c'l/c]
C     DCL       - chord extension due to deployment of leading
C                 edge device                       [Delta cl / c]
C     DT(3)     - deflection angles (deg) of up to 3 elements
C                                                        [delta t]
C     DCT(3)    - chord extensions due to deployment of up to 3
C                 elements                               [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements     [ct/c]
C     RLT       - leading edge radius of section or of deployed leading
C                 edge device / thickness                [rhol/t]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)                 [phit]
C     ZCM       - section maximum camber height          [zcm/c]
C     ZU125     - section upper and lower surface ordinates
C     ZL125       at x=0.0125c                 [(zu/c)1.25, (zl/c)1.25]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C
C     Input/Output
C     ------------
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C
C     Output
C     ------
C     DCLMT       - increment in aerofoil max. lift coefft. due to
C                   trailing-edge device [Delta CLmt]
C     FAULT       - fault number
C
C     -----------------------------------------------------------------
C
      INTEGER NL,NT,FAULT
      REAL RK,T,XUM,ZUM,TAU,ZUG(17),ZLG(17),TAUA,
     *     CXL,DCL,DT(3),DCT(3),CT(3),RLT,PHIT,
     *     ZCM,ZU125,ZL125,CXC,DCLMT
C
C     Choose the subroutine appropriate to the device type
C     ----------------------------------------------------
      GO TO (10, 20, 30, 30, 30), NT
C
C     NT = 1
C     ------
   10 CALL SUBRI6(NL,RK,CXL,DCL,DT(1),CT(1),RLT,PHIT,CXC,DCLMT,FAULT)
      GO TO 40
C
C     NT = 2
C     ------
   20 CALL SUBRI7(RK,DT(1),CT(1),ZCM,ZU125,ZL125,CXC,DCLMT,FAULT)
      GO TO 40
C
C     NT = 3, 4 or 5
C     --------------
C
   30 CALL SUBRI8(NT,RK,T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,DT,DCT,CT,
     *            ZUG(3),CXC,DCLMT,FAULT)
C
C
   40 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRI3(NLTJ,A,TR,EOTP,CXL,DCL,DTJ,CTJ,RLT
     *            ,PHIT,LDHJ,LD50,CXC,EITPEF,PHIO,PHII,DCLMTG,FAULT)
C     =============================================================
C
C     Purpose
C     -------
C     Calculation of [Delta CLmt / FR (Phi o - Phi i)]gen
C     for Nt = 1
C
C     Input
C     -----
C     NL     - device type of leading-edge panel containing ETAP    [Nl]
C     A         - aspect ratio of wing    [A]
C     TR         - taper ratio of wing     [lambda]
C     EOTP      - outboard limit of trailing-edge flap
C                 panel which contains ETAP  [(eta ol)p]
C     CXL       - leading edge extended chord  [c'l/c]
C     DCL       - chord extension due to deployment of leading
C                 edge device                       [Delta cl / c]
C     DT        - deflection angle (deg) [delta t]
C     CT        - flap chord / c  [ct/c]
C     RLT       - leading edge radius of section or of deployed leading
C                 edge device / thickness                [rhol/t]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)                 [phit]
C     LDH        - hinge-line sweep (deg)                 [Lambda h]
C     LD50      - Lambda1/2
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     EITPEF      - effective spanwise position of inboard edge
C                   of trailing-edge device
C                   as a proportion of semi-span [(eta it)p eff]
C
C     Output
C     ------
C     PHIO,PHII   - Phi o and Phi i
C     DCLMTG      - [Delta CLmt / FR (Phi o - Phi i)]gen
C     FAULT       - fault number
C
C     Local
C     -----
C     DTOR        - (radians) = DTOR * (degrees)
C     AT          - [at] calculated by Subroutine 11
C     LD2         - hinge-line sweep LDH [Lambda2 = Lambda h]
C     CS          - cos(Lambda2)
C     X           - input parameter for plots
C     KF,JP,KG,   - factors in the formulae in Section i
C     KT,T
C     XSCX,CTCX   - [x's/c'] and [ct/c']
C     TOL         - tolerance
C     TOP         - dividend
C
C     -----------------------------------------------------------------
C
      INTEGER NL,FAULT
      REAL A,TR,EOTP,CXL,DCL,DT,CT,RLT,PHIT,LDH,LD50,
     *            CXC,EITPEF,PHIO,PHII,DCLMTG
C
      REAL DTOR,AT,LD2,CS,X,KF,JP,KG,KT,T,XSCX,CTCX,TOL,TOP
C
      INTEGER NLTJ
      REAL   DTJ,CTJ,LDHJ
C
      FAULT = 0
      DCLMTG = 0.0
      DTOR = 3.141593 / 180.0
      TOL = 1.0E-8
C
      NL = NLTJ
      CT = CTJ
      DT = DTJ
C
C     Lambda2 = (Lambda h)
      LDH = LDHJ
      LD2 = LDH
C
      IF (CXC .LE. TOL) FAULT = 1024
      IF (FAULT .NE. 0) GO TO 10
C
C     Subroutine 11 gives (at) as a function of (ct/c) and (c'/c)
C     -----------------------------------------------------------
      CALL SUBR11(CT,CXC,AT,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Figure 1 of Item 94028 gives Jp
C     as a function of X = [(delta t) + (phi t)] * sec(Lambda2)
C     ---------------------------------------------------------
      CS = COS(DTOR * LD2)
      IF (ABS(CS) .LE. TOL) FAULT = 1025
      IF (FAULT .NE. 0) GO TO 10
      X = (DT + PHIT) / CS
      CALL FIG28A(X,JP,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     KG = 1.225 + 4.525 * (rho l/t)
C     ------------------------------
      KG = 1.225 + 4.525 * RLT
C
C     Kf and Kt are simply:
C     ---------------------
      KF = 1.0
      KT = 0.8
C
C     (ct/c') = (ct /c) / (c'/c)
C     --------------------------
      CTCX = CT /CXC
C
      IF (NL .EQ. 0) THEN
C      If Nl = 0 then (x's/c') = 0.0
C      -----------------------------
       XSCX = 0.0
      ELSE
       IF (NL .LE. 4) THEN
C       If Nl = 1 to 4 then (x's/c') = 1/2 * (c'l/c) / (c'/c)
C       -----------------------------------------------------
        XSCX = 0.5 * CXL / CXC
       ELSE
C       If Nl = 5 or 6 then
C       (x's/c') = 1/2 * [(c'l/c) - (delta cl/c)] / (c'/c)
C       --------------------------------------------------
C     Next line avoids use warning
        DCL=DCL
         XSCX = 0.5 * CXL / CXC
       END IF
      END IF
C
C     Figure 2 of Item 94028 gives T
C     as a function of (ct/c') and (x's/c')
C     -------------------------------------
      CALL FIG29A(CTCX,XSCX,T,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     [Delta CLmt / FR (Phi o - Phi i)]gen =
C     Kf * KG * Kt * T * (c'/c) * Jp * (at) * (pi/180)
C     * (delta t) * sec(Lambda2)
C     ================================================
      TOP = KF * KG * KT * T * CXC * JP * AT * DTOR * DT
      IF (ABS(CS) .LE. TOL * ABS(TOP)) FAULT = 1025
      IF (FAULT .NE. 0) GO TO 10
      DCLMTG = TOP / CS
C
C     Read (Phi o) and (Phi i) from Figure 3a of Item 91014
C     -----------------------------------------------------
C     X = A * tan(Lambda1/2) - 8 * lambda
      X = A * TAN(DTOR * LD50) - 8.0 * TR
C     (Phi o) is a function of X and (eta ot)p
      CALL FIG17A(X,EOTP,PHIO,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C     (Phi i) is a function of X and (eta it)peff
      CALL FIG17A(X,EITPEF,PHII,FAULT)
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRI4(A,TR,EOTP,DTJ,CTJ,ZCM,ZU125,ZL125,LDHJ,LD0,
     *                  LD50,CXC,EITPEF,PHIO,PHII,DCLMTG,FAULT)
C     ==========================================================
C
C     Purpose
C     -------
C     Calculation of [Delta CLmt / FR (Phi o - Phi i)]gen
C     for Nt = 2
C
C     Input
C     -----
C     A         - aspect ratio of wing    [A]
C     TR        - taper ratio of wing     [lambda]
C     EOTP      - outboard limit of trailing-edge flap
C                 panel which contains ETAP  [(eta ol)p]
C     DT        - deflection angle (deg) [delta t]
C     CT        - flap chord / c  [ct/c]
C     ZCM       - section maximum camber height          [zcm/c]
C     ZU125,    - section upper and lower surface ordinates
C     ZL125       at x=0.0125c                 [(zu/c)1.25, (zl/c)1.25]
C     LDH       - hinge-line sweep (deg)                 [Lambda h]
C     LD0       - Lambda0
C     LD50      - Lambda1/2
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     EITPEF      - effective spanwise position of inboard edge
C                   of trailing-edge device
C                   as a proportion of semi-span [(eta it)p eff]
C
C     Output
C     ------
C     PHIO,PHII   - Phi o and Phi i
C     DCLMTG      - [Delta CLmt / FR (Phi o - Phi i)]gen
C     FAULT       - fault number
C
C     Local
C     -----
C     DTOR        - (radians) = DTOR * (degrees)
C     AT          - [at] calculated by Subroutine 11
C     LD2         - hinge-line sweep LDH [Lambda2 = Lambda h]
C     CS          - cos(Lambda2)
C     X           - input parameter for plots
C     KF,KTM,T    - factors in the formulae in Section i
C     XSCX,CTCX   - [x's/c'] and [ct/c']
C     DCLMTD      - (Delta C'Lmt)d
C     TOL         - tolerance
C     TOP         - dividend
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL A,TR,EOTP,DT,CT,ZCM,ZU125,ZL125,LDH,LD0,
     *     LD50,CXC,EITPEF,PHIO,PHII,DCLMTG
C
      REAL DTOR,AT,LD2,CS,X,KF,KTM,T,XSCX,CTCX,DCLMTD,TOL,TOP
C
      REAL LDHJ,DTJ,CTJ
C
C
      CT = CTJ
      DT = DTJ
      FAULT = 0
      DCLMTG = 0.0
      DTOR = 3.141593 / 180.0
      TOL = 1.0E-8
C     Lambda2 = (Lambda h)
      LDH = LDHJ
      LD2 = LDH
      CS = COS(DTOR * LD2)
C
      IF (ABS(CXC) .LE. TOL) FAULT = 1026
      IF (ABS(CS) .LE. TOL) FAULT = 1027
      IF (FAULT .NE. 0) GO TO 10
C
C     Subroutine 11 gives at
C     as a function of (ct/c) and (c'/c)
C     ----------------------------------
      CALL SUBR11(CT,CXC,AT,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Ktm = 0.95 - 0.00593 * (delta t) * sec(Lambda2)
C     -----------------------------------------------
      KTM = 0.95 - 0.00593 * DT / CS
C
C     Kf is simply:
C     -------------
      KF = 1.0
C
C     Figure 2 of Item 94028 gives T
C     as a function of (ct/c') and (x's/c')
C     with (x's/c') = 0
C     -------------------------------------
C     (x's/c') = 0.0
      XSCX = 0.0
C     (ct/c') = (ct/c) / (c'/c)
      CTCX = CT / CXC
      CALL FIG29A(CTCX,XSCX,T,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     (Delta C'Lmt)d is given by Figure 2 of Item 94029 as a function
C     of X = (1/2) * [(zu/c)125 - (zl/c)125] * sec(Lambda)
C     ---------------------------------------------------------------
      IF (ABS(COS(DTOR * LD0)) .LE. TOL) FAULT = 1028
      IF (FAULT .NE. 0) GO TO 10
      X = 0.5 * (ZU125 - ZL125) / COS(DTOR * LD0)
      CALL FIG30A(X,DCLMTD,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     [Delta CLmt / FR (Phi o - Phi i)]gen =
C     Kf * (c'/c) * [(Delta C'Lmt)d - 8 * (zcm/c) * sec(Lambda)]
C     * Ktm * T * (at) * (pi/180) * (delta t) * sec(Lambda2)
C     ==========================================================
      TOP = KF * CXC * (DCLMTD - 8.0 * ZCM / COS(DTOR * LD0))
     *      * KTM * T * AT * DTOR * DT
      IF (ABS(CS) .LE. TOL * ABS(TOP)) FAULT = 1029
      IF (FAULT .NE. 0) GO TO 10
      DCLMTG = TOP / CS
C
C     Read Phi o and Phi i from Figure 3a of Item 91014
C     -------------------------------------------------
C     X = A * tan(Lambda1/2) - 8 * lambda
      X = A * TAN(DTOR * LD50) - 8.0 * TR
C     (Phi o) is a function of X and (eta ot)p
      CALL FIG17A(X,EOTP,PHIO,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C     (Phi i) is a function of X and (eta it)peff
      CALL FIG17A(X,EITPEF,PHII,FAULT)
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRI5(NTJ,A,TR,T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,EOTP,
     *            DTJ,DCTJ,CTJ,ZU125,LDHJ,LD0,LD50,LD1,CXC,EITPEF,
     *            PHIO,PHII,DCLMTG,FAULT)
C     ===============================================================
C
C     Purpose
C     -------
C     Calculation of [Delta CLmt / FR (Phi o - Phi i)]gen
C     for trailing edge device types Nt = 3, 4 and 5
C
C     Input
C     -----
C     NT     - device type of trailing-edge panel containing EATP   [Nt]
C     A         - aspect ratio of wing    [A]
C     TR        - taper ratio of wing     [lambda]
C     T         - thickness to chord ratio [t/c]
C     XUM,ZUM   - dimensionless chordwise location and height
C                 maximum height [xum/c and zum/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17),  - dimensionless upper-surface and lower-surface
C     ZLG(17)     coordinates at each of 17 standard chordwise
C                 locations [(zu/c)g and (zl/c)g]
C     EOTP      - outboard limit of trailing-edge flap
C                 panel which contains ETAP  [(eta ol)p]
C     DT(3)     - deflection angles (deg) of up to 3 elements
C                                                        [delta t]
C     DCT(3)    - chord extensions due to deployment of up to 3
C                 elements                               [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements     [ct/c]
C     ZU125,    - section upper surface ordinate at x=0.0125c
C                 [(zu/c)1.25, (zl/c)1.25]
C     LDH       - hinge-line sweep (deg)                 [Lambda h]
C     LD0,LD50, - Lambda0, Lambda1/2 and Lambda1 sweep back angles
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C     EITPEF      - effective spanwise position of inboard edge
C                   of trailing-edge device
C                   as a proportion of semi-span [(eta it)p eff]
C
C     Input/Output
C     ------------
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C
C     Output
C     ------
C     PHIO,PHII   - Phi o and Phi i
C     DCLMTG      - [Delta CLmt / FR (Phi o - Phi i)]gen
C     FAULT       - fault number
C
C     Local
C     -----
C     DTOR        - (radians) = DTOR * (degrees)
C     RTOD        - (degrees) = RTOD * (radians)
C     LD2         - hinge-line sweep-back [Lambda2 = Lambdah]
C     RE          - datum Reynolds number = 3.5E6
C     SN          - sin(of an angle)
C     TN          - tan(of an angle)
C     A0BTP       - (alpha 0BT)p
C     A10PD       - (a1)0pd
C     TNTU        - tan(tau u)
C     DCLPD       - (Delta CL)pd
C     FS          - factor FS
C     FM          - factor FM
C     CLMBD       - datum maximum lift coefficient [(CLmB)d]
C     XX,YY       - plot coordinates
C     KT0         - KT from Figure 3 of Item 94030
C     KT(3)       - Kt1, Kt2, Kt3
C     JT(3)       - Jt1, Jt2, Jt3
C     CETCX(3)    - cet1/c', cet2/c', cetc3/c'
C     DCXL(3)     - Delta C'L1, Delta C'L2, Delta C'L3
C     DTSEC       - (delta ti) * sec(of an angle) where i = 1,2 or 3
C     TOL         - tolerance
C     ITYPE  - integer version of TYPE:
C              1 = 'P' = program decides
C              2 = 'M' = modern
C              3 = 'C' = conventional
C              N.B. ITYPE = 1 i.e. TYPE = 'P' here
C     MSG         - message number (discarded here)
C
C     -----------------------------------------------------------------
C
      INTEGER NT,FAULT
      REAL A,TR,T,XUM,ZUM,TAU,ZUG(17),ZLG(17),TAUA,EOTP,
     *     DT(3),DCT(3),CT(3),ZU125,LDH,LD0,LD50,LD1,CXC,EITPEF,
     *     PHIO,PHII,DCLMTG
C
      INTEGER NTJ ,JJ
      REAL DTJ(3), DCTJ(3),CTJ(3),LDHJ
      INTEGER  NE,I,ITYPE,MSG
      REAL DTOR,RTOD,LD2,RE,SN,TN,A0BTP,A10PD,TNTU,DCLPD,FS,FM,
     *     CLMBD,XX,YY,KT0,KT(3),JT(3),CETCX(3),DCXL(3),DTSEC,TOL
C
      FAULT = 0
      DCLMTG = 0.0
      DTOR = 3.141593 / 180.0
      RTOD = 180.0 / 3.141593
      TOL = 1.0E-8
C
      LDH = LDHJ
      NT = NTJ
C
C     TYPE = 'P' here
      ITYPE = 1
C     Lambda2 = (Lambda h)
      LD2 = LDH
C
      IF (ABS(1.0 - XUM) .LE. TOL)       FAULT = 1030
      IF (ABS(COS(DTOR * LD0)) .LE. TOL) FAULT = 1031
      IF (ABS(CXC) .LE. TOL)             FAULT = 1032
      IF (ABS(COS(DTOR * LD2)) .LE. TOL) FAULT = 1033
      IF (FAULT .NE. 0) GO TO 50
C
      DO 10 I = 1,3
      KT(I) = 0.0
      JT(I) = 0.0
      CETCX(I) = 0.0
      DCXL(I) = 0.0
   10 CONTINUE
C
C     Calculation of datum maximum lift coefficient (CLmb)d at eta p
C     for a Reynolds number of 3.5E6
C     ==============================================================
      RE = 3.5E6
C
C     Subroutine 6 gives (alpha 0BT)p as a function
C     of the arrays (zu/c)g and (zl/c)g (with g = 1 to 17)
C     ----------------------------------------------------
      CALL SUBR06(ZUG,ZLG,A0BTP)
C
C     Calculate (tau a) = 2 * arc tan[{[(zu/c)14 - (zl/c)14]
C                                     - [(zu/c)16 - (zl/c)16]} / 0.18
C     ----------------------------------------------------------------
      TN = ((ZUG(14) - ZLG(14)) - (ZUG(16) - ZLG(16))) / 0.18
      SN = TN / SQRT(1.0 + TN * TN)
      TAUA = 2.0 * RTOD * ASIN(SN)
C
C     Subroutine 5 gives (a1)0pd
C     --------------------------
C     Next line to take XTR2 = 0.0 into subroutine
      CALL SUBR05(RE,T,TAU,TAUA,A10PD,FAULT,0.0)
      IF (FAULT .NE. 0) GO TO 50
C
C     Calculate tan(tau u) = (zum/c) / [1 - (xum/c)]
C     ----------------------------------------------
      TNTU = ZUM / (1.0 - XUM)
C
C     Subroutine 7 gives (Delta CL)pd as a function
C     Re, (zu/c)3, Lambda0, tan(tau u) and Lambda1
C     ---------------------------------------------
C
      CALL SUBR07(RE,ZUG(3),LD0,TNTU,LD1,DCLPD,FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Subroutine 8 gives Fs as a function of
C     Re, Lambda0, ITYPE, (zu/c)14, (zl/c)14, (zu/c)17 and (zl/c)17
C     -------------------------------------------------------------
      CALL SUBR08(RE,LD0,ITYPE,ZUG(14),ZLG(14),ZUG(17),ZLG(17),FS,
     *            MSG,FAULT)
C     The message number MSG will be discarded this time.
      IF (FAULT .NE. 0) GO TO 50
C
C     The datum maximum lift coefficient (CLmb)d is given by:
C     (Clmb)d = [(Delta CL)pd - (alpha 0BT)p * (a1)0pd * sec(Lambda0)]
C               * FS * FM        with FM = 1.0
C     -------------------------------------------------------
      FM = 1.0
C
      CLMBD = (DCLPD - A0BTP * A10PD / COS(DTOR * LD0)) * FS * FM
C
C
C     Figure 3b of Item 91014 gives Phi o and Phi i
C     ---------------------------------------------
C     XX = A * tan(Lambda1/2) - 8 * lambda
      XX = A * TAN(DTOR * LD50) - 8.0 * TR
C     (Phi o) is a function of XX and (eta ot)p
C
      CALL FIG31A(XX,EOTP,PHIO,FAULT)
C
      IF (FAULT .NE. 0) GO TO 50
C     (Phi i) is a function of XX and (eta it)peff
C
      CALL FIG31A(XX,EITPEF,PHII,FAULT)
C
      IF (FAULT .NE. 0) GO TO 50
C
C     Figure 3 of Item 94030 gives KT
C     as a function of (xum/c) and YY = (zu/c)1.25
C     --------------------------------------------
      YY = ZU125 / COS(DTOR * LD0)
      CALL FIG32A(XUM,YY,KT0,FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Calculate (cet1/c'), (cet2/c'), (cet3/c')
C     for the appropriate number of elements (Ne)
C     -----------------------------------------
C     (ceti/c') = Sigma[(ctj/c) + (Delta ctj/c)] / (c'/c)
C     for j = i to Ne
      NT = NTJ
      NE = NT - 2
      DO 30 I = 1,NE
      DO 20 JJ = I,NE
C
      CT(JJ) =  CTJ(JJ)
      DCT(JJ) = DCTJ(JJ)
      CETCX(I) = CETCX(I) + CT(JJ) + DCT(JJ)
   20 CONTINUE
      CETCX(I) = CETCX(I) / CXC
   30 CONTINUE
C
C     Calculation of Kti, Jti and Delta C'Li for i = 1 to NE
C     ======================================================
C
C     For all three types calculate Kt1, Jt1 and Delta C'L1
C     =====================================================
C     Figure 4 of Item 94030 gives Kt1
C     as a function of (delta t1) * sec(Lambda2)
C     ------------------------------------------
      DT(1) = DTJ(1)
      DTSEC = DT(1) / COS(DTOR * LD2)
C      DTSEC = DT(1) / COS(DTOR * LD2)
      CALL FIG33A(DTSEC,KT(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Subroutine SUBJT1 gives Jt1
C     as a function of (delta t1) and Lambda2
C     ---------------------------------------
      CALL SUBJT1(DT(1),LD2,JT(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Figure 4 of Item 94031 gives Delta C'L1
C     as a function of (cet1/c') and (delta t1) * sec(Lambda2)
C     --------------------------------------------------------
      CALL FIG18A(CETCX(1),DTSEC,DCXL(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     For types 4 and 5 calculate Kt2, Jt2 and Delta C'L2
C     ===================================================
      IF (NT .GE. 4) THEN
C
C      Figure 9a of Item 94031 gives Kt2
C      as a function of (delta t1) * sec(Lambda2)
C      ------------------------------------------
       DTSEC = DT(1) / COS(DTOR * LD2)
       CALL FIG34A(DTSEC,KT(2),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C      Subroutine SUBJT2 gives Jt2
C      as a function of (delta t1) and Lambda2
C      ---------------------------------------
       CALL SUBJT2(DT(1),LD2,JT(2),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C     Figure 5 of Item 94031 gives (delta C'L2)
C     as a function of (cet2/c') and [(delta t2)* sec(Lambda2)]
C     ---------------------------------------------------------
      DT(2) = DTJ(2)
      DTSEC = DT(2) / COS(DTOR * LD2)
      CALL FIG19A(CETCX(2),DTSEC,DCXL(2),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
      END IF
C
C     For type 5 calculate Kt3, Jt3 and Delta C'L3
C     ============================================
      IF (NT .EQ. 5) THEN
C
      DT(3) = DTJ(3)
C
C      Figure 9b of Item 94031 has a constant Kt3
C      ------------------------------------------
       KT(3) = 0.08
C
C      Subroutine SUBJT3 gives Jt3
C      as a function of (delt t3) and Lambda2
C      --------------------------------------
       CALL SUBJT3(DT(3),LD2,JT(3),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C      Figure 6 of Item 94031 gives Delta C'L3
C      as a function of (cet3/c') and [(delta t3)*sec(Lambda2)]
C      --------------------------------------------------------
       DTSEC = DT(3) / COS(DTOR * LDH)
       CALL FIG20A(CETCX(3),DTSEC,DCXL(3),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
      END IF
C
C     Calculate [Delta CLmt / FR (Phi o - Phi i)]gen
C     ==============================================
C     (The formula is rearranged slightly to deal with all three types)
C     [Delta CLmt / FR (Phi o - Phi i)]gen =
C     (c'/c) * KT0 * Sigma{Kti * Jti * (Delta C'Li)] (for i = 1 to Ne)
C     + [(c'/c) - 1] * {1 - sin[(delta t1) * sec(Lambda2)]} * (CLmB)d
      DCLMTG = 0.0
      DO 40 I = 1,3
      DCLMTG = DCLMTG + KT(I) * JT(I) * DCXL(I)
   40 CONTINUE
      DCLMTG = CXC * KT0 * DCLMTG
     *       + (CXC - 1.0) * (1.0 - SIN(DTOR * DT(1) / COS(DTOR * LD2)))
     *       * CLMBD
C
   50 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRI6(NL,RK,CXL,DCL,DT,CT,RLT,PHIT,CXC,DCLMT,FAULT)
C     ===========================================================
C
C     Purpose
C     -------
C     Calculation of Delta CLmt for Nt = 1 for an aerofoil
C
C     Input
C     -----
C     NL        - device type of leading-edge panel [Nl]
C     RK        - cuurent Reynolds number [Rk]
C     CXL       - leading edge extended chord [c'l/c]
C     DCL       - chord extension due to deployment of leading
C                 edge device[Delta cl / c]
C     DT        - deflection angle (deg) [delta t]
C     CT        - flap chord / c  [ct/c]
C     RLT       - leading edge radius of section or of deployed leading
C                 edge device / thickness [rhol/t]
C     PHIT      - angle from aerofoil datum to tangent to upper surface
C                 at trailing edge (deg)  [phit]
C     CXC       - extended chord / chord [c'/c]
C
C     Output
C     ------
C     PHIO,PHII   - Phi o and Phi i
C     DCLMT       - Delta CLmt
C     FAULT       - fault number
C
C     Local
C     -----
C     DTOR        - (radians) = DTOR * (degrees)
C     AT          - [at] calculated by Subroutine 11
C     LD          - Lambda (= 0)
C     LD2         - Lambda2 (=0)
C     CS          - cos(Lambda2)
C     X           - input parameter for plots
C     KF,JP,KG,   - factors in the formulae
C     KT,T
C     XSCX,CTCX   - [x's/c'] and [ct/c']
C     TOL         - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER NL,FAULT
      REAL FR,RK
      REAL CXL,DCL,DT,CT,RLT,PHIT,CXC,DCLMT
C
      REAL DTOR,AT,LD,LD2,CS,X,KF,JP,KG,KT,T,XSCX,CTCX,DCL0T,TOL
C
      FAULT = 0
      DCLMT = 0.0
      DTOR = 3.141593 / 180.0
      TOL = 1.0E-8
C
C     Lambda = 0
      LD = 0.0
      LD = LD
C     Lambda2 = 0
      LD2 = 0.0
C
      IF (RK .LE. 0.0) FAULT = 1034
      IF (ABS(COS(DTOR * LD2)) .LE. TOL) FAULT = 1035
      IF (ABS(CXC) .LE. TOL) FAULT = 1036
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate FR = 0.153 * log10(Rk)
C     --------------------------------
      FR = 0.153 * LOG10(RK)
C
C     Subroutine 11 gives (at)
C     as a function of (ct/c) and (c'/c)
C     ----------------------------------
      CALL SUBR11(CT,CXC,AT,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Figure 1 of Item 94028 gives Jp
C     as a function of X = [(delta t)+(phi t)] sec(Lambda2)
C     -----------------------------------------------------
      CS = COS(DTOR * LD2)
      X = (DT + PHIT) / CS
      CALL FIG28A(X,JP,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate Delta CL0t = (c'/c) * Jp * (delta t) * (pi/180) * (at)
C     ----------------------------------------------------------------
      DCL0T = CXC * JP * DT * DTOR * AT
C
C     KG = 1.225 + 4.525 * (rho l/t)
C     ------------------------------
      KG = 1.225 + 4.525 * RLT
C
C     Kf and Kt are simply:
C     ---------------------
      KF = 1.0
      KF = KF + 0.0
      KT = 0.8
C
C     Calculate [ct/c'] and [x's/c']
C     ------------------------------
C     (ct/c') = (ct/c) / (c'/c)
      CTCX = CT /CXC
C
      IF (NL .EQ. 0) THEN
C      If Nl = 0 then (x's/c') = 0
C      ---------------------------
       XSCX = 0.0
      ELSE
       IF (NL .LE. 4) THEN
C       If Nl = 1 to 4 then (x's/c') = 1/2 * (c'l/c) / (c'/c)
C       -----------------------------------------------------
        XSCX = 0.5 * CXL / CXC
       ELSE
C       If Nl = 5 or 6 then
C       (x's/c') = 1/2 * [(c'l/c) - (delta cl/c)] / (c'/c)
C       --------------------------------------------------
C     Next line avoids use warning
        DCL=DCL
        XSCX = 0.5 * CXL / CXC
       END IF
      END IF
C
C     Figure 2 of Item 94028 gives T
C     as a function of (ct/c') and (x's/c')
C     -------------------------------------
      CALL FIG29A(CTCX,XSCX,T,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Delta CLmt = FR * KG * Kt * (Delta CL0t)
C     ========================================
      DCLMT = FR * KG * KT * T * DCL0T
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRI7(RK,DT,CT,ZCM,ZU125,ZL125,CXC,DCLMT,FAULT)
C     ===========================================================
C
C     Purpose
C     -------
C     Calculation of Delta CLmt for Nt = 2 for an aerofoil
C
C     Input
C     -----
C     RK        - current Reynolds number [Rk]
C     DT        - deflection angle (deg) [delta t]
C     CT        - flap chord / c  [ct/c]
C     ZCM       - section maximum camber height [zcm/c]
C     ZU125,    - section upper and lower surface ordinates
C     ZL125       at x=0.0125c  (zu/c)1.25, (zl/c)1.25]
C     CXC         - extended chord / chord with both leading
C                   and trailing edges extended [c'/c]
C
C     Output
C     ------
C     DCLMT       - Delta CLmt
C     FAULT       - fault number
C
C     Local
C     -----
C     DTOR        - (radians) = DTOR * (degrees)
C     AT          - [at] calculated by Subroutine 11
C     LD          - Lambda (= 0.0)
C     LD2         - Lambda2 (= 0.0)
C     CS          - cos(Lambda2)
C     X           - input parameter for plots
C     FR,KTM,T    - factors in the formulae in Section i
C     XSCX,CTCX   - [x's/c'] and [ct/c']
C     DCLMTD      - (Delta C'Lmt)d
C     TOL         - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL RK,DT,CT,ZCM,ZU125,ZL125,CXC,DCLMT
      REAL TOL
C
      REAL DTOR,AT,LD,LD2,CS,X,FR,KTM,T,XSCX,CTCX,DCLMTD
C
      FAULT = 0
      DCLMT = 0.0
      DTOR = 3.141593 / 180.0
      TOL = 1.0E-8
C
C     Lambda = 0
      LD = 0.0
C     Lambda2 = 0
      LD2 = 0.0
      CS = COS(DTOR * LD2)
C
      IF (RK .LE. 0.0)       FAULT = 1037
      IF (ABS(CXC) .LE. TOL) FAULT = 1038
      IF (FAULT .NE. 0) GO TO 10
C
C     FR = 0.153 * log10(Rk)
C     ----------------------
      FR = 0.153 * LOG10(RK)
C
C     Subroutine 11 gives (at)
C     as a function of (ct/c) and (c'/c)
C     ----------------------------------
      CALL SUBR11(CT,CXC,AT,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Ktm = 0.95 - 0.00595 * (delta t) * sec(Lambda2)
C     -----------------------------------------------
      KTM = 0.95 - 0.00593 * DT / CS
C
C     Figure 2 of Item 94028 gives T as a function of
C     (ct/c') = (ct/c) / (c'/c) and (x's/c') = 0.0
C     -----------------------------------------------
      XSCX = 0.0
      CTCX = CT /CXC
      CALL FIG29A(CTCX,XSCX,T,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     (Delta C'Lmt)d is given by Figure 2 of Item 94029
C     as a function of X = 1/2 * [(zu/c)1.25 - (zl/c)1.25] * sec(Lambda)
C     ------------------------------------------------------------------
      X = 0.5 * (ZU125 - ZL125) / COS(DTOR * LD)
      CALL FIG30A(X,DCLMTD,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Delta CLmt =
C            FR * (c'/c) * [(Delta C'Lmt)d - 8 * (zcm/c) * sec(Lambda)]
C            * Ktm * T * (at) * (delta t) * sec(Lambda2) * (pi/180)
C     =================================================================
      DCLMT = FR * CXC * (DCLMTD - 8.0 * ZCM / COS(DTOR * LD))
     *        * KTM * T * AT  * DT * DTOR / CS
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRI8(NT,RK,T,XUM,ZUM,TAU,ZUG,ZLG,TAUA,
     *                  DT,DCT,CT,ZU125,CXC,DCLMT,FAULT)
C     ===================================================
C
C     Purpose
C     -------
C     Calculation of Delta CLmt for Nt = 3, 4 or 5 for an aerofoil
C
C     Input
C     -----
C     NT     - device type of trailing-edge panel containing EATP   [Nt]
C     RK        - current Reynolds number [Rk]
C     T         - thickness to chord ratio [t/c]
C     XUM,ZUM   - dimensionless chordwise location and height
C                 maximum height [xum/c and zum/c]
C     TAU       - trailing edge angle (deg) [tau]
C     ZUG(17),  - dimensionless upper-surface and lower-surface
C     ZLG(17)     coordinates at each of 17 standard chordwise
C                 locations [(zu/c)g and (zl/c)g]
C     DT(3)     - deflection angles (deg) of up to 3 elements
C                                                        [delta t]
C     DCT(3)    - chord extensions due to deployment of up to 3
C                 elements                               [Delta ct / c]
C     CT(3)     - flap chord / c of up to 3 elements     [ct/c]
C     ZU125     - section upper surface ordinate at x=0.0125c
C                 [(zu/c)1.25, (zl/c)1.25]
C     CXC         - extended chord / chord  with both leading
C                   and trailing edges extended [c'/c]
C
C     Input/Output
C     ------------
C     TAUA      - trailing edge angle (deg) in Sketch 1.1b  [tau a]
C
C     Output
C     ------
C     DCLMT       - Delta CLmt
C     FAULT       - fault number
C
C     Local
C     -----
C     DTOR        - (radians) = DTOR * (degrees)
C     RTOD        - (degrees) = RTOD * (radians)
C     LD          - Lambda (= 0.0)
C     LD2         - Lambda2 (= 0.0)
C     RE          - datum Reynolds number = 3.5E6
C     SN          - sin(of an angle)
C     TN          - tan(of an angle)
C     A0BT        - (alpha 0BT)p
C     A10G        - (a1)0g
C     TNTU        - tan(tau u)
C     DCL         - Delta CL
C     FR          - factor FR
C     FS          - factor FS
C     FM          - factor FM
C     CLMBD       - datum maximum lift coefficient [(CLmB)d]
C     XX,YY       - plot coordinates
C     KT0         - KT from Figure 3 of Item 94030
C     KT(3)       - Kt1, Kt2, Kt3
C     JT(3)       - Jt1, Jt2, Jt3
C     CETCX(3)    - cet1/c', cet2/c', cetc3/c'
C     DCXL(3)     - Delta C'L1, Delta C'L2, Delta C'L3
C     DTSEC       - (delta ti) * sec(of an angle) where i = 1,2 or 3
C     TOL         - tolerance
C     MSG         - message number (discarded here)
C     ITYPE  - integer version of TYPE:
C              1 = 'P' = program decides
C              2 = 'M' = modern
C              3 = 'C' = conventional
C              N.B. This is taken as 1 (see the notes)
C
C     -----------------------------------------------------------------
C
      INTEGER NT,FAULT
      REAL RK,T,XUM,ZUM,TAU,ZUG(17),ZLG(17),TAUA,
     *     DT(3),DCT(3),CT(3),ZU125,CXC,DCLMT
C
      INTEGER NE,I,J,ITYPE,MSG
      REAL DTOR,RTOD,RE,SN,TN,A0BT,A10G,TNTU,DCL,FR,FS,FM,
     *     CLMBD,YY,KT0,KT(3),JT(3),CETCX(3),DCXL(3),DTSEC,
     *     LD,LD2,TOL
C
      FAULT = 0
      DCLMT = 0.0
      DTOR = 3.141593 / 180.0
      RTOD = 180.0 / 3.141593
      TOL = 1.0E-8
C     Lambda = 0 and Lambda2 = 0
      LD = 0.0
      LD2 = 0.0
C     Set ITYPE = 1 so that TYPE = 'P' = (program decides)
      ITYPE = 1
C
      IF (RK .LE. 0.0)             FAULT = 1039
      IF (ABS(1.0 - XUM) .LE. TOL) FAULT = 1040
      IF (ABS(CXC) .LE. TOL)       FAULT = 1041
      IF (FAULT .NE. 0) GO TO 50
C
      DO 10 I = 1,3
      KT(I) = 0.0
      JT(I) = 0.0
      CETCX(I) = 0.0
      DCXL(I) = 0.0
   10 CONTINUE
C
C     FR = 0.153 * log10(Rk)
C     ----------------------
      FR = 0.153 * LOG10(RK)
C
C     Calculation of datum maximum lift coefficient (CLmb)d at eta p
C     for a Reynolds number of 3.5E6
C     ==============================================================
      RE = 3.5E6
C
C     Subroutine 6 gives (alpha 0BT)
C     as a function of (zu/c)g and (zl/c)g for g = 1 to 17
C     ----------------------------------------------------
      CALL SUBR06(ZUG,ZLG,A0BT)
C
C     Calculate (tau a) = 2 *
C     arc tan{[[(zu/c)14 - (zl/c)14] - [(zu/c)16 - (zl/c)16]] / 0.18]
C     -----------------
      TN = ((ZUG(14) - ZLG(14)) - (ZUG(16) - ZLG(16))) / 0.18
      SN = TN / SQRT(1.0 + TN * TN)
      TAUA = 2.0 * RTOD * ASIN(SN)
C
C     Subroutine 5 gives (a1)0g as a function of
C     Re, (t/c), tau, and (tau a)
C     ------------------------------------------
C next line to take XTR2 = 0.0 into subroutine
      CALL SUBR05(RE,T,TAU,TAUA,A10G,FAULT,0.0)
      IF (FAULT .NE. 0) GO TO 50
C
C     Calculate tan(tau u) = (zum/c) / [1 - (xum/c)]
C     ----------------------------------------------
      TNTU = ZUM / (1.0 - XUM)
C
C     Subroutine 7 gives (Delta CL) for the parameters
C     Re, (zu/c)3, Lambda, tan(Tau u) and Lambda
C     with Re = 3.5E6 and Lambda = 0.0
C     ------------------------------------------------
      CALL SUBR07(RE,ZUG(3),LD,TNTU,LD,DCL,FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Subroutine 8 gives Fs for the parameters
C     Re, Lambda, ITYPE, (zu/c)14, (zl/c)14, (zu/c)17 and (zl/c)17
C     ------------------------------------------------------------
      CALL SUBR08(RE,LD,ITYPE,ZUG(14),ZLG(14),ZUG(17),ZLG(17),FS,
     *            MSG,FAULT)
C     The message number MSG will be discarded this time.
      IF (FAULT .NE. 0) GO TO 50
C
C     The datum maximum lift coefficient (CLmb)d is given by
C     (CLmb)d = [(Delta CL) - (alpha 0BT) * (a1)0g] * FS * FM
C     -------------------------------------------------------
      FM = 1.0
C
      CLMBD = (DCL - A0BT * A10G) * FS * FM
C
C
C     Figure 3 of Item 94030 gives KT
C     as a function of (xum/c) and YY = (zu/c)1.25 * sec(Lambda)
C     ----------------------------------------------------------
      YY = ZU125 / COS(DTOR * LD)
      CALL FIG32A(XUM,YY,KT0,FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Calculate (cet1/c'), (cet2/c'), (cet3/c')
C     for the appropriate number of elements (Ne)
C     (ceti/c) = Sigma[(ctj/c) + (delta ctj/c)] / (c'/c)
C     for j = i to Ne
C     --------------------------------------------------
      NE = NT - 2
      DO 30 I = 1,NE
C next line to zeroes elements cf earlier routine for CETCC(I)
      CETCX(I) = 0
      DO 20 J = I,NE
      CETCX(I) = CETCX(I) + CT(J) + DCT(J)
   20 CONTINUE
      CETCX(I) = CETCX(I) / CXC
   30 CONTINUE
C
C     Calculation of Kti, Jti and Delta C'Li for i = 1 to NE
C     ======================================================
C
C     For all three types calculate Kt1, Jt1 and Delta C'L1
C     =====================================================
C     Figure 4 of Item 94030 gives Kt1
C     as a function of DTSEC = (delta t1) * sec(Lambda2)
C     --------------------------------------------------
      DTSEC = DT(1) / COS(DTOR * LD2)
      CALL FIG33A(DTSEC,KT(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Subroutine SUBJT1 gives Jt1
C     as a function of (delta t1) and Lambda2
C     ---------------------------------------
      CALL SUBJT1(DT(1),LD2,JT(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Figure 4 of Item 94031 gives Delta C'L1 as a function of
C     (cet1/c') and DTSEC = (delta t1) * sec(Lambda2)
C     --------------------------------------------------------
      CALL FIG18A(CETCX(1),DTSEC,DCXL(1),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     For types 4 and 5 calculate Kt2, Jt2 and Delta C'L2
C     ===================================================
      IF (NT .GE. 4) THEN
C
C      Figure 9a of Item 94031 gives Kt2
C      as a function of DTSEC = (delta t1) * sec(Lambda2)
C      --------------------------------------------------
       CALL FIG34A(DTSEC,KT(2),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C      Subroutine SUBJT2 gives Jt2
C      as a function of (delta t1) and Lambda2
C      ---------------------------------------
       CALL SUBJT2(DT(1),LD2,JT(2),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C     Figure 5 of Item 94031 gives (Delta C'L2)
C     as a function of (cet2/c') and DTSEC = (delta t2) * sec(Lambda2)
C     ----------------------------------------------------------------
      DTSEC = DT(2) / COS(DTOR * LD2)
      CALL FIG19A(CETCX(2),DTSEC,DCXL(2),FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
      END IF
C
C     For type 5 calculate Kt3, Jt3 and Delta C'L3
C     ============================================
      IF (NT .EQ. 5) THEN
C
C      Figure 9b of Item 94031 has a constant Kt3
C      ------------------------------------------
       KT(3) = 0.08
C
C      Subroutine SUBJT3 gives Jt3
C      as a function of (delta t3) and Lambda2
C      ---------------------------------------
       CALL SUBJT3(DT(3),LD2,JT(3),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
C      Figure 6 of Item 94031 gives Delta C'L3
C      as a function of (cet3/c') and DTSEC = (delta t3) * sec(Lambda2)
C      ----------------------------------------------------------------
       DTSEC = DT(3) / COS(DTOR * LD2)
       CALL FIG20A(CETCX(3),DTSEC,DCXL(3),FAULT)
       IF (FAULT .NE. 0) GO TO 50
C
      END IF
C
C     Calculate (Delta CLmt)
C     ======================
C     (The formula is rearranged slightly to deal with all three types)
C     (Delta CLmt) = FR *
C     { (c'/c) * Kt0 * Sigma[Kti * Jti * (Delta C'Li)](for i = 1 to Ne)
C      + [(c'/c) - 1] * [1 - sin[(delta t1) * sec(Lambda2)] * (CLmb)d }
      DCLMT = 0.0
      DO 40 I = 1,NE
      DCLMT = DCLMT + KT(I) * JT(I) * DCXL(I)
   40 CONTINUE
      DCLMT = CXC * KT0 * DCLMT
     *       + (CXC - 1.0) * (1.0 - SIN(DTOR * DT(1) / COS(DTOR * LD2)))
     *         * CLMBD
      DCLMT = FR * DCLMT
C
   50 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRJJ
C     =================
C
C     Purpose
C     -------
C     Calculation of overall device increments
C
C     Input/Output
C     ------------
C     CALC    - calculation type (1 <= CALC <= 18)
C
C     Results for Aerofoils
C     ---------------------
C     DCL0L      - increment in aerofoil lift coefficient at zero angle
C                  of attack due to deployment of leading-edge device
C                  [Delta CL0l]
C     DCL0T      - increment in aerofoil lift coefficient at zero angle
C                  of attack due to deployment of trailing-edge device
C                  [Delta CL0t]
C     DCL0       - increment in aerofoil lift coefft. at zero angle of
C                  attack due to deployment of high-lift devices
C                  [Delta CL0]
C     CL0B       - lift coefft. at zero angle of attack for basic
C                  aerofoil (high-lift devices not deployed) [CL0B]
C     CL0        - aerofoil lift coefft. at zero angle of attack with
C                  high-lift devices deployed [CL0]
C     DCLML      - increment in aerofoil max. lift coefft. due to
C                  leading-edge device [Delta CLml]
C     DCLMT      - increment in aerofoil max. lift coefft. due to
C                  trailing-edge device [Delta CLmt]
C     DCLM       - increment in aerofoil max. lift coefft. due to
C                  high-lift devices [Delta CLm]
C     CLMB       - max. lift coefft. of basic aerofoil
C                  (high-lift devices not deployed) [CLmB]
C     CLM        - max. lift coefft. of aerofoil with high-lift devices
C                  deployed [CLm]
C
C     Results for Wings
C     -----------------
C     DC0LWJ(NNL) - increments in wing lift coefft. at zero angle of
C                   attack due to NNL leading-edge devices
C                   [(Delta CL0lw)j]
C     DC0TWJ(NNt) - increments in wing lift coefft. at zero angle of
C                   attack due to NNT trailing-edge devices
C                   [(Delta CL0tw)j]
C     DCL0LW      - increment in wing lift coefft. at zero angle of
C                   attack due to leading-edge devices [Delta CL0lw]
C     DCL0TW      - increment in wing lift coefft. at zero angle of
C                   attack due to trailing-edge devices [Delta CL0tw]
C     DCL0W       - increment in wing lift coefft. at zero angle of
C                   attack due to high-lift devices
C     CL0BW       - lift coefft. at zero angle of attack for basic wing
C                   (high-lift devices not deployed)
C     CL0W        - lift coefft. of wing at zero angle of attack with
C                   high-lift devices deployed
C     DCLMXL      - increment in max. lift coefft. of wing due to
C                   deployment of leading-edge high-lift devices
C                   [(DCL max l)]
C     DCLMXT      - increment in max. lift coefft. of wing due to
C                   deployment of trailing-edge high-lift devices
C                   [(DCL max t)]
C     DCLMX       - increment in wing max. lift coefft. due to high-
C                   lift devices [Delta CL max]
C     CLMXB       - max. lift coefft. of basic wing (high-lift devices
C                   not deployed) [CL max B]
C     CLMXW       - max lift coefft. of wing with high-lift devices
C                   deployed [CL max W]
C
C     Results for Wing-Fuselage Combinations
C     --------------------------------------
C     CL0BF       - lift coefft. at zero angle of attack for basic
C                   wing-fuselage combination [CL0Bf]
C     CL0WF       - lift coefft. at zero angle of attack for
C                   wing-fuselage combination with high-lift devices
C                   deployed [CL0wf]
C     DCLMXF      - increment in max. lift coefft. due to fuselage
C                   [Delta CL max f]
C     CLMXBF      - max. lift coefft. of basic wing-fuselage combination
C                   [CL max Bf]
C     CLMXWF      - max. lift coefft. of wing-fuselage combination with
C                   high-lift devices deployed [CL max wf]
C
C     Input is from and output is to Common Block ZE9931.
C     CALC (calculation type) from Common Block ZB9931
C     decides the actions to be taken.
C
C     Local
C     -----
C     I            - action number (I = 1 to 12)
C     LIST(18,12)  - flags on actions for each calculation type
C                    If LIST(CALC,I) is not zero, then do action I.
C     (Fortran has rows and columns the "wrong way round".)
C
C     -----------------------------------------------------------------
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
C
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
      INTEGER I,LIST(18,12)
C
      DATA LIST /
     1 0, 0, 0, 0, 0, 0, 7, 8, 9,10,11,12,13,14,15,16,17,18,
     2 1, 2, 3, 4, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     3 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     4 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13,14,15,16, 0, 0,
     5 0, 0, 0, 0, 0, 0, 7, 8, 9,10, 0, 0, 0, 0, 0, 0, 0, 0,
     6 1, 2, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     7 0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     8 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     9 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     1 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     2 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 /
C
C     Take each row(I) of the above table in turn and look at the column
C     that belongs to calculation type CALC.  If the entry is not zero,
C     perform action I.
C     ------------------------------------------------------------------
      DO 200 I = 1,12
C
      IF (LIST(CALC,I) .GT. 0) THEN
       GO TO ( 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12), I
C
C      ................................................................
C      Section j1i
C      =============
C      (Delta CL0w) = (Delta CL0lw) + Delta CL0tw) CALC = 7 to 18
C      ----------------------------------------------------------
    1  DCL0W = DCL0LW + DCL0TW
       GO TO 100
C
C      Substitute for j1i for CALC = 1, 2, 3, 4, 6
C      (Delta CL0) = (Delta CL0l) + (Delta CL0t)
C      -------------------------------------------
    2  DCL0 = DCL0L + DCL0T
       GO TO 100
C
C      Substitute for j1i for CALC = 5
C      (Delta CL0) = (Delta CL0l) + (Delta CL0t)
C      -----------------------------------------
    3  DCL0 = DCL0L + DCL0T
       GO TO 100
C      ................................................................
C
C      Section j1ii
C      ==============
C      (CL0wf) = (CL0Bf) + (Delta CL0w) for CALC = 13 to 16
C      ----------------------------------------------------
    4  CL0WF = CL0BF + DCL0W
       GO TO 100
C
C      Substitute for j1ii for CALC = 7 to 10
C      (CL0w) = (CL0Bw) + (Delta CL0w)
C      --------------------------------------
    5  CL0W = CL0BW + DCL0W
       GO TO 100
C
C      Substitute for j1ii for CALC = 1 to 4
C      (CL0) = (CL0B) + (Delta CL0)
C      -------------------------------------
    6  CL0 = CL0B + DCL0
       GO TO 100
C      ................................................................
C
C      Section j2i
C      =============
C      (Delta CLmax) = (Delta CLmaxl) + (Delta CLmaxt)
C      for CALC = 7, 8, 11, 13,14,17
C      -----------------------------------------------
    7  DCLMX = DCLMXL + DCLMXT
       GO TO 100
C
C      Substitute for j2i for CALC = 1, 2
C      (Delta CLm) = (Delta CLml) + (Delta CLmt)
C      -----------------------------------------
    8  DCLM = DCLML + DCLMT
       GO TO 100
C
C      Substitute for j2i for CALC = 5
C      (Delta CLm) = (CLmB) + (Delta CLm)
C      ----------------------------------
    9  DCLM = DCLML + DCLMT
C
       GO TO 100
C      ................................................................
C
C      Section j2ii
C      ==============
C      (CL max wf) = (CL max Bf) + (Delta CL max) for CALC = 13, 14
C      ------------------------------------------------------------
   10  CLMXWF = CLMXBF + DCLMX
       GO TO 100
C
C      Substitute for j2ii for CALC = 7, 8
C      (CL max w) = (CL max B) + (Delta CL max)
C      ----------------------------------------
   11  CLMXW = CLMXB + DCLMX
       GO TO 100
C
C      Substitute for j2ii for CALC = 1,2
C      (CLm) = (CLmB) + (Delta CLm)
C      ----------------------------------
   12  CLM = CLMB + DCLM
       GO TO 100
C      .................................................................
C
  100  CONTINUE
      END IF
C
  200 CONTINUE
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRKK(JL,JT,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Section k: Calculation of lift curve
C
C     Input
C     -----
C     JL      - leading-edge device setting number
C     JT      - trailing-edge device setting number
C
C     Output
C     ------
C     FAULT   - fault number
C
C     Input from common blocks
C     ------------------------
C     CALC      - calculation type (1 to 18)
C     NDL       - number of leading edge device settings (0<=NDL<=10)
C     NDT       - number of trailing-edge device settings (0<=NDT<=10)
C     NNL       - number of leading-edge device panels (0<=NNL<=5)
C     NNT       - number of trailing-edge device panels (0<=NNT<=5)
C     NTJ(5)    - trailing-edge device types  [(Nt)j]
C     W         - ratio of body width to semi-span  [W/s]
C     NT        - trailing-edge device type  (Nt)
C     DT(3,5)   - deflection angles for up to 3 elements (delat t)i
C     DCT(3,5)  - chord extensions for up to 3 elements (Delta ct/c)i
C     CT(3)     - flap chords for up to 3 elements (ct/c)i
C     CXCT      - extended chord / chord with trailing edge extended
C                 (c'/c)t
C     EIT(5),   - positions of inner and outer edges of NNT trailing
C     EOT(5)      edge panels                 [(eta il)j and (eta ol)j]
C     DCLJ(5,10)   - NNL*NDL extensions on deployment [(Delta cl / c)j]
C     DTJ(3,5,10)  - deflection angles for up to 3 elements, for NNT
C                    trailing edge devices, for NDT device settings
C                    [(delta t)j]
C     DCTJ(3,5,10) - chord extensions for up to 3 elements, for NNT
C                    trailing edge devices, for NDT device settings
C                    [(Delta ct / c)j]
C     CTJ(3,5)     - flap chords for up to 3 elements, for NNT devices
C                    [(ct/c)j]
C     CL0        - aerofoil lift coefft. at zero angle of attack with
C                  high-lift devices deployed [CL0]
C     CLM        - max. lift coefft. of aerofoil with high-lift devices
C                  deployed [CLm]
C     CL0W        - lift coefft. of wing at zero angle of attack with
C                   high-lift devices deployed
C     CLMXW       - max lift coefft. of wing with high-lift devices
C                   deployed [CL max W]
C     CL0WF       - lift coefft. at zero angle of attack for
C                   wing-fuselage combination with high-lift devices
C                   deployed [CL0wf]
C     CLMXWF      - max. lift coefft. of wing-fuselage combination with
C                   high-lift devices deployed [CL max wf]
C     LCS      - lift-curve slope in Section b1 [a1]
C     EB       - spanwise centre of pressure in Section b2 [eta bar]
C     RXK      - Reynolds number based on cp in Section b3 [R'k]
C     CXCTJ(5)    - extended chords / chords with trailing edges
C                   extended [((c'/c)t)j]
C     EIL1EF      - effective spanwise position of inboard edge
C                   of innermost leading-edge device as a proportion
C                   of semi-span [(eta il)1 eff]
C     EIT1EF      - effective spanwise position of inboard edge
C                   of innermost trailing-edge device as a proportion
C                   of semi-span [(eta it)1 eff]
C
C     Output to common blocks
C     -----------------------
C     QJ(5)       - the quantities (Delta ct / c - K delta ct / c)j
C                   in Section k1
C     D           - the factor D in Section k2
C     P           - the power p in Section k3
C     A0          - angle of attack for zero lift (deg) [alpha 0]
C     ACLMX       - angle of attack for maximum lift (deg) [alpha CLmax]
C     NCL         - number of items in lift curve plot [CL vs. alpha d]
C     AD(200)     - NCL angles of attack (deg) [alpha d]
C     CL(200)     - NCL corresponding lift coefficients [CL]
C
C     Local
C     -----
C     CL0TOT      - CL0 or CL0W  or CL0WF  (according to CALC)
C     CLMTOT      - CLM or CLMXW or CLMXWF (according to CALC)
C     Q           - the quantity (Delta ct / c - K delta ct / c)
C                   for CALC = 1 or 2
C     AX          - alpha* in the notes
C     I           - array index
C     RTOD        - (degrees) = RTOD * (radians)
C
C     -----------------------------------------------------------------
C
      INTEGER JL,JT,FAULT
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
C
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
C
      REAL RK2
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
C next line brings in RK (as RK2)
      COMMON /ZJ9931/ RK2
      INTEGER I
      REAL CL0TOT,CLMTOT,Q,AX,RTOD
C
C
      RTOD = 180.0 / 3.141593
      RTOD = RTOD
      FAULT = 0
      NCL = 0
      A0 = 0.0
      ACLMX = 0.0
      D = 0.0
      P = 0.0
      Q = 0.0
C
      DO 4 I = 1,5
      QJ(I) = 0.0
    4 CONTINUE
C
      DO 5 I = 1,200
      AD(I) = 0.0
      CL(I) = 0.0
    5 CONTINUE
C
      CL0TOT = 0.0
      CLMTOT = 0.0
      AX = 0.0
C
C     Assign numbers to CL0TOT and CLMTOT or escape from this routine
C     according to calculation type CALC
C     ---------------------------------------------------------------
C     CALC:   1  2  3  4  5  6  7  8  9 10 11 12 13 14 15 16 17 18
      GO TO (10,10,10,80,80,80,20,20,20,80,80,80,30,30,30,80,80,80),CALC
C
C     CALC = 1 or 2
C     -------------
   10 CL0TOT = CL0
      CLMTOT = CLM
C
C
C     Calculate Q = (Delta ct / c - K delta ct / c)
C     ---------------------------------------------
      IF (NDT .GT. 0) CALL SUBRK0(NT,DT(1,JT),DCT(1,JT),CT,CXCT,Q)
C
C     Calculate D and P
C     -----------------
      D = 1.0
      IF (NDL .GT. 0) D = D + DCL(JL)
      IF (NDT .GT. 0) D = D + Q
      P = 1.3
C
      GO TO 50
C
C     CALC = 7 or 8
C     -------------
   20 CL0TOT = CL0W
      CLMTOT = CLMXW
      GO TO 40
C
C     CALC = 13 or 14
C     ---------------
   30 CL0TOT = CL0WF
      CLMTOT = CLMXWF
      GO TO 40
C
   40 IF (NDL .EQ. 0) NNL = 0
      IF (NDT .EQ. 0) NNT = 0
C
C     Section k1 calculates the quantities
C     (Delta ct / c - K delta ct / c)j
C     --------------------------------------
      IF (NNT .GT. 0)
     *   CALL SUBRK1(NNT,NTJ,DTJ(1,1,JT),DCTJ(1,1,JT),CTJ,CXCTJ,QJ)
C
C     Section k2 calculates the factor D
C     ------------------------------------
      D = 1.0
      IF (NNL .GT. 0 .OR. NNT .GT. 0)
     *CALL SUBRK2(NNL,NNT,DCLJ(1,JL),EIT,EOT,EB,EIL1EF,EIT1EF,
     *            QJ,D,FAULT)
      IF (FAULT .NE. 0) GO TO 80
C
C     Section k3 calculates the power p
C     -----------------------------------
      CALL SUBRK3(NNL,NNT,W,EOT,EIL1EF,P)
C
C     Section k4 calls Subroutine 14 to calculate (CL vs. alpha)
C     ------------------------------------------------------------
   50 CALL SUBR14(RK2,CL0TOT,CLMTOT,LCS,D,P,A0,AX,ACLMX,NCL,CL,AD,
     *            FAULT)
C
C     N.B. A0 = alpha0 and AX = alpha* are in degrees
C
   80 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRK0(NT,DT,DCT,CT,CXCT,Q)
C     ======================================
C
C     Purpose
C     -------
C     Modification of Section k1 for CALC = 1 and 2:
C     Calculation of the quantity (Delta ct / c - K delta ct / c)
C
C     Input
C     -----
C     NT        - trailing-edge device type  (Nt)
C     DT(3)     - deflection angles for up to 3 elements (delat t)i
C     DCT(3)    - chord extensions for up to 3 elements (Delta ct/c)i
C     CT(3)     - flap chords for up to 3 elements (ct/c)i
C     CXCT      - extended chord / chord with trailing edge extended
C                 (c'/c)t
C
C     Output
C     ------
C     Q         - the quantity (Delta ct / c - K delta ct / c)
C
C     Local
C     -----
C     SD1,SD2,SD3 - total angles Sigma(delta ti)
C     CS1,CS2,CS3 - [1 - cos(SD1)] etc
C
C     -----------------------------------------------------------------
C
      INTEGER NT
      REAL DT(3),DCT(3),CT(3),CXCT,Q
C
      REAL DTOR,SD1,SD2,SD3,CS1,CS2,CS3
C
      DTOR = 3.141593 / 180.0
C
C     Form the three total angles
C     ---------------------------
      SD1 = DT(1)
      SD2 = DT(1) + DT(2)
      SD3 = DT(1) + DT(2) + DT(3)
C
C     Calculate [1 - cos(SD1)] etc
C     ----------------------------
      CS1 = 1.0 - COS(DTOR * SD1)
      CS2 = 1.0 - COS(DTOR * SD2)
      CS3 = 1.0 - COS(DTOR * SD3)
C
C     Choose the formula appropriate to the device type (Nt)
C     ======================================================
      GO TO (10, 20, 30, 40, 50), NT
C
C     (Nt) = 1
C     --------
C     (Delta ct / c - K delta ct / c) =
C     (Delta ct/c) - [(1 - cos(delta t)] * (ct/c)
C     -------------------------------------------
   10 Q = DCT(1) - CS1 * CT(1)
      GO TO 60
C
C     (Nt) = 2
C     --------
C     (Delta ct / c - K delta ct / c) = (delta ct/c)
C     ----------------------------------------------
   20 Q = DCT(1)
      GO TO 60
C
C     (Nt) = 3
C     --------
C     (Delta ct / c - K delta ct / c) =
C     ((c'/c)t) - 1 + [1 - cos(Delta t1)] * (ct1/c)
C     ---------------------------------------------
   30 Q = CXCT - 1.0 - CS1 * CT(1)
      GO TO 60
C
C     (Nt) = 4
C     --------
C     (Delta ct / c - K delta ct / c) =
C     ((c'/c)t) - 1 + [1 - cos(Delta t1)] * (ct1/c)
C     + [1 - cos[(delta t1) + (delta t2)] ] *
C     [(ct2/c) + (Delta ct2/c)]
C     ---------------------------------------------
   40 Q = CXCT - 1.0 - ( CS1 * CT(1)
     *               + CS2 * (CT(2) + DCT(2)))
      GO TO 60
C
C     (Nt) = 5
C     --------
C     (Delta ct / c - K delta ct / c) =
C     ((c'/c)t) - 1 + [1 - cos(Delta t1)] * (ct1/c)
C     + [1 - cos[(delta t1) + (delta t2)]] *
C     [(ct2/c) + (Delta ct2/c)]
C     + [1 - cos[(delta t1) + (delta t2)](delta t3)]] *
C     [(ct3/c) + (Delta ct3/c)]
C     -------------------------------------------------
   50 Q = CXCT - 1.0 - ( CS1 * CT(1)
     *               + CS2 * (CT(2) + DCT(2))
     *               + CS3 * (CT(3) + DCT(3)))
      GO TO 60
C
   60 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRK1(NNT,NTJ,DTJ,DCTJ,CTJ,CXCTJ,QJ)
C     ===============================================
C
C     Purpose
C     -------
C     Section k1:
C     Calculation of the quantities (Delta ct / c - K delta ct / c)j
C
C     Input
C     -----
C     NNT    - number of trailing-edge device panels (0<=NNT<=5)
C     NTJ(5) - trailing-edge device types  [(Nt)j]
C     DTJ(3,5)     - deflection angles for up to 3 elements, for NNT
C                    trailing edge devices [(delta t)j]
C     DCTJ(3,5)    - chord extensions for up to 3 elements, for NNT
C                    trailing edge devices [(Delta ct / c)j]
C     CTJ(3,5)     - flap chords for up to 3 elements [(ct/c)j]
C     CXCTJ(5)    - extended chords / chords with trailing edges
C                   extended [((c'/c)t)j]
C
C     Output
C     ------
C     QJ(5)       - the quantities (Delta ct / c - K delta ct / c)j
C
C     Local
C     -----
C     J           - trailing-edge device number
C     SD1,SD2,SD3 - total angles Sigma[(delta ti)j]
C     CS1,CS2,CS3 - [1 - cos(SD1)] etc
C
C     -----------------------------------------------------------------
C
      INTEGER NNT,NTJ(5)
      REAL DTJ(3,5),DCTJ(3,5),CTJ(3,5),CXCTJ(5),QJ(5)
C
      INTEGER J
      REAL DTOR,SD1,SD2,SD3,CS1,CS2,CS3
C
      DTOR = 3.141593 / 180.0
C
C     Take each trailing-edge device in turn
C     ======================================
      DO 60 J = 1,NNT
C
C     Form the three total angles
C     ---------------------------
      SD1 = DTJ(1,J)
      SD2 = DTJ(1,J) + DTJ(2,J)
      SD3 = DTJ(1,J) + DTJ(2,J) + DTJ(3,J)
C
C     Calculate [1 - cos(SD1)] etc
C     ----------------------------
      CS1 = 1.0 - COS(DTOR * SD1)
      CS2 = 1.0 - COS(DTOR * SD2)
      CS3 = 1.0 - COS(DTOR * SD3)
C
C     Choose the formula appropriate to the device type (Nt)j
C     =======================================================
      GO TO (10, 20, 30, 40, 50), NTJ(J)
C
C     (Nt)j = 1
C     ---------
C     (Delta ct / c - K delta ct / c)j =
C     (Delta ct/c)j - [(1 - cos(delta t)j] * (ct/c)j
C     ----------------------------------------------
   10 QJ(J) = DCTJ(1,J) - CS1 * CTJ(1,J)
      GO TO 60
C
C     (Nt)j = 2
C     ---------
C     (Delta ct / c - K delta ct / c)j = (delta ct/c)j
C     ------------------------------------------------
   20 QJ(J) = DCTJ(1,J)
      GO TO 60
C
C     (Nt)j = 3
C     ---------
C     (Delta ct / c - K delta ct / c)j =
C     ((c'/c)t)j - 1 + [1 - cos(Delta t1)j] * (ct1/c)j
C     ------------------------------------------------
   30 QJ(J) = CXCTJ(J) - 1.0 - CS1 * CTJ(1,J)
      GO TO 60
C
C     (Nt)j = 4
C     ---------
C     (Delta ct / c - K delta ct / c)j =
C     ((c'/c)t)j - 1 + [1 - cos(Delta t1)j] * (ct1/c)j
C     + [1 - cos[(delta t1)j + (delta t2)j]] *
C     [(ct2/c)j + (Delta ct2/c)j]
C     ------------------------------------------------
   40 QJ(J) = CXCTJ(J) - 1.0 - ( CS1 * CTJ(1,J)
     *                       + CS2 * (CTJ(2,J) + DCTJ(2,J)))
      GO TO 60
C
C     (Nt)j = 5
C     ---------
C     (Delta ct / c - K delta ct / c)j =
C     ((c'/c)t)j - 1 + [1 - cos(Delta t1)j] * (ct1/c)j
C     + [1 - cos[(delta t1)j + (delta t2)j]] *
C     [(ct2/c)j + (Delta ct2/c)j]
C     + [1 - cos[(delta t1)j + (delta t2)j (delta t3)j]] *
C     [(ct3/c)j + (Delta ct3/c)j]
C     ----------------------------------------------------
   50 QJ(J) = CXCTJ(J) - 1.0 - ( CS1 * CTJ(1,J)
     *                       + CS2 * (CTJ(2,J) + DCTJ(2,J))
     *                       + CS3 * (CTJ(3,J) + DCTJ(3,J)))
      GO TO 60
C
   60 CONTINUE
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRK2(NNL,NNT,DCLJ,EIT,EOT,EB,EIL1EF,EIT1EF,
     *                  QJ,D,FAULT)
C     ========================================================
C
C     Purpose
C     -------
C     Section k2: calculation of factor D for lift curve calculation
C
C     Input
C     -----
C     NNL    - number of leading-edge device panels (0<=NNL<=5)
C     NNT    - number of trailing-edge device panels (0<=NNT<=5)
C     EIT(5),     - positions of inner and outer edges of NNT trailing
C     EOT(5)       edge panels                 [(eta il)j and (eta ol)j]
C     DCLJ(5      - NNL*NDL extensions on deployment [(Delta cl / c)j]
C     EB          - spanwise centre of pressure in Section b2 [eta bar]
C     EIL1EF      - effective spanwise position of inboard edge
C                   of innermost leading-edge device as a proportion
C                   of semi-span [(eta il)1 eff]
C     EIT1EF      - effective spanwise position of inboard edge
C                   of innermost trailing-edge device as a proportion
C                   of semi-span [(eta it)1 eff]
C     QJ(5)       - the quantities (Delta ct / c - K delta ct / c)j
C                   in Section k1
C
C     Output
C     ------
C     D           - the factor D in Section k2
C     FAULT       - fault number
C
C     Local
C     -----
C     J           - trailing edge device number
C     ETA         - eta
C     PHIXI       - Phi'i
C     PHIXOJ      - Phi'oj
C     PHIXIJ      - Phi'ij
C
C     -----------------------------------------------------------------
C
      INTEGER NNL,NNT,FAULT
      REAL DCLJ(5),EIT(5),EOT(5),EB,EIL1EF,EIT1EF,QJ(5),D
C
      INTEGER J
      REAL ETA,PHIXI,PHIXOJ,PHIXIJ
C
      FAULT = 0
C
C     D = 1.0 + (a contribution from the leading edge)
C             + (a contribution from the trailing edge)
C
      D = 1.0
C
C     Contribution of the leading edge
C     ================================
      IF (NNL .GT. 0) THEN
C
C      Figure 3 of Item 93019 gives Phi'i
C      as a function of (eta bar) and eta = (eta il)1eff
C      -------------------------------------------------
       ETA = EIL1EF
       CALL FIG13A(EB,ETA,PHIXI,FAULT)
       IF (FAULT .NE. 0) GO TO 20
C
C      Add [1 - (Phi'i)] * (Delta Cl/c)1 to D
C      --------------------------------------
       D = D + (1.0 - PHIXI) * DCLJ(1)
      END IF
C
C     Contribution of the trailing edge
C     =================================
      IF (NNT .GT. 0) THEN
C
C      Take each trailing-edge device in turn
C      --------------------------------------
       DO 10 J = 1,NNT
C
C      Figure 3 of Item 93019 gives (Phi'o)j
C      as a function of (eta bar) and (eta ot)j
C      ----------------------------------------
       ETA = EOT(J)
       CALL FIG13A(EB,ETA,PHIXOJ,FAULT)
       IF (FAULT .NE. 0) GO TO 20
C
C      Figure 3 of Item 93019 gives (Phi'i)j
C      as a functionof (eta bar)
C      and (eta it)j for j > 1
C      or (etait)1eff for j = 1
C      -------------------------------------
       ETA = EIT(J)
       IF (J .EQ. 1) ETA = EIT1EF
       CALL FIG13A(EB,ETA,PHIXIJ,FAULT)
       IF (FAULT .NE. 0) GO TO 20
C
C      Add to D the contribution of trailing edge panel j; i.e. add
C      [(Phi'o)j - (Phi'i)j] * (Delta ct / c - K delta ct / c)j
C      ------------------------------------------------------------
      D = D + ( PHIXOJ - PHIXIJ ) * QJ(J)
C
   10  CONTINUE
C
      END IF
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRK3(NNL,NNT,W,EOT,EIL1EF,P)
C     =========================================
C
C     Purpose
C     -------
C     Section k3: calculation of the power p for the lift curve
C
C     Input
C     -----
C     NNL       - number of leading-edge device panels (0<=NNL<=5)
C     NNT       - number of trailing-edge device panels (0<=NNT<=5)
C     W         - ratio of body width to semi-span  [W/s]
C     EOT(5)    - positions of outer edges of NNT trailing-edge
C                 panels  [(eta ol)j]
C     EIL1EF    - effective spanwise position of inboard edge
C                 of innermost leading-edge device as a proportion
C
C     Output
C     ------
C     P         - the power p
C
C     Local
C     -----
C     ETAIL     - eta il
C     ETAOT     - eta ot
C
C     -----------------------------------------------------------------
C
      INTEGER NNL,NNT
      REAL W,EOT(5),EIL1EF,P
C
      REAL ETAIL,ETAOT
C
C     If Nnl = 0, (eta il) = 0.0
C     Otherwise (eta il) = (eta il)1eff
C     ---------------------------------
      ETAIL = 0.0
      IF (NNL .GT. 0) ETAIL = EIL1EF
C
C     If Nnt = 0, (eta ot) = 1.0
C     Otherwise (eta ot) = (eta ot)j with j = NNt
C     -------------------------------------------
      ETAOT = 1.0
      IF (NNT .GT. 0) ETAOT = EOT(NNT)
C
C     Subroutine 15 gives p as a function of
C     (eta il), (eta ot) and (W/s)
C     -------------------------------------
      CALL SUBR15(ETAIL,ETAOT,W,P)
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRLL(OUTFIL,K,JL,JT)
C     =================================
C
C     Purpose
C     -------
C     Section l: output of results for a particular combination
C     of Mach + Reynolds number pair plus leading-edge device setting
C     plus trailing-edge device setting
C
C     Input
C     -----
C     OUTFIL   - output unit number
C     K        - Mach plus Reynolds number pair
C     JL       - leading-edge device setting number
C     JT       - trailing-edge device setting number
C     The results are supplied by common blocks.
C
C     ICOUNT - output loop counter
C     IZERO  - to zero ICOUNT
C     IST    - first loop identifier
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,K,JL,JT
C
C     Common block to contain integer data
C     ------------------------------------
      INTEGER        CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ,NTJ,NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
      COMMON /ZB9931/CALC,NMR,TES,INT,NDL,NDT,NNL,NNT,
     *               NLJ(5),NTJ(5),NL,NT,CSL,CST,ITYPE,NLINES,NCL,MSG
C
C     Common block to contain floating point data
C     -------------------------------------------
      REAL           MN,RN,A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG,ZUG,ZLG,ZC92,D23,TCR,XTRR,TAUR,
     *               XRG,ZURG,ZLRG,Z92R,T23,XTR23,TAU23,
     *               X23G,ZU23G,ZL23G,Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL,RL,
     *               CXL,DCL,GL,HL,LL,XL,
     *               XN,DT,DCT,CT,RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL,EOL,
     *               EIT,EOT,DLJ,CXLJ,DCLJ,
     *               DTJ,DCTJ,CTJ,PHITJ,
     *               XLMJ,ZLMJ,TJ,TAUJ,TAUAJ,XTSJ,
     *               XCL0B,XCLMB,XCL0BW,XCLMBW,
     *               XCL0BF,XCLMBF,XDCLMF
      COMMON /ZD9931/MN(10),RN(10),A,TR,N,LDN,EP,T,XTR,XUM,ZUM,TAU,
     *               XG(17),ZUG(17),ZLG(17),ZC92,D23,TCR,XTRR,TAUR,
     *               XRG(15),ZURG(15),ZLRG(15),Z92R,T23,XTR23,TAU23,
     *               X23G(15),ZU23G(15),ZL23G(15),Z9223,TAUA,TAUAU,
     *               ZU5,ZL5,W,IW,H,EILP,EITP,EOTP,DL(10),RL(10),
     *               CXL(10),DCL(10),GL(10),HL(10),LL(10),XL(10),
     *               XN(10),DT(3,10),DCT(3,10),CT(3),RLT,PHIT,
     *               XLM,ZLM,ZCM,ZU125,ZL125,XTS,LDH,EIL(5),EOL(5),
     *               EIT(5),EOT(5),DLJ(5,10),CXLJ(5,10),DCLJ(5,10),
     *               DTJ(3,5,10),DCTJ(3,5,10),CTJ(3,5),PHITJ(5),
     *               XLMJ(5),ZLMJ(5),TJ(5),TAUJ(5),TAUAJ(5),XTSJ(5),
     *               XCL0B(10),XCLMB(10),XCL0BW(10),XCLMBW(10),
     *               XCL0BF(10),XCLMBF(10),XDCLMF(10)
C
C     Common block to contain main results
C     ------------------------------------
      REAL   DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ,DC0TWJ,DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD,CL
C
      REAL DCLMTJ
      COMMON /ZE9931/
     *       DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *       DC0LWJ(5),DC0TWJ(5),DCL0LW,DCL0TW,DCL0W,CL0BW,CL0W,
     *       DCLMXL,DCLMXT,DCLMX,CLMXB,CLMXW,
     *       CL0BF,CL0WF,DCLMXF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),CL(200)
C
       COMMON /ZP9931/ DCLMTJ(5)
C     Common block to contain intermediate results
C     --------------------------------------------
      REAL LDX,KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *     A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *     CXCL,CXCT,CXC,CXCLJ,CXCTJ,CXCM,CELCXM,EILPEF,EITPEF,
     *     EIL1EF,EIT1EF,QJ,D,P
C
      COMMON /ZF9931/
     *       LDX(4),KAPPA,CPCBB,CRCBB,C23CBB,LCS,EB,RXK,RXKR,RXK23,MUP,
     *       A0BW,A0BF,A0BT,LCS0T,A0BTP,LCS0P,
     *       CXCL,CXCT,CXC,CXCLJ(5),CXCTJ(5),CXCM,CELCXM,EILPEF,EITPEF,
     *       EIL1EF,EIT1EF,QJ(5),D,P
C
      INTEGER ICOUNT,IZERO,IST
      COMMON /ZQ9931/ ICOUNT,IZERO,IST
      INTEGER LIST(18,11)
      DATA LIST /
     * 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13,14,15,16, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 9,10, 0, 0, 0, 0, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 9,10, 0, 0,13,14,15,16, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 9, 0, 0, 0,13,14,15, 0, 0, 0 /
C
      WRITE(OUTFIL,10)
   10 FORMAT(//,
     *1X,72(1H-))
C
C     Print header
C
      IF (IST .EQ. 0  )WRITE (OUTFIL,28)
   28 FORMAT (1X,/,'  RESULTS        RESULTS        RESULTS',//,
     *1X,72(1H-),/)
C
C     Print any message from Subroutine 8 about aerofoil type
C     -------------------------------------------------------
      IF (MSG .GT. 0 .AND. IST .EQ. 0) CALL SUBRL1(OUTFIL,MSG)
      IST = 1
C
      IZERO = NDL * NDT
      IF (NDL .EQ. 0) IZERO = NDT
      IF (NDT .EQ. 0) IZERO = NDL
C
C     Print Mach number, Reynolds number pair
C     ---------------------------------------
      IF (ICOUNT .EQ. 0 .OR. ICOUNT .EQ. (IZERO)) THEN
      WRITE(OUTFIL,20) K,MN(K),RN(K)
   20 FORMAT(/,
     *1X,'Mach number, Reynolds number pair: ',I2,/,
     *1X,'Mach number     =',F12.4,/,
     *1X,'Reynolds number =',G12.4,//,1X,72(1H-))
C
         IF (CALC .GT. 6) THEN
      IF (LIST(CALC,1) .GT. 0) WRITE(OUTFIL,16) CL0BF
      IF (LIST(CALC,2) .GT. 0) WRITE(OUTFIL,26) CL0BW
   16 FORMAT(/,
     *1X,'Lift coefficient at zero angle of attack for basic wing-',
     *'fuselage',/,
     *1X,'CL0Bf =',G12.3)
   26 FORMAT(/,
     *1X,'Lift coefficient at zero angle of attack for basic wing',/,
     *1X,'CL0Bw =',G12.3)
C
      IF (LIST(CALC,11) .GT. 0) WRITE(OUTFIL,27) LCS
   27 FORMAT(/,
     *1X,'Theoretical (linear) lift-curve slope (per rad.): ',G12.3)
C
      IF (LIST(CALC,3) .GT. 0) WRITE(OUTFIL,36) CLMXBF
      IF (LIST(CALC,4) .GT. 0) WRITE(OUTFIL,46) CLMXB
   36 FORMAT(/,
     *1X,'Maximum lift coefficient for basic wing-fuselage',/,
     *1X,'CLmaxBf =',G12.3)
   46 FORMAT(/,
     *1X,'Maximum lift coefficient for basic wing',/,
     *1X,'CLmaxB =',G12.3)
      WRITE (OUTFIL,47)
   47 FORMAT (//,1X,72(1H-))
         ELSE
      IF (CALC . LE. 4) WRITE(OUTFIL,19) CL0B
   19 FORMAT(/,
     *1X,'Lift coefficient at zero angle of attack for basic aerofoil',/
     *,1X,'CL0B =',G12.3)
C
      IF (CALC .LE. 3) WRITE(OUTFIL,18) LCS
   18 FORMAT(/,
     *1X,'Theoretical (linear) lift-curve slope (per rad.): ',G12.3)
C
      IF (CALC .LE. 2) WRITE(OUTFIL,29) CLMB
   29 FORMAT(/,
     *1X,'Maximum lift coefficient for basic aerofoil',/,
     *1X,'CLmB =',G12.3)
      WRITE (OUTFIL,48)
   48 FORMAT (//,1X,72(1H-))
C
         END IF
      IF ( ICOUNT .NE. 0 )ICOUNT = ICOUNT - IZERO
      END IF
C     Print leading-edge and trailing-edge setting numbers
C     ----------------------------------------------------
      IF (NDL .GT. 0) WRITE(OUTFIL,30) JL
   30 FORMAT(/,
     *1X,'Leading-edge device setting number:  ',I2)
C
      IF (NDT .GT. 0) WRITE(OUTFIL,40) JT
   40 FORMAT(/,
     *1X,'Trailing-edge device setting number: ',I2)
C
C
C     Calculations (1 to 6) and (7 to 18) are treated separately
C     ----------------------------------------------------------
      IF (CALC .GT. 6) THEN
       CALL SUBRL2(OUTFIL,CALC,NNL,NNT,NLJ,NTJ,NL,NT,NCL,
     *             DL(JL),DT(1,JT),DLJ(1,JL),DTJ(1,1,JT),
     *             DC0LWJ,DC0TWJ,DCL0LW,
     *             DCL0TW,DCL0W,CL0BW,CL0W,DCLMXL,DCLMXT,
     *             DCLMX,CLMXB,CLMXW,CL0BF,CL0WF,CLMXBF,
     *             CLMXWF,A0,ACLMX,AD,CL,LCS,DCLMTJ)
      ELSE
C
       CALL SUBRL3(OUTFIL,CALC,NL,NT,NCL,DL(JL),DT(1,JT),
     *             DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *             A0,ACLMX,AD,CL,LCS)
C
      END IF
C
      ICOUNT = ICOUNT + 1
C
      IF (NDL .EQ. 0 .AND. NDT .EQ. 0) ICOUNT = 0
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRL1(OUTFIL,MSG)
C     =============================
C
C     Purpose
C     -------
C     To print a message from Suboutine 8 about the aerofoil type ITYPE
C
C     Input
C     -----
C     OUTFIL  - output unit number
C     MSG     - message number
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,MSG
C
      INTEGER I,NLNS(6)
      CHARACTER*64 NOTE(4,6)
C
      DATA NLNS / 2, 2, 2, 4, 3, 4/
C
      DATA (NOTE(I,1), I = 1,2) /
     *'The section geometry of the basic aerofoil or wing at eta p',
     *'is assessed as modern, see Section 3 of Item No. 99031.'/
C
      DATA (NOTE(I,2), I = 1,2) /
     *'The section geometry of the basic aerofoil or wing at eta p',
     *'is assessed as conventional, see Section 3 of Item No. 99031.'/
C
      DATA (NOTE(I,3), I = 1,2) /
     *'The section geometry of the basic aerofoil or wing at eta p',
     *'has been specified as modern, see Section 3 of Item No. 99031.'/
C
      DATA (NOTE(I,4), I = 1,4) /
     *'The section geometry of the basic aerofoil or wing at eta p',
     *'has been specified as modern, but the geometry does not satisfy',
     *'the criteria for a modern section given in Section 3 of Item',
     *'Number 99031. (Fs is taken from Figure 5 of Item No. 84026.)'/
C
      DATA (NOTE(I,5), I = 1,3) /
     *'The section geometry of the basic aerofoil or wing at eta p',
     *'has been specified as conventional, see Section 3 of Item',
     *'Number 99031.'/
C
      DATA (NOTE(I,6), I = 1,4) /
     *'The section geometry of the basic aerofoil or wing at eta p',
     *'has been specified as conventional although the geometry',
     *'satisfies the criteria for a modern section given in Section 3',
     *'of Item No. 99031. (Fs is taken as unity, see Item No. 84026.)'/
C
      IF (MSG .NE. 0) THEN
       DO 20 I = 1,NLNS(MSG)
       WRITE(OUTFIL,10) NOTE(I,MSG)
   10  FORMAT(1X,A64)
   20  CONTINUE
       WRITE (OUTFIL,11)
   11 FORMAT (//,1X,72(1H-))
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRL2(OUTFIL,CALC,NNL,NNT,NLJ,NTJ,NL,NT,NCL,
     *                  DL,DT,DLJ,DTJ,DC0LWJ,DC0TWJ,DCL0LW,
     *                  DCL0TW,DCL0W,CL0BW,CL0W,DCLMXL,DCLMXT,
     *                  DCLMX,CLMXB,CLMXW,CL0BF,CL0WF,CLMXBF,
     *                  CLMXWF,A0,ACLMX,AD,CL,LCS,DCLMTJ)
C     ========================================================
C
C     Purpose
C     -------
C     To print results for wings and wing-body combinations
C     CALC = 7 to 18
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,CALC,NNL,NNT,NLJ(5),NTJ(5),NL,NT,NCL
      REAL DL,DT(3),DLJ(5),DTJ(3,5),DC0LWJ(5),DC0TWJ(5),DCL0LW,
     *     DCL0TW,DCL0W,CL0BW,CL0W,DCLMXL,DCLMXT,DCLMX,CLMXB,
     *     CLMXW,CL0BF,CL0WF,CLMXBF,CLMXWF,A0,ACLMX,AD(200),
     *     CL(200),LCS
C
      REAL DCLMTJ(5)
C
      INTEGER I,J,L,LIST(18,11)
      INTEGER NE
      REAL ZERO
      CHARACTER*14 LETYPE(6),TETYPE(5),WHERE(3)
C
      DATA WHERE / '(innermost)','(outermost)','           '/
C
      DATA LETYPE / 'plain flap', 'droop', 'sealed slat',
     *              'Kruger',     'slat',  'vented Kruger' /
C
      DATA TETYPE / 'plain',      'split', 'slotted',
     *              'double-slotted', 'triple-slotted' /
C
      DATA LIST /
     * 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13,14,15,16, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 9,10, 0, 0, 0, 0, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0,11, 0,13,14, 0, 0,17, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 9,10, 0, 0,13,14,15,16, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 0, 0, 0, 0,13,14, 0, 0, 0, 0,
     * 0, 0, 0, 0, 0, 0, 7, 8, 9, 0, 0, 0,13,14,15, 0, 0, 0 /
C
C to avoid use warning
      DT(1) = DT(1)+ 0.0
      DT(2) = DT(2)+ 0.0
      DT(3) = DT(3)+ 0.0
      NT = NT + 0
      CL0BW = CL0BW + 0.0
      CLMXB = CLMXB + 0.0
      CL0BF = CL0BF + 0.0
      CLMXBF = CLMXBF + 0.0
      LCS = LCS + 0.0
C
      IF (NNL .GT. 0) THEN
       WRITE(OUTFIL,50)
   50  FORMAT(/,
     * 1X,'Increments in CL0 due to leading-edge devices',/,
     * 1X,'---------------------------------------------',/,
     * 1X,'Panel           ','  Device type  ','    Setting angle ',
     *    '  Increment   ',/,
     * 1X,'j               ','               ','      (degrees)  ',
     *    ' (Delta CL0lw)j)')
C
       DO 70 J = 1,NNL
C
       IF (NNL .EQ. 1 .OR. (J .GT. 1 .AND. J .LT. NNL)) THEN
        L = 3
       ELSE
        IF (J .EQ. 1)   L = 1
        IF (J .EQ. NNL) L = 2
       END IF
C
       WRITE(OUTFIL,60) J,WHERE(L),LETYPE(NLJ(J)),DLJ(J),DC0LWJ(J)
   60  FORMAT(1X,I1,A15,A15,F15.3,G15.3)
C
   70  CONTINUE
C
       WRITE(OUTFIL,80)DCL0LW
   80  FORMAT(/,
     * 1X,'Total increment due to leading-edge devices',/,
     * 1X,'Delta CL0lw =',G12.3)
C
      END IF
C
      IF (NNT .GT. 0) THEN
       WRITE(OUTFIL,90)
   90  FORMAT(/,
     * 1X,'Increments in CL0 due to trailing-edge flaps',/,
     * 1X,'--------------------------------------------',/,
     * 1X,'Panel           ',' Flap type     ',' Flap element  ',
     *    '  Deflection angl','e  Increment   ',/,
     * 1X,'j               ','               ','               ',
     *    '     (degrees)   ',' (Delta CL0tw)j')
C
       DO 130 J = 1,NNT
C
       IF (NNT .EQ. 1 .OR. (J .GT. 1 .AND. J .LT. NNT)) THEN
        L = 3
       ELSE
        IF (J .EQ. 1)   L = 1
        IF (J .EQ. NNT) L = 2
       END IF
C
       NE = 1
       IF (NTJ(J) .GT. 3) NE = NTJ(J) - 2
C
       I = 1
       WRITE(OUTFIL,100) J,WHERE(L),TETYPE(NTJ(J)),I,DTJ(1,J),DC0TWJ(J)
  100  FORMAT(1X,I1,A15,A15,7X,I1,7X,F15.3,G15.3)
C
       IF (NE .GT. 1) THEN
        DO 120 I = 2,NE
        WRITE(OUTFIL,110) I,DTJ(I,J)
  110   FORMAT(1X,31X,7X,I1,7X,F15.3)
  120   CONTINUE
       END IF
C
        WRITE (OUTFIL,111)
  111 FORMAT (1X,/)
C
  130  CONTINUE
C
       WRITE(OUTFIL,140) DCL0TW
  140  FORMAT(/,
     * 1X,'Total increment due to trailing-edge devices',/,
     * 1X,'Delta CL0tw =',G12.3)
C
      END IF
C
      WRITE(OUTFIL,150) DCL0W
  150 FORMAT(/,
     *1X,'Total increment due to high-lift system',/,
     *1X,'Delta CL0w =',G12.3)
C
      IF (LIST(CALC,5) .GT. 0) THEN
C
       NL = NLJ(1)
       DL = DLJ(1)
       IF (NL .GT. 0) WRITE(OUTFIL,160) LETYPE(NLJ(1)),DL,DCLMXL
  160  FORMAT(//,
     * 1X,'Increment in CLmax due to leading-edge device',/,
     * 1X,'---------------------------------------------',/,
     * 1X,'leading-edge device =',A15,/,
     * 1X,'setting angle (deg) =',F12.3,/,
     * 1X,'Delta CLmaxl =',G12.3)
C
      IF (NNT .GT. 0) THEN
       WRITE(OUTFIL,95)
   95  FORMAT(/,
     * 1X,'Increments in CLmax due to trailing-edge flaps',/,
     * 1X,'--------------------------------------------',/,
     * 1X,'Panel           ',' Flap type     ',' Flap element  ',
     *    ' Deflection angl','e  Increment   ',/,
     * 1X,'j               ','               ','               ',
     *    '    (degrees)   ','  (Delta CLmaxt)j')
C
       DO 135 J = 1,NNT
C
       IF (NNT .EQ. 1 .OR. (J .GT. 1 .AND. J .LT. NNT)) THEN
        L = 3
       ELSE
        IF (J .EQ. 1)   L = 1
        IF (J .EQ. NNT) L = 2
       END IF
C
       NE = 1
       IF (NTJ(J) .GT. 3) NE = NTJ(J) - 2
C
       I = 1
       WRITE(OUTFIL,105) J,WHERE(L),TETYPE(NTJ(J)),I,DTJ(1,J),DCLMTJ(J)
  105  FORMAT(1X,I1,A15,A15,7X,I1,7X,F15.3,G15.3)
C
       IF (NE .GT. 1) THEN
        DO 125 I = 2,NE
        WRITE(OUTFIL,115) I,DTJ(I,J)
  115   FORMAT(1X,31X,7X,I1,7X,F15.3)
  125   CONTINUE
       END IF
C
       WRITE (OUTFIL,111)
C
  135  CONTINUE
C
C
       WRITE(OUTFIL,210) DCLMXT
  210  FORMAT(1X,'Total increment due to trailing-edge devices',/,
     + 1X,'Delta CLmaxt =',G12.3)
C
       END IF
C
       WRITE(OUTFIL,220) DCLMX
  220  FORMAT(//,
     * 1X,'Total increment due to high-lift system',/,
     * 1X,'Delta CLmax =',G12.3)
C
      END IF
C
C
                    IF ((NNL+NNT) .NE. 0 ) THEN
      IF (LIST(CALC,6) .GT. 0) THEN
       WRITE(OUTFIL,230)
  230  FORMAT(/,
     + 1X,'--------------------------------------------------------',//,
     * 1X,'Lift coefficient at zero angle of attack with high-lift ',
     *    'devices deployed')
       IF (CALC .LE. 12) WRITE(OUTFIL,240) CL0W
  240  FORMAT(1X,'CL0w =',G12.3)
       IF (CALC .GE. 13) WRITE(OUTFIL,250) CL0WF
  250  FORMAT(1X,'CL0wf =',G12.3)
      END IF
C
      IF (LIST(CALC,7) .GT. 0) THEN
       WRITE(OUTFIL,260)
  260  FORMAT(//,
     * 1X,'Maximum lift coefficient with high-lift devices deployed')
       IF (CALC .LE. 12) WRITE(OUTFIL,270) CLMXW
  270  FORMAT(1X,'CLmaxw =',G12.3)
       IF (CALC .GE. 13) WRITE(OUTFIL,280) CLMXWF
  280  FORMAT(1X,'CLmaxwf =',G12.3)
      END IF
C
                   END IF
      IF (LIST(CALC,11) .GT. 0) WRITE(OUTFIL,290) A0
  290 FORMAT(/,
     *1X,'Angle of attack for zero lift coefficient',/,
     *1X,'alpha 0 (deg) =',F12.2)
C
      IF (LIST(CALC,9) .GT. 0) WRITE(OUTFIL,300) ACLMX
  300 FORMAT(/,
     *1X,'Angle of attack for maximum lift coefficient',/,
     *1X,'alpha CLmax (deg) =',F12.2)
C
      IF (LIST(CALC,10) .GT. 0) THEN
          IF (AD(1) .LT. -4.9999999) THEN
       WRITE(OUTFIL,310)
  310  FORMAT(/,
     * 1X,'Lift curve  - Lift coefficients at angles of attack',/,
     + 1X,'---------     much less than minus 5 degrees are unlikely',/,
     * 1X,'              to represent achievable values but are',/,
     + 1X,'              generated in the construction of the lift',/,
     + 1X,'              curve to maximum lift coefficient,',/,
     + 1X,'                                        see Item No. 96003.',
     + 1X,/,
     * 1X,'----------',//,
     * 1X,'Angle of attack',5X,'Lift coefficient',/,
     * 1X,'     (deg)     ',5X,'       CL       ')
         ELSE
       WRITE(OUTFIL,311)
  311  FORMAT(/,
     * 1X,'Lift curve  ',/,
     + 1X,'----------',//,
     * 1X,'Angle of attack',5X,'Lift coefficient',/,
     * 1X,'     (deg)     ',5X,'       CL       ')
         END IF
C
       ZERO = 0.0
       WRITE(OUTFIL,320) A0,ZERO
  320  FORMAT(1X,F15.2,5X,G15.4)
       DO 330 I = 1,NCL
C
         IF (AD(I) .GT. -5.00001 .AND. AD(I) .LT. -4.750001)
     * WRITE (OUTFIL,321)
  321  FORMAT (1X,//,'      ------------------------------')
       IF (AD(I) .GT. -10.24999 ) WRITE(OUTFIL,320) AD(I),CL(I)
C
  330  CONTINUE
       IF (CALC .LE. 12) WRITE(OUTFIL,320) ACLMX,CLMXW
       IF (CALC .GE. 13) WRITE(OUTFIL,320) ACLMX,CLMXWF
C
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBRL3(OUTFIL,CALC,NL,NT,NCL,DL,DT,DCL0L,DCL0T,DCL0,
     *                  CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,A0,ACLMX,AD,
     *                  CL,LCS)
C     =================================================================
C
C     Purpose
C     -------
C     To print results for aerofoils (CALC = 1 to 6)
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,CALC,NL,NT,NCL
      REAL DL,DT(3),DCL0L,DCL0T,DCL0,CL0B,CL0,DCLML,DCLMT,DCLM,CLMB,CLM,
     *     A0,ACLMX,AD(200),CL(200),LCS
C
      INTEGER I,LIST(6,14)
      REAL ZERO
      CHARACTER*14 LETYPE(6),TETYPE(5)
C
      DATA LETYPE / 'plain flap', 'droop', 'sealed slat',
     *              'Kruger',     'slat',  'vented Kruger' /
C
      DATA TETYPE / 'plain',      'split', 'slotted',
     *              'double-slotted', 'triple-slotted' /
C
      DATA LIST /
     * 1, 2, 3, 4, 0, 0,
     * 1, 2, 0, 0, 0, 0,
     * 1, 2, 3, 4, 5, 6,
     * 1, 2, 3, 4, 5, 6,
     * 1, 2, 3, 4, 5, 6,
     * 1, 2, 0, 0, 5, 0,
     * 1, 2, 0, 0, 5, 0,
     * 1, 2, 0, 0, 5, 0,
     * 1, 2, 3, 4, 0, 0,
     * 1, 2, 0, 0, 0, 0,
     * 1, 2, 3, 4, 0, 0,
     * 1, 2, 0, 0, 0, 0,
     * 1, 2, 0, 0, 0, 0,
     * 1, 2, 3, 0, 0, 0 /
C
C to avoid 'use' warnings
      CL0B = CL0B + 0.0
      CLMB = CLMB + 0.0
      LCS = LCS + 0.0
C
      IF (LIST(CALC,3) .GT. 0 .AND. NL .GT. 0)
     * WRITE(OUTFIL,30) LETYPE(NL),DL,DCL0L
   30 FORMAT(//,
     *1X,'Increment in CL0 due to leading-edge device',/,
     *1X,'device type =',A15,/,
     *1X,'setting angle (deg) =',F12.3,/,
     *1X,'Delta CL0l =',G12.3)
C
      IF (LIST(CALC,4) .GT. 0 .AND.NT .GT. 0) THEN
C
       WRITE(OUTFIL,40) TETYPE(NT)
   40  FORMAT(//,
     * 1X,'Increment in CL0 due to trailing-edge flap',/,
     * 1X,'flap type =',A15)
C
       IF (NT .LE. 3) WRITE(OUTFIL,50) DT(1)
   50  FORMAT(1X,'deflection angle (deg) =',F12.3)
C
       IF (NT .EQ. 4) WRITE(OUTFIL,60) DT(1),DT(2)
   60  FORMAT(
     * 1X,'deflection angle of first element  (deg) =',F12.3,/,
     * 1X,'deflection angle of second element (deg) =',F12.3)
C
       IF (NT .EQ. 5) WRITE(OUTFIL,70) DT(1),DT(2),DT(3)
   70  FORMAT(
     * 1X,'deflection angle of first element  (deg) =',F12.3,/,
     * 1X,'deflection angle of second element (deg) =',F12.3,/,
     * 1X,'deflection angle of third element  (deg) =',F12.3)
C
       WRITE(OUTFIL,80) DCL0T
   80  FORMAT(1X,'Delta CL0t =',G12.3)
C
      END IF
C
      IF (LIST(CALC,5) .GT. 0) WRITE(OUTFIL,90) DCL0
   90 FORMAT(//,
     *1X,'Total increment due to high-lift system',/,
     *1X,'Delta CL0 =',G12.3)
C
      IF (LIST(CALC,6) .GT. 0 .AND. NL .GT. 0)
     * WRITE(OUTFIL,100) LETYPE(NL),DL,DCLML
  100 FORMAT(//,
     *1X,'Increment in CLmax due to leading-edge device',/,
     *1X,'device type =',A15,/,
     *1X,'setting angle (deg) =',F12.3,/,
     *1X,'Delta CLml =',G12.3)
C
      IF (LIST(CALC,7) .GT. 0 .AND.NT .GT. 0) THEN
C
       WRITE(OUTFIL,110) TETYPE(NT)
  110  FORMAT(//,
     * 1X,'Increment in CLmax due to trailing-edge flap',/,
     * 1X,'flap type =',A15)
C
       IF (NT .LE. 3) WRITE(OUTFIL,50) DT(1)
       IF (NT .EQ. 4) WRITE(OUTFIL,60) DT(1),DT(2)
       IF (NT .EQ. 5) WRITE(OUTFIL,70) DT(1),DT(2),DT(3)
C
       WRITE(OUTFIL,120) DCLMT
  120  FORMAT(1X,'Delta CLmt =',G12.3)
C
      END IF
C
      IF (LIST(CALC,8) .GT. 0) WRITE(OUTFIL,130) DCLM
  130 FORMAT(//,
     *1X,'Total increment due to high-lift system',/,
     *1X,'Delta CLm =',G12.3)
C
                        IF ((NL+NT) .NE. 0) THEN
      IF (LIST(CALC,9) .GT. 0) WRITE(OUTFIL,140) CL0
  140 FORMAT(/,
     *1X,'Lift coefficient at zero angle of attack with high-lift ',
     *   'devices deployed',/,
     *1X,'CL0 =',G12.3)
C
      IF (LIST(CALC,10) .GT. 0) WRITE(OUTFIL,150) CLM
  150 FORMAT(//,
     *1X,'Maximum lift coefficient with high-lift devices deployed',/,
     *1X,'CLm =',G12.3)
                        END IF
C
C     Dont print A0 if CALC=4 or CALC=3
      IF (CALC.EQ.4) GOTO 998
c      IF (CALC.EQ.3) GOTO 998
      IF (LIST(CALC,11) .GT. 0) WRITE(OUTFIL,160) A0
  160 FORMAT(/,
     *1X,'Angle of attack for zero lift coefficient',/,
     *1X,'alpha 0 (deg) =',F12.2)
  998 CONTINUE
C
      IF (LIST(CALC,12) .GT. 0) WRITE(OUTFIL,170) ACLMX
  170 FORMAT(/,
     *1X,'Angle of attack for maximum lift coefficient',/,
     *1X,'alpha CLmax (deg) =',F12.2)
C
      IF (LIST(CALC,13) .GT. 0) THEN
           IF (AD(1) .LT. -4.999999)    THEN
       WRITE(OUTFIL,180)
  180  FORMAT(/,
     * 1X,'Lift curve  - Lift coefficients at angles of attack',/,
     + 1X,'---------     much less than minus 5 degrees are unlikely',/,
     * 1X,'              to represent achievable values but are',/,
     + 1X,'              generated in the construction of the lift',/,
     + 1X,'              curve to maximum lift coefficient,',/,
     + 1X,'                                        see Item No. 96003.',
     + 1X,/,
     * 1X,'----------',//,
     * 1X,'Angle of attack',5X,'Lift coefficient',/,
     * 1X,'     (deg)     ',5X,'       CL       ')
           ELSE
       WRITE(OUTFIL,181)
  181  FORMAT(/,
     * 1X,'Lift curve  ',/,
     + 1X,'----------',//,
     * 1X,'Angle of attack',5X,'Lift coefficient',/,
     * 1X,'     (deg)     ',5X,'       CL       ')
           END IF
C
       ZERO = 0.0
       WRITE(OUTFIL,190) A0,ZERO
  190  FORMAT(1X,F15.2,5X,G15.4)
       DO 200 I = 1,NCL
C
         IF (AD(I) .GT. -5.00001 .AND. AD(I) .LT. -4.750001)
     * WRITE (OUTFIL,321)
  321  FORMAT (1X,//,'      ------------------------------')
       IF (AD(I) .GT. -10.24999 ) WRITE(OUTFIL,190) AD(I),CL(I)
  200  CONTINUE
       WRITE(OUTFIL,190) ACLMX,CLM
C
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE PARERR(OUTFIL,FAULT)
C     ===============================
C
C     Purpose
C     -------
C     To print an error found by Sections a to l of the notes
C
C     Input
C     -----
C     OUTFIL    - output unit number
C     FAULT     - fault number
C                 (This set of fault numbers runs from 1001 to 1041.)
C
C     Local
C     -----
C     TXT(2,41) - two lines of text per message
C     I,J       - array indices
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,FAULT
C
      INTEGER I,J
      CHARACTER*62 TXT
      COMMON /PARTXT/ TXT(2,41)
C
      J = FAULT - 1000
      IF (J .GT. 0 .AND. J .LE. 41) THEN
       WRITE(OUTFIL,10) (TXT(I,J), I = 1,2)
   10  FORMAT(2(/,1X,A62),/)
      ELSE
       WRITE(OUTFIL,20) FAULT
   20  FORMAT(1X,'Program error - Error ',I5,' should not exist.')
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA PARFLT
C     =================
C
C     Text of error messages for use in Subroutine PARERR
C     ---------------------------------------------------
C
      INTEGER I,J
      CHARACTER*62 TXT
      COMMON /PARTXT/ TXT(2,41)
C
      DATA ((TXT(I,J), I = 1,2), J = 1,5) /
     *'Error detected by Section c4 (Subroutine SUBRC4)',
     *'(t/c) is too small.',
     *'Error detected by Section c4 (Subroutine SUBRC4)',
     *'Mk makes beta too small or imaginary.',
     *'Error detected by Section d1 (Subroutine SUBRD1)',
     *'(xum/c) is too close to 1.0',
     *'Error detected by Section d1 (Subroutine SUBRD1)',
     *'cos(Lambda0) is too small.',
     *'Error detected by Section d1 (Subroutine SUBRD1)',
     *'(mu p) is too small.'/
C
      DATA ((TXT(I,J), I = 1,2), J = 6,10) /
     *'Error detected by Section d3 (Subroutine SUBRD3)',
     *'(xum/c) is too close to 1.0',
     *'Error detected by Section e2 (Subroutine SUBRE2)',
     *'Extended chord / chord (c~/c) is too small.',
     *'Error detected by Section f (Subroutine SUBRF1)',
     *'Extended chord / chord (c~/c) is too small.',
     *'Error detected by Section F2 (Subroutine SUBRF2)',
     *'Extended chord / chord (c~/c) is too small.',
     *'Error in calculation of J factor Jt1 (Subroutine SUBJT1)',
     *'(delta t1) / cos(Lambda2) should not be negative.'/
C
      DATA ((TXT(I,J), I = 1,2), J = 11,15) /
     *'Error in calculation of J factor Jt2 (Subroutine SUBJT2)',
     *'(delta t1) / cos(Lambda2) should not be less than -10',
     *'Error in calculation of J factor Jt3 (Subroutine SUBJT3)',
     *'(delta t1) / cos(Lambda2) should not be negative.',
     *'Error detected in Section g (Subroutine SUBRG5)',
     *'extended chord / chord with trailing edge extended too small',
     *'Error detected in Section g2 (Subroutine SUBRG8)',
     *'extended chord / chord is too small.',
     *'Error detected in Section h (Subroutine SUBRH1)',
     *'cos(Lambda0) is too small.' /
C
      DATA ((TXT(I,J), I = 1,2), J = 16,20) /
     *'Error detected in Section h (Subroutine SUBRH1)',
     *'Reynolds number should exceed zero.',
     *'Error detected in Section h (Subroutine SUBRH1)',
     *'|(xl/c) - (xn/c)| is too small.',
     *'Error detected in Section h (Subroutine SUBRH1)',
     *'(mu p) is too small.',
     *'Error detected in Section H2 (Subroutine SUBRH2)',
     *'extended chord / chord is too small.',
     *'Error detected in Section H2 (Subroutine SUBRH2)',
     *'Reynolds number should exceed zero.' /
C
      DATA ((TXT(I,J), I = 1,2), J = 21,25) /
     *'Error detected in Section i (Subroutine SUBRI1)',
     *'Reynolds number and cos(Lambda0)^2 should exceed zero.',
     *'Error detected in Section i (Subroutine SUBRI1)',
     *'cos(Lambda1/4) should exceed zero.',
     *'Error detected in Section i (Subroutine SUBRI1)',
     *'(mu p) is too small.',
     *'Error detected in Section i (Subroutine SUBRI3)',
     *'extended chord / chord is too small.',
     *'Error detected in Section i (Subroutine SUBRI3)',
     *'|cos(Lambda h)| is too small.' /
C
      DATA ((TXT(I,J), I = 1,2), J = 26,30) /
     *'Error detected in Section i (Subroutine SUBRI4)',
     *'extended chord / chord is too small.',
     *'Error detected in Section i (Subroutine SUBRI4)',
     *'|cos(Lambda h)| is too small.',
     *'Error detected in Section i (Subroutine SUBRI4)',
     *'|cos(Lambda 0)| is too small.',
     *'Error detected in Section i (Subroutine SUBRI4)',
     *'[Delta CLmt / FR (Phi o - Phi i)]gen could not be calculated',
     *'Error detected in Section i (Subroutine SUBRI5)',
     *'|1 - (xum/c)| is too small.'/
C
      DATA ((TXT(I,J), I = 1,2), J = 31,35) /
     *'Error detected in Section i (Subroutine SUBRI5)',
     *'|cos(Lambda0)| is too small.',
     *'Error detected in Section i (Subroutine SUBRI5)',
     *'extended chord / chord is too small.',
     *'Error detected in Section i (Subroutine SUBRI5)',
     *'|cos(Lambda h)| is too small.',
     *'Error detected in Section I2 (Subroutine SUBRI6)',
     *'Reynolds number should exceed zero.',
     *'Error detected in Section I2 (Subroutine SUBRI6)',
     *'cos(Lambda2) is too small.'/
C
      DATA ((TXT(I,J), I = 1,2), J = 36,41) /
     *'Error detected in Section I2 (Subroutine SUBRI6)',
     *'extended chord / chord is too small.',
     *'Error detected in Section I2 (Subroutine SUBRI7)',
     *'Reynolds number should be positive.',
     *'Error detected in Section I2 (Subroutine SUBRI7)',
     *'extended chord / chord is too small.',
     *'Error detected in Section I2 (Subroutine SUBRI8)',
     *'Reynolds number should exceed zero.',
     *'Error detected in Section I2 (Subroutine SUBRI8)',
     *'|1 - (xum/c)| is too small.',
     *'Error detected in Section I2 (Subroutine SUBRI8)',
     *'extended chord / chord is too small.'/
C
      END

