C     --------------------------------------------------------
      SUBROUTINE FIG00A(W,X,Y,Z,FAULT)
C     ================================
C
C     Purpose
C     -------
C     To read Item 70011   Figure 1
C
C     Input
C     -----
C     W     - lambda
C     X     - A tan Lambda.5
C     Y     - Beta A
C
C     Output
C     ------
C     Z     - 1/A dCL/dalpha (1/rad)
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL W,X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *'lambda',
     *'A tan(Lambda1/2)',
     *'Beta A',
     *'1/A (d CL / d alpha)',
     *'Figure 1 of Item 70011' /
C
      DATA FLAGS /
     * 1, 1, 1,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    1.0,  0.0,
     * -6.0,   6.0,  0.0,
     * 0.0,   12.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,1) = W
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 1 of Item 70011
C     ---------------------------
      CALL FIG00B(W,X,Y,Z,FOUND)
C
C     Store the data if FIG00B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3000
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG00B(W,X,Y,Z,FOUND)
C     ================================
C
C     Purpose
C     -------
C     To read Item 70011   Figure 1
C
C     Input
C     -----
C     W     - lambda
C     X     - A tan Lambda.5
C     Y     - Beta A
C
C     Output
C     ------
C     Z     - 1/A dCL/dalpha (1/rad)
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N          - (5) the number of plots in Figure 1
C     WW(5)      - lambda for each of the five plots
C     ZZ(5)      - Z for lambda = 0.0, 0.125, 0.25, 0.5, 1.0
C                  and the given X and Y
C
C     ------------------------------------------------------------------
C
      INTEGER FOUND
      REAL W,X,Y,Z
C
      INTEGER N
      REAL WW(5),ZZ(5)
C
      DATA WW / 0.0, 0.125, 0.25, 0.5, 1.0 /
      DATA N / 5 /
C
C     Find Z for lambda = 0.0, 0.125, 0.25, 0.5 and 1.0
C     =================================================
C
C     Figure 1(a) lambda = 0.0
C     ------------------------
      CALL FIG00C(X,Y,ZZ(1),FOUND)
      IF (FOUND .NE. 1) GO TO 10
C
C     Figure 1(b) lambda = 0.125
C     --------------------------
      CALL FIG00D(X,Y,ZZ(2),FOUND)
      IF (FOUND .NE. 1) GO TO 10
C
C     Figure 1(c) lambda = 0.25
C     -------------------------
      CALL FIG00E(X,Y,ZZ(3),FOUND)
      IF (FOUND .NE. 1) GO TO 10
C
C     Figure 1(d) lambda = 0.5
C     ------------------------
      CALL FIG00F(X,Y,ZZ(4),FOUND)
      IF (FOUND .NE. 1) GO TO 10
C
C     Figure 1(e) lambda = 1.0
C     ------------------------
      CALL FIG00G(X,Y,ZZ(5),FOUND)
      IF (FOUND .NE. 1) GO TO 10
C
C     Fit a curve to the five points WW(1),ZZ(1) to WW(5),ZZ(5)
C     and interpolate for Z at the given W
C     ---------------------------------------------------------
      CALL A9G799(N,WW,ZZ,W,Z,FOUND)
C
   10 RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG00C(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 70011   Figure 1(a)
C
C     Input
C     -----
C     X     - A tan Lambda.5
C     Y     - Beta A
C
C     Output
C     ------
C     Z     - 1/A dCL/dalpha (1/rad)
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     I         - array index
C     XP        - |X|
C
C     The subroutine divides the plot into three patches:
C
C     (a) X = -3 to +6 and Y = 1.0 to 12.0
C     ORDERA    - order of polynomial
C     CA( )     - ORDERA * (ORDERA + 1) / 2 polynomial coefficients
C     XMNA,XMXA - minimum and maximum X
C     YMNA,YMXA - minimum and maximum Y
C
C     (b) X = +2.0 to +6.0 and Y = 0.0 to 1.0
C     ORDERB    - order of polynomial
C     CB( )     - ORDERB * (ORDERB + 1) / 2 polynomial coefficients
C     XMNB,XMXB - minimum and maximum X
C     YMNB,YMXB - minimum and maximum Y
C
C     (c) X = -2.0 to +2.0 and Y = 0.0 to 1.0
C     ORDERC    - order of polynomial
C     CC( )     - ORDERC * (ORDERC + 1) / 2 polynomial coefficients
C     XMNC,XMXC - minimum and maximum X
C     YMNC,YMXC - minimum and maximum Y
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      REAL XP
      COMMON /PLIC00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTC00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
      REAL X,Y,Z
C
C     The plot is symmetric about X = 0.0 so use the modulus of X.
C     ------------------------------------------------------------
      XP = ABS(X)
C
C     Calculate Z for the given X and Y (if possible).
C     Try the three patches in turn.
C     ================================================
C
C     Patch (a)
C     ---------
      CALL A9E799(XP,Y,XMNA,XMXA,YMNA,YMXA,ORDERA,CA,Z,FOUND)
C
C     Patch (b)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNB,XMXB,YMNB,YMXB,ORDERB,CB,Z,FOUND)
C
C     Patch (c)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNC,XMXC,YMNC,YMXC,ORDERC,CC,Z,FOUND)
C
C     A negative X should not be below -3.0
C     -------------------------------------
      IF (X .LT. -3.0) FOUND = 0
C
C     The maximum Z is 1.571
C     ----------------------
      Z = AMIN1(Z,1.571)
C
      RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGC00
C     =================
C
C     Data for Item 70011 Figure 1(a)
C     -------------------------------
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      COMMON /PLIC00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTC00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
      INTEGER I
C
C     Data for X between -3 and 6 and Y between 1 and 12
C     ==================================================
C
      DATA ORDERA/15/
C
      DATA XMNA,XMXA,YMNA,YMXA/-3.0,6.0,1.0,12.0/
C
C
      DATA (CA(I),I=1,40) /
     *.68680973E+00 ,-.34518993E+00,.77918266E-01 ,-.15074234E-01,
     *.21593051E-02 ,-.44322124E-03,.44585212E-03 ,-.12673037E-03,
     *-.20781894E-03,-.10015380E-04,.15926501E-03 ,.78636058E-04 ,
     *-.80986542E-04,-.10617517E-03,.30947250E-04 ,-.81210142E-01,
     *.10019149E+00 ,-.42641000E-01,.13959370E-01 ,-.31207567E-02,
     *.84946121E-03 ,-.33711426E-03,-.24712452E-03,.18108873E-04 ,
     *.22313704E-03 ,.36583925E-04 ,-.13411975E-03,-.25139044E-04,
     *.10752752E-03 ,-.62461585E-01,.77692386E-01 ,-.32785795E-01,
     *.10624121E-01 ,-.25408083E-02,.66297115E-03 ,-.33081391E-03,
     *-.89710905E-04,.15295332E-03 ,-.32691101E-04,.55946141E-05 /
C
      DATA (CA(I),I=41,80) /
     *.85803598E-05 ,-.36639434E-04,.14218543E-01 ,-.22624154E-01,
     *.12171031E-01 ,-.54619422E-02,.23511635E-02 ,-.76657804E-03,
     *.28493190E-03 ,-.31424649E-04,.82788205E-06 ,-.37498564E-05,
     *-.13739373E-04,.62747282E-05 ,.42203417E-02 ,-.63761531E-02,
     *.35860607E-02 ,-.15092992E-02,.30728571E-03 ,-.15097634E-03,
     *.74105752E-04 ,.64483252E-04 ,.18532813E-03 ,-.15478819E-03,
     *-.11023350E-03,-.76201812E-03,.84633057E-03 ,-.61617000E-04,
     *-.28729792E-03,-.53207945E-04,-.55078710E-04,.45888587E-04 ,
     *.27170472E-03 ,-.88939128E-04,-.92272727E-04,-.12817986E-02,
     *.24000911E-02 ,-.19219469E-02,.12933226E-02 ,-.90921827E-03/
C
      DATA (CA(I),I=81,120) /
     *.27683917E-03 ,.27107285E-04 ,.22896417E-04 ,.66074510E-04 ,
     *-.42623836E-04,.36383757E-04 ,-.55587724E-03,.32181389E-03 ,
     *-.10149885E-03,.43443979E-04 ,.12200008E-04 ,.33217375E-04 ,
     *.26579502E-03 ,-.91413233E-03,.67789031E-03 ,-.49139897E-03,
     *.27009596E-03 ,-.63692993E-04,.64869559E-04 ,.18424272E-03 ,
     *-.31365777E-03,.29302803E-03 ,-.17725460E-03,.11932128E-03 ,
     *-.12542264E-04,-.64678935E-04,.40522786E-03 ,-.26371079E-03,
     *.20428762E-03 ,-.74802840E-04,-.19036831E-03,.38623827E-03 ,
     *-.56106817E-04,.91821315E-04 ,.12254576E-03 ,-.29444245E-03,
     *.22607876E-03 ,.17378769E-03 ,-.35053619E-03,-.15161200E-03/
C
C     Data for X between 2 and 6 and Y between 0 and 1
C     ================================================
C
      DATA ORDERB/7/
C
      DATA XMNB,XMXB,YMNB,YMXB/2.0,6.0,0.0,1.0/
C
C
      DATA (CB(I),I=1,28) /
     *.10663134E+01 ,-.52926926E-01,-.50759682E-02,.31815104E-02 ,
     *-.90699715E-03,.30549335E-03 ,-.17030183E-03,-.32731324E+00,
     *.62164102E-01 ,.34767301E-02 ,-.50911120E-02,.17346195E-02 ,
     *-.67135536E-03,.43815647E-01 ,-.26189525E-01,-.16299590E-03,
     *.27766628E-02 ,-.12085799E-02,-.64600925E-02,.99032100E-02 ,
     *-.34434806E-03,-.12235361E-02,.65948020E-03 ,-.30676706E-02,
     *.12085929E-03 ,-.23826863E-03,-.21117870E-03,.60738641E-04 /
C
C     Data for X between -2 and 2 and Y between 0 and 1
C     =================================================
C
      DATA ORDERC/7/
C
      DATA XMNC,XMXC,YMNC,YMXC/-2.0,2.0,0.0,1.0/
C
C
      DATA (CC(I),I=1,28) /
     *.14743478E+01 ,-.12081326E+00,-.13522922E-01,.85736138E-02 ,
     *-.18366078E-02,.11699005E-03 ,-.21998922E-03,-.26956423E-15,
     *.33465807E-16 ,.92668296E-16 ,-.84889321E-17,-.15065804E-16,
     *.55485691E-16 ,-.30512836E-01,-.33389225E-01,.60142667E-02 ,
     *.44818258E-02 ,-.31922516E-02,.48183258E-16 ,-.67924508E-17,
     *-.36750342E-16,-.40257024E-17,.10075429E-02 ,.94168684E-03 ,
     *-.75487170E-03,.13405957E-16 ,.38577389E-16 ,-.28724180E-03/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG00D(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 70011  Figure 1(b)
C     lambda = 0.125
C
C     Input
C     -----
C     X     - A tan Lambda .5
C     Y     - Beta A
C
C     Output
C     ------
C     Z     - 1/A dCL/dalpha (1/rad)
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     I         - array index
C     XP        - |X|
C
C     The subroutine divides the plot into three patches:
C
C     (a) X = -3 to +6 and Y = 1.0 to 12.0
C     ORDERA    - order of polynomial
C     CA( )     - ORDERA * (ORDERA + 1) / 2 polynomial coefficients
C     XMNA,XMXA - minimum and maximum X
C     YMNA,YMXA - minimum and maximum Y
C
C     (b) X = +2.0 to +6.0 and Y = 0.0 to 1.0
C     ORDERB    - order of polynomial
C     CB( )     - ORDERB * (ORDERB + 1) / 2 polynomial coefficients
C     XMNB,XMXB - minimum and maximum X
C     YMNB,YMXB - minimum and maximum Y
C
C     (c) X = -2.0 to +2.0 and Y = 0.0 to 1.0
C     ORDERC    - order of polynomial
C     CC( )     - ORDERC * (ORDERC + 1) / 2 polynomial coefficients
C     XMNC,XMXC - minimum and maximum X
C     YMNC,YMXC - minimum and maximum Y
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND
      REAL X,Y,Z
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      REAL XP
      COMMON /PLID00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTD00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
C     The plot is symmetric about X = 0.0 so use the modulus of X.
C     ------------------------------------------------------------
      XP = ABS(X)
C
C     Calculate Z for the given X and Y (if possible).
C     Try the three patches in turn.
C     ================================================
C
C     Patch (a)
C     ---------
      CALL A9E799(XP,Y,XMNA,XMXA,YMNA,YMXA,ORDERA,CA,Z,FOUND)
C
C     Patch (b)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNB,XMXB,YMNB,YMXB,ORDERB,CB,Z,FOUND)
C
C     Patch (c)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNC,XMXC,YMNC,YMXC,ORDERC,CC,Z,FOUND)
C
C     A negative X should not be below -3.0
C     -------------------------------------
      IF (X .LT. -3.0) FOUND = 0
C
C     The maximum Z is 1.571
C     ----------------------
      Z = AMIN1(Z,1.571)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGD00
C     =================
C
C     Data for Item 70011 Figure 1(b)
C     -------------------------------
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      COMMON /PLID00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTD00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
      INTEGER I
C
C     Data for X between -3 and 6 and Y between 1 and 12
C     ==================================================
C
      DATA ORDERA/15/
C
      DATA XMNA,XMXA,YMNA,YMXA/-3.0,6.0,1.0,12.0/
C
      DATA (CA(I),I=1,40) /
     *.71241579E+00 ,-.36334789E+00,.81505739E-01 ,-.15467694E-01,
     *.16715482E-02 ,-.63348944E-03,.11467570E-02 ,-.85085125E-03,
     *.20458429E-03 ,-.12018851E-03,.20575881E-03 ,-.72601835E-04,
     *-.78098049E-05,.10588814E-04 ,-.39934850E-04,-.87134706E-01,
     *.10685078E+00 ,-.45030226E-01,.14945421E-01 ,-.45897666E-02,
     *.18275892E-02 ,-.10594608E-02,.58991116E-03 ,-.34327244E-03,
     *.92248605E-04 ,.13293106E-04 ,.17118736E-03 ,-.14265937E-03,
     *-.11739731E-03,-.66022430E-01,.81074574E-01 ,-.33459498E-01,
     *.10148231E-01 ,-.24470917E-02,.56459793E-03 ,-.31501834E-04,
     *.28964441E-04 ,-.26319263E-03,.29190849E-03 ,-.21879897E-03/
C
      DATA (CA(I),I=41,80) /
     *.15574993E-03 ,-.59731600E-04,.14204780E-01 ,-.22722737E-01,
     *.12294424E-01 ,-.45951758E-02,.12038982E-02 ,.11187349E-03 ,
     *-.74514324E-03,.47706889E-03 ,.37566652E-03 ,-.68783783E-03,
     *.32680189E-03 ,.40685446E-04 ,.49879484E-02 ,-.77928889E-02,
     *.45647743E-02 ,-.21361364E-02,.86514624E-03 ,-.37447200E-03,
     *.14177730E-03 ,-.14021055E-04,.13715960E-03 ,-.93454493E-04,
     *-.11096436E-03,-.17509676E-03,.58901270E-05 ,.95291107E-03 ,
     *-.14187593E-02,.11662820E-02 ,-.69100928E-03,.74768576E-03 ,
     *-.47846168E-03,.29635967E-04 ,.29165553E-03 ,-.14092543E-02,
     *.27164461E-02 ,-.20189200E-02,.13792751E-02 ,-.89210732E-03/
C
      DATA (CA(I),I=81,120) /
     *.50916069E-03 ,-.29482033E-03,.18473209E-03 ,-.44262551E-04,
     *-.49075322E-03,.89875547E-03 ,-.73614711E-03,.62323400E-03 ,
     *-.46632908E-03,.41511178E-03 ,-.14169695E-03,.54727838E-04 ,
     *-.62318280E-04,-.19411322E-03,.24986984E-03 ,-.24548702E-03,
     *.17846793E-03 ,-.44242174E-04,-.26246790E-04,.37111083E-03 ,
     *-.67377054E-03,.47790061E-03 ,-.31391855E-03,.19445905E-03 ,
     *-.15783683E-03,.27731711E-03 ,-.33782338E-03,.15160401E-03 ,
     *-.38912286E-04,-.86114938E-05,-.17694380E-03,.35032731E-03 ,
     *-.24669656E-03,.14634166E-03 ,-.72582268E-04,.81168545E-04 ,
     *.16444016E-04 ,.94878328E-04 ,-.20092486E-03,-.58498247E-04/
C
C
C     Data for X between 2 and 6 and Y between 0 and 1
C     ================================================
C
      DATA ORDERB/7/
C
      DATA XMNB,XMXB,YMNB,YMXB/2.0,6.0,0.0,1.0/
C
C
      DATA (CB(I),I=1,28) /
     *.10988705E+01 ,-.39044807E-01,-.55951341E-02,.84864444E-03 ,
     *-.83901374E-03,.51105061E-03 ,-.11729818E-03,-.33963538E+00,
     *.45265933E-01 ,.43524418E-02 ,-.18499353E-02,.13932228E-02 ,
     *-.79397013E-03,.39900274E-01 ,-.18434636E-01,.13412903E-02 ,
     *.13661237E-02 ,-.11557793E-02,.27656558E-02 ,.88391049E-02 ,
     *-.26137049E-02,-.11210776E-02,-.24307510E-02,-.38773099E-02,
     *.59806899E-03 ,-.59334673E-03,-.65057702E-03,.80975614E-03 /
C
C
C     Data for X between -2 and 2 and Y between 0 and 1
C     =================================================
C
      DATA ORDERC/7/
C
      DATA XMNC,XMXC,YMNC,YMXC/-2.0,2.0,0.0,1.0/
C
C
      DATA (CC(I),I=1,28) /
     *.15033103E+01 ,-.84725289E-01,-.13257813E-01,.14036410E-02 ,
     *-.14700066E-02,.10659211E-02 ,-.24913388E-03,.30215386E-15 ,
     *.20008734E-16 ,-.11189780E-15,-.68737769E-18,.46384468E-16 ,
     *.33685823E-17 ,-.26632015E-01,-.29084736E-01,.38198030E-02 ,
     *.30444733E-02 ,-.22537527E-02,-.66191076E-16,-.11513758E-16,
     *.32378379E-16 ,-.50711584E-17,-.28655347E-02,-.43975167E-03,
     *.42137358E-02 ,.92598989E-16 ,.49914513E-16 ,.36000878E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG00E(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 70011  Figure 1(c)  lambda = 0.25
C
C     Input
C     -----
C     X     - A tan Lambda .5
C     Y     - Beta A
C
C     Output
C     ------
C     Z     - 1/A dCL/dalpha (1/rad)
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     I         - array index
C     XP        - |X|
C
C     The subroutine divides the plot into three patches:
C
C     (a) X = -3 to +6 and Y = 1.0 to 12.0
C     ORDERA    - order of polynomial
C     CA( )     - ORDERA * (ORDERA + 1) / 2 polynomial coefficients
C     XMNA,XMXA - minimum and maximum X
C     YMNA,YMXA - minimum and maximum Y
C
C     (b) X = +2.0 to +6.0 and Y = 0.0 to 1.0
C     ORDERB    - order of polynomial
C     CB( )     - ORDERB * (ORDERB + 1) / 2 polynomial coefficients
C     XMNB,XMXB - minimum and maximum X
C     YMNB,YMXB - minimum and maximum Y
C
C     (c) X = -2.0 to +2.0 and Y = 0.0 to 1.0
C     ORDERC    - order of polynomial
C     CC( )     - ORDERC * (ORDERC + 1) / 2 polynomial coefficients
C     XMNC,XMXC - minimum and maximum X
C     YMNC,YMXC - minimum and maximum Y
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND
      REAL X,Y,Z
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      REAL XP
      COMMON /PLIE00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTE00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
C     The plot is symmetric about X = 0.0 so use the modulus of X.
C     ------------------------------------------------------------
      XP = ABS(X)
C
C     Calculate Z for the given X and Y (if possible).
C     Try the three patches in turn.
C     ================================================
C
C     Patch (a)
C     ---------
      CALL A9E799(XP,Y,XMNA,XMXA,YMNA,YMXA,ORDERA,CA,Z,FOUND)
C
C     Patch (b)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNB,XMXB,YMNB,YMXB,ORDERB,CB,Z,FOUND)
C
C     Patch (c)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNC,XMXC,YMNC,YMXC,ORDERC,CC,Z,FOUND)
C
C     A negative X should not be below -3.0
C     -------------------------------------
      IF (X .LT. -3.0) FOUND = 0
C
C     The maximum Z is 1.571
C     ----------------------
      Z = AMIN1(Z,1.571)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGE00
C     =================
C
C     Data for Item 70011 Figure 1(c)
C     -------------------------------
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      COMMON /PLIE00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTE00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
      INTEGER I
C
C     Data for X between -3 and 6 and Y between 1 and 12
C     ==================================================
C
      DATA ORDERA/15/
C
      DATA XMNA,XMXA,YMNA,YMXA/-3.0,6.0,1.0,12.0/
C
      DATA (CA(I),I=1,40) /
     *.71884217E+00 ,-.36620705E+00,.80163567E-01 ,-.13719586E-01,
     *.58602011E-03 ,.70882480E-03 ,-.12330843E-03,.52966598E-04 ,
     *-.89621401E-04,-.16739104E-03,.34505472E-03 ,-.12898031E-03,
     *-.83340407E-04,.27616569E-04 ,-.22402985E-04,-.89414546E-01,
     *.10910277E+00 ,-.45678445E-01,.14460192E-01 ,-.28526210E-02,
     *.65880543E-03 ,-.23206443E-03,.62851457E-04 ,-.20497865E-04,
     *.49923130E-04 ,.32415221E-04 ,-.13222619E-03,.10262217E-03 ,
     *.74073075E-05 ,-.67134552E-01,.81814319E-01 ,-.33681087E-01,
     *.10021620E-01 ,-.19734159E-02,.30147106E-03 ,-.90162186E-04,
     *.16480788E-04 ,.23675320E-04 ,.17942783E-04 ,-.70845753E-04/
C
      DATA (CA(I),I=41,80) /
     *-.18993801E-04,.81315231E-04 ,.13697729E-01 ,-.21351341E-01,
     *.10949950E-01 ,-.41722581E-02,.14064052E-02 ,-.31028228E-03,
     *-.15112798E-03,.15461966E-04 ,.79752582E-04 ,-.64454611E-04,
     *.87362872E-04 ,-.10234712E-03,.53287908E-02 ,-.80326137E-02,
     *.43556929E-02 ,-.19671195E-02,.26751036E-03 ,-.15356564E-03,
     *.16860566E-04 ,-.71311409E-04,.85441661E-04 ,.25772507E-04 ,
     *-.13302767E-03,.35755334E-03 ,-.79612527E-03,.12686994E-02 ,
     *-.11258007E-02,.46014678E-03 ,-.39267177E-03,.26985792E-03 ,
     *-.15453575E-03,.78747787E-04 ,-.33464708E-04,-.12658186E-02,
     *.25551784E-02 ,-.16187207E-02,.99591768E-03 ,-.79283665E-03/
C
      DATA (CA(I),I=81,120) /
     *.21924054E-03 ,.64893744E-04 ,-.98120089E-04,.16496168E-04 ,
     *-.26097084E-03,.51324361E-03 ,-.25837475E-03,.43814950E-03 ,
     *-.22404745E-03,.11762747E-03 ,.71466202E-04 ,-.21058507E-04,
     *-.42060821E-03,.37904209E-03 ,-.30332222E-04,-.13100155E-03,
     *.41064221E-03 ,-.23084634E-03,.11250879E-03 ,.41293058E-03 ,
     *-.75915140E-03,.40341306E-03 ,-.22403271E-03,.10249905E-03 ,
     *.20741411E-07 ,.55244136E-03 ,-.79365238E-03,.27596943E-03 ,
     *-.37440911E-04,-.22939153E-03,-.44086845E-03,.78321463E-03 ,
     *-.49850572E-03,.10291024E-03 ,-.19481297E-03,.26769631E-03 ,
     *-.25484857E-04,.31945735E-03 ,-.57495260E-03,-.38966181E-04/
C
C     Data for X between 2 and 6 and Y between 0 and 1
C     ================================================
C
      DATA ORDERB/7/
C
      DATA XMNB,XMXB,YMNB,YMXB/2.0,6.0,0.0,1.0/
C
C
      DATA (CB(I),I=1,28) /
     *.11036949E+01 ,-.42562714E-01,-.56978166E-02,.18342228E-02 ,
     *-.89402401E-03,.39215982E-03 ,-.59537994E-04,-.34227469E+00,
     *.47793489E-01 ,.54310500E-02 ,-.33749858E-02,.68707474E-03 ,
     *-.18262190E-03,.36282094E-01 ,-.19198255E-01,.74938466E-03 ,
     *.21651724E-02 ,-.10333813E-02,.56754457E-02 ,.58007960E-02 ,
     *-.18077350E-02,-.95714199E-03,-.20012571E-02,-.14964282E-02,
     *.79146951E-03 ,-.50206522E-03,-.46108752E-03,.64170784E-03 /
C
C     Data for X between -2 and 2 and Y between 0 and 1
C     =================================================
C
      DATA ORDERC/7/
C
      DATA XMNC,XMXC,YMNC,YMXC/-2.0,2.0,0.0,1.0/
C
C
      DATA (CC(I),I=1,28) /
     *.15039798E+01 ,-.85535353E-01,-.14973629E-01,.22576635E-02 ,
     *-.67581737E-03,.55376238E-03 ,-.27617122E-03,.18348297E-15 ,
     *-.12769541E-15,-.33241449E-16,-.32025621E-16,.26456376E-16 ,
     *-.15102118E-16,-.26881393E-01,-.31054121E-01,.29269258E-02 ,
     *.48217544E-02 ,-.17270054E-02,.54361356E-16 ,-.15302506E-16,
     *-.14106542E-16,-.82112835E-17,-.19261192E-02,.45767459E-03 ,
     *.44792898E-02 ,.39025313E-16 ,-.45796331E-16,.21954286E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG00F(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 70011  Figure 1(d)  lambda = 0.5
C
C     Input
C     -----
C     X     - A tan Lambda .5
C     Y     - Beta A
C
C     Output
C     ------
C     Z     - 1/A dCL/dalpha (1/rad)
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     I         - array index
C     XP        - |X|
C
C     The subroutine divides the plot into three patches:
C
C     (a) X = -3 to +6 and Y = 1.0 to 12.0
C     ORDERA    - order of polynomial
C     CA( )     - ORDERA * (ORDERA + 1) / 2 polynomial coefficients
C     XMNA,XMXA - minimum and maximum X
C     YMNA,YMXA - minimum and maximum Y
C
C     (b) X = +2.0 to +6.0 and Y = 0.0 to 1.0
C     ORDERB    - order of polynomial
C     CB( )     - ORDERB * (ORDERB + 1) / 2 polynomial coefficients
C     XMNB,XMXB - minimum and maximum X
C     YMNB,YMXB - minimum and maximum Y
C
C     (c) X = -2.0 to +2.0 and Y = 0.0 to 1.0
C     ORDERC    - order of polynomial
C     CC( )     - ORDERC * (ORDERC + 1) / 2 polynomial coefficients
C     XMNC,XMXC - minimum and maximum X
C     YMNC,YMXC - minimum and maximum Y
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND
      REAL X,Y,Z
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      REAL XP
      COMMON /PLIF00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTF00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
C     The plot is symmetric about X = 0.0 so use the modulus of X.
C     ------------------------------------------------------------
      XP = ABS(X)
C
C     Calculate Z for the given X and Y (if possible).
C     Try the three patches in turn.
C     ================================================
C
C     Patch (a)
C     ---------
      CALL A9E799(XP,Y,XMNA,XMXA,YMNA,YMXA,ORDERA,CA,Z,FOUND)
C
C     Patch (b)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNB,XMXB,YMNB,YMXB,ORDERB,CB,Z,FOUND)
C
C     Patch (c)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNC,XMXC,YMNC,YMXC,ORDERC,CC,Z,FOUND)
C
C     A negative X should not be below -3.0
C     -------------------------------------
      IF (X .LT. -3.0) FOUND = 0
C
C     The maximum Z is 1.571
C     ----------------------
      Z = AMIN1(Z,1.571)
C
      RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGF00
C     =================
C
C     Data for Item 70011 Figure 1(d)
C     -------------------------------
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      COMMON /PLIF00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTF00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
      INTEGER I
C
C     Data for X between -3 and 6 and Y between 1 and 12
C     ==================================================
C
      DATA ORDERA/15/
C
      DATA XMNA,XMXA,YMNA,YMXA/-3.0,6.0,1.0,12.0/
C
C
      DATA (CA(I),I=1,40) /
     *.71765621E+00 ,-.36413474E+00,.82787219E-01 ,-.12622933E-01,
     *.31106260E-02 ,.10604113E-02 ,.11783871E-02 ,.36792757E-03 ,
     *.52132542E-03 ,-.54840638E-04,.34451100E-03 ,-.34634087E-03,
     *-.90042347E-04,-.70131501E-04,-.71992031E-04,-.88805456E-01,
     *.11577823E+00 ,-.42684965E-01,.18257423E-01 ,-.98163947E-03,
     *.31843882E-02 ,.16496201E-02 ,.10155589E-02 ,.91415922E-03 ,
     *-.10254083E-03,.16239157E-03 ,-.23446294E-03,-.76080893E-04,
     *-.21135551E-03,-.67846491E-01,.89818061E-01 ,-.31747653E-01,
     *.13957373E-01 ,.31489932E-03 ,.22036810E-02 ,.17001771E-02 ,
     *.66400446E-03 ,.81831038E-03 ,.41598816E-04 ,.12757634E-03 /
C
      DATA (CA(I),I=41,80) /
     *-.31632543E-03,-.98714227E-04,.17636050E-01 ,-.21087917E-01,
     *.15295332E-01 ,-.19814866E-02,.33425513E-02 ,.18497959E-02 ,
     *.10380058E-02 ,.86521557E-03 ,.53778186E-03 ,-.24114861E-03,
     *.74744948E-04 ,-.95452530E-04,.61732257E-02 ,-.45678944E-02,
     *.62627472E-02 ,.66705703E-03 ,.22873482E-02 ,.11579521E-02 ,
     *.85071902E-03 ,.37359558E-03 ,.41846421E-03 ,-.75444896E-04,
     *.96293253E-04 ,.28222191E-03 ,.28451015E-02 ,.19720933E-02 ,
     *.85229216E-03 ,.21470174E-02 ,.14077217E-03 ,.10546003E-02 ,
     *-.18653481E-03,.31478983E-03 ,-.10445974E-03,-.85701876E-03,
     *.40397513E-02 ,-.98169511E-03,.23998757E-02 ,.22460652E-04 /
C
      DATA (CA(I),I=81,120) /
     *.89462937E-03 ,.83882474E-04 ,.74060329E-04 ,.92432325E-04 ,
     *.20888576E-03 ,.10516410E-02 ,.22551722E-03 ,.95740007E-03 ,
     *.29924917E-04 ,.40950072E-03 ,.74502690E-04 ,-.72468552E-04,
     *.51380749E-03 ,-.45588009E-03,.67317021E-03 ,-.34508730E-03,
     *.49916198E-03 ,-.20070495E-03,.21679758E-03 ,.27747832E-03 ,
     *-.46984564E-03,.43511883E-03 ,-.25385882E-03,.22687530E-04 ,
     *-.81713445E-04,-.13191487E-03,.21042840E-04 ,-.64118637E-04,
     *.76706166E-04 ,-.35053356E-03,-.28275317E-03,.16279467E-03 ,
     *-.49321956E-03,-.64060512E-04,.28589003E-04 ,-.36029562E-03,
     *-.37417538E-04,.10217895E-03 ,-.33422796E-03,-.15525484E-03/
C
C     Data for X between 2 and 6 and Y between 0 and 1
C     ================================================
C
      DATA ORDERB/7/
C
      DATA XMNB,XMXB,YMNB,YMXB/2.0,6.0,0.0,1.0/
C
C
      DATA (CB(I),I=1,28) /
     *.11005382E+01 ,-.41417130E-01,-.71069895E-02,.17612848E-02 ,
     *.31400388E-03 ,-.48803557E-03,.35812483E-04 ,-.34703188E+00,
     *.45832539E-01 ,.81020932E-02 ,-.27694136E-02,-.23922464E-03,
     *.65969762E-03 ,.38701219E-01 ,-.17627612E-01,-.22277829E-02,
     *.15069440E-02 ,.28652706E-03 ,.15295835E-02 ,.41979715E-02 ,
     *-.10249871E-03,-.46343700E-03,-.16840099E-02,-.37603700E-03,
     *.40527998E-03 ,-.32127981E-03,-.56095105E-03,.52112810E-03 /
C
C     Data for X between -2 and 2 and Y between 0 and 1
C     =================================================
C
      DATA ORDERC/7/
C
      DATA XMNC,XMXC,YMNC,YMXC/-2.0,2.0,0.0,1.0/
C
C
      DATA (CC(I),I=1,28) /
     *.15114216E+01 ,-.77275947E-01,-.16788597E-01,.13603608E-02 ,
     *.15058611E-03 ,-.38494258E-03,.13824905E-03 ,-.15170096E-16,
     *-.77431287E-16,.49772110E-16 ,.28596119E-16 ,-.13000114E-17,
     *-.17661640E-16,-.25873427E-01,-.30892510E-01,-.21096018E-02,
     *.43953237E-02 ,.76813081E-03 ,.25508061E-16 ,-.53517876E-16,
     *.22791545E-16 ,-.16110883E-16,-.22805824E-02,-.99546604E-03,
     *.22808208E-02 ,-.17575672E-16,.63629252E-16 ,.43952931E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG00G(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 70011  Figure 1(e)  lambda = 1.0
C
C     Input
C     -----
C     X     - A tan Lambda .5
C     Y     - Beta A
C
C     Output
C     ------
C     Z     - 1/A dCL/dalpha (1/rad)
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     I         - array index
C     XP        - |X|
C
C     The subroutine divides the plot into three patches:
C
C     (a) X = -3 to +6 and Y = 1.0 to 12.0
C     ORDERA    - order of polynomial
C     CA( )     - ORDERA * (ORDERA + 1) / 2 polynomial coefficients
C     XMNA,XMXA - minimum and maximum X
C     YMNA,YMXA - minimum and maximum Y
C
C     (b) X = +2.0 to +6.0 and Y = 0.0 to 1.0
C     ORDERB    - order of polynomial
C     CB( )     - ORDERB * (ORDERB + 1) / 2 polynomial coefficients
C     XMNB,XMXB - minimum and maximum X
C     YMNB,YMXB - minimum and maximum Y
C
C     (c) X = -2.0 to +2.0 and Y = 0.0 to 1.0
C     ORDERC    - order of polynomial
C     CC( )     - ORDERC * (ORDERC + 1) / 2 polynomial coefficients
C     XMNC,XMXC - minimum and maximum X
C     YMNC,YMXC - minimum and maximum Y
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND
      REAL X,Y,Z
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      REAL XP
      COMMON /PLIG00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTG00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
C     The plot is symmetric about X = 0.0 so use the modulus of X.
C     ------------------------------------------------------------
      XP = ABS(X)
C
C     Calculate Z for the given X and Y (if possible).
C     Try the three patches in turn.
C     ================================================
C
C     Patch (a)
C     ---------
      CALL A9E799(XP,Y,XMNA,XMXA,YMNA,YMXA,ORDERA,CA,Z,FOUND)
C
C     Patch (b)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNB,XMXB,YMNB,YMXB,ORDERB,CB,Z,FOUND)
C
C     Patch (c)
C     ---------
      IF (FOUND .NE. 1)
     *CALL A9E799(XP,Y,XMNC,XMXC,YMNC,YMXC,ORDERC,CC,Z,FOUND)
C
C     A negative X should not be below -3.0
C     -------------------------------------
      IF (X .LT. -3.0) FOUND = 0
C
C     The maximum Z is 1.571
C     ----------------------
      Z = AMIN1(Z,1.571)
C
      RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGG00
C     =================
C
C     Data for Item 70011 Figure 1(e)
C     -------------------------------
C
      INTEGER ORDERA,ORDERB,ORDERC
      REAL XMNA,XMXA,YMNA,YMXA,CA
      REAL XMNB,XMXB,YMNB,YMXB,CB
      REAL XMNC,XMXC,YMNC,YMXC,CC
      COMMON /PLIG00/ ORDERA,ORDERB,ORDERC
      COMMON /PLTG00/ XMNA,XMXA,YMNA,YMXA,CA(120),
     *                XMNB,XMXB,YMNB,YMXB,CB(28),
     *                XMNC,XMXC,YMNC,YMXC,CC(28)
C
      INTEGER I
C
C     Data for X between -3 and 6 and Y between 1 and 12
C     ==================================================
C
      DATA ORDERA/15/
C
      DATA XMNA,XMXA,YMNA,YMXA/-3.0,6.0,1.0,12.0/
C
C
      DATA (CA(I),I=1,40) /
     *.69785200E+00 ,-.35958241E+00,.82102117E-01 ,-.15802334E-01,
     *.16110266E-02 ,.17217174E-03 ,.86672895E-04 ,-.33953358E-03,
     *-.17624916E-03,-.16905013E-04,.31571538E-03 ,-.14019837E-04,
     *-.68932845E-04,-.29623361E-04,-.32365184E-05,-.91833771E-01,
     *.11381751E+00 ,-.49304265E-01,.16843430E-01 ,-.49988878E-02,
     *.17827734E-02 ,-.30932643E-03,.41449109E-03 ,-.15094053E-03,
     *-.57566157E-04,.43173637E-04 ,-.10374626E-03,.24221833E-04 ,
     *-.63746782E-04,-.69941057E-01,.87620792E-01 ,-.37598372E-01,
     *.12271165E-01 ,-.32768586E-02,.81674798E-03 ,-.10977456E-03,
     *.14713779E-03 ,-.24960537E-03,.10247731E-03 ,-.85794729E-04/
C
      DATA (CA(I),I=41,80) /
     *.15925630E-04 ,.17220118E-03 ,.16695778E-01 ,-.26485643E-01,
     *.14290480E-01 ,-.58042782E-02,.20281961E-02 ,-.46125480E-03,
     *-.33224339E-03,.17658442E-03 ,.23845821E-03 ,-.58410784E-04,
     *-.17319313E-05,-.54540789E-04,.56463525E-02 ,-.85425593E-02,
     *.47786505E-02 ,-.22902487E-02,.98027880E-03 ,-.33107868E-03,
     *.34361824E-04 ,.13101270E-03 ,-.11640447E-03,.89777215E-04 ,
     *-.14446470E-03,-.47764515E-03,.12903423E-02 ,-.14462972E-03,
     *-.60262173E-03,.79201983E-03 ,-.91433100E-03,.68800223E-04 ,
     *-.21653550E-03,-.41952460E-04,.10969732E-03 ,-.15585229E-02,
     *.22977587E-02 ,-.18529228E-02,.10801701E-02 ,-.60549061E-03/
C
      DATA (CA(I),I=81,120) /
     *.47031015E-03 ,.89932093E-04 ,.31565158E-03 ,-.15662334E-03,
     *-.26783696E-03,.31253879E-03 ,-.47304842E-03,.56106859E-03 ,
     *-.51691437E-03,.19320861E-03 ,-.13408460E-03,.11130753E-03 ,
     *-.16767680E-03,.15797926E-03 ,-.67131697E-05,-.14359216E-03,
     *.34832660E-03 ,-.35383588E-03,.26671359E-04 ,.39393055E-03 ,
     *-.53919164E-03,.41377083E-03 ,-.22690220E-03,.78434968E-04 ,
     *-.34092160E-04,.40300185E-03 ,-.53202195E-03,.32130921E-03 ,
     *-.40575883E-04,-.20685094E-03,-.35810038E-03,.45680168E-03 ,
     *-.28910111E-03,-.48178983E-05,-.10247149E-03,.11725968E-03 ,
     *-.18702339E-04,.27865340E-03 ,-.38884363E-03,-.10527779E-03/
C
C     Data for X between 2 and 6 and Y between 0 and 1
C     ================================================
C
      DATA ORDERB/7/
C
      DATA XMNB,XMXB,YMNB,YMXB/2.0,6.0,0.0,1.0/
C
C
      DATA (CB(I),I=1,28) /
     *.10648287E+01 ,-.38276031E-01,-.61466396E-02,.29017380E-02 ,
     *.44361355E-03 ,-.54037320E-03,-.67987641E-04,-.36005190E+00,
     *.50965810E-01 ,.72837496E-02 ,-.49417524E-02,-.55813938E-03,
     *.81130122E-03 ,.48269620E-01 ,-.24052645E-01,-.19664501E-02,
     *.34621221E-02 ,.55914209E-04 ,-.88376935E-03,.10836575E-01 ,
     *-.12016294E-03,-.22773412E-02,-.27227815E-02,-.22454943E-02,
     *.24078015E-03 ,-.30088293E-03,-.95320582E-03,.90032294E-03 /
C
C     Data for X between -2 and 2 and Y between 0 and 1
C     =================================================
C
      DATA ORDERC/7/
C
      DATA XMNC,XMXC,YMNC,YMXC/-2.0,2.0,0.0,1.0/
C
C
      DATA (CC(I),I=1,28) /
     *.15057625E+01 ,-.86374811E-01,-.17983893E-01,.45487533E-02 ,
     *.97867411E-03 ,-.79575243E-03,-.12697434E-03,-.31796512E-15,
     *.19261066E-15 ,-.56926588E-16,.63365195E-16 ,.29990687E-17 ,
     *-.63561346E-16,-.31719652E-01,-.38457544E-01,-.25407889E-03,
     *.78671768E-02 ,.57830485E-03 ,.11741472E-16 ,-.26717411E-16,
     *.21871102E-16 ,-.24131371E-16,-.22793687E-02,-.49054397E-03,
     *.37279747E-02 ,-.14245153E-16,-.18535625E-16,.45098697E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG01A(W,X,Y,Z,FAULT)
C     ================================
C
C     Purpose
C     -------
C     Figures 1 to 5 of Item 83040
C
C     Input
C     -----
C     W     - Beta A
C     X     - kappa
C     Y     - A tan(Lambda1/2)
C
C     Output
C     ------
C     Z     - eta bar (EB)
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL W,X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *'Beta A',
     *'kappa',
     *'A tan(Lambda1/2)',
     *'eta bar',
     *'Figures 1 to 5 of Item 83040' /
C
      DATA FLAGS /
     * 1, 1, 1,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 1.5,    12.0, 0.0,
     * 0.3333, 0.5,  0.0,
     * 0.0,    6.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,1) = W
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figures 1 to 5 of Item 83040
C     ---------------------------------
      CALL FIG01B(W,X,Y,Z,FOUND)
C
C     Store the data if FIG01B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3001
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG01B(W,X,Y,Z,FOUND)
C     ===============================
C
C     Purpose
C     -------
C     Figures 1 to 5
C     Item 83040
C
C     Input
C     -----
C     W     - Beta A
C     X     - kappa
C     Y     - A tan(Lambda1/2)
C
C     Output
C     ------
C     Z     - eta bar (EB)
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C     XX      - usually just X but ensures that if X is just below
C               0.333333 it is not treated as out of range
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER,I,NW
      REAL W,X,Y,Z
      REAL XX,ZZ(5)
C
      REAL WW,XMN,XMX,YMN,YMX,C
      COMMON /PLTB01/ WW(5),XMN,XMX,YMN,YMX,C(78,5)
C
      DATA NW,ORDER/5, 12/
C
C     Calculate Z for the given X and Y and each WW
C     ---------------------------------------------
      XX = X
      IF (X .GE. 0.333) XX = AMAX1(X,0.3333333)
      DO 10 I = 1,5
      CALL A9E799(XX,Y,XMN,XMX,YMN,YMX,ORDER,C(1,I),ZZ(I),FOUND)
      IF (FOUND .NE. 1) GO TO 20
   10 CONTINUE
C
C     Use a spline fit to interpolate Z for the given W
C     -------------------------------------------------
      CALL A9G799(NW,WW,ZZ,W,Z,FOUND)
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB01
C     =================
C
C     Data for Item 83040 Figures 1 to 5
C     ----------------------------------
C
      REAL WW,XMN,XMX,YMN,YMX,C
      COMMON /PLTB01/ WW(5),XMN,XMX,YMN,YMX,C(78,5)
C
      INTEGER I
C
      DATA WW / 1.5, 3.0, 5.0, 8.0, 12.0 /
C
      DATA XMN,XMX,YMN,YMX/0.333333,0.5,0.0,6.0/
C
      DATA (C(I,1),I=1,40) /
     *.43544112E+00 ,.15853311E-01 ,-.11080262E-02,-.14261079E-02,
     *-.51008650E-04,.25195965E-04 ,.14088044E-04 ,.48296331E-04 ,
     *-.33261533E-05,-.35935188E-04,-.23844372E-06,.17668421E-04 ,
     *.18264952E-01 ,.13866546E-01 ,.20910898E-02 ,-.13437002E-02,
     *.12498161E-03 ,.16391592E-04 ,-.34104268E-04,.48914909E-04 ,
     *.77691968E-05 ,-.34607271E-04,.82445616E-06 ,-.33605975E-02,
     *-.16098932E-02,.16047652E-04 ,.25313197E-03 ,.15032788E-03 ,
     *-.26318190E-06,-.40134423E-04,-.10512199E-04,.85308082E-05 ,
     *.67884512E-05 ,.13542208E-02 ,.67406733E-03 ,-.68777936E-04,
     *-.12416348E-03,-.47925370E-04,.20476369E-05 ,.12826899E-04 /
C
      DATA (C(I,1),I=41,78) /
     *.42701041E-05 ,-.27488966E-05,-.39173329E-03,-.34705311E-03,
     *.57029913E-04 ,.82352030E-04 ,-.20246799E-04,-.30683311E-05,
     *.55280913E-05 ,-.20416417E-05,.15028437E-03 ,.18488217E-03 ,
     *-.10348917E-04,-.43718358E-04,.39129630E-04 ,.89281674E-06 ,
     *-.10928871E-04,-.10106806E-03,-.11273580E-03,.10487190E-04 ,
     *.24540730E-04 ,-.20498739E-04,-.11002393E-05,.95705355E-04 ,
     *.39335854E-04 ,-.16884966E-04,-.26913401E-04,.61172032E-06 ,
     *-.44986666E-04,-.30970427E-04,.28390443E-04 ,.24980715E-04 ,
     *.10443366E-04 ,.71871676E-05 ,-.29892122E-04,-.64422987E-05,
     *.68365364E-05 ,.12764248E-04/
C
      DATA (C(I,2),I=1,40) /
     *.43335968E+00 ,.14260419E-01 ,-.15578704E-02,-.27427202E-03,
     *-.65676151E-04,.28087767E-05 ,.18210988E-04 ,.10229355E-04 ,
     *-.43486614E-05,-.71126972E-05,-.26529931E-06,.32300062E-05 ,
     *.24285579E-01 ,.10058923E-01 ,.14274817E-02 ,-.65424013E-03,
     *-.20329628E-04,.13635037E-04 ,.56066308E-05 ,.21189229E-04 ,
     *-.13181195E-05,-.16268531E-04,-.99783853E-07,-.38708656E-02,
     *-.97287939E-03,.63915154E-04 ,.15741453E-03 ,.37683365E-04 ,
     *-.60733789E-05,-.96936105E-05,-.38042798E-05,.18012993E-05 ,
     *.36322620E-05 ,.12677718E-02 ,.13586535E-03 ,-.10764921E-03,
     *-.10378012E-04,.46464851E-04 ,.13689693E-05 ,-.12256216E-04/
C
      DATA (C(I,2),I=41,78) /
     *-.19719617E-06,.24999881E-05 ,-.10980261E-03,.18821840E-03 ,
     *.55446126E-04 ,-.10615836E-03,-.11495513E-06,.44750060E-05 ,
     *-.29825125E-06,.23906094E-05 ,-.72900025E-04,-.15079521E-03,
     *.23374287E-04 ,.76941128E-04 ,-.19951289E-04,-.44941865E-05,
     *.52931850E-05 ,-.17900544E-05,.45953554E-04 ,.16904260E-04 ,
     *-.27924408E-04,.66029095E-05 ,.24556743E-05 ,.67924897E-04 ,
     *-.12704606E-04,.50290670E-05 ,.58491703E-05 ,.92426834E-06 ,
     *-.50897844E-04,-.23104779E-04,-.63604013E-05,.72431419E-05 ,
     *.18518146E-04 ,.59760820E-05 ,-.74102404E-05,.12223770E-04 ,
     *.21039188E-04 ,-.14480142E-04/
C
      DATA (C(I,3),I=1,40) /
     *.43025328E+00 ,.12873271E-01 ,-.12863173E-02,-.10500042E-03,
     *-.23259141E-04,.72626497E-06 ,.62267828E-05 ,.40774236E-05 ,
     *-.13355936E-05,-.27576087E-05,-.22302998E-06,.12078544E-05 ,
     *.31182755E-01 ,.61448720E-02 ,.76466792E-03 ,-.17116048E-03,
     *-.27590437E-04,.89048642E-07 ,.75619852E-05 ,.71533961E-05 ,
     *-.17456505E-05,-.46050616E-05,-.16271704E-06,-.40401696E-02,
     *-.42351333E-03,.77332341E-04 ,.67995865E-04 ,-.12822503E-04,
     *-.36700894E-05,.34093267E-05 ,-.11590354E-05,-.71477804E-06,
     *.14643038E-05 ,.11323172E-02 ,.76027295E-04 ,.54872360E-04 ,
     *-.34506224E-04,-.25584163E-05,-.20884370E-06,.42638585E-06 /
C
      DATA (C(I,3),I=41,78) /
     *.15471010E-05 ,.90560259E-07 ,.18683020E-03 ,.96731288E-04 ,
     *-.57747338E-04,.86677369E-05 ,-.42505493E-05,-.58836439E-06,
     *.15724004E-05 ,-.91947364E-07,-.20023811E-03,.56503590E-04 ,
     *.54663458E-04 ,-.23001924E-04,-.48221981E-05,.24906786E-05 ,
     *.81037533E-06 ,-.24509544E-04,.97500479E-05 ,.23974332E-04 ,
     *-.25272981E-04,-.31901231E-05,.32441617E-05 ,.75181162E-04 ,
     *.11461705E-04 ,-.63935238E-04,.98408867E-05 ,.15418496E-05 ,
     *-.11745627E-04,-.13944954E-04,.28696991E-05 ,-.35340122E-05,
     *-.29803362E-04,-.17069759E-04,.25394535E-04 ,.73661355E-05 ,
     *-.72098672E-05,.15711122E-04/
C
      DATA (C(I,4),I=1,40) /
     *.42691159E+00 ,.10691110E-01 ,-.86030610E-03,-.27300408E-04,
     *-.13449177E-04,-.28542769E-06,.37184302E-05 ,.12797180E-05 ,
     *-.88058143E-06,-.76464210E-06,-.60601531E-07,.27562449E-06 ,
     *.38261711E-01 ,.33352608E-02 ,.37317157E-03 ,-.12210828E-03,
     *-.40526996E-05,.21137167E-05 ,.15909003E-05 ,.41541429E-05 ,
     *-.69742926E-06,-.30793349E-05,.25448113E-06 ,-.37771182E-02,
     *-.18687483E-03,.80999186E-04 ,.57363507E-04 ,.67960947E-05 ,
     *-.30028495E-05,-.18324537E-05,-.10210355E-05,.40223261E-06 ,
     *.12447332E-05 ,.15018776E-02 ,.49843799E-04 ,.86334398E-05 ,
     *.58523905E-04 ,-.92620614E-06,-.26791256E-05,.32109104E-06 /
C
      DATA (C(I,4),I=41,78) /
     *-.12196647E-05,-.12035918E-06,-.38305804E-03,-.21139414E-04,
     *-.25270982E-04,-.81973019E-04,-.58790009E-05,.36246419E-05 ,
     *.17484031E-05 ,.17675973E-05 ,.13540884E-03 ,.10817561E-04 ,
     *.43736676E-04 ,-.16255722E-04,-.72438789E-05,.16736194E-05 ,
     *.14045269E-05 ,-.63013755E-04,.20808609E-04 ,-.50233634E-05,
     *.34893820E-04 ,.54595768E-05 ,-.15392497E-05,.17004365E-04 ,
     *-.31023767E-04,-.37505723E-06,.10472548E-04 ,.44351879E-05 ,
     *-.12618268E-04,-.88210583E-05,.16446286E-04 ,-.27371381E-04,
     *-.75089830E-05,.15153612E-04 ,-.16295102E-04,.13107186E-04 ,
     *-.31466327E-05,.20273640E-04/
C
      DATA (C(I,5),I=1,40) /
     *.42373026E+00 ,.90364788E-02 ,.27557371E-04 ,.74262229E-04 ,
     *.17053869E-04 ,-.13324494E-05,-.47349298E-05,-.25046442E-05,
     *.11348525E-05 ,.18679914E-05 ,.65321149E-07 ,-.92052974E-06,
     *.45270093E-01 ,.49423978E-03 ,.64317453E-03 ,.24883235E-03 ,
     *.55641273E-04 ,-.75554025E-05,-.16332760E-04,-.69615459E-05,
     *.45148222E-05 ,.59487577E-05 ,-.29954226E-06,-.41627312E-02,
     *-.16060941E-02,.50217359E-03 ,.67660989E-04 ,.25200340E-04 ,
     *-.20215187E-05,-.78891927E-05,-.19081563E-05,.24966760E-05 ,
     *.16208308E-05 ,.20024320E-02 ,.59757021E-03 ,-.18292751E-03,
     *-.10003305E-04,-.33461824E-05,.48306693E-06 ,.13478177E-05 /
C
      DATA (C(I,5),I=41,78) /
     *.19685700E-06 ,-.60731588E-06,-.10629581E-02,-.21943690E-03,
     *.27141955E-04 ,.37758209E-04 ,-.13073573E-05,-.33130167E-05,
     *-.40202602E-06,-.53332692E-07,.55495941E-03 ,.28198642E-03 ,
     *.79993613E-06 ,-.61354280E-04,-.18003198E-04,.68204182E-05 ,
     *.58291512E-05 ,-.39335996E-03,-.50602102E-04,-.77088742E-04,
     *-.15904579E-04,.11057874E-05 ,-.12511428E-05,.21925672E-03 ,
     *.82506719E-04 ,-.19820279E-04,.66834827E-05 ,.89065230E-05 ,
     *-.11307715E-03,-.61887952E-04,.84353078E-05 ,-.98148032E-05,
     *.71292861E-04 ,.13711481E-04 ,.36546492E-04 ,-.77277434E-04,
     *-.36959603E-04,.73870941E-04/
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE FIG02A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 89034  Figure 2
C
C     Input
C     -----
C     X     - lambda
C     Y     - eta bar
C
C     Output
C     ------
C     Z     - mu p
C     FAULT - fault number (0 means"none", 999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'lambda',
     *'eta bar',
     *' mu p',
     *'Figure 2 of Item 83040' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 1, 1 /
C
      DATA WXYZ /
     * 0.0,  0.0,  0.0,
     * 0.0,  1.0,  0.0,
     * 0.36, 0.48, 0.0,
     * 0.0,  1.8,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 2 of Item 89034
C     ---------------------------
      CALL FIG02B(X,Y,Z,FOUND)
C
C     Store the data if FIG02B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3002
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG02B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 89034  Figure 2
C
C     Input
C     -----
C     X     - lambda
C     Y     - eta bar
C
C     Output
C     ------
C     Z     - mu p
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER,J
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB02/ XMN(2),XMX(2),YMN,YMX,C(120,2)
C
      DATA ORDER/15/
C
C     Calculate 1/Z for the given X and Y
C     -----------------------------------
C     Try the left hand side first.
      DO 10 J = 1,2
      CALL A9E799(X,Y,XMN(J),XMX(J),YMN,YMX,ORDER,C(1,J),Z,FOUND)
      IF (FOUND .EQ. 1) GO TO 20
   10 CONTINUE
C
C     A9E799 gave the reciprocal of Z
C     ------------------------------
   20 IF (FOUND .EQ. 1) Z = 1.0 / Z
C
C     Treat Z as out of range if it exceeds 1.8
C     -----------------------------------------
      IF (Z .GT. 1.8) FOUND = 0
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB02
C     =================
C
C     Data for Item 89034 Figure 2
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB02/ XMN(2),XMX(2),YMN,YMX,C(120,2)
C
      INTEGER I
C
      DATA XMN(1),XMX(1),XMN(2),XMX(2),YMN,YMX /
     * 0.0,   0.15,
     * 0.15,  1.0,
     * 0.36,  0.48 /
C
      DATA (C(I,1),I=1,40) /
     *.62584000E+00 ,-.21322478E+00,.37713692E-01 ,.89965784E-02 ,
     *-.40027859E-03,-.61448097E-02,.68676844E-02 ,-.61161991E-02,
     *.51783859E-02 ,-.38372010E-02,.26188995E-02 ,-.17685449E-02,
     *.11354191E-02 ,-.59873289E-03,.13334564E-03 ,.11900405E+00 ,
     *-.42389366E-01,-.50245650E-01,.39897944E-01 ,-.15094433E-01,
     *.76965860E-02 ,-.92784986E-02,.10571210E-01 ,-.87965808E-02,
     *.61989466E-02 ,-.39684557E-02,.24637707E-02 ,-.18550898E-02,
     *.13488214E-02 ,-.24591771E-01,.44383260E-01 ,-.11540504E-01,
     *-.17042478E-01,.18695522E-01 ,-.11115671E-01,.73813972E-02 ,
     *-.58768149E-02,.44671762E-02 ,-.33065165E-02,.27669314E-02 /
C
      DATA (C(I,1),I=41,80) /
     *-.22512162E-02,.13228536E-02 ,.53871607E-02 ,-.12272785E-01,
     *.69174658E-02 ,.17619293E-02 ,-.79468635E-02,.80916577E-02 ,
     *-.31467472E-02,.57884470E-03 ,-.94400090E-03,.11547074E-02 ,
     *-.81660166E-03,.45447697E-03 ,-.57286662E-03,.14332730E-04 ,
     *.62631922E-04 ,-.28113281E-03,.87433773E-03 ,-.10344444E-02,
     *.38299087E-04 ,.71681323E-03 ,-.54116729E-03,.17053497E-03 ,
     *-.88223474E-04,-.53367261E-03,.13308572E-02 ,-.95375643E-03,
     *.13233064E-03 ,.84951883E-03 ,-.12379429E-02,.42450978E-03 ,
     *.83981256E-04 ,.53868043E-04 ,-.28089203E-03,.21943837E-03 ,
     *-.12861717E-04,.94127684E-05 ,.12062287E-03 ,-.38645961E-03/
C
      DATA (C(I,1),I=81,120) /
     *.39675466E-03 ,.51945754E-04 ,-.35204708E-03,.20253197E-03 ,
     *.81932858E-04 ,-.26707849E-03,.30574468E-03 ,-.18173567E-03,
     *-.18110265E-03,.42981043E-03 ,-.11369431E-03,-.11533483E-03,
     *-.99748899E-04,.41815740E-05 ,-.21507017E-04,-.57458483E-04,
     *.20876790E-03 ,-.19063268E-03,-.66723755E-04,.63404693E-05 ,
     *.38040642E-04 ,-.13271193E-03,.13150290E-03 ,.45028291E-04 ,
     *-.19169437E-03,.44814074E-04 ,.60297242E-05 ,.17120530E-04 ,
     *.22665364E-04 ,-.11680575E-03,-.23678241E-04,.20344825E-04 ,
     *.65761265E-04 ,-.83953415E-04,-.16113843E-04,-.15353270E-04,
     *-.76878600E-05,.23442504E-04 ,-.32211483E-04,.88320768E-06 /
C
      DATA (C(I,2),I=1,40) /
     *.79771154E+00 ,-.28698202E-02,-.35889899E-01,-.13324089E-02,
     *-.17108047E-02,-.37242372E-03,.31294649E-03 ,-.87322878E-04,
     *-.29733791E-03,.53948596E-04 ,.21170997E-03 ,.81847325E-04 ,
     *-.22030385E-04,-.10755594E-03,-.83898845E-04,.12230328E-01 ,
     *.18433105E+00 ,.14682073E-01 ,-.23473536E-01,-.65980651E-02,
     *.72834337E-03 ,.28613306E-03 ,-.40940197E-03,-.49656186E-04,
     *.78840362E-04 ,.19820323E-03 ,.21179091E-03 ,-.55478006E-04,
     *-.13838625E-03,-.42539779E-01,-.33068141E-01,.20490939E-01 ,
     *.92163815E-02 ,-.50498025E-02,-.31545935E-02,-.37330247E-03,
     *.45591613E-03 ,.55108439E-03 ,.30987410E-03 ,-.20655161E-03/
C
      DATA (C(I,2),I=41,80) /
     *-.27317242E-03,.96896170E-04 ,.11530356E-01 ,.28660753E-02 ,
     *-.84662003E-02,-.37121516E-03,.29538084E-02 ,-.33090799E-03,
     *-.16147823E-02,-.19498115E-03,.71514396E-03 ,.19970724E-03 ,
     *-.15231122E-03,-.56684581E-04,-.40718847E-02,-.16149191E-02,
     *.24323923E-02 ,-.68713250E-03,-.87932320E-03,.11819524E-02 ,
     *.43381281E-03 ,-.59587217E-03,-.30897820E-03,.30278876E-03 ,
     *.18586911E-03 ,.17549608E-02 ,.14799236E-03 ,-.17947389E-02,
     *-.44956506E-03,.37654087E-03 ,-.17226025E-03,.22430909E-03 ,
     *.43497001E-03 ,-.71480510E-04,-.41367731E-03,-.63664642E-03,
     *.57180841E-03 ,.84032500E-03 ,.79585070E-03 ,.46868531E-03 /
C
      DATA (C(I,2),I=81,120) /
     *-.40673240E-04,.11808574E-03 ,.43031864E-04 ,-.10122851E-03,
     *-.27152986E-03,-.84699322E-03,-.18554735E-03,-.29107885E-03,
     *-.28409582E-03,.49432920E-03 ,-.30232923E-03,-.28846450E-03,
     *.62946002E-04 ,-.86160645E-04,-.24580914E-03,.25130052E-03 ,
     *.34926247E-03 ,-.80328721E-04,.10081534E-04 ,-.40652320E-04,
     *.16968690E-03 ,.50010290E-04 ,-.23213043E-03,-.17413848E-03,
     *-.14645683E-03,.18945970E-03 ,-.95520197E-04,-.16304689E-03,
     *-.11553603E-03,.66998913E-04 ,-.13855656E-03,-.98659666E-04,
     *.54384525E-04 ,.17127720E-03 ,-.35857477E-04,.15467434E-03 ,
     *.35077309E-04 ,.14987312E-03 ,.15945290E-03 ,-.93492414E-04/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG03A(W,X,Y,Z,FAULT)
C     ================================
C
C     Purpose
C     -------
C     Interpolation of Figures 1.a to 1.d of Item 87031
C
C     Input
C     -----
C     W     - lambda
C     X     - A
C     Y     - A tan(Lambda1/4)
C
C     Output
C     ------
C     Z     - [(alpha or)2 / delta et]
C     FAULT - fault number (0 means "none", 999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL W,X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *'lambda',
     *'A',
     *'A tan (Lambda1/4)',
     *'[(alpha or)2 / delta et]',
     *'Figure 1 of Item 87031' /
C
      DATA FLAGS /
     * 1, 1, 1,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0, 1.0,  0.0,
     * 2.0, 10.0, 0.0,
     * 0.0, 6.0,  0.0,
     * 0.0, 0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,1) = W
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 1 of Item 87031
C     ---------------------------
      CALL FIG03B(W,X,Y,Z,FOUND)
C
C     Store the data if FIG03B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3003
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG03B(W,X,Y,Z,FOUND)
C     ================================
C
C     Purpose
C     -------
C     Interpolation of Figures 1.a to 1.d of Item 87031
C
C     Input
C     -----
C     W     - lambda
C     X     - A
C     Y     - A tan(Lambda1/4)
C
C     Output
C     ------
C     Z     - [(alpha or)2 / delta et]
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C(36,4) - coefficients of the four plots
C     WW(4)   - constant lambdas for each of the four plots
C     ZZ(4)   - Z from each of the four plots
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,ORDER
      INTEGER I
      REAL X,Y,Z,W
      REAL ZZ(4)
C
      REAL XMN,XMX,YMN,YMX,C,WW
      COMMON /PLTB03/ XMN,XMX,YMN,YMX,C(36,4),WW(4)
C
      DATA ORDER/8/
C
C     Calculate ZZ(I) for WW(I) and the given X and Y
C     -----------------------------------------------
      DO 10 I = 1,4
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C(1,I),ZZ(I),FOUND)
      IF (FOUND .NE. 1) GO TO 20
   10 CONTINUE
C
C     Interpolate Z for the given W, X and Y
C     --------------------------------------
      I = 4
      CALL A9G799(I,WW,ZZ,W,Z,FOUND)
C
   20 RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGB03
C     =================
C
C     Data for Item 87031 Figure 1
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C,WW
      COMMON /PLTB03/ XMN,XMX,YMN,YMX,C(36,4),WW(4)
C
      INTEGER I
C
      DATA WW / 0.0, 0.25, 0.5, 1.0 /
C
      DATA XMN,XMX,YMN,YMX/2.0,10.0,0.0,6.0/
C
C     Figure 1.a - lambda = 0.0
C     -------------------------
      DATA (C(I,1),I=1,36) /
     *-.35304068E+00,.17429249E-01 ,-.46173894E-03,.65479211E-04 ,
     *.80515124E-05 ,.41424809E-05 ,-.16478666E-05,-.46700916E-05,
     *.10923843E-01 ,-.96007352E-02,-.12351693E-02,-.71180048E-04,
     *-.23301709E-04,-.11151953E-06,.61487457E-05 ,-.23686385E-02,
     *.18774766E-02 ,.36783109E-03 ,.11932622E-03 ,.94238907E-05 ,
     *.10966147E-06 ,.37197914E-03 ,-.34420300E-03,-.29016531E-04,
     *.68683667E-05 ,-.61535104E-05,.58315766E-04 ,-.27951275E-04,
     *-.69402470E-04,.41768173E-04 ,-.23897644E-04,.15336959E-04 ,
     *.16043244E-04 ,-.22134172E-04,.23563409E-04 ,.91188040E-05 /
C
C     Figure 1.b - lambda = 0.25
C     --------------------------
      DATA (C(I,2),I=1,36) /
     *-.38015475E+00,.16344568E-01 ,-.84350261E-03,.11373284E-03 ,
     *-.76221065E-04,.39958465E-05 ,.22462637E-04 ,-.66300666E-05,
     *-.36960939E-02,-.95941295E-02,-.11468171E-02,.71266028E-03 ,
     *-.10564655E-03,-.27759784E-04,.27923502E-04 ,.11934761E-02 ,
     *.35682637E-02 ,.25461877E-03 ,-.20387611E-03,.85671577E-04 ,
     *.12124993E-04 ,.22394785E-03 ,-.14365899E-03,-.48840606E-04,
     *-.20761892E-03,-.14072034E-04,-.32586043E-03,-.27305891E-03,
     *.75454068E-04 ,.17298134E-03 ,.11029797E-04 ,-.22176054E-04,
     *.80350916E-05 ,.90840820E-04 ,.11989869E-03 ,-.11793178E-04/
C
C     Figure 1.c - lambda = 0.5
C     -------------------------
      DATA (C(I,3),I=1,36) /
     *-.39744782E+00,.14268309E-01 ,-.88671782E-04,.19595019E-04 ,
     *-.71422356E-05,.37411110E-05 ,.12671799E-04 ,-.25556465E-05,
     *-.11682660E-01,-.92751316E-02,-.12679024E-02,-.16923683E-04,
     *-.26326645E-04,-.91578704E-05,-.90753484E-05,.38950989E-02 ,
     *.47984493E-02 ,.98660523E-03 ,-.15348709E-03,.31153418E-04 ,
     *.10802219E-04 ,-.42539175E-03,-.13846006E-02,-.83844058E-03,
     *-.41088346E-04,.85302330E-05 ,.17038501E-04 ,.28102312E-03 ,
     *.45025540E-03 ,.77949187E-04 ,-.43314379E-04,-.52401904E-04,
     *-.18083214E-04,.43411673E-04 ,-.18307781E-04,.98732134E-05 /
C
C     Figure 1.d - lambda = 1.0
C     -------------------------
      DATA (C(I,4),I=1,36) /
     *-.41705898E+00,.75486969E-02 ,-.41806640E-03,.98346524E-04 ,
     *-.21709069E-04,-.15194129E-07,.14127563E-04 ,-.41268725E-05,
     *-.17189768E-01,-.45547273E-02,-.12791536E-03,.14697094E-03 ,
     *-.65222806E-04,-.42422016E-05,.25320890E-05 ,.44311247E-02 ,
     *.35040580E-02 ,.37980148E-03 ,.37502711E-04 ,-.96218811E-05,
     *.10229983E-06 ,-.16051641E-02,-.17457060E-02,-.64398753E-03,
     *.10342671E-05 ,.67515454E-05 ,.68603319E-03 ,.63289266E-03 ,
     *.38344262E-03 ,.84230420E-05 ,-.16095992E-03,-.16009090E-03,
     *-.91788628E-04,-.47385533E-04,-.55477887E-04,.74895637E-04 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG04A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 84026  Figure 1 (Zu125/c)sec Lambda < 0.017
C
C     Input
C     -----
C     X     - (Zu125/c) sec Lambda
C     Y     - R (cos Lambda)**2
C
C     Output
C     ------
C     Z     - Delta CL
C     FAULT - fault number (0 means "none", 999 means "out of range")
C
C     --------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER *44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'(Zu125/c) sec(Lambda)',
     *'R (cos Lambda)**2',
     *'Delta Cl',
     *'Figure 1 of Item 84026' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,      0.0,       0.0,
     * 0.007,    0.017,     0.0,
     * 700000.0, 9000000.0, 0.0,
     * 0.0,      0.0,       0.0 /
C
      FAULT = 0
      WXYZ(3,1) = 0.0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 1 of Item 84026
C     ---------------------------
      CALL FIG04B(X,Y,Z,FOUND)
C
C     Store the data if FIG04B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3004
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG04B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 84026  Figure 1 (Zu125/c)sec Lambda < 0.017
C
C     Input
C     -----
C     X     - (Zu125/c) sec Lambda
C     Y     - R (cos Lambda)**2
C
C     Output
C     ------
C     Z     - Delta CL
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C     XX      - dummy X (XX = 0.007 if X <= 0.007)
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z,XX
C
      REAL C
      REAL XMN,XMX,YMN,YMX
      COMMON /PLTB04/ XMN,XMX,YMN,YMX,C(120)
C
      DATA ORDER/15/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      XX = AMAX1(X,0.007)
      CALL A9E799(XX,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
C     Z is never less than 0.8
      Z = AMAX1(Z,0.8)
C
      RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGB04
C     =================
C
C     Data for Item 84026 Figure 1
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX
      REAL C
      COMMON /PLTB04/ XMN,XMX,YMN,YMX,C(120)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/0.007,0.017,700000.0,9000000.0/
C
      DATA (C(I),I=1,40) /
     *.10410396E+01 ,.11458019E+00 ,-.52095470E-01,.23722610E-01 ,
     *-.54698455E-02,-.21913528E-02,.33315612E-02 ,-.15887669E-02,
     *-.56173031E-03,.14656616E-02 ,-.88765676E-03,-.11992519E-03,
     *.56246932E-03 ,-.34322187E-03,-.81680461E-04,.26705224E+00 ,
     *.98256807E-01 ,-.67822098E-01,.28918594E-01 ,-.54648521E-02,
     *-.41739467E-02,.50117436E-02 ,-.20669248E-02,-.10593875E-02,
     *.22009990E-02 ,-.12797158E-02,-.17159644E-03,.80685242E-03 ,
     *-.49453300E-03,-.54081894E-03,-.29967744E-01,-.39290881E-02,
     *.18024472E-02 ,.14945401E-02 ,-.19630487E-02,.99924345E-03 ,
     *.46039501E-04 ,-.58086777E-03,.55856597E-03 ,-.19949677E-03/
C
      DATA (C(I),I=41,80) /
     *-.14099966E-03,.21034569E-03 ,-.28968191E-01,-.10865033E-01,
     *.14961249E-01 ,-.68465029E-02,.12405158E-02 ,.14269667E-02 ,
     *-.19736070E-02,.12421627E-02 ,-.12823371E-03,-.55431297E-03,
     *.56221067E-03 ,-.21753289E-03,-.11283646E-02,.30313504E-02 ,
     *.13351400E-02 ,-.27172454E-02,.51978559E-03 ,.72035112E-03 ,
     *-.10026332E-02,.65679248E-03 ,-.13086989E-03,-.20709911E-03,
     *.23381461E-03 ,.19007564E-02 ,-.57394361E-03,-.22962528E-02,
     *.14522447E-02 ,.63109516E-03 ,-.85918909E-03,.52226337E-03 ,
     *-.14529464E-03,-.20498426E-03,.39217502E-03 ,.41446686E-03 ,
     *-.92710025E-03,-.34379936E-03,.38098428E-03 ,-.47277852E-03/
C
      DATA (C(I),I=81,120) /
     *.35442918E-04 ,.24607988E-03 ,-.20377928E-03,.28910051E-04 ,
     *-.32762479E-03,.28062108E-04 ,.33964611E-03 ,-.41969870E-03,
     *-.27443952E-03,.38936310E-03 ,-.14254041E-03,-.12209278E-03,
     *-.28053378E-04,.25668720E-03 ,.31469013E-03 ,-.42408252E-04,
     *.77031741E-04 ,.13283131E-03 ,-.18758575E-03,.60091537E-04 ,
     *.41882311E-04 ,-.49629514E-04,.21853378E-04 ,.12678723E-03 ,
     *-.16988119E-03,-.62744169E-04,-.10196307E-03,-.10133971E-03,
     *-.52700899E-04,.57270243E-04 ,-.23264497E-04,.29947403E-04 ,
     *.40693276E-04 ,.28281403E-04 ,.55770395E-05 ,.15018573E-04 ,
     *-.82968352E-04,.32612252E-04 ,-.10719399E-04,.64942469E-05 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG05A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 84026 Figure 2
C
C     Input
C     -----
C     X     - R cos(Lambda)**2
C     Y     - [tan(tau u)]sec(Lambda 2)
C
C     Output
C     ------
C     Z     - Delta CL
C     FAULT - fault (0 means "none", 999 means "out of range")
C
C     --------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     * ' ',
     * 'R cos(Lambda)**2',
     * 'tan(tau u) sec(Lambda 2)',
     * ' Delta CL',
     * ' Figure 2 of Item 84026' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,      0.0,       0.0,
     * 700000.0, 9000000.0, 0.0,
     * 0.08,     0.22,      0.0,
     * 0.0,      0.0,       0.0 /
C
      FAULT = 0
      WXYZ(3,1) = 0.0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 2 of Item 84026
C     ---------------------------
      CALL FIG05B(X,Y,Z,FOUND)
C
C     Store the data if FIG05B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3005
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG05B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 84026 Figure 2
C
C     Input
C     -----
C     X     - R cos(Lambda)**2
C     Y     - [tan(tau u)]sec(Lambda 2)
C
C     Output
C     ------
C     Z     - Delta CL
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     I       - array index
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N,I
      REAL X,Y,Z,ZZ(2)
C
      REAL XMN,XMX,C,YY
      COMMON /PLTB05/ XMN,XMX,C(16,2),YY(2)
C
      DATA N /16/
C
C     Interploate Z for each of the curves of constant Y
C     --------------------------------------------------
      DO 10 I = 1,2
      CALL A9F799(X,XMN,XMX,N,C(1,I),ZZ(I),FOUND)
      IF (FOUND .NE. 1) GO TO 20
   10 CONTINUE
C
C     Use linear interpolation to find Z for the given X and Y
C     --------------------------------------------------------
      IF (Y .LT. YY(1) .OR. Y .GT. YY(2)) THEN
       FOUND = 0
      ELSE
       FOUND = 1
       Z = (ZZ(1) * (YY(2) - Y) + ZZ(2) * (Y - YY(1))) / (YY(2) - YY(1))
      END IF
C
   20 CONTINUE
C
      RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGB05
C     =================
C
C     Data for Item 84026 Figure 5
C     ----------------------------
C
      REAL XMN,XMX,C,YY
      COMMON /PLTB05/ XMN,XMX,C(16,2),YY(2)
C
      DATA XMN,XMX /700000.0,9000000.0/
C
      DATA YY / 0.08, 0.22 /
C
      DATA C /
     *.15218296E+01 ,.18968227E+00 ,-.76534487E-01 ,.27379301E-01 ,
     *-.72820080E-02 ,.63036975E-03 ,.77908010E-03 ,-.56447533E-03 ,
     *-.34790913E-03 ,.76266138E-03 ,-.19922143E-03 ,-.46790628E-03 ,
     *.50460067E-03 ,-.11450688E-03 ,-.24129111E-03 ,.33789254E-03 ,
     *.96600105E+00 ,.22986854E+00 ,-.74359522E-01 ,.10519249E-01 ,
     *-.47828655E-02 ,.30455615E-02 ,-.20440502E-02 ,.12538742E-02 ,
     *-.10259689E-02 ,.96828065E-03 ,-.69578721E-03 ,.38605049E-03 ,
     *-.21978468E-03 ,.11794264E-03 ,-.30618117E-04 ,-.14818654E-04 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG06A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 84026 Figure 5
C     Factor on CLM for modern aerofoils
C
C     Input
C     -----
C     X     - R cos(Lambda)**2
C
C     Output
C     ------
C     Z     - Fs
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'R cos(Lambda)**2',
     *' ',
     *'Fs',
     *'Figure 5 of Item 84026' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,      0.0,       0.0,
     * 700000.0, 9000000.0, 0.0,
     * 0.0,      0.0,       0.0,
     * 0.0,      0.0,       0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 5 of Item 84026
C     ---------------------------
      CALL FIG06B(X,Z,FOUND)
C
C     Store the data if FIG06 failed
C     ------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3006
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG06B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 84026 Figure 5
C     Factor on CLM for modern aerofoils
C
C     Input
C     -----
C     X     - R cos(Lambda)**2
C
C     Output
C     ------
C     Z     - Fs
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB06 / XMN,XMX,C(16)
C
      DATA N /16/
C
C     Calculate Z for the given X (if possible).
C     ------------------------------------------
      CALL A9F799(X,XMN,XMX,N,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB06
C     =================
C
C     Data for Item 84026 Figure 5
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB06 / XMN,XMX,C(16)
C
      DATA XMN,XMX /700000.0,9000000.0/
C
      DATA C /
     *.11102891E+01 ,.37838642E-01 ,-.85872893E-02 ,.70025951E-03 ,
     *-.27842661E-03 ,-.49176704E-05 ,.11779773E-03 ,-.41462011E-04 ,
     *-.43414949E-04 ,.70519209E-05 ,.61813864E-06 ,.24987655E-05 ,
     *-.66008607E-05 ,-.76019642E-05 ,.15371188E-04 ,.79916148E-05 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG07A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 84026 Figure 7
C     Parameter in Equation (7.1)
C
C
C     Input
C     -----
C     X     - [(Zu/C)5 - (Zu/C)2]
C
C     Output
C     ------
C     Z     - F2
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'(Zu/c)5 - (Zu/c)2',
     *' ',
     *'F2',
     *'Figure 7 of Item 84026' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.006,  0.03, 0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 7 of Item 84026
C     ---------------------------
      CALL FIG07B(X,Z,FOUND)
C
C     Store the data if FIG06B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3007
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG07B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 84026 Figure 7
C     Parameter in Equation (7.1)
C
C
C     Input
C     -----
C     X     - [(Zu/C)5 - (Zu/C)2]
C
C     Output
C     ------
C     Z     - F2
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N,I
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB07/ XMN(2),XMX(2),C(16,2)
C
      DATA N /16/
C
C     Calculate Z for the given X
C     ---------------------------
C     The plot is in two parts.  Try each in turn.
      DO 10 I = 1,2
      CALL A9F799(X,XMN(I),XMX(I),N,C(1,I),Z,FOUND)
      IF (FOUND .EQ. 1) GO TO 20
   10 CONTINUE
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB07
C     =================
C
C     Data for Item 84026 Figure 7
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB07/ XMN(2),XMX(2),C(16,2)
C
C     The first plot is for 0.006 <= X <= 0.017
      DATA XMN(1),XMX(1) /0.006,0.017/
C
C     The second plot is for 0.017 <= X <= 0.030
      DATA XMN(2),XMX(2) /0.017,0.03/
C
      DATA C /
     *.12906826E+01 ,.13281137E+01 ,-.24856630E+00 ,-.23617755E+00 ,
     *.83989569E-01 ,.55103889E-02 ,-.23419288E-01 ,.10288876E-01 ,
     *.99897736E-03 ,-.12178231E-02 ,.47525480E-03 ,-.20458780E-02 ,
     *.23859945E-02 ,-.66817138E-03 ,-.20130470E-02 ,.21693483E-02 ,
     *.89820916E+00 ,-.10417451E+01 ,.38621493E+00 ,.22808172E-02 ,
     *-.82006667E-01 ,.45577574E-01 ,-.44251825E-02 ,-.98869515E-02 ,
     *.98290838E-02 ,-.44175595E-02 ,-.20728951E-02 ,.43153662E-02 ,
     *-.13815478E-02 ,-.16000018E-02 ,.60218204E-03 ,.16090307E-02 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG08A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 84026 Figure 6
C     Parameter in Equation (7.1)
C
C     Input
C     -----
C     X     - M
C
C     Output
C     ------
C     Z     - F1
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'M',
     *' ',
     *'F1',
     *'Figure  6 of Item 84026' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,    0.4,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 6 of Item 84026
C     ---------------------------
      CALL FIG08B(X,Z,FOUND)
C
C     Store the data if FIG08B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3008
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG08B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 84026 Figure 6
C     Parameter in Equation (7.1)
C
C     Input
C     -----
C     X     - M
C
C     Output
C     ------
C     Z     - F1
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB08/ XMN,XMX,C(16)
C
      DATA N /16/
      IF (X .GE. 0.0 .AND. X .LE. 0.1) THEN
C      If M <= 0.1 then F1 = 0.0
C      -------------------------
       FOUND = 1
       Z = 0.0
      ELSE
C      Calculate Z for the given X (if possible).
C      ------------------------------------------
       CALL A9F799(X,XMN,XMX,N,C,Z,FOUND)
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB08
C     =================
C
C     Data for Item 84026 Figure 6
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB08/ XMN,XMX,C(16)
C
      DATA XMN,XMX /0.1,0.4/
C
      DATA C /
     *.68891308E-01 ,.76627605E-01 ,.15736075E-02 ,-.67327156E-02 ,
     *.86232302E-04 ,.56438685E-03 ,.12245061E-04 ,-.85565289E-05 ,
     *-.14725138E-03 ,.12720739E-03 ,.13599642E-03 ,-.65893725E-04 ,
     *-.72382801E-04 ,-.69606548E-04 ,.23696765E-04 ,.84641367E-04 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG09A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 89034 Figure 3
C     Increment in Delta CLM due to Mach number
C
C
C     Input
C     -----
C     X     - (Zu/C)3 sec(Lambda 0)
C     Y     - M cos(Lambda 0)
C
C     Output
C     ------
C     Z     - Delta CLM / cos(Lambda 0)**4
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'(Zu/C)3 sec(Lambda0)',
     *'M cos(Lambda0)',
     *'Delta CLM / cos(Lambda0)**4',
     *'Figure 3 of Item 89034' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 1, 1, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,   0.0,
     * 0.011,  0.045, 0.0,
     * 0.0,    0.7,   0.0,
     * -1.0,   0.0,   0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 3 of Item 89034
C     ---------------------------
      CALL FIG09B(X,Y,Z,FOUND)
C
C     Store the data if FIG09B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3009
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG09B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 89034 Figure 3
C     Increment in Delta CLM due to Mach number
C
C
C     Input
C     -----
C     X     - (Zu/C)3 sec(Lambda 0)
C     Y     - M cos(Lambda 0)
C
C     Output
C     ------
C     Z     - Delta CLM / cos(Lambda 0)**4
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER         - order of polynomial
C     C(120,2)      - two sets of coefficients:
C                     1 for X = 0.011 to 0.0325
C                     2 for X = 0.0325 to 0.045
C     XMN(2),XMX(2) - minimum and maximum X
C     YMN,YMX       - minimum and maximum Y
C     I             - array index
C     YY            - dummy Y (When Y <= 0.16, Z = 0.0)
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER,I
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      REAL YY
      COMMON /PLTB09/ XMN(2),XMX(2),YMN,YMX,C(120,2)
C
      DATA ORDER/15/
C
C     The plot has been stored in two rectangular patches.
C     Try each in turn.
C     ----------------------------------------------------
      YY = AMAX1(Y,0.16)
      DO 10 I = 1,2
      CALL A9E799(X,YY,XMN(I),XMX(I),YMN,YMX,ORDER,C(1,I),Z,FOUND)
      IF (FOUND .EQ. 1) GO TO 20
   10 CONTINUE
C
C     Z should not exceed zero and if Y <= 0.16, Z is zero
C     ----------------------------------------------------
   20 Z = AMIN1(Z,0.0)
      IF (Y .LE. 0.16) Z = 0.0
C
C     Cut the plot off at Z = -1.0
C     ----------------------------
      IF (Z .LT. -1.0) FOUND = 0
C
C     M cos(Lambda0) must not be less than 0.0
C     ----------------------------------------
      IF (Y .LT. 0.0) FOUND = 0
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB09
C     =================
C
C     Data for Item 89034 Figure 3
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB09/ XMN(2),XMX(2),YMN,YMX,C(120,2)
C
      INTEGER I
C
      DATA XMN(1),XMX(1) / 0.0110, 0.0325 /
      DATA XMN(2),XMX(2) / 0.0325, 0.0450 /
      DATA YMN,YMX       / 0.16,   0.70 /
C
      DATA (C(I,1),I=1,40) /
     *-.33380708E+00,-.30883232E+00,.44330960E-02 ,-.10320660E-01,
     *.51544755E-02 ,-.12207213E-02,.98775030E-03 ,-.90670139E-03,
     *.66452676E-03 ,-.63387164E-03,.42312824E-03 ,-.20923783E-03,
     *.16588963E-03 ,-.10679890E-03,.19263473E-05 ,-.22844311E+00,
     *-.23383341E+00,-.18820217E-01,-.66317265E-02,.38556925E-02 ,
     *-.15932918E-02,.11699786E-02 ,-.33455377E-03,-.32567269E-03,
     *.13429229E-03 ,.12846304E-03 ,-.13387622E-03,.11781409E-03 ,
     *-.64193385E-04,.31010539E-01 ,.23012551E-02 ,-.25316619E-01,
     *-.46944510E-04,-.17032052E-02,-.97415096E-06,-.42351284E-03,
     *.73409975E-03 ,-.61424602E-03,.31066770E-03 ,.99778425E-04 /
C
      DATA (C(I,1),I=41,80) /
     *-.18251583E-03,.11223407E-03 ,-.52861560E-01,-.49601183E-01,
     *.87595411E-03 ,-.37518144E-02,-.82735163E-03,.80331053E-03 ,
     *.14475341E-03 ,-.23385687E-03,-.21661846E-03,.20801970E-03 ,
     *.11405265E-03 ,-.17389662E-03,.14077537E-01 ,.13551953E-01 ,
     *.45479722E-03 ,.12337160E-03 ,.18671595E-03 ,.10506705E-02 ,
     *.37497804E-03 ,-.63679654E-03,-.97456551E-05,.17836534E-03 ,
     *-.28447700E-03,-.28412190E-02,-.28474620E-02,.57217994E-03 ,
     *.65393361E-03 ,.49638754E-03 ,.37242204E-03 ,-.64226078E-04,
     *-.15073572E-03,.55971147E-04 ,-.98881674E-04,.38521423E-02 ,
     *.57935257E-02 ,.25235803E-02 ,.11011406E-02 ,-.20026322E-03/
C
      DATA (C(I,1),I=81,120) /
     *-.63912760E-03,.31712891E-03 ,.10021457E-03 ,-.20771734E-03,
     *-.86087466E-03,-.93374293E-03,-.32989647E-03,.30495017E-03 ,
     *.38875062E-04 ,-.19655832E-03,-.70651125E-04,.21221952E-04 ,
     *-.46852769E-03,-.61919547E-03,-.17326097E-03,-.62132299E-03,
     *.15626407E-03 ,.35622046E-03 ,-.77510152E-04,-.46179819E-03,
     *-.11260108E-02,-.10406935E-02,-.30018523E-03,-.14638777E-03,
     *.10398306E-04 ,.73820815E-04 ,.44622270E-04 ,-.83679116E-04,
     *.12228064E-04 ,-.17188325E-03,.96501212E-04 ,.51828595E-03 ,
     *.68435538E-03 ,.61548360E-04 ,.34334978E-03 ,.35010067E-03 ,
     *.69141860E-04 ,.52357994E-04 ,.38450350E-04 ,-.36720785E-03/
C
      DATA (C(I,2),I=1,40) /
     *-.11076459E+01,-.11449087E+01,-.43357751E-01,.18273268E-01 ,
     *.18139646E-01 ,.41095377E-02 ,.74176406E-02 ,-.45925213E-02,
     *-.12037804E-02,-.66640184E-03,-.15818725E-03,.11423428E-02 ,
     *-.29168650E-03,.61626410E-04 ,.20857939E-03 ,-.64840112E+00,
     *-.68326999E+00,-.53136229E-02,.51048925E-01 ,.18148569E-01 ,
     *.65369360E-02 ,.68292365E-02 ,-.37904349E-02,.28933639E-03 ,
     *-.21670687E-02,-.13769630E-02,.20061376E-02 ,-.31871088E-03,
     *.36096371E-03 ,-.95117442E-01,-.87046038E-01,.19260381E-01 ,
     *.15727333E-01 ,.47269195E-02 ,.33778134E-02 ,.26739887E-02 ,
     *-.16457450E-02,.49462774E-03 ,-.72916616E-03,-.13824632E-02/
C
      DATA (C(I,2),I=41,80) /
     *.14025648E-02 ,-.13549969E-03,.23610820E-01 ,.34486494E-01 ,
     *.12271268E-01 ,-.61062514E-02,-.53914970E-02,.40403294E-02 ,
     *.26003355E-02 ,-.16369427E-02,-.11486007E-02,.10918232E-02 ,
     *-.34486489E-03,-.15856368E-04,.50772961E-02 ,.17903264E-02 ,
     *-.10072808E-01,-.88561734E-02,.68242429E-03 ,.55742015E-02 ,
     *.18722943E-02 ,-.25374437E-02,-.19848489E-02,.13096534E-02 ,
     *.10405814E-02 ,-.41271574E-02,-.83270131E-02,-.49650916E-02,
     *.83265816E-03 ,.55147211E-02 ,.43864315E-02 ,.62469888E-04 ,
     *-.22582997E-02,-.15055815E-02,.10137148E-02 ,.27428717E-03 ,
     *.13343002E-02 ,.18470825E-02 ,.90741997E-03 ,-.67829958E-03/
C
      DATA (C(I,2),I=81,120) /
     *-.13868184E-02,-.36650300E-03,.55357893E-03 ,.45531544E-03 ,
     *.21578908E-02 ,.42070464E-02 ,.24301909E-02 ,-.26762009E-03,
     *-.27853300E-02,-.26969449E-02,-.60050430E-03,.89269263E-03 ,
     *-.11090215E-02,-.18697928E-02,-.63525499E-03,.61051211E-03 ,
     *.89146086E-03 ,.37373122E-03 ,-.30127523E-03,-.78363704E-03,
     *-.15667897E-02,-.10033157E-02,.24110678E-04 ,.99980782E-03 ,
     *.10696610E-02 ,.90779651E-03 ,.15448231E-02 ,.60019237E-03 ,
     *-.54396945E-03,-.83500217E-03,-.20065465E-03,-.87403926E-04,
     *.28688354E-03 ,.16972696E-03 ,-.52352128E-03,-.93060601E-03,
     *-.48889597E-03,.54336933E-03 ,.65120507E-03 ,.21137838E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG10A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 89034 Figure 4
C     Increment in Delta CLR due to Reynolds number
C
C
C     Input
C     -----
C     X     - R'k cos(Lambda 0)**2
C     Y     - Lambda 0 (degrees)
C
C     Output
C     ------
C     Z     - Delta CLR
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'Rk cos(Lambda0)**2',
     *'Lambda0',
     *'Delta CLR',
     *'Figure 4 of Item 89034' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 0, 1,
     * 0, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,      0.0,       0.0,
     * 300000.0, 5200000.0, 0.0,
     * 37.0,     50.0,      0.0,
     * 0.0,      0.0,       0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 4 of Item 89034
C     ---------------------------
      CALL FIG10B(X,Y,Z,FOUND)
C
C     Store the data if FIG10B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3010
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG10B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 89034 Figure 4
C     Increment in Delta CLR due to Reynolds number
C
C
C     Input
C     -----
C     X     - R'k cos(Lambda 0)**2
C     Y     - Lambda 0 (degrees)
C
C     Output
C     ------
C     Z     - Delta CLR
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C     XX,YY   - dummy X and Y
C               If X >= 5.2 treat X as 5.2
C               If Y <= 37  treat Y as 37
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z,XX,YY
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB10/ XMN,XMX,YMN,YMX,C(120)
C
      DATA ORDER/15/
C
      XX = AMIN1(X,5.2E6)
      YY = AMAX1(Y,37.0)
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(XX,YY,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
      IF (X .GE. 5.2E6 .OR. Y .LE. 37.0) Z = 0.0
C
      RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGB10
C     =================
C
C     Data for Item 89034 Figure 4
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB10/ XMN,XMX,YMN,YMX,C(120)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/300000.0,5200000.0,37.0,50.0/
C
      DATA (C(I),I=1,40) /
     *.61850389E-01 ,.56177618E-01 ,-.36152170E-02,.22773757E-02 ,
     *-.69219607E-03,-.22476575E-03,.50796618E-03 ,-.37250324E-03,
     *.79094095E-04 ,.16015227E-03 ,-.17044638E-03,.26957274E-04 ,
     *.54251637E-04 ,-.36968434E-04,.71854371E-05 ,-.78164075E-01,
     *-.70082338E-01,.47441423E-02 ,-.31930223E-02,.13138047E-02 ,
     *.33825594E-03 ,-.68479432E-03,.37799762E-03 ,-.43303283E-04,
     *-.15589612E-03,.14809446E-03 ,-.57129959E-04,-.12515834E-04,
     *.59327785E-04 ,.19858608E-01 ,.17162267E-01 ,-.11276603E-02,
     *.10006208E-02 ,-.52416909E-03,-.88416606E-06,.61890029E-04 ,
     *.11143456E-03 ,-.84547468E-04,-.72080018E-04,.81392080E-04 /
C
      DATA (C(I),I=41,80) /
     *.37475967E-04 ,-.67115416E-04,-.49396521E-02,-.43983699E-02,
     *-.90610978E-04,.76453746E-04 ,.37395590E-04 ,-.24730802E-03,
     *.28030656E-03 ,-.26702223E-03,.71429067E-04 ,.11039086E-03 ,
     *-.12021387E-03,.27289449E-04 ,.14095263E-02 ,.14322512E-02 ,
     *.54525379E-03 ,.15465557E-03 ,-.12121117E-03,.95264673E-04 ,
     *-.76631607E-04,.12996897E-03 ,-.48796075E-04,-.51256727E-04,
     *.66012560E-04 ,-.26897533E-03,-.65605972E-03,-.49531415E-03,
     *-.29181414E-03,-.69536176E-04,.92798495E-05 ,-.97208998E-04,
     *-.44455716E-05,.14687066E-04 ,.41437293E-04 ,.25533540E-03 ,
     *.37135080E-03 ,.10507641E-03 ,.11813143E-04 ,.98042090E-04 /
C
      DATA (C(I),I=81,120) /
     *.12500113E-03 ,.43355576E-04 ,.53873671E-05 ,-.16199035E-04,
     *.92748712E-04 ,.65164711E-04 ,-.19206074E-03,-.13814224E-03,
     *-.39979977E-04,-.14073030E-03,-.10659714E-03,.29825757E-04 ,
     *.58515988E-05 ,.51458902E-04 ,.13968090E-03 ,.85285828E-04 ,
     *.16735642E-04 ,.46853927E-04 ,.67854120E-04 ,-.11632502E-03,
     *-.17648186E-03,.45893745E-05 ,.20173497E-04 ,-.79795863E-04,
     *-.17429983E-04,-.29668919E-04,.39242893E-04 ,-.14383306E-04,
     *.22686454E-05 ,.80186598E-04 ,.30470401E-04 ,-.15505517E-04,
     *-.39570693E-04,-.11868181E-05,.49360490E-04 ,.36733076E-04 ,
     *.52440330E-04 ,-.56852111E-04,.20912016E-05 ,.17613479E-04 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG11A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 89034 Figure 5
C     Increment in Delta CL Delta for swept wings
C
C
C     Input
C     -----
C     X     - Delta 0 (degrees)
C     Y     - (Zu/C)3 sec(Lambda 0)
C
C     Output
C     ------
C     Z     - (Delta CL)Delta
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'Lambda0',
     *'(Zu/c)3 sec(Lambda0)',
     *'Delta CL Lambda',
     *'Figure 5 of Item 89034' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,   50.0,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 5 of Item 89034
C     ---------------------------
      CALL FIG11B(X,Y,Z,FOUND)
C
C     Store the data if FIG11B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3011
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG11B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 89034 Figure 5
C     Increment in Delta CL Delta for swept wings
C
C
C     Input
C     -----
C     X     - Delta 0 (degrees)
C     Y     - (Zu/C)3 sec(Lambda 0)
C
C     Output
C     ------
C     Z     - (Delta CL)Delta
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER         - order of polynomial
C     C(120,2)      - polynomial coefficients for two patches
C                     (below and above Y = 0.18)
C     XMN,XMX       - minimum and maximum X
C     YMN(2),YMX(2) - minimum and maximum Ys for the two patches
C     I             - array index
C     YY            - = 0.005 if Y <= 0.005
C                     = 0.024 if Y >= 0.024
c                     = Y otherwise
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER,I
      REAL X,Y,Z,YY
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB11/ XMN,XMX,YMN(2),YMX(2),C(120,2)
C
      DATA ORDER/15/
C
C     Calculate Z for the given X and Y
C     ---------------------------------
      YY = AMAX1(Y,0.005)
      YY = AMIN1(YY, 0.024)
      DO 10 I = 1,2
      CALL A9E799(X,YY,XMN,XMX,YMN(I),YMX(I),ORDER,C(1,I),Z,FOUND)
      IF (FOUND .EQ. 1) GO TO 20
   10 CONTINUE
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB11
C     =================
C
C     Data for Item 89034 Figure 5
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB11/ XMN,XMX,YMN(2),YMX(2),C(120,2)
C
      INTEGER I
C
      DATA XMN,XMX / 0.0, 50.0 /
      DATA YMN(1),YMX(1) / 0.005, 0.018 /
      DATA YMN(2),YMX(2) / 0.018, 0.024 /
C
      DATA (C(I,1),I=1,40) /
     *.14328367E-01 ,-.10946777E+00,-.18107977E-01,.37622236E-02 ,
     *.79170019E-02 ,.28212576E-02 ,.50450781E-03 ,.61125960E-03 ,
     *.15106756E-02 ,.45792646E-03 ,-.56383931E-03,-.33086919E-03,
     *.16135139E-03 ,.13836405E-03 ,-.17211324E-03,.13667121E-01 ,
     *-.13138131E+00,-.27873425E-01,-.66891574E-03,.43798002E-02 ,
     *-.14709510E-02,-.35947089E-02,-.77530411E-03,.94553694E-03 ,
     *.93796485E-04 ,-.74176138E-03,-.29919924E-03,.41879677E-03 ,
     *.40706174E-03 ,-.42881835E-03,-.20273241E-01,-.87449305E-02,
     *-.37508678E-02,-.33494859E-02,-.40308487E-02,-.36552455E-02,
     *-.72980420E-03,-.11030529E-03,-.21961659E-03,-.20110283E-03/
C
      DATA (C(I,1),I=41,80) /
     *-.26881394E-04,.18647802E-03 ,.84192738E-03 ,.37293861E-02 ,
     *.23473559E-02 ,.18590376E-02 ,.14171383E-02 ,.12057641E-02 ,
     *.11065076E-02 ,.85697916E-03 ,.73961001E-03 ,.30927341E-03 ,
     *-.12442758E-03,-.21966386E-03,.53783076E-03 ,.17425222E-02 ,
     *.15180453E-02 ,.13805995E-02 ,.92564387E-03 ,.95396253E-03 ,
     *.73530359E-03 ,.56771944E-04 ,.72340742E-04 ,.15312335E-03 ,
     *-.92191703E-05,-.78091705E-04,-.54482239E-03,-.22934046E-03,
     *-.12723370E-03,-.39680687E-03,-.20470132E-03,-.14559543E-03,
     *-.78606780E-04,-.18733840E-03,-.60919868E-05,-.43234095E-04,
     *-.22859610E-03,-.30682174E-03,-.45879452E-03,-.12380593E-03/
C
      DATA (C(I,1),I=81,120) /
     *-.20880222E-03,-.17928542E-03,.39958760E-05 ,-.65037481E-06,
     *-.55695610E-04,.28354393E-04 ,.15250857E-03 ,-.64427017E-04,
     *.14314819E-04 ,.86604229E-04 ,.66365493E-04 ,-.89962183E-04,
     *-.28426209E-04,.97471818E-04 ,-.69513333E-04,.59842900E-04 ,
     *.92249922E-04 ,.61774182E-04 ,.30289440E-04 ,-.29856620E-04,
     *-.10598824E-03,-.11702351E-03,.16139295E-04 ,-.36674529E-04,
     *-.81773494E-04,-.11730125E-04,-.93635317E-04,.67883286E-05 ,
     *.57844888E-04 ,-.84183458E-04,.55542733E-04 ,.17310667E-03 ,
     *.94032108E-04 ,.53640496E-05 ,.76887486E-04 ,.52182845E-04 ,
     *.10072962E-03 ,-.17905035E-04,-.10291668E-03,-.78341331E-04/
C
      DATA (C(I,2),I=1,40) /
     *-.32705589E-01,.69489378E-01 ,-.12728570E-02,-.64833859E-02,
     *.90286189E-03 ,.46407265E-03 ,-.31739977E-04,-.52262898E-04,
     *.86345015E-05 ,-.92822005E-04,-.36185434E-04,.12278956E-03 ,
     *.16699310E-04 ,-.56428327E-04,.63334093E-05 ,-.63322266E-01,
     *.93303354E-01 ,-.13300893E-02,-.11117519E-01,.61469450E-03 ,
     *.95051574E-03 ,-.53545882E-04,-.81070059E-04,.26351933E-04 ,
     *-.20851973E-03,-.31941166E-04,.24882388E-03 ,.11747121E-04 ,
     *-.12002237E-03,-.30584110E-01,.20751398E-01 ,.18699857E-02 ,
     *-.59856504E-02,-.98461908E-03,.76024950E-03 ,.95139832E-04 ,
     *.75331428E-05 ,-.57872056E-04,-.21588023E-03,.69014149E-04 /
C
      DATA (C(I,2),I=41,80) /
     *.19846522E-03 ,-.35509088E-04,.36931736E-02 ,-.79225220E-02,
     *.30101634E-02 ,-.60427119E-03,-.94544389E-03,.45496411E-03 ,
     *.48373630E-04 ,.45491037E-04 ,-.16854693E-04,-.15803790E-03,
     *.42941496E-04 ,.10615147E-03 ,.42646363E-02 ,-.48345153E-02,
     *.34045095E-03 ,.12624093E-02 ,-.13838834E-03,.94390102E-04 ,
     *-.11013261E-03,-.27809949E-05,.78367665E-04 ,-.37173372E-04,
     *-.34962689E-04,.59991287E-04 ,.60244815E-03 ,-.85383163E-03,
     *.74267852E-03 ,.47151310E-04 ,-.19845537E-03,.21963295E-04 ,
     *-.10620528E-04,-.57493219E-05,.42357157E-04 ,-.52277011E-03,
     *.69782943E-03 ,-.32172737E-03,.14444624E-03 ,.35766418E-04 /
C
      DATA (C(I,2),I=81,120) /
     *-.60640972E-04,.60494759E-04 ,-.19875872E-04,-.24818669E-04,
     *-.34678604E-04,.23293168E-03 ,-.10637017E-03,-.27609707E-03,
     *.18001581E-03 ,-.89662277E-05,-.36733303E-04,-.54455904E-05,
     *-.13705393E-03,.12222349E-03 ,.28266821E-03 ,-.20675617E-03,
     *.44037410E-04 ,-.76367812E-04,-.46173858E-04,-.13895647E-05,
     *-.46229876E-04,-.21060215E-04,.12180329E-03 ,-.80328076E-04,
     *.65179777E-04 ,.92413912E-04 ,-.12667347E-03,-.23082399E-03,
     *.14646138E-03 ,-.50142461E-04,.23827738E-04 ,-.10305288E-03,
     *.11250315E-03 ,-.75237481E-04,.48683660E-04 ,-.57579358E-05,
     *.14135402E-03 ,-.54123623E-07,.56454485E-04 ,-.83865810E-04/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG12A(W,X,Y,Z,FAULT)
C     ================================
C
C     Purpose
C     -------
C     Item 89034 Figures 6a to 6d
C     Increment due to twist, Delta CLT
C
C     Input
C     -----
C     W     - lambda
C     X     - A
C     Y     - tan(Lambda1/2)
C
C     Output
C     ------
C     Z     - [Delta CLT / delta et]
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL W,X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *'lambda',
     *'A',
     *'tan(Lambda1/2)',
     *'[Delta CLT / delta et]',
     *'Figures 6a to 6d of Item 89034' /
C
      DATA FLAGS /
     * 1, 1, 1,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.1,    1.0,  0.0,
     * 1.5,   10.0,  0.0,
     * 0.0,    1.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,1) = W
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figures 6a to 6d of Item 89034
C     -----------------------------------
      CALL FIG12B(W,X,Y,Z,FOUND)
C
C     Store the data if FIG01B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3012
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG12B(W,X,Y,Z,FOUND)
C     ================================
C
C     Purpose
C     -------
C     Item 89034 Figures 6a to 6d
C     Increment due to twist, Delta CLT
C
C     Input
C     -----
C     W     - lambda
C     X     - A
C     Y     - tan(Lambda1/2)
C
C     Output
C     ------
C     Z     - [Delta CLT / delta et]
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     WW(3)   - lambda = 0.1, 0.5, 1.0
C     ORDER   - order of polynomial
C     C(78,3) - polynomial coefficients for lambda = 0.1, 0.5 and 1.0
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     ZZ(3)   - [Delta CLT / delta et] for each WW
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER,I
      REAL W,X,Y,Z,ZZ(3)
C
      REAL XMN,XMX,YMN,YMX,C,WW
      COMMON /PLTB12/ XMN,XMX,YMN,YMX,C(78,3),WW(3)
C
      DATA ORDER/12/
C
C     Check W
C     -------
      FOUND = 0
      IF (W .LT. 0.1 .OR. W .GT. 1.0) GO TO 20
C
C     Calculate a Z(I) for each WW(I)
C     -------------------------------
      DO 10 I = 1,3
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C(1,I),ZZ(I),FOUND)
      IF (FOUND .NE. 1) GO TO 20
   10 CONTINUE
C
C     Interpolate Z for the given W
C     -----------------------------
      Z = ZZ(1) * (W - WW(2)) * (W - WW(3))
     *    / ((WW(1) - WW(2)) * (WW(1) - WW(3)))
     *  + ZZ(2) * (W - WW(1)) * (W - WW(3))
     *    / ((WW(2) - WW(1)) * (WW(2) - WW(3)))
     *  + ZZ(3) * (W - WW(1)) * (W - WW(2))
     *    / ((WW(3) - WW(1)) * (WW(3) - WW(2)))
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB12
C     =================
C
C     Data for Item 89034 Figures 6(a) to 6(d)
C     ----------------------------------------
C
      REAL XMN,XMX,YMN,YMX,C,WW
      COMMON /PLTB12/ XMN,XMX,YMN,YMX,C(78,3),WW(3)
C
      INTEGER I
C
      DATA WW / 0.1, 0.5, 1.0 /
C
      DATA XMN,XMX,YMN,YMX/1.5,10.0,0.0,1.0/
C
      DATA (C(I,1),I=1,40) /
     *-.49424474E-02,.21755555E-02 ,.15663424E-02 ,.27943175E-03 ,
     *-.72979106E-04,-.42675374E-04,.34642976E-04 ,.23799755E-04 ,
     *-.16274866E-04,-.17459397E-04,.59424718E-05 ,.11692065E-04 ,
     *-.28384309E-02,.20076313E-02 ,.82560832E-03 ,.18351580E-03 ,
     *-.17836710E-03,-.66445224E-04,.58210829E-04 ,.37756645E-04 ,
     *-.19948097E-04,-.22587984E-04,.55122921E-05 ,.28939609E-03 ,
     *-.48377430E-04,-.23168624E-03,-.11963955E-04,.72834227E-05 ,
     *-.10696908E-04,.40087954E-05 ,.68116629E-05 ,-.35646960E-05,
     *-.36329813E-05,-.21567696E-04,-.30739668E-04,.90178996E-06 ,
     *.22393291E-04 ,.33775735E-04 ,.78800600E-05 ,-.12710953E-04/
C
      DATA (C(I,1),I=41,78) /
     *-.56526033E-05,.49624393E-05 ,-.69386272E-05,-.66048081E-05,
     *.27104181E-05 ,-.39322958E-05,.17173221E-04 ,.34429103E-05 ,
     *-.62948368E-05,-.19547053E-05,.10347020E-04 ,.10532718E-04 ,
     *-.12892457E-04,-.32544336E-06,-.81908272E-05,-.20619245E-05,
     *.21277330E-05 ,.57669542E-06 ,-.35631233E-05,.75207141E-05 ,
     *-.44196374E-06,-.30260900E-05,-.18321785E-05,-.78314553E-05,
     *-.22967966E-06,.63155332E-05 ,-.11759924E-05,.41491097E-05 ,
     *.89994490E-05 ,.10804852E-05 ,-.10713597E-04,.39882539E-05 ,
     *-.62431456E-05,.30595639E-06 ,.75762622E-05 ,.23223981E-05 ,
     *-.16049605E-05,-.12015718E-06/
C
      DATA (C(I,2),I=1,40) /
     *.34331920E-02 ,-.37986227E-03,.79676531E-03 ,-.76724362E-04,
     *-.16621430E-03,.94573524E-05 ,.61520873E-04 ,-.64964648E-05,
     *-.24234474E-04,.55993049E-05 ,.78608002E-05 ,-.39534887E-05,
     *-.14517358E-02,-.51751255E-03,.44918549E-03 ,-.26834586E-04,
     *-.14938289E-04,.22592249E-04 ,.64332978E-05 ,-.17054784E-04,
     *-.29331969E-05,.12018024E-04 ,.11330831E-05 ,.13293329E-03 ,
     *-.33854081E-04,-.29615217E-03,-.26663878E-04,.18586770E-03 ,
     *-.29141480E-05,-.69050534E-04,.28963460E-05 ,.26797239E-04 ,
     *-.16571133E-05,-.16203490E-04,.67745150E-05 ,.25104468E-04 ,
     *.23721305E-05 ,-.31112693E-04,-.21088492E-04,.57485665E-05 /
C
      DATA (C(I,2),I=41,78) /
     *.18320363E-04 ,-.31645644E-06,.13414267E-04 ,-.18333995E-04,
     *-.11215859E-04,.18280669E-04 ,-.46616382E-05,-.93420347E-05,
     *.40890793E-05 ,.59556461E-05 ,-.36374892E-05,.10205587E-04 ,
     *.75171146E-06 ,-.12027515E-04,.94030030E-06 ,.81683776E-05 ,
     *-.18379415E-06,-.12137518E-05,-.60486977E-05,.37922460E-06 ,
     *.15027930E-05 ,.19885225E-06 ,.25278868E-06 ,.27249923E-05 ,
     *-.69200197E-06,.58628646E-06 ,.33404051E-05 ,.87376307E-06 ,
     *-.30196440E-05,.59726905E-05 ,.23667669E-06 ,-.74061798E-05,
     *.17804319E-05 ,-.55476335E-05,.17934241E-06 ,.39600362E-08 ,
     *.23262479E-05 ,-.12305609E-05/
C
      DATA (C(I,3),I=1,40) /
     *.13345009E-01 ,-.53637101E-02,-.16942026E-03,.13934822E-03 ,
     *.22509392E-04 ,.20496652E-04 ,-.30825234E-05,-.93948045E-05,
     *.43616009E-06 ,.75187633E-06 ,-.64034029E-06,.12608719E-05 ,
     *.34861674E-04 ,-.53995590E-02,.24009795E-04 ,-.26832703E-03,
     *.75262572E-04 ,-.65319003E-05,-.14368385E-04,.94044514E-05 ,
     *.11401543E-05 ,-.95558880E-06,.67039898E-06 ,-.24223674E-02,
     *-.36746476E-03,.52865331E-04 ,.12316248E-04 ,-.73803684E-04,
     *.80527397E-05 ,.13911807E-04 ,-.73614544E-05,-.11598884E-06,
     *.47147492E-05 ,.46794579E-03 ,-.51452641E-04,-.12985839E-04,
     *.23432276E-03 ,.68361465E-04 ,.15317338E-04 ,-.19704768E-04/
C
      DATA (C(I,3),I=41,78) /
     *-.11079479E-04,.43890405E-05 ,-.20164843E-03,.13673586E-03 ,
     *.59145338E-04 ,-.48351026E-04,.40869397E-04 ,-.13256910E-04,
     *-.38601552E-05,.42012496E-05 ,.10007555E-03 ,-.10628142E-03,
     *-.38344863E-04,.60324499E-04 ,-.59261397E-04,.10129413E-04 ,
     *.70662553E-05 ,-.53683615E-04,.58268823E-04 ,.12829243E-04 ,
     *-.59915391E-04,.49489216E-04 ,-.12432607E-04,.42884072E-04 ,
     *-.78683261E-06,.66966969E-06 ,.28734568E-04 ,-.37264329E-04,
     *-.28110425E-04,-.12787466E-04,.28999658E-05 ,-.45971467E-05,
     *.60924022E-05 ,.28271840E-05 ,-.90806898E-05,.14464109E-05 ,
     *-.41131087E-05,-.45196300E-06/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG13A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Items      93019,    95021,96032,     96003
C     Figures        3,        7,    1,         2
C     Result (Psi)i&oj,(Phi)i&oj,Psi'i,(Phi')i&oj
C
C     Input
C     -----
C     X     - eta bar
C     Y     - eta
C
C     Output
C     ------
C     Z     - (Psi)i&oj, (Phi)i&oj, (Psi')i, (Phi')i&oj
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'eta bar',
     *'eta',
     *'(Psi)i,j and (Psi)o,j etc',
     *'Figure 3 of Item 93019 and others' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.36,   0.48, 0.0,
     * 0.0,    1.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 3 of Item 93019
C     ---------------------------
      CALL FIG13B(X,Y,Z,FOUND)
C
C     Store the data if FIG13B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3013
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG13B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Items      93019,    95021,96032,     96003
C     Figures        3,        7,    1,         2
C     Result (Psi)i&oj,(Phi)i&oj,Psi'i,(Phi')i&oj
C
C     Input
C     -----
C     X     - eta bar
C     Y     - eta
C
C     Output
C     ------
C     Z     - (Psi)i&oj, (Phi)i&oj, (Psi')i, (Phi')i&oj
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB13/ XMN,XMX,YMN,YMX,C(36)
C
      DATA ORDER/8/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
C     Z is never less than 0.0 or greater than 1.0
C     --------------------------------------------
      Z = AMAX1(Z,0.0)
      Z = AMIN1(Z,1.0)
C
      RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGB13
C     =================
C
C     Data for Item 93019 Figure 3
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB13/ XMN,XMX,YMN,YMX,C(36)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/0.36,0.48,0.0,1.0/
C
      DATA (C(I),I=1,36) /
     *.56360137E+00 ,.51083509E+00 ,-.62959058E-01,-.11311120E-01,
     *-.88532311E-03,.46440198E-03 ,.33586064E-03 ,.50197939E-04 ,
     *-.40675403E-01,.70517056E-03 ,.44197281E-01 ,.44469213E-03 ,
     *-.38494521E-02,-.16706970E-02,.18991941E-03 ,.17587067E-03 ,
     *-.24093385E-03,-.37742083E-04,.37940414E-03 ,-.89125089E-04,
     *-.13648435E-03,-.25465833E-04,.19382708E-04 ,.65000787E-04 ,
     *-.76061531E-04,.11213244E-04 ,-.94064816E-04,.43424650E-03 ,
     *.12278155E-03 ,-.36533735E-03,-.15152288E-03,-.51744265E-03,
     *.12257158E-04 ,-.11324426E-04,.10221248E-04 ,.58570876E-04 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG14A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94027 Figure 1a
C     Correlation factor Kl
C
C     Input
C     -----
C     X     - delta l cos(Lambda) degrees
C
C     Output
C     ------
C     Z     - Kl
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'delta l cos(Lambda)',
     *' ',
     *'Kl',
     *'Figure 1a of Item 94027' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,   43.5,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 1a of Item 94027
C     ----------------------------
      CALL FIG14B(X,Z,FOUND)
C
C     Store the data if FIG01B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3014
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG14B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94027 Figure 1a
C     Correlation factor Kl
C
C     Input
C     -----
C     X     - delta l cos(Lambda) degrees
C
C     Output
C     ------
C     Z     - Kl
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     XX      - dummy X for cases where X <= 23.0
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z
C
      REAL XMN,XMX,C
      REAL XX
      COMMON /PLTB14/ XMN,XMX,C(5)
C
      DATA N /5/
C
C     Calculate Z for the given X (if possible).
C     ------------------------------------------
      XX = AMAX1(X,23.0)
      CALL A9F799(XX,XMN,XMX,N,C,Z,FOUND)
      Z = AMIN1(Z,1.0)
C
      RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGB14
C     =================
C
C     Data for Item 94027 Figure 1(a)
C     -------------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB14/ XMN,XMX,C(5)
C
      DATA XMN,XMX /23.0,43.5/
C
      DATA C /
     *.68451956E+00 ,-.35276976E+00 ,-.33924960E-01 ,.24338113E-02 ,
     *-.47978053E-03/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG15A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 97011 Figure 1
C     Efficiency factor Jp0
C
C
C     Input
C     -----
C     X     - delta t + phi t (degrees)
C
C     Output
C     ------
C     Z     - Jp0
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'delta t and phi t',
     *' ',
     *'Jpo',
     *'Figure 1 of Item 97011' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,   80.0,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 1 of Item 97011
C     ---------------------------
      CALL FIG15B(X,Z,FOUND)
C
C     Store the data if FIG15B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3015
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG15B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 97011 Figure 1
C     Efficiency factor Jp0
C
C
C     Input
C     -----
C     X     - delta t + phi t (degrees)
C
C     Output
C     ------
C     Z     - Jp0
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
C
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB15/ XMN,XMX,C(16)
C
      DATA N /16/
C
C     Calculate Z for the given X
C     ===========================
C     If 10.0 < X <= 80.0 use the curve
C     ----------------------------------
      IF (X .GT. 10.0) THEN
       CALL A9F799(X,XMN,XMX,N,C,Z,FOUND)
      ELSE
C      Otherwise if 0.0 <= X <= 10.0, Z = 1.0
C      --------------------------------------
       IF (X .GE. 0.0) THEN
        FOUND = 1
        Z = 1.0
       ELSE
        FOUND = 0
       END IF
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB15
C     =================
C
C     Data for Item 97011 Figure 1
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB15/ XMN,XMX,C(16)
C
      DATA XMN,XMX /10.0,80.0/
C
      DATA C /
     *.63906627E+00 ,-.31981728E+00 ,.68344740E-01 ,.60812609E-02 ,
     *-.18998786E-01 ,.85364908E-02 ,.16118421E-02 ,-.42180773E-02 ,
     *.16584923E-02 ,.42998401E-03 ,-.16138090E-03 ,-.19925405E-03 ,
     *-.37616221E-03 ,.65298621E-03 ,-.17643376E-03 ,-.17406867E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG16A(W,X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94029 Figure 1
C     Basic aerofoil with Ct/C=0.2 and deltat=60
C
C     Input
C     -----
C     W     - xlm/c
C     X     - (-zlm/c)
C
C     Output
C     ------
C     Z     - (Delta C'Lot)d
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL W,X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *'(xlm/c)j',
     *'(-zol/c)j',
     *' ',
     *'(Delta CLot)d',
     *'Figure 1 of Item 94029' /
C
      DATA FLAGS /
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 1, 1 /
C
      DATA WXYZ /
     * 0.12,   0.5,  0.0,
     * 0.0,    0.14, 0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    2.1,  0.0 /
C
      FAULT = 0
      WXYZ(3,1) = W
      WXYZ(3,2) = X
C
C     Read Figure 1 of Item 94029
C     ---------------------------
      CALL FIG16B(W,X,Z,FOUND)
C
C     Store the data if FIG16B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3016
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG16B(W,X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94029 Figure 1
C     Basic aerofoil with Ct/C=0.2 and deltat=60
C
C     Input
C     -----
C     W     - xlm/c
C     X     - (-zlm/c)
C
C     Output
C     ------
C     Z     - (Delta C'Lot)d
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N             - number of coefficients
C     C(16,3 )      - polynomial coefficients for the curves
C                     of ZZ versus X for the three WWs
C     WW(3)         - xlm/c = 0.12, 0.35, 0.5
C     XMN(3),XMX(3) - minimum and maximum X for the three WWs
C     ZZ(3)         - Zs for the given X and the three WWs
C     FLAGS(3)      - flags on the three ZZs (0 means not found)
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N,I,FLAGS(3)
      REAL W,X,Z,ZZ(3)
C
      REAL XMN,XMX,C,WW
      COMMON /PLTB16/ XMN(3),XMX(3),C(16,3),WW(3)
C
      DATA N /16/
C
C     Calculate Z for the given X and two of the three WWs
C     ----------------------------------------------------
      DO 10 I = 1,3
      CALL A9F799(X,XMN(I),XMX(I),N,C(1,I),ZZ(I),FLAGS(I))
C     N.B. On the left hand side, Z = 1.2 for X <= 0.02
      IF (I .LE. 2 .AND. X .GE. 0.0 .AND. X .LE. 0.02) THEN
       FLAGS(I) = 1
       ZZ(I) = 1.2
      END IF
   10 CONTINUE
C
C     Linear interpolation to get Z for the given W
C     ---------------------------------------------
      IF (W .GE. 0.12 .AND. W .LE. 0.35) THEN
       IF (FLAGS(1) .EQ. 1 .AND. FLAGS(2) .EQ. 1) THEN
        FOUND = 1
       Z = (ZZ(1) * (WW(2) - W) + ZZ(2) * (W - WW(1))) / (WW(2) - WW(1))
        Z = AMAX1(Z,1.2)
       ELSE
        FOUND = 0
       END IF
      END IF
C
      IF (W .GE. 0.35 .AND. W .LE. 0.5) THEN
       IF (FLAGS(2) .EQ. 1 .AND. FLAGS(3) .EQ. 1) THEN
        FOUND = 1
       Z = (ZZ(2) * (WW(3) - W) + ZZ(3) * (W - WW(2))) / (WW(3) - WW(2))
        Z = AMAX1(Z,1.2)
       ELSE
        FOUND = 0
       END IF
      END IF
C
C     W ranges from 0.12 to 0,5
C     -------------------------
      IF (W .LT. 0.12 .OR. W .GT. 0.5) FOUND = 0
C
C     Clip the plot off above Z = 2.1
C     -------------------------------
      IF (Z .GT. 2.1) FOUND = 0
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB16
C     =================
C
C     Data for Item 94029 Figure 1
C     ----------------------------
C
      REAL XMN,XMX,C,WW
      INTEGER I
      COMMON /PLTB16/ XMN(3),XMX(3),C(16,3),WW(3)
C
      DATA XMN / 0.02, 0.02, 0.00 /
      DATA XMX / 0.14, 0.14, 0.14 /
C
      DATA WW / 0.12, 0.35, 0.5 /
C
      DATA (C(I,1), I = 1,16) /
     *.19601702E+01 ,.76163814E+00 ,-.29082904E-01 ,-.50275508E-01 ,
     *-.14854716E-01 ,.23553651E-01 ,.21762037E-01 ,-.96567196E-02 ,
     *-.17950793E-01 ,.19136983E-02 ,.11780391E-01 ,.13131825E-02 ,
     *-.64241759E-02 ,-.17369025E-02 ,.29844823E-02 ,.11851203E-02 /
C
      DATA (C(I,2), I = 1,16) /
     *.13620391E+01 ,.19328205E+00 ,.76115584E-02 ,-.13354622E-01 ,
     *.72481572E-02 ,-.26336907E-02 ,.12296593E-02 ,-.18476195E-03 ,
     *-.59462809E-03 ,.48529823E-03 ,-.16974434E-03 ,.21415466E-04 ,
     *.11379359E-03 ,-.17097769E-03 ,.97179659E-04 ,.10131206E-04 /
C
      DATA (C(I,3), I = 1,16) /
     *.15267088E+01 ,.28845468E+00 ,-.36531845E-01 ,.39212240E-02 ,
     *-.11598516E-03 ,-.15179322E-02 ,.16442935E-02 ,-.18705098E-03 ,
     *-.93978865E-03 ,.65480288E-03 ,.19453200E-03 ,-.47949739E-03 ,
     *.13503020E-03 ,.17533546E-03 ,-.15013122E-03 ,-.19624947E-05 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG17A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 91014 Figure 3a
C     Item 97011 Figure 2
C     Part-span factor for plain and split flaps
C
C     Input
C     -----
C     X     - A tan(Lambda1/2) - 8 lambda
C     Y     - eta
C
C     Output
C     ------
C     Z     - Phi oj and Phi ij
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'A tan(Lambda1/2) - 8.0 * lambda',
     *'eta',
     *'(Phi)oj and (Phi)ij',
     *'Figure 3a of Item 91014' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * -8.0,   4.0,  0.0,
     * 0.0,    1.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 3a of Item 91014
C     ----------------------------
      CALL FIG17B(X,Y,Z,FOUND)
C
C     Store the data if FIG17B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3017
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG17B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 91014 Figure 3a
C     Item 97011 Figure 2
C     Part-span factor for plain and split flaps
C
C     Input
C     -----
C     X     - A tan(Lambda1/2) - 8 lambda
C     Y     - eta
C
C     Output
C     ------
C     Z     - Phi oj and Phi ij
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB17/ XMN,XMX,YMN,YMX,C(78)
C
      DATA ORDER/12/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB17
C     =================
C
C     Data for Item 91014 Figure 3(a)
C     -------------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB17/ XMN,XMX,YMN,YMX,C(78)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/-8.0,4.0,0.0,1.0/
C
      DATA (C(I),I=1,40) /
     *.56749297E+00 ,.50777835E+00 ,-.68510353E-01,-.77435744E-02,
     *.13702391E-02 ,-.25144626E-03,-.48193746E-03,.33360777E-03 ,
     *.17072629E-03 ,-.19035062E-03,-.57106993E-04,.14137925E-03 ,
     *.34760396E-01 ,-.35108753E-02,-.35468699E-01,.38776652E-02 ,
     *.65221323E-03 ,-.33974868E-03,.17216048E-03 ,-.11775647E-03,
     *-.17172019E-03,.16080603E-03 ,.65516820E-04 ,.58701725E-02 ,
     *-.20617577E-02,-.57668429E-02,.23926160E-02 ,-.18177008E-03,
     *-.46398911E-03,.11197396E-03 ,.19073791E-03 ,-.41079601E-04,
     *-.72644534E-04,-.74032575E-03,.15454588E-03 ,.11918166E-02 ,
     *.31980434E-03 ,-.44668651E-03,-.77358112E-03,-.67789770E-04/
C
      DATA (C(I),I=41,78) /
     *.44943182E-03 ,.10374376E-03 ,.13917606E-03 ,.71487060E-04 ,
     *-.24763930E-03,-.15177098E-03,.14620169E-03 ,.16782605E-03 ,
     *-.43759413E-04,-.14120790E-03,-.14844282E-04,-.73539589E-04,
     *-.72539719E-04,-.18939165E-04,.44704603E-04 ,.10514808E-03 ,
     *.73366394E-04 ,-.52846425E-04,.11033895E-05 ,.70834884E-04 ,
     *.26279404E-04 ,-.32328051E-04,-.46143382E-04,.38001686E-04 ,
     *.27550977E-04 ,-.16529032E-04,-.46802111E-05,-.19135116E-05,
     *.22308882E-04 ,-.14487176E-04,-.18388749E-04,.44672747E-05 ,
     *-.21462755E-04,-.32224311E-05,.24862853E-04 ,-.77028412E-05,
     *.12421424E-04 ,.69118040E-05/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG18A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 94031 Figure 4
C
C     Input
C     -----
C     X     - (C et1 / C')
C     Y     - delta t1 sec(Lambda2) degrees
C
C     Output
C     ------
C     Z     - Delta C'L1
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'(cet1/c)',
     *'delta t1 sec(Lambda2)',
     *'Delta CL1',
     *'Figure 4 of Item 94031' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.1,    0.4,  0.0,
     * 0.0,   70.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 4 of Item 94031
C     ---------------------------
      CALL FIG18B(X,Y,Z,FOUND)
C
C     Store the data if FIG18B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3018
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG18B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 94031 Figure 4
C
C     Input
C     -----
C     X     - (C et1 / C')
C     Y     - delta t1 sec(Lambda2) degrees
C
C     Output
C     ------
C     Z     - Delta C'L1
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB18/ XMN,XMX,YMN,YMX,C(120)
C
      DATA ORDER/15/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
      Z = AMAX1(Z,0.0)
C
C     N.B. If -10 <= [delta t1 sec(Lambda2)] <= 0.0 then Delta C'L1 = 0
      IF (Y .GE. -10.0 .AND. Y .LE. 0.0) THEN
       Z= 0.0
       FOUND = 1
       IF (X .LT. 0.1 .OR. X .GT. 0.4) FOUND = 0
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB18
C     =================
C
C     Data for Item 94031 Figure 4
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB18/ XMN,XMX,YMN,YMX,C(120)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/0.1,0.4,0.0,70.0/
C
      DATA (C(I),I=1,40) /
     *.98666354E+00 ,.62767337E+00 ,-.29488979E+00,.50036397E-01 ,
     *-.90248556E-02,.13130043E-02 ,-.27800130E-02,.11310670E-02 ,
     *.16921191E-03 ,.10649450E-03 ,.15625138E-03 ,.47600516E-03 ,
     *-.51877811E-03,-.84934650E-03,.72023335E-03 ,.30712044E+00 ,
     *.19521343E+00 ,-.87800876E-01,.21235661E-01 ,-.26745156E-02,
     *-.12788284E-03,.41731900E-03 ,.60556254E-03 ,.13683736E-03 ,
     *.18659034E-03 ,-.87999488E-03,-.41651703E-03,.73427619E-03 ,
     *.89459814E-04 ,-.22532410E-01,-.13916707E-01,.58990995E-02 ,
     *-.10601514E-02,-.60292617E-03,-.26353705E-03,.21956062E-02 ,
     *-.87157590E-03,-.64693040E-03,.91371629E-03 ,-.11148666E-03/
C
      DATA (C(I),I=41,80) /
     *-.72591380E-03,.36709098E-03 ,.82993375E-04 ,-.79820941E-04,
     *-.24901973E-02,-.16792815E-03,.23452916E-02 ,-.33908934E-03,
     *-.16510385E-02,-.73481291E-03,.33343345E-03 ,-.33764846E-03,
     *-.79227738E-04,.23151676E-03 ,-.80382501E-03,.15429688E-03 ,
     *.10479170E-02 ,.61800232E-03 ,.47808834E-03 ,-.37596043E-04,
     *-.12625541E-03,.10106191E-03 ,-.15021363E-03,-.48153872E-03,
     *.43068794E-03 ,-.26516003E-03,.28811454E-03 ,-.17543995E-04,
     *-.31785976E-03,-.71371337E-03,-.84064990E-03,.35738141E-03 ,
     *.32953677E-03 ,-.15457778E-03,-.46792736E-03,-.35959503E-03,
     *.52433447E-03 ,.22516406E-04 ,-.51673266E-03,.71366947E-04 /
C
      DATA (C(I),I=81,120) /
     *-.80942013E-04,.34557862E-03 ,-.23120560E-03,-.38249875E-03,
     *.38210806E-04 ,.38645139E-04 ,.81888470E-04 ,.80776064E-04 ,
     *.21912431E-03 ,.19426927E-03 ,.14542157E-04 ,-.36749136E-04,
     *.15626873E-03 ,-.39686906E-03,-.60454057E-04,.20626351E-03 ,
     *-.93105622E-04,.34461390E-04 ,-.20631037E-03,.13968022E-04 ,
     *-.13450502E-03,-.33523509E-04,-.26881959E-04,-.63356561E-04,
     *.16312154E-04 ,.49478265E-05 ,.20362202E-03 ,.32590320E-04 ,
     *-.26788815E-04,.65262548E-04 ,-.91993069E-05,.88702982E-04 ,
     *-.91040425E-05,.18056400E-04 ,-.93054115E-06,-.92653977E-04,
     *-.45747072E-04,.96005937E-05 ,-.22697099E-04,-.33503993E-04/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG19A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 94031 Figure 5
C
C     Input
C     -----
C     X     - (C et2 / C')
C     Y     - delta t2 sec(Lambda2) degrees
C
C     Output
C     ------
C     Z     - Delta C'L2
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'cet2/c',
     *'delta t2 sec(Lambda2)',
     *'Delta CL2',
     *'Figure 5 of Item 94031' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.05,   0.4,  0.0,
     * 0.0,   60.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figures 5 of Item 94031
C     ----------------------------
      CALL FIG19B(X,Y,Z,FOUND)
C
C     Store the data if FIG19B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3019
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG19B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 94031 Figure 5
C
C     Input
C     -----
C     X     - (C et2 / C')
C     Y     - delta t2 sec(Lambda2) degrees
C
C     Output
C     ------
C     Z     - Delta C'L2
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB19/ XMN,XMX,YMN,YMX,C(120)
C
      DATA ORDER/15/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
      Z = AMAX1(Z,0.0)
C
      RETURN
      END
C     --------------------------------------------------------
      BLOCK DATA FIGB19
C     =================
C
C     Data for Item 94031 Figure 5
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB19/ XMN,XMX,YMN,YMX,C(120)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/0.05,0.4,0.0,60.0/
C
      DATA (C(I),I=1,40) /
     *.65217230E+00 ,.44377256E+00 ,-.15822710E+00,.37611919E-01 ,
     *-.13726757E-01,.16787489E-03 ,.10688559E-02 ,-.80224360E-03,
     *.73582399E-04 ,.71955853E-03 ,-.43090609E-03,-.35613860E-03,
     *.27987790E-03 ,.35211558E-04 ,.30524725E-04 ,.26920268E+00 ,
     *.18357597E+00 ,-.62325840E-01,.17544358E-01 ,-.51055255E-02,
     *.82777812E-04 ,-.44357599E-03,-.64542031E-03,-.68790860E-03,
     *.51080175E-03 ,.71385543E-04 ,-.16326663E-03,.32909535E-03 ,
     *-.86194618E-04,-.40818381E-01,-.26362996E-01,.10817217E-01 ,
     *-.22976100E-02,.19168191E-02 ,-.20862797E-03,-.18833072E-03,
     *.33829109E-04 ,-.11024942E-02,-.47921423E-03,.26537812E-03 /
C
      DATA (C(I),I=41,80) /
     *.64280974E-03 ,.16888660E-03 ,.12478075E-01 ,.10584277E-01 ,
     *-.47043552E-02,-.84912284E-03,.68365386E-03 ,-.23408255E-03,
     *.15583475E-02 ,.40537243E-03 ,-.49010919E-03,-.44199535E-03,
     *.83610398E-04 ,-.20101579E-03,-.53000272E-02,-.51394133E-02,
     *.10305070E-02 ,-.63545948E-03,-.20633952E-03,.10740859E-02 ,
     *-.17210413E-03,-.13193497E-03,-.85518566E-04,.47985446E-03 ,
     *.14230228E-03 ,.24660675E-02 ,.21657309E-02 ,-.64505172E-03,
     *-.23682031E-03,.94607657E-03 ,-.27243422E-03,-.10606028E-02,
     *.80413952E-03 ,.46864391E-03 ,-.40724236E-03,-.35942959E-03,
     *.14228725E-03 ,.30991544E-03 ,.12293440E-03 ,-.12357843E-03/
C
      DATA (C(I),I=81,120) /
     *-.24949641E-03,.54386760E-04 ,-.19664729E-03,.27393672E-03 ,
     *.27838851E-03 ,.11711653E-03 ,.18208929E-03 ,.26703975E-03 ,
     *.39361803E-03 ,-.11628492E-03,-.38076735E-03,-.65244103E-04,
     *-.81449412E-04,-.12739423E-03,-.10208756E-03,-.13252733E-03,
     *-.78069410E-04,.11158782E-03 ,.11206502E-03 ,-.59963019E-03,
     *-.32270810E-03,-.16450712E-03,-.19679393E-03,-.44976554E-03,
     *.11680358E-03 ,.21129334E-03 ,.11989103E-03 ,-.12321727E-04,
     *.89326129E-04 ,.11329494E-03 ,.21231331E-03 ,-.55748668E-05,
     *.17526649E-03 ,.89828435E-04 ,.30073773E-04 ,.72383272E-04 ,
     *-.20020194E-04,-.52139833E-04,.76600065E-04 ,-.58389840E-04/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG20A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 94031 Figure 6
C
C     Input
C     -----
C     X     - (C et3 / C')
C     Y     - delta t3 sec(Lambda2) degrees
C
C     Output
C     ------
C     Z     - Delta C'L3
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'cet3/c',
     *'delta t3 sec(Lambda2)',
     *'Delta CL3',
     *'Figure 6 of Item 94031' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0, 0.0,
     * 0.05,   0.4,  0.0,
     * 0.0,   40.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 6 of Item 94031
C     ---------------------------
      CALL FIG20B(X,Y,Z,FOUND)
C
C     Store the data if FIG20B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3020
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG20B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 94031 Figure 6
C
C     Input
C     -----
C     X     - (C et3 / C')
C     Y     - delta t3 sec(Lambda2) degrees
C
C     Output
C     ------
C     Z     - Delta C'L3
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB20/ XMN,XMX,YMN,YMX,C(120)
C
      DATA ORDER/15/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
      Z = AMAX1(Z,0.0)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB20
C     =================
C
C     Data for Item 94031 Figure 6
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB20/ XMN,XMX,YMN,YMX,C(120)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/0.05,0.4,0.0,40.0/
C
      DATA (C(I),I=1,40) /
     *.40251489E+00 ,.25286758E+00 ,-.94795619E-01,.36306130E-01 ,
     *-.14420847E-01,.41489580E-02 ,-.81998920E-03,-.22395327E-03,
     *.27515223E-03 ,-.24288752E-03,.60596634E-06 ,.44425045E-04 ,
     *.22870406E-03 ,-.15144836E-03,-.74555175E-04,.19346566E+00 ,
     *.11524152E+00 ,-.36163499E-01,.23439299E-01 ,-.12288128E-01,
     *.55534974E-02 ,-.15988319E-02,.47001321E-03 ,.61555747E-03 ,
     *-.67916473E-03,-.58603770E-05,.36278965E-04 ,.21455634E-03 ,
     *-.56307270E-04,-.43258509E-01,-.28235920E-01,.55982509E-02 ,
     *-.60670826E-02,.28348481E-02 ,-.99964786E-03,-.21484879E-03,
     *.29310424E-03 ,-.19820112E-03,-.16313637E-03,.26622589E-03 /
C
      DATA (C(I),I=41,80) /
     *.65439169E-04 ,-.15742930E-03,.96271637E-02 ,.10304423E-01 ,
     *-.12457348E-02,.39769112E-03 ,.11430573E-02 ,-.11872597E-03,
     *.90125886E-03 ,-.49719247E-03,.87215982E-04 ,.14277368E-03 ,
     *-.41487716E-03,.17548368E-03 ,-.20211747E-02,-.35061487E-02,
     *.29255606E-04 ,-.15024185E-03,-.16929720E-02,.27672427E-03 ,
     *.24743342E-03 ,-.18992939E-03,-.16004635E-03,.75599124E-04 ,
     *.15609577E-03 ,.35656011E-03 ,.10459820E-02 ,-.40521512E-03,
     *.54330121E-04 ,.99996116E-03 ,.19843311E-05 ,.30101459E-03 ,
     *-.32392284E-04,-.17665510E-03,.21523086E-04 ,-.32374403E-03,
     *.10051032E-02 ,.72240326E-03 ,.38250730E-03 ,.36719367E-03 /
C
      DATA (C(I),I=81,120) /
     *-.22444031E-03,.40581107E-03 ,-.81434818E-04,.21015797E-03 ,
     *-.72283847E-04,-.29670539E-03,-.63362083E-03,-.28940223E-03,
     *.21439073E-03 ,-.87493575E-04,-.19707654E-03,.20600324E-05 ,
     *.30048664E-04 ,-.40923707E-03,-.19690763E-03,-.23825272E-03,
     *-.13209006E-03,.32003951E-04 ,-.24058429E-03,.52066949E-04 ,
     *-.43133974E-04,.64130351E-03 ,.16801138E-03 ,-.37935484E-03,
     *.10569403E-03 ,.83973759E-04 ,.66540333E-04 ,-.56505575E-04,
     *.43296231E-04 ,.46504025E-04 ,-.39846951E-04,.12654162E-03 ,
     *-.24284759E-03,-.24325256E-04,.12098242E-04 ,.93362175E-04 ,
     *.64618508E-04 ,-.38222536E-04,-.17204772E-03,-.36540772E-04/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG21A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 92031 Figure 3
C
C     Input
C     -----
C     X     - eta
C
C     Output
C     ------
C     Z     - Phi i
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'eta',
     *' ',
     *'Phi i',
     *'Figure 3 of Item 92031' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,    1.0,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 3 of Item 92031
C     ---------------------------
      CALL FIG21B(X,Z,FOUND)
C
C     Store the data if FIG21B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3021
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG21B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 92031 Figure 3
C
C     Input
C     -----
C     X     - eta
C
C     Output
C     ------
C     Z     - Phi i
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB21/ XMN,XMX,C(16)
C
      DATA N /16/
C
C     Calculate Z for the given X (if possible).
C     ------------------------------------------
      CALL A9F799(X,XMN,XMX,N,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB21
C     =================
C
C     Data for Item 92031 Figure 3
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB21/ XMN,XMX,C(16)
C
      DATA XMN,XMX /0.0,1.0/
C
      DATA C /
     *.38151018E+00 ,-.48367751E+00 ,.14042667E+00 ,-.39379837E-01 ,
     *-.11836313E-01 ,.24200933E-01 ,-.15247296E-01 ,.27346245E-02 ,
     *.38899290E-02 ,-.43978346E-02 ,.23039042E-02 ,-.30509078E-03 ,
     *-.57836122E-03 ,.64728476E-03 ,-.48135228E-03 ,.20633799E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG22A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94027 Figure 2a
C     Correlation factor Kg
C
C     Input
C     -----
C     X     - rho l / c sec(Lambda)
C
C     Output
C     ------
C     Z     - Kg
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'rho l / c sec(Lambda)',
     *' ',
     *'Kg',
     *'Figure 2a of Item 94027' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,  0.024,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 2a of Item 94027
C     ----------------------------
      CALL FIG22B(X,Z,FOUND)
C
C     Store the data if FIG22B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3022
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG22B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94027 Figure 2a
C     Correlation factor Kg
C
C     Input
C     -----
C     X     - rho l / c sec(Lambda)
C
C     Output
C     ------
C     Z     - Kg
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB22/ XMN,XMX,C(16)
C
      DATA N /16/
C
C     Calculate Z for the given X (if possible).
C     ------------------------------------------
      CALL A9F799(X,XMN,XMX,N,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB22
C     =================
C
C     Data for Item 94027 Figure 2(a)
C     -------------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB22/ XMN,XMX,C(16)
C
      DATA XMN,XMX /0.0,0.024/
C
      DATA C /
     *.75708930E+00 ,-.44981798E-01 ,-.23141188E+00 ,.35916838E-01 ,
     *.17987856E-01 ,-.86462084E-02 ,-.90116456E-03 ,-.71470847E-03 ,
     *.37976632E-03 ,.11768691E-02 ,-.14365458E-02 ,-.34423108E-04 ,
     *.10899372E-02 ,-.47419067E-03 ,-.25565411E-03 ,.36395112E-03 /
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE FIG23A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 94027 Figure 1c
C
C     Input
C     -----
C     X     - delta l cos(Lambda) degrees
C     Y     - Hl / C sec(Lambda)
C
C     Output
C     ------
C     Z     - Kl
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'delt l cos(Lambda)',
     *'Hl/c sec(Lambda)',
     *'Kl',
     *'Figure 1c of Item 94027' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,   90.0,  0.0,
     * 0.0,  0.042,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 1c of Item 94027
C     ----------------------------
      CALL FIG23B(X,Y,Z,FOUND)
C
C     Store the data if FIG23B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3023
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE FIG23B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 94027 Figure 1c
C
C     Input
C     -----
C     X     - delta l cos(Lambda) degrees
C     Y     - Hl / C sec(Lambda)
C
C     Output
C     ------
C     Z     - Kl
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial on right
C     N       - number of coefficients in single curve fit on left
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     YY      - abs(Y - 0.01) for Y >= 0.0
C               and 0.01 for y < 0.0
C     Z1      - result of plot of Z versus X and Y
C     Z2      - result of plot of Z versus Y (on left hand side)
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C     A9F799    - evaluation of a single Chebyschev polynomial
C
C     Notes
C     -----
C     (1) The plot is symmetric about Y = 0.01
C     (2) It is made up of two sub-plots.  A result is calculated for
C         each plot and the smaller result is chosen.
C     (3) One sub-plot is a surface.  The other is a curve of Z versus Y
C         regardless of X.
C     (4) The result is never allowed to be less than 0.0 or greater
C         than 1.0
C     (5) If Y is less than 0.0, it is taken as 0.0
C
C     --------------------------------------------------------
C
      INTEGER FOUND1,FOUND2,FOUND,ORDER,N
      REAL X,Y,Z,YY,Z1,Z2
C
      REAL XMN,XMX,YMN,YMX,C1,C2
      COMMON /PLTB23/ XMN,XMX,YMN,YMX,C1(120),C2(16)
C
      DATA ORDER,N/ 15, 16 /
C
C     Calculate Z for the given X and Y
C     ---------------------------------
C     According to the plot:
      YY = AMAX1(Y,0.0)
C     According to the plot:
      YY = AMIN1(YY,0.042)
C     The plot is symmetrical about Y = 0.01
C     So move the Y origin 0.01 to the right
      YY = ABS(YY - 0.01)
      CALL A9E799(X,YY,XMN,XMX,YMN,YMX,ORDER,C1,Z1,FOUND1)
C
C     Calculate Z for the given Y (on left hand side of plot)
C     -------------------------------------------------------
      CALL A9F799(YY,YMN,YMX,N,C2,Z2,FOUND2)
C
      FOUND = FOUND2
      Z = Z2
      IF (FOUND2 .EQ. 0) GO TO 10
C
C     Choose the smaller Z
C     --------------------
      IF (FOUND1 .EQ. 1) Z = AMIN1(Z1,Z2)
C
C     The result is never less than 0.0 or greater than 1.0
C     -----------------------------------------------------
      Z = AMAX1(Z,0.0)
      Z = AMIN1(Z,1.0)
C
C     X must never be less than 0.0 or greater than 90.0
C     --------------------------------------------------
   10 IF (X .LT. 0.0 .OR. X .GT. 90.0) FOUND = 0
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB23
C     =================
C
C     Data for Item 94027 Figure 1(c)
C     -------------------------------
C
      REAL XMN,XMX,YMN,YMX,C1,C2
      COMMON /PLTB23/ XMN,XMX,YMN,YMX,C1(120),C2(16)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/19.0,90.0,0.0,0.032/
C
C
      DATA (C1(I),I=1,40) /
     *.89207480E-01 ,-.58961930E+00,.99866450E-01 ,.36003847E-01 ,
     *.10076317E-01 ,-.32450399E-02,-.27417107E-02,.10073164E-02 ,
     *.16640272E-02 ,-.72423827E-03,-.82136636E-03,.74556294E-03 ,
     *.35294033E-03 ,-.59911874E-03,.14033377E-04 ,-.39946523E+00,
     *.22239802E-01 ,-.68331986E-02,.78264341E-02 ,-.41028044E-02,
     *.62108030E-03 ,.14748665E-03 ,.63231899E-03 ,.49865633E-03 ,
     *-.11300231E-02,-.68488464E-03,.12549936E-02 ,.44111358E-03 ,
     *-.73415514E-03,.40905137E-01 ,-.17698587E-02,.13592855E-01 ,
     *.36142911E-02 ,.47570691E-02 ,-.23492588E-03,-.12786193E-02,
     *-.84542097E-03,.48110935E-03 ,.78788703E-03 ,-.18845458E-04/
C
      DATA (C1(I),I=41,80) /
     *-.58244319E-03,-.20505621E-03,-.77828271E-02,.30231348E-01 ,
     *.21836144E-01 ,.14350414E-01 ,.70168861E-02 ,.99302373E-03 ,
     *.15361923E-04 ,.10493682E-03 ,.31359885E-04 ,-.32696215E-03,
     *.38154836E-04 ,.32112156E-03 ,.65463278E-02 ,-.55036511E-02,
     *-.10880119E-01,-.48050588E-02,-.42669055E-02,.42624144E-03 ,
     *.92776099E-03 ,.10305756E-02 ,.21108916E-04 ,-.44170811E-03,
     *-.15750456E-03,-.10833576E-02,.63259147E-03 ,.75397600E-02 ,
     *.19655439E-02 ,.27324509E-02 ,-.77415335E-03,-.99700945E-03,
     *-.15246861E-03,-.93900797E-04,.29311498E-03 ,-.11774096E-03,
     *.55415027E-03 ,-.43226299E-02,-.16501165E-02,-.16284391E-02/
C
      DATA (C1(I),I=81,120) /
     *.83796171E-03 ,.14654709E-02 ,-.18182854E-03,-.32375146E-03,
     *.33158026E-03 ,.35442159E-03 ,.12683071E-02 ,.77486819E-03 ,
     *.52277275E-03 ,-.55757768E-03,-.80129485E-03,.22775767E-03 ,
     *-.27479961E-04,-.66670979E-03,.34330059E-03 ,-.85179018E-04,
     *-.53171238E-03,.49878049E-03 ,.18865598E-03 ,-.14939802E-03,
     *.39065681E-03 ,-.67370579E-03,-.20422970E-03,.71768840E-03 ,
     *-.65511536E-03,.20929965E-04 ,-.67243902E-04,.61920117E-03 ,
     *.26646619E-03 ,-.33070093E-03,-.18102501E-06,-.19453485E-03,
     *-.34037452E-03,-.59086546E-04,.40519053E-04 ,.20668469E-03 ,
     *-.37885903E-04,-.92505090E-04,-.13871117E-03,.10455762E-03 /
C
      DATA C2 /
     *.52576233E+00 ,-.59648672E+00 ,.51038467E-01 ,.26211924E-01 ,
     *.99795810E-02 ,-.26709210E-01 ,.17469957E-01 ,-.16814248E-01 ,
     *.13186343E-01 ,-.20766554E-02 ,-.29865789E-02 ,.30593706E-02 ,
     *-.30591233E-02 ,.11250598E-02 ,.10660888E-02 ,-.10195226E-02 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG24A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94027 Figure 3
C     Correlation factor Ke
C
C
C     Input
C     -----
C     X     - (Ll/c) / [(xl/c) - (xn/c)]
C
C     Output
C     ------
C     Z     - Ke
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'(Ll/c) / (xl/c - xn/c)',
     *' ',
     *'Ke',
     *'Figure 3 of Item 94027' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * -0.7,   0.9,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 3 of Item 94027
C     ---------------------------
      CALL FIG24B(X,Z,FOUND)
C
C     Store the data if FIG24B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3024
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG24B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94027 Figure 3
C     Correlation factor Ke
C
C
C     Input
C     -----
C     X     - (Ll/c) / [(xl/c) - (xn/c)]
C
C     Output
C     ------
C     Z     - Ke
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB24/ XMN,XMX,C(12)
C
      DATA N /12/
C
C     Calculate Z for the given X (if possible).
C     ------------------------------------------
      CALL A9F799(X,XMN,XMX,N,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB24
C     =================
C
C     Data for Item 94027 Figure 3
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB24/ XMN,XMX,C(12)
C
      DATA XMN,XMX /-0.7,0.9/
C
      DATA C /
     *.80159682E+00 ,-.11736125E+00 ,-.20594379E+00 ,-.18301038E-01 ,
     *-.13528405E-01 ,-.30752777E-02 ,-.14797408E-02 ,-.10227990E-02 ,
     *-.70183544E-03 ,-.53792120E-03 ,-.44408146E-04 ,.32382498E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG25A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94027 Figure 2b
C     Slats and vented Kruger flaps
C
C     Input
C     -----
C     X     - rhol/c sec(Lambda)
C
C     Output
C     ------
C     Z     - Kg
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'rho l / c sec(Lambda)',
     *' ',
     *'Kg',
     *'Figure 2b of Item 94027' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,  0.024,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 2b of Item 94027
C     ----------------------------
      CALL FIG25B(X,Z,FOUND)
C
C     Store the data if FIG25B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3025
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG25B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94027 Figure 2b
C     Slats and vented Kruger flaps
C
C     Input
C     -----
C     X     - rhol/c sec(Lambda)
C
C     Output
C     ------
C     Z     - Kg
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N,J
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB25/ XMN(2),XMX(2),C(16,2)
C
      DATA N /16/
C
C     Calculate Z for the given X (if possible).
C     ------------------------------------------
      DO 10 J = 1,2
      CALL A9F799(X,XMN(J),XMX(J),N,C(1,J),Z,FOUND)
      IF (FOUND .EQ. 1) GO TO 20
   10 CONTINUE
C
      IF (X .GE. 0.0 .AND. X .LE. 0.08) THEN
       FOUND = 1
       Z = 1.29
      END IF
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB25
C     =================
C
C     Data for Item 94027 Figure 2(b)
C     -------------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB25/ XMN(2),XMX(2),C(16,2)
C
      INTEGER I
C
      DATA XMN,XMX /0.008, 0.016, 0.0176, 0.024/
C
      DATA (C(I,1), I = 1,16) /
     *.16673971E+01 ,.52720100E+00 ,.11918725E+00 ,-.77921591E-01 ,
     *-.56461929E-01 ,.70549849E-03 ,.15490356E-01 ,.69369774E-02 ,
     *.13541573E-02 ,-.12008784E-02 ,-.21043490E-02 ,-.96144793E-03 ,
     *-.41222939E-03 ,-.25955174E-03 ,.59760322E-03 ,.70956320E-03 /
C
      DATA (C(I,2), I = 1,16) /
     *.19738897E+01 ,-.28620643E+00 ,-.95118184E-01 ,.27837379E-01 ,
     *-.31367389E-03 ,-.25784133E-02 ,.29169376E-03 ,-.69645539E-04 ,
     *.68028206E-03 ,-.26242980E-03 ,-.64075947E-03 ,.56069852E-03 ,
     *.25380853E-03 ,-.44213329E-03 ,-.46357489E-04 ,.24966729E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG26A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 94027 Figure 1b
C     Slats and vented Kruger flaps
C
C     Input
C     -----
C     X     - deltal cos(Lambda)
C     Y     - (Gl/c) sec(Lambda) degrees
C
C     Output
C     ------
C     Z     - Kl
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'delta l cos(Lambda)',
     *'(Gl/c) sec(Lambda)',
     *'Kl',
     *'Figure 1b of Item 94027' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 1, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 10.0,   58.0,  0.0,
     * 0.01,  0.06,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 1b of Item 94027
C     ----------------------------
      CALL FIG26B(X,Y,Z,FOUND)
C
C     Store the data if FIG26B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3026
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG26B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 94027 Figure 1b
C     Slats and vented Kruger flaps
C
C     Input
C     -----
C     X     - deltal cos(Lambda)
C     Y     - (Gl/c) sec(Lambda) degrees
C
C     Output
C     ------
C     Z     - Kl
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER     - order of polynomial for r.h.s
C     C1( )     - polynomial coeffts. of r.h.s
C     XMN1,XMX1 - minimum and maximum X of r.h.s
C     YMN1,YMX1 - minimum and maximum Y of r.h.s
C     N         - number of coeffts. in polynomial for l.h.s
C     YMN2,YMX2 - minimum and maximum of Y of l.h.s
C     C2(16)    - polynomial coeffts. for l.h.s
C
C     I         - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      INTEGER FOUND1,FOUND2
      REAL Z1,Z2
C
      INTEGER N
      REAL XMN1,XMX1,YMN1,YMX1,C1,YMN2,YMX2,C2
      COMMON /PLTB26/ XMN1,XMX1,YMN1,YMX1,C1(120),YMN2,YMX2,C2(16)
C
      DATA N /16/
C
      DATA ORDER/15/
C
C     Calculate Z for the given X and Y
C     ---------------------------------
      CALL A9E799(X,Y,XMN1,XMX1,YMN1,YMX1,ORDER,C1,Z1,FOUND1)
C
      CALL A9F799(Y,YMN2,YMX2,N,C2,Z2,FOUND2)
C
      FOUND = FOUND2
      Z = Z2
      IF (FOUND1 .EQ. 1) Z = AMIN1(Z,Z1)
C
C
      IF (X .LT. 10.0 .OR. X .GT. 58.0) FOUND = 0
      IF (Z .LT. 0.0) FOUND = 0
C
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB26
C     =================
C
C     Data for Item 94027 Figure 1(b)
C     -------------------------------
C
      REAL XMN1,XMX1,YMN1,YMX1,C1,YMN2,YMX2,C2
      COMMON /PLTB26/ XMN1,XMX1,YMN1,YMX1,C1(120),YMN2,YMX2,C2(16)
C
      INTEGER I
C
      DATA YMN2,YMX2 /0.01,0.06/
C
      DATA XMN1,XMX1,YMN1,YMX1/10,58.0,0.01,0.06/
C
      DATA (C1(I),I=1,40) /
     *.53323089E+00 ,-.16312537E+00,.12500812E-01 ,-.41197795E-02,
     *.17609499E-01 ,.13646571E-02 ,-.31774380E-02,.81237384E-03 ,
     *.88858730E-03 ,-.78025048E-03,-.57707133E-03,.11421595E-03 ,
     *.32636341E-03 ,.28063061E-03 ,-.83270984E-04,-.73052341E+00,
     *-.12153214E+00,-.78248789E-01,.13722618E-01 ,-.47105723E-01,
     *.20802376E-02 ,.51018493E-02 ,-.21391775E-02,-.10298583E-02,
     *.10733300E-02 ,.17013954E-02 ,-.14652022E-03,-.12846575E-02,
     *-.34003708E-03,-.41169303E-01,-.19428151E-01,.75749700E-01 ,
     *-.15554589E-01,.29353218E-01 ,.29432526E-02 ,-.37832785E-02,
     *.25393216E-03 ,.10074536E-02 ,-.15574415E-03,-.14559967E-02/
C
      DATA (C1(I),I=41,80) /
     *-.57242618E-03,.13984078E-02 ,-.18378044E-01,.13278429E-01 ,
     *-.68511639E-01,.66620550E-02 ,-.29298217E-01,-.19142720E-03,
     *.26728257E-02 ,-.10551196E-02,-.34753086E-04,.81188752E-03 ,
     *.56810577E-03 ,-.17815919E-03,.29175745E-01 ,-.16720581E-01,
     *.47334941E-01 ,.16480417E-02 ,.13291253E-01 ,.18025103E-02 ,
     *-.89040888E-03,.43058343E-03 ,-.38213766E-03,-.59392710E-03,
     *-.10388586E-04,-.20921294E-01,-.95953191E-03,-.30728818E-01,
     *-.87438260E-03,-.13769127E-01,.13804383E-02 ,.75482735E-03 ,
     *-.85958452E-03,.87545233E-03 ,.28359897E-03 ,.15841483E-01 ,
     *.36110778E-02 ,.18826378E-01 ,.58573460E-02 ,.24320631E-02 /
C
      DATA (C1(I),I=81,120) /
     *.38825118E-02 ,-.58797194E-03,-.13514170E-02,-.28943892E-04,
     *-.67806881E-02,-.87738197E-02,-.10395594E-01,-.46726834E-02,
     *-.35050353E-03,-.15178359E-02,-.27728470E-03,.85720604E-03 ,
     *.32482255E-02 ,.58042329E-02 ,.25069289E-02 ,.54532783E-02 ,
     *-.20083762E-03,.79367720E-03 ,-.28801134E-03,-.13706725E-02,
     *-.36863055E-02,-.21132212E-03,-.21950406E-02,.35194393E-03 ,
     *.31416155E-03 ,.93037572E-04 ,.23146443E-02 ,.31660421E-03 ,
     *-.56833503E-03,-.99101921E-03,.33087558E-03 ,.65974598E-03 ,
     *.25529210E-03 ,.87136269E-03 ,-.99979136E-03,-.14329849E-02,
     *-.87597085E-03,.37620189E-03 ,.11170729E-02 ,.49667261E-04 /
C
      DATA C2 /
     *.10273714E+01 ,.32403291E-01 ,-.67783192E-01 ,-.20866385E-02 ,
     *.22528050E-01 ,-.73980864E-02 ,-.11473620E-01 ,.23088846E-02 ,
     *.73016743E-02 ,.11156175E-03 ,-.49641824E-02 ,-.61822747E-03 ,
     *.33661899E-02 ,.36121443E-03 ,-.21967540E-02 ,-.48758896E-04 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG27A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94030 Figure 5
C     Correlation factor Kl for slats in presence
C     of trailing-edge slotted flaps
C
C     Input
C     -----
C     X     - delta l cos(Lambda 0) degrees
C
C     Output
C     ------
C     Z     - Kl
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'delta l cos(Lambda)',
     *' ',
     *'Kl',
     *'Figure 5 of Item 94030' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 15.0,  57.5,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 5 of Item 94030
C     ---------------------------
      CALL FIG27B(X,Z,FOUND)
C
C     Store the data if FIG27B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3027
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG27B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94030 Figure 5
C     Correlation factor Kl for slats in presence
C     of trailing-edge slotted flaps
C
C     Input
C     -----
C     X     - delta l cos(Lambda 0) degrees
C
C     Output
C     ------
C     Z     - Kl
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB27/ XMN,XMX,C(6)
C
      DATA N /6/
C
C     Calculate Z for the given X (if possible).
C     ------------------------------------------
      CALL A9F799(X,XMN,XMX,N,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB27
C     =================
C
C     Data for Item 94030 Figure 5
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB27/ XMN,XMX,C(6)
C
      DATA XMN,XMX /20.0,57.5/
C
      DATA C /
     *.50226494E+00 ,-.39661870E+00 ,-.13741242E-01 ,.93036593E-02 ,
     *-.39728106E-02 ,.21126837E-02/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG28A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94028 Figure 1
C     Efficiency factor Jp
C
C
C     Input
C     -----
C     X     - (deltat + phit) sec(Lambda2) degrees
C
C     Output
C     ------
C     Z     - Jp
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'(delta t + phi t) sec(Lambda2)',
     *' ',
     *'Jp',
     *'Figure 1 of Item 94028' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 5.0,   80.0,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 1 of Item 94028
C     ---------------------------
      CALL FIG28B(X,Z,FOUND)
C
C     Store the data if FIG28B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3028
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG28B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94028 Figure 1
C     Efficiency factor Jp
C
C
C     Input
C     -----
C     X     - (deltat + phit) sec(Lambda2) degrees
C
C     Output
C     ------
C     Z     - Jp
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z
C
      REAL XMN,XMX,C
      COMMON /PLTB28/ XMN,XMX,C(12)
C
      DATA N /12/
C
C     Calculate Z for the given X (if possible).
C     ------------------------------------------
      CALL A9F799(X,XMN,XMX,N,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB28
C     =================
C
C     Data for Item 94028 Figure 1
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB28/ XMN,XMX,C(12)
C
      DATA XMN,XMX /5.0,80.0/
C
      DATA C /
     *.55531354E+00 ,-.30631974E+00 ,.10477625E+00 ,-.34647521E-01 ,
     *.39103794E-02 ,.45414160E-02 ,-.15212393E-02 ,-.48171210E-03 ,
     *.83915670E-03 ,-.28868780E-03 ,-.41918329E-03 ,.36065485E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG29A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 94028 Figure 2
C     Theoretical parameter T
C
C     Input
C     -----
C     X     - ct/c'
C     Y     - x's/c'
C
C     Output
C     ------
C     Z     - T
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'ct/c',
     *'xs/c',
     *'T',
     *'Figure 2 of Item 94028' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,    0.5,  0.0,
     * 0.0,    0.25, 0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 2 of Item 94028
C     ---------------------------
      CALL FIG29B(X,Y,Z,FOUND)
C
C     Store the data if FIG29B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3029
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG29B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 94028 Figure 2
C     Theoretical parameter T
C
C     Input
C     -----
C     X     - ct/c'
C     Y     - x's/c'
C
C     Output
C     ------
C     Z     - T
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB29/ XMN,XMX,YMN,YMX,C(120)
C
      DATA ORDER/15/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB29
C     =================
C
C     Data for Item 94028 Figure 2
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB29/ XMN,XMX,YMN,YMX,C(120)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/0.0,0.5,0.0,0.25/
C
      DATA (C(I),I=1,40) /
     *.34861402E+00 ,-.10854067E+00,-.90532065E-02,-.10703025E-02,
     *-.17951652E-03,.19631486E-03 ,-.62842888E-05,-.91413625E-04,
     *.82909471E-05 ,.44802718E-04 ,.69308511E-05 ,-.15328530E-04,
     *-.89956614E-05,.26700404E-06 ,.26352661E-05 ,-.81895969E-01,
     *-.30851618E-01,-.46421143E-02,-.92370561E-03,-.59541722E-03,
     *.38165436E-04 ,.87358347E-04 ,-.62978894E-05,-.33664804E-04,
     *-.92174036E-05,.34318058E-04 ,.22872287E-04 ,-.21181204E-04,
     *-.23752879E-04,-.83623782E-02,-.45685264E-02,-.71527478E-03,
     *-.13391815E-03,-.80305761E-04,.86390357E-04 ,-.24699506E-04,
     *-.47789228E-04,.22396162E-04 ,.27960535E-04 ,-.81418756E-05/
C
      DATA (C(I),I=41,80) /
     *-.17113742E-04,.12547431E-05 ,-.13102494E-02,-.13627972E-02,
     *-.40902986E-03,-.21279978E-03,-.93715035E-04,.19492396E-03 ,
     *.52115284E-04 ,-.68397786E-04,-.31708100E-04,.12031917E-04 ,
     *.17966609E-04 ,.39828301E-05 ,-.31852312E-03,-.41441828E-03,
     *-.37196563E-04,.34961175E-03 ,.23266637E-03 ,.35032105E-04 ,
     *-.40605780E-04,-.29148600E-04,.14773533E-05 ,.10494211E-04 ,
     *-.36219897E-06,-.10309927E-03,-.81388354E-04,-.23066931E-03,
     *.79308811E-04 ,.44172742E-04 ,-.87565838E-04,-.39795731E-05,
     *.42175426E-04 ,.64920614E-05 ,-.13871053E-04,.98756385E-04 ,
     *.39194097E-04 ,-.30721337E-03,-.35774778E-04,-.65094478E-04/
C
      DATA (C(I),I=81,120) /
     *-.10102040E-03,.10057440E-04 ,.45789615E-04 ,.56024239E-05 ,
     *.10909766E-03 ,.75505514E-04 ,-.20343212E-03,-.32858566E-04,
     *-.31123972E-04,-.50086693E-04,.77442908E-06 ,.24939328E-04 ,
     *-.40623472E-04,.20875953E-04 ,-.75252232E-04,-.64358306E-04,
     *-.45665877E-05,.22934447E-05 ,-.30148158E-06,-.98540921E-04,
     *-.56594220E-04,.12880460E-04 ,-.39598837E-04,-.19727484E-06,
     *.31836088E-04 ,-.24408545E-04,-.40020066E-04,.79105197E-04 ,
     *.33608473E-04 ,.20971629E-05 ,.39367092E-04 ,.20029107E-04 ,
     *.86326873E-04 ,.53807957E-04 ,.25085968E-04 ,.17541911E-04 ,
     *.12979465E-04 ,-.39091054E-05,-.61770537E-05,-.18936817E-05/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG30A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94029 Figure 2
C     Datum value (Delta C'lmt)d for uncambered
C     aerofoil with ct/c=0.2 and deltat=60 degrees
C
C     Input
C     -----
C     X     - 0.5[(zu/c)125 - (zl/c)125] sec(Lambda)
C
C     Output
C     ------
C     Z     - (Delta C'lmt)d
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'0.5 [(zu/c)125 - (zl/c)125] sec(Lambda)',
     *' ',
     *'(Delta CLmt)d',
     *'Figure 2 of Item 94029' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.0,   0.08,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 2 of Item 94029
C     ---------------------------
      CALL FIG30B(X,Z,FOUND)
C
C     Store the data if FIG30B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3030
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG30B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94029 Figure 2
C     Datum value (Delta C'lmt)d for uncambered
C     aerofoil with ct/c=0.2 and deltat=60 degrees
C
C     Input
C     -----
C     X     - 0.5[(zu/c)125 - (zl/c)125] sec(Lambda)
C
C     Output
C     ------
C     Z     - (Delta C'lmt)d
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N         - number of coefficients
C     C1( )     - polynomial coefficients for left hand end
C     XMN1,XMX1 - minimum and maximum X of left hand end
C     C2( )     - polynomial coefficients for right hand end
C     XMN2,XMX2 - minimum and maximum X of right hand end
C                 (The two sections overlap)
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z
C
      REAL XMN1,XMX1,C1,XMN2,XMX2,C2
      COMMON /PLTB30/ XMN1,XMX1,C1(16),XMN2,XMX2,C2(16)
C
      DATA N /16/
C
      IF (X .GE. 0.0 .AND. X .LE. 0.005) THEN
       FOUND = 1
       Z = 0.9
      ELSE
C
C      Try the right hand first and then the left
C      ------------------------------------------
       CALL A9F799(X,XMN2,XMX2,N,C2,Z,FOUND)
       IF (FOUND .NE. 1) THEN
        CALL A9F799(X,XMN1,XMX1,N,C1,Z,FOUND)
       END IF
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB30
C     =================
C
C     Data for Item 94029 Figure 2
C     ----------------------------
C
      REAL XMN1,XMX1,C1,XMN2,XMX2,C2
      COMMON /PLTB30/ XMN1,XMX1,C1(16),XMN2,XMX2,C2(16)
C
      DATA XMN1,XMX1 /0.005,0.02/
      DATA XMN2,XMX2 /0.015,0.08/
C
      DATA C1 /
     *.89484204E+00 ,.67089319E-01 ,.11457863E+00 ,.40431416E-01 ,
     *-.14784434E-01 ,-.10330700E-01 ,.87020055E-02 ,.38944114E-02 ,
     *-.54033083E-02 ,-.14936446E-02 ,.33349796E-02 ,.55622774E-03 ,
     *-.20422486E-02 ,-.19305287E-03 ,.12152826E-02 ,.67719150E-04 /
C
      DATA C2 /
     *.14344130E+01 ,.35223588E+00 ,-.16460305E+00 ,.84878976E-01 ,
     *-.37600497E-01 ,.11257534E-01 ,.28630173E-02 ,-.53174939E-02 ,
     *.14037186E-02 ,.16013478E-02 ,-.21402230E-02 ,.14452072E-02 ,
     *.74912486E-05 ,-.11728387E-02 ,.10529987E-02 ,-.30548219E-03 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG31A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 91014 Figure 3b
C     Part-span factor for slotted flaps
C
C     Input
C     -----
C     X     - A tan(Lambda1/2) - 8 lambda
C     Y     - eta
C
C     Output
C     ------
C     Z     - Phi
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'A tan(Lambda1/2) - 8.0 lambda',
     *'eta',
     *'Phi o and Phi i',
     *'Figure 3b of Item 91014' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * -8.0,   4.0,  0.0,
     * 0.0,    1.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 3b of Item 91014
C     ----------------------------
      CALL FIG31B(X,Y,Z,FOUND)
C
C     Store the data if FIG31B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3031
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG31B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 91014 Figure 3b
C     Part-span factor for slotted flaps
C
C
C     Input
C     -----
C     X     - A tan(Lambda1/2) - 8 lambda
C     Y     - eta
C
C     Output
C     ------
C     Z     - Phi
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB31/ XMN,XMX,YMN,YMX,C(45)
C
      DATA ORDER/9/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB31
C     =================
C
C     Data for Item 91014 Figure 3(b)
C     -------------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB31/ XMN,XMX,YMN,YMX,C(45)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/-8.0,4.0,0.0,1.0/
C
      DATA (C(I),I=1,40) /
     *.55485311E+00 ,.49793808E+00 ,-.53234746E-01,.34964732E-02 ,
     *-.17739662E-02,-.20207847E-02,.19387405E-03 ,.76650183E-03 ,
     *-.13098537E-03,.19203422E-01 ,.14512674E-02 ,-.18921427E-01,
     *-.25423791E-02,-.32843820E-03,.15341404E-02 ,-.23101152E-04,
     *-.56986859E-03,.30364104E-02 ,.61254214E-03 ,-.31609245E-02,
     *-.94026087E-03,.12460993E-03 ,.46620518E-03 ,.50210173E-05 ,
     *.29488430E-04 ,.53553124E-06 ,-.16531648E-04,-.30041361E-04,
     *-.52812863E-05,.40016944E-04 ,-.58976860E-05,-.10710625E-06,
     *.33063297E-05 ,.60082723E-05 ,.10562573E-05 ,-.12450670E-04,
     *-.22611319E-06,.69800293E-05 ,.12684130E-04 ,-.34013110E-05/
C
      DATA (C(I),I=41,45) /
     *-.61770270E-07,.19068251E-05 ,.45246797E-05 ,.82171460E-07 ,
     *.42357474E-05/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG32A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 94030 Figure 3
C
C     Input
C     -----
C     X     - xum/c
C     Y     - (zu/c)125 sec(Lambda0)
C
C     Output
C     ------
C     Z     - KT
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'xum/c',
     *'(zu/c)125 sec(Lambda0)',
     *'KT',
     *'Figure 3 of Item 94030' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 0.25, 0.475,  0.0,
     * 0.0,  0.072,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 3 of Item 94030
C     ---------------------------
      CALL FIG32B(X,Y,Z,FOUND)
C
C     Store the data if FIG32B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3032
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG32B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 94030 Figure 3
C
C     Input
C     -----
C     X     - xum/c
C     Y     - (zu/c)125 sec(Lambda0)
C
C     Output
C     ------
C     Z     - KT
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     XX    - abs(X - 0.4)
C     YY    - = 0.008  if Y < 0.008
C             = 0.0188 if Y > 0.0188
C             = Y otherwise
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     Notes
C     -----
C     (1) The origin is moves to X = 0.4
C         If X >= 0.4 then XX = X - 0.4
C         If X <  0.4 then XX = (0.4 - X ) / 2.0
C     (2) Z is constant for Y <= 0.008
C     (3) Z is constant for Y >= 0.0188
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z,XX,YY
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB32/ XMN,XMX,YMN,YMX,C(120)
C
      DATA ORDER/15/
C
      IF (X .GE. 0.4) THEN
       XX = X - 0.4
      ELSE
       XX = (0.4 - X) / 2.0
      END IF
C
      IF (Y .LT. 0.008) THEN
       YY = 0.008
      ELSE
       IF (Y .GT. 0.0188) THEN
        YY = 0.0188
       ELSE
        YY = Y
       END IF
      END IF
C
C     Check that Y is in the range 0.0 to 0.072
      IF (Y .GE. 0.0 .AND. Y .LE. 0.072) THEN
C      Calculate Z for the given X and Y
       CALL A9E799(XX,YY,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
      ELSE
       FOUND = 0
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB32
C     =================
C
C     Data for Item 94030 Figure 3
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB32/ XMN,XMX,YMN,YMX,C(120)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/0.0,0.075,0.008,0.0188/
C
      DATA (C(I),I=1,40) /
     *.18097249E+01 ,.25475835E+00 ,.13866759E+00 ,.60904355E-01 ,
     *.23457138E-01 ,.81191491E-02 ,.17482165E-02 ,-.37684302E-03,
     *.75916966E-03 ,.22036419E-02 ,.17349739E-02 ,.22358211E-03 ,
     *-.77367490E-03,-.96285785E-03,-.63074097E-03,-.42551698E-01,
     *-.73413836E-01,-.46328492E-01,-.21858132E-01,-.89270739E-02,
     *-.35600380E-02,-.11962132E-02,-.13618274E-03,-.17533842E-03,
     *-.52040567E-03,-.43636993E-03,-.63755802E-04,.19575935E-03 ,
     *.26097272E-03 ,-.23341196E-03,-.39501538E-03,-.13763031E-03,
     *.80736091E-04 ,.16968166E-03 ,.24644554E-03 ,.22753748E-03 ,
     *.12017378E-03 ,.44385167E-05 ,-.52174683E-04,-.44657806E-04/
C
      DATA (C(I),I=41,80) /
     *-.10241880E-04,.14940986E-04 ,-.25775689E-03,-.46791437E-03,
     *-.36439112E-03,-.22369109E-03,-.89274930E-04,-.19789549E-04,
     *.28090949E-05 ,.17184833E-05 ,-.50784706E-05,-.67318725E-05,
     *-.16612154E-05,.45232972E-05 ,-.32498305E-04,-.51319667E-04,
     *-.22474107E-04,.13992322E-04 ,.41594612E-04 ,.42034216E-04 ,
     *.26002077E-04 ,.77621729E-05 ,-.39856305E-05,-.78340402E-05,
     *-.68526294E-05,-.12109989E-05,-.20449624E-05,.67887582E-05 ,
     *.10468485E-04 ,.51234712E-05 ,.36605305E-05 ,.55168305E-06 ,
     *-.29332858E-05,-.32784639E-05,-.38885771E-06,.11004341E-04 ,
     *.18467820E-04 ,.66285505E-05 ,-.39225709E-05,-.87588142E-05/
C
      DATA (C(I),I=81,120) /
     *-.11944978E-04,-.10487520E-04,-.52867568E-05,-.14789530E-07,
     *.11386730E-04 ,.20598615E-04 ,.12158882E-04 ,.45433324E-05 ,
     *.13705345E-05 ,-.87003553E-06,-.37790611E-06,.12837113E-05 ,
     *-.39824957E-05,-.72904391E-05,-.18525859E-05,.96571798E-06 ,
     *.20549010E-06 ,.30491854E-05 ,.47321785E-05 ,-.70578321E-05,
     *-.12795387E-04,-.91194726E-05,-.49601983E-05,-.18775478E-05,
     *-.15552659E-06,.10242950E-05 ,.22496834E-05 ,.13929453E-06 ,
     *.31756058E-07 ,.17768062E-05 ,.27105550E-05 ,.49315340E-05 ,
     *.45167435E-05 ,.32784988E-05 ,.26689674E-06 ,.17132234E-06 ,
     *.40974450E-06 ,-.76975738E-07,-.15909472E-06,-.71604760E-06/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG33A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94030 Figure 4
C
C     Input
C     -----
C     X     - delta t1 sec(Lambda h) degrees
C
C     Output
C     ------
C     Z     - Kt1
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'delta t1 sec(Lambda h)',
     *' ',
     *'Kt1',
     *'Figure 4 of Item 94030' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 0, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 2.4,   30.0,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 4 of Item 94030
C     ---------------------------
      CALL FIG33B(X,Z,FOUND)
C
C     Store the data if FIG33B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3033
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG33B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94030 Figure 4
C
C     Input
C     -----
C     X     - delta t1 sec(Lambda h) degrees
C
C     Output
C     ------
C     Z     - Kt1
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     XX      - XX = X    for X <= 25.0
C                  = 25.0 for X > 25.0
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z,XX
C
      REAL XMN,XMX,C
      COMMON /PLTB33/ XMN,XMX,C(16)
C
      DATA N /16/
C
C     Calculate Z for the given X
C     ---------------------------
      XX = AMIN1(X,25.0)
      CALL A9F799(XX,XMN,XMX,N,C,Z,FOUND)
      Z = AMAX1(Z,0.35)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB33
C     =================
C
C     Data for Item 94030 Figure 4
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB33/ XMN,XMX,C(16)
C
      DATA XMN,XMX /2.4,25.0/
C
      DATA C /
     *.56427520E+00 ,-.31823865E+00 ,.14899611E+00 ,-.73096113E-01 ,
     *.48784421E-01 ,-.36149936E-01 ,.26622355E-01 ,-.19628829E-01 ,
     *.15060000E-01 ,-.11980477E-01 ,.95554991E-02 ,-.73479863E-02 ,
     *.57197192E-02 ,-.47332348E-02 ,.36251321E-02 ,-.21833748E-02 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG34A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94031 Figure 9a
C
C     Input
C     -----
C     X     - delta t1 sec(Lambda h) degrees
C
C     Output
C     ------
C     Z     - Kt2
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'delta t1 sec(Lambda h)',
     *' ',
     *'Kt2',
     *'Figure 9a of Item 94031' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * -10.0, 40.0,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 9a of Item 94031
C     ----------------------------
      CALL FIG34B(X,Z,FOUND)
C
C     Store the data if FIG34B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3034
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG34B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 94031 Figure 9a
C
C     Input
C     -----
C     X     - delta t1 sec(Lambda h) degrees
C
C     Output
C     ------
C     Z     - Kt2
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     XX      - XX = X    for X <= 21.5
C               XX = 21.5 for X > 21.5
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z,XX
C
      REAL XMN,XMX,C
      COMMON /PLTB34/XMN,XMX,C(12)
C
      DATA N /12/
C
C     Calculate Z for the given X
C     ---------------------------
      XX = AMIN1(X,21.5)
      CALL A9F799(XX,XMN,XMX,N,C,Z,FOUND)
      Z = AMAX1(Z,0.14)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB34
C     =================
C
C     Data for Item 94031 Figure 9(a)
C     -------------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB34/XMN,XMX,C(12)
C
      DATA XMN,XMX /-10.0,21.5/
C
      DATA C /
     *.23297592E+00 ,-.85366010E-01 ,-.12006453E-01 ,.59164884E-02 ,
     *-.13905327E-02 ,-.63469834E-03 ,.69158152E-03 ,-.23066239E-04 ,
     *-.37814704E-03 ,.25677537E-03 ,.71779473E-04 ,-.22640606E-03 /
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE FIG35A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 94031 Figure 9b
C
C     Input
C     -----
C     X     - delta t3 sec(Lambda h)
C
C     Output
C     ------
C     Z     - Kt3
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'delta t3 sec(Lambda h)',
     *' ',
     *'Kt3',
     *'Figure 9b of Item 94031' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 7.0,   38.0,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
C     Z is a constant from X = 7.0 to X = 38.0
C     and out of range everywhere else
C     ----------------------------------------
      FAULT = 0
      WXYZ(3,2) = X
      Z = 0.08
      IF (X .LT. 7.0 .OR. X .GT. 38.0) THEN
       FAULT = 3035
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG36A(X,Z,FAULT)
C     ============================
C
C     Purpose
C     -------
C     Item 96003 Figure 1
C
C     Input
C     -----
C     X     - log10(R)
C
C     Output
C     ------
C     Z     - N
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'log10(R)',
     *' ',
     *'N',
     *'Figure 1 of Item 96003' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 0, 1,
     * 0, 0, 0,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 5.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
C
C     Read Figure 1 of Item 96003
C     ---------------------------
      CALL FIG36B(X,Z,FOUND)
C
C     Store the data if FIG36B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3036
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG36B(X,Z,FOUND)
C     ============================
C
C     Purpose
C     -------
C     Item 96003 Figure 1
C
C     Input
C     -----
C     X     - log10(R)
C
C     Output
C     ------
C     Z     - N
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     N       - number of coefficients
C     C( )    - polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     XX      - XX = X   for X <= 8.0
C             - XX = 8.0 for X > 8.0
C
C     Subroutine Called
C     -----------------
C     A9F799    - evaluation of a Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND,N
      REAL X,Z,XX
C
      REAL XMN,XMX,C
      COMMON /PLTB36/ XMN,XMX,C(11)
C
      DATA N /11/
C
C     Calculate Z for the given X
C     ---------------------------
      XX = AMIN1(X,8.0)
      CALL A9F799(XX,XMN,XMX,N,C,Z,FOUND)
      Z = AMAX1(Z,0.0)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB36
C     =================
C
C     Data for Item 96003 Figure 1
C     ----------------------------
C
      REAL XMN,XMX,C
      COMMON /PLTB36/ XMN,XMX,C(11)

      DATA XMN,XMX /5.0,8.0/
C
      DATA C /
     *.59994071E+00 ,-.51586115E+00 ,-.10391677E+00 ,.17452766E-01 ,
     *.38933935E-02 ,-.17123832E-02 ,.64783953E-03 ,-.58746966E-04 ,
     *-.96104840E-03 ,.34246984E-03 ,.60432730E-03/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG37A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 98011 Figure 1
C     Viscous correction factor kv
C
C     Input
C     -----
C     X     - log10(Zc92/Zc50)
C     Y     - log10(R)
C
C     Output
C     ------
C     Z     - kv
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'Zc92 / Zc50',
     *'log10(R)',
     *'kv',
     *'Figure 1 of Item 98011' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * -1.0,   1.0,  0.0,
     * 6.0,    8.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 1 of Item 98011
C     ---------------------------
      CALL FIG37B(X,Y,Z,FOUND)
C
C     Store the data if FIG37B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3037
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG37B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 98011 Figure 1
C     Viscous correction factor kv
C
C     Input
C     -----
C     X     - log10(Zc92/Zc50)
C     Y     - log10(R)
C
C     Output
C     ------
C     Z     - kv
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB37/ XMN,XMX,YMN,YMX,C(120)
C
      DATA ORDER/15/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB37
C     =================
C
C     Data for Item 98011 Figure 1
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB37/ XMN,XMX,YMN,YMX,C(120)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/-1.0,1.0,6.0,8.0/
C
      DATA (C(I),I=1,40) /
     *.84055621E+00 ,.77643177E-01 ,-.10365327E-01,-.57297521E-04,
     *.24156547E-03 ,-.13332792E-03,.10389810E-03 ,.60743923E-04 ,
     *-.42258730E-04,-.10242148E-04,.74453187E-05 ,-.79855500E-05,
     *-.30514937E-05,.65128636E-05 ,.30550085E-05 ,-.12762299E+00,
     *.52559468E-01 ,-.12496616E-01,-.22759970E-03,.29843500E-03 ,
     *-.13245425E-03,.11017306E-03 ,.65814870E-04 ,-.44557901E-04,
     *-.12975434E-04,.68453309E-05 ,-.68777556E-05,-.27250697E-05,
     *.61077361E-05 ,-.38061890E-06,-.43780282E-06,-.41307476E-07,
     *-.16853017E-06,.78155673E-07 ,.54070674E-06 ,.24513759E-06 ,
     *.92805071E-07 ,.25717946E-06 ,.59093579E-07 ,-.17502608E-06/
C
      DATA (C(I),I=41,80) /
     *-.12983460E-06,-.16161928E-07,.49772769E-07 ,.32157589E-06 ,
     *-.69026086E-07,-.92751337E-07,.58582777E-07 ,-.27167686E-06,
     *-.88465330E-07,.45294322E-07 ,.61000495E-07 ,-.28466957E-07,
     *.24913054E-07 ,.61377362E-07 ,.46817620E-07 ,.10383374E-06 ,
     *.16300477E-07 ,.73137423E-07 ,-.43175174E-07,-.38424987E-07,
     *.73381715E-07 ,-.20109157E-06,-.10855646E-06,.70432909E-07 ,
     *-.61230816E-07,-.87357276E-07,-.21508907E-06,-.42408474E-07,
     *-.14695166E-06,.10160738E-07 ,.19767292E-06 ,-.26673583E-07,
     *.23163224E-06 ,.22200928E-06 ,-.40111831E-07,.14948855E-06 ,
     *.32330349E-06 ,.18733996E-07 ,.64532402E-07 ,-.56667825E-07/
C
      DATA (C(I),I=81,120) /
     *-.29169427E-06,.41644582E-07 ,-.15185199E-06,-.25639925E-06,
     *-.65823703E-07,-.19625545E-06,-.27375207E-07,-.80639952E-08,
     *.28515351E-07 ,.19560858E-06 ,.96097450E-08 ,.39457972E-07 ,
     *.39499961E-07 ,.77319492E-08 ,-.25999420E-07,.83212416E-07 ,
     *-.22332501E-07,-.87670577E-07,.17465314E-07 ,.10661084E-07 ,
     *.14818409E-06 ,.27867669E-08 ,.25445583E-07 ,.14515195E-08 ,
     *-.11415427E-06,-.51905475E-07,-.96501638E-07,.18866301E-08 ,
     *-.81777958E-07,-.35777525E-08,.39040734E-07 ,-.32643397E-07,
     *.37761711E-07 ,-.14417430E-07,-.10554601E-07,.18472262E-07 ,
     *-.15498669E-07,-.19555889E-07,.91507145E-08 ,.17734403E-07 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG38A(X,Y,Z,FAULT)
C     ==============================
C
C     Purpose
C     -------
C     Item 98011 Figure 2
C     Compressibility correction factor kM0
C
C     Input
C     -----
C     X     - log10(R)
C     Y     - M
C
C     Output
C     ------
C     Z     - kM0
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *' ',
     *'log10(R)',
     *'M',
     *'kM0',
     *'Figure 2 of Item 98011' /
C
      DATA FLAGS /
     * 0, 0, 0,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.0,  0.0,
     * 6.0,    8.0,  0.0,
     * 0.0,    0.6,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figure 2 of Item 98011
C     ---------------------------
      CALL FIG38B(X,Y,Z,FOUND)
C
C     Store the data if FIG38B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3038
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG38B(X,Y,Z,FOUND)
C     ==============================
C
C     Purpose
C     -------
C     Item 98011 Figure 2
C     Compressibility correction factor kM0
C
C     Input
C     -----
C     X     - log10(R)
C     Y     - M
C
C     Output
C     ------
C     Z     - kM0
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER   - order of polynomial
C     C( )    - ORDER * (ORDER + 1) / 2 polynomial coefficients
C     XMN,XMX - minimum and maximum X
C     YMN,YMX - minimum and maximum Y
C     I       - array index
C
C     Subroutine Called
C     -----------------
C     A9E799   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB38/ XMN,XMX,YMN,YMX,C(120)
C
      DATA ORDER/15/
C
C     Calculate Z for the given X and Y (if possible).
C     ------------------------------------------------
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C
      Z = AMIN1(Z,1.0)
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB38
C     =================
C
C     Data for Item 98011 Figure 2
C     ----------------------------
C
      REAL XMN,XMX,YMN,YMX,C
      COMMON /PLTB38/ XMN,XMX,YMN,YMX,C(120)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/6.0,8.0,0.0,0.6/
C
      DATA (C(I),I=1,40) /
     *.96561993E+00 ,-.48137053E-01,-.17732079E-01,-.48967755E-02,
     *-.11550450E-02,-.24129011E-03,.43257736E-04 ,.49793818E-04 ,
     *-.11356598E-04,.47946970E-05 ,.37042064E-04 ,.26404322E-04 ,
     *-.61644402E-05,-.18663618E-04,-.20749656E-04,.19573769E-01 ,
     *.24696105E-01 ,.65583125E-02 ,.17381043E-02 ,.37039319E-03 ,
     *.65807582E-04 ,-.21489967E-04,-.16086749E-04,.85095645E-05 ,
     *.44566417E-06 ,-.13598736E-04,-.99684817E-05,.21358748E-05 ,
     *.61728967E-05 ,-.42245261E-02,-.53684053E-02,-.14470187E-02,
     *-.34446671E-03,-.46696471E-04,-.40576480E-05,.48110603E-05 ,
     *.20875900E-05 ,-.31687857E-05,-.84517221E-06,.27391937E-05 /
C
      DATA (C(I),I=41,80) /
     *.21303318E-05 ,-.36283232E-06,.23724624E-04 ,.36746848E-04 ,
     *.96399458E-05 ,-.17500404E-04,-.28995822E-04,-.23217797E-04,
     *-.86871489E-05,.31423624E-05 ,.58436013E-05 ,.22802873E-05 ,
     *-.92255996E-06,-.11995762E-05,-.10461423E-05,-.14755757E-04,
     *-.26654670E-06,.81034457E-05 ,.48316899E-06 ,.92904265E-05 ,
     *.14151099E-05 ,-.27373652E-05,-.77859170E-07,.26339877E-06 ,
     *-.66317869E-06,-.70898613E-05,-.10575234E-04,-.27626765E-05,
     *.46441977E-05 ,.83132647E-05 ,.66076712E-05 ,.20606122E-05 ,
     *-.11528933E-05,-.15891860E-05,-.56884875E-06,.64898300E-05 ,
     *.22760816E-04 ,.26797687E-05 ,-.11747191E-04,-.67618004E-05/
C
      DATA (C(I),I=81,120) /
     *-.13472704E-04,-.26240337E-05,.39147918E-05 ,.16746245E-05 ,
     *-.77286984E-05,-.11522076E-04,-.22775393E-05,.61598491E-05 ,
     *.92767474E-05 ,.68738005E-05 ,.18714646E-05 ,-.17465189E-05,
     *.55012271E-05 ,-.42989894E-05,.10954502E-05 ,.21043994E-05 ,
     *-.76191951E-05,.28251085E-05 ,.10477735E-06 ,.27556360E-05 ,
     *.41545632E-05 ,.91221802E-06 ,-.20949673E-05,-.34879549E-05,
     *-.30279404E-05,-.78780135E-05,-.45497715E-07,-.25121759E-05,
     *-.90455879E-06,.10065583E-04 ,.22477420E-05 ,.35886210E-05 ,
     *.13723224E-05 ,-.10388050E-05,.37900820E-05 ,-.48091447E-05,
     *.86104400E-06 ,-.18983576E-05,-.29975352E-05,-.12756835E-05/
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG39A(W,X,Y,Z,FAULT)
C     ================================
C
C     Purpose
C     -------
C     Item 97020 Figures 1 to 6
C     [(a1)V / (a1)T]
C
C     Input
C     -----
C     W     - xtr/c
C     X     - tan(tau a / 2 * beta)
C     Y     - log10(R)
C
C     Output
C     ------
C     Z     - [(a1)V / (a1)T] sym
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL W,X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *'Xtr/C',
     *'tan(tau a / 2 beta)',
     *'log10(R)',
     *'[(a1)V / (a1)T] sym',
     *'Figures 1 to 6 of Item 97020' /
C
      DATA FLAGS /
     * 1, 1, 1,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 0.0,    0.5,  0.0,
     * 0.0,    0.2,  0.0,
     * 6.0,    8.0,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,1) = W
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figures 1 to 6 of Item 97020
C     ---------------------------------
      CALL FIG39B(W,X,Y,Z,FOUND)
C
C     Store the data if FIG??B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3039
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG39B(W,X,Y,Z,FOUND)
C     ================================
C
C     Purpose
C     -------
C     Item 97020 Figures 1 to 6
C     [(a1)V / (a1)T]
C
C     Input
C     -----
C     W     - xtr/c
C     X     - tan(tau a / 2 * beta)
C     Y     - log10(R)
C
C     Output
C     ------
C     Z     - [(a1)V / (a1)T]
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER     - order of polynomial
C     C(120,6)  - polynomial coefficients for W = 0, .1, .2, .3, .4, .5
C     WW(6)     - W for each plot
C     ZZ(6)     - Z for W = 0, .1, .2, .3, .4, .5
C     N         - number of plots (6)
C     K         - plot number
C     XMN,XMX   - minimum and maximum X
C     YMN,YMX   - minimum and maximum Y
C     I         - array index
C
C     Subroutine Called
C     -----------------
C     ZVSXY   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER,K,N
      REAL X,Y,Z,ZZ(6)
C
      REAL XMN,XMX,YMN,YMX,C,WW,W
      COMMON /PLTB39/ XMN,XMX,YMN,YMX,C(120,6),WW(6)
C
      DATA ORDER,N / 15, 6 /
C
C     Calculate Z for each WW
C     -----------------------
      DO 10 K = 1,N
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C(1,K),ZZ(K),FOUND)
      IF (FOUND .NE. 1) GO TO 20
   10 CONTINUE
C
C     Fit a curve to the six points (WW(K),ZZ(K))
C     and interpolate for Z at the given W
C     -------------------------------------------
      CALL A9G799(N,WW,ZZ,W,Z,FOUND)
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB39
C     =================
C
C     Data for Item 97020 Figures 1 to 6
C     ----------------------------------
C
      REAL XMN,XMX,YMN,YMX,C,WW
      COMMON /PLTB39/ XMN,XMX,YMN,YMX,C(120,6),WW(6)
C
      INTEGER I
C
      DATA WW / 0.0, 0.1, 0.2, 0.3, 0.4, 0.5 /
C
      DATA XMN,XMX,YMN,YMX/0.0,0.2,6.0,8.0/
C
      DATA (C(I,1),I=1,40) /
     *.93655282E+00 ,.21580366E-01 ,-.25188233E-02,.22879217E-05 ,
     *-.39658074E-05,.20240708E-05 ,.53540813E-06 ,-.14882526E-05,
     *.32694587E-05 ,.19750297E-05 ,-.43451744E-05,-.15094997E-05,
     *.34794870E-05 ,.49996169E-06 ,-.19131090E-05,-.54604270E-01,
     *.17915123E-01 ,-.18438334E-02,-.13382482E-04,.63670854E-05 ,
     *.16670227E-04 ,.17827675E-05 ,.11587180E-04 ,.14882923E-05 ,
     *-.30414928E-05,-.90986290E-06,-.36852867E-05,.17981636E-06 ,
     *.29395972E-05 ,-.94086849E-02,.20185992E-02 ,-.19652302E-03,
     *-.40815970E-05,.10382506E-04 ,-.34837351E-05,-.29150663E-05,
     *-.98594574E-06,-.38196151E-05,.51769217E-05 ,.24288883E-05 /
C
      DATA (C(I,1),I=41,80) /
     *-.52698533E-05,.11479567E-05 ,.50816135E-04 ,-.10904292E-04,
     *.21462882E-04 ,-.79260789E-05,.25233993E-05 ,.35036669E-06 ,
     *-.32682937E-05,.19054868E-05 ,.15197479E-05 ,.51076458E-06 ,
     *-.52680136E-08,-.19424549E-05,-.17937674E-03,.60963371E-04 ,
     *.23470838E-04 ,.51096102E-05 ,.85977749E-05 ,-.80937188E-05,
     *.24223682E-05 ,.27023212E-05 ,-.51109629E-05,.12852418E-05 ,
     *.34306689E-05 ,.52309203E-04 ,.12620388E-04 ,-.48516399E-04,
     *.83732005E-06 ,.82041583E-05 ,-.51716707E-05,-.16031918E-08,
     *.26904827E-05 ,.25671297E-05 ,-.45087083E-05,.77348422E-04 ,
     *-.36473500E-04,-.21704642E-04,-.89104787E-05,.41339550E-05 /
C
      DATA (C(I,1),I=81,120) /
     *-.19857065E-05,.93111609E-05 ,.16840498E-05 ,.30665375E-05 ,
     *-.22062649E-04,-.21706190E-04,.40599460E-04 ,.68633407E-05 ,
     *.25859220E-06 ,-.28621048E-05,-.18171343E-05,.81883815E-06 ,
     *-.61138883E-05,-.35346596E-04,.15949236E-04 ,.28288087E-05 ,
     *.38418117E-05 ,-.36590481E-06,-.32924015E-05,-.12989533E-04,
     *-.16405340E-04,-.64960654E-05,.61837018E-06 ,-.10915595E-05,
     *.25284027E-06 ,-.99339377E-05,.24781924E-04 ,-.65544259E-05,
     *.36288289E-06 ,-.37138009E-05,.21367325E-04 ,.29023941E-04 ,
     *-.10043571E-04,-.38291996E-05,.55851747E-05 ,.57402799E-05 ,
     *-.37562547E-06,-.10993748E-04,-.15985242E-04,-.26018458E-05/
C
      DATA (C(I,2),I=1,40) /
     *.94658726E+00 ,-.44251606E-01,-.58441069E-02,-.18855414E-05,
     *-.40330930E-05,-.34587215E-05,.25714401E-05 ,.59998862E-05 ,
     *.22735553E-05 ,-.15805418E-05,-.29447059E-05,-.11620162E-05,
     *.18104643E-05 ,.90292796E-06 ,-.10196538E-05,.19783424E-01 ,
     *.16645314E-01 ,.12893843E-02 ,.14289716E-05 ,.51279868E-05 ,
     *-.15269579E-06,-.15886708E-05,-.17975287E-05,.32133138E-05 ,
     *.26184589E-05 ,.85756693E-06 ,-.12937820E-05,-.38728200E-05,
     *.43174500E-06 ,-.25144795E-02,-.22073237E-02,-.19530520E-03,
     *-.14008288E-05,-.17767224E-05,.42341089E-05 ,.41209143E-05 ,
     *.19724749E-05 ,.10072084E-06 ,-.28053483E-05,-.31457842E-06/
C
      DATA (C(I,2),I=41,80) /
     *.15814689E-05 ,-.73198346E-06,-.25406710E-05,.19519305E-05 ,
     *.99168941E-06 ,.22008999E-05 ,.16896065E-05 ,-.38261761E-05,
     *-.81743609E-05,-.26589673E-05,.24791700E-05 ,.87883945E-06 ,
     *.19211144E-06 ,.94529413E-06 ,.57678421E-05 ,.56961818E-05 ,
     *-.78339769E-06,-.70701149E-06,-.55933908E-06,-.75799012E-06,
     *.35774904E-05 ,.40490279E-06 ,-.37811542E-05,-.14358403E-05,
     *.24721414E-05 ,.39204425E-05 ,.22092090E-05 ,.50774784E-05 ,
     *.30776700E-05 ,-.12917979E-05,.41424194E-05 ,.51396927E-05 ,
     *.44864302E-05 ,.15557440E-05 ,-.78052416E-06,.32714832E-05 ,
     *-.65634713E-05,-.46736727E-05,-.22469592E-07,.12498739E-05 /
C
      DATA (C(I,2),I=81,120) /
     *.62957088E-06 ,-.27229945E-05,-.49721848E-05,-.54295112E-07,
     *.84185262E-07 ,-.55384441E-07,-.16094638E-05,.76894748E-06 ,
     *.58746386E-05 ,.40496132E-05 ,.43899538E-05 ,-.57680250E-06,
     *-.54190327E-05,-.56441817E-05,.56361757E-06 ,-.22117704E-05,
     *-.36237453E-05,-.66911582E-06,.29085897E-05 ,-.15737741E-05,
     *.92140253E-06 ,.33265545E-05 ,-.54562025E-06,.47763276E-06 ,
     *-.77293326E-06,.32988415E-05 ,.57684324E-05 ,.12145769E-05 ,
     *.14485013E-05 ,.16113426E-05 ,.20414491E-05 ,-.41750981E-07,
     *-.28760622E-05,.93357301E-06 ,-.13576429E-05,-.28971458E-05,
     *-.18929965E-05,-.11181801E-05,-.25603937E-06,.70540121E-06 /
C
      DATA (C(I,3),I=1,40) /
     *.95491661E+00 ,-.37211784E-01,-.51914183E-02,.14281853E-05 ,
     *.40459778E-05 ,.51954081E-05 ,.55091014E-05 ,.59062610E-06 ,
     *-.30101362E-05,-.24834908E-05,.38424330E-07 ,.22501552E-05 ,
     *.12759100E-05 ,-.11697913E-05,-.14232377E-05,.18298693E-01 ,
     *.15566626E-01 ,.17314023E-02 ,-.23237859E-05,.95239413E-06 ,
     *-.50340634E-06,-.45321024E-05,.22760229E-05 ,.38524627E-05 ,
     *.19632452E-05 ,-.87430918E-06,-.32609245E-05,-.11030528E-05,
     *.17545365E-05 ,-.24700529E-02,-.24019965E-02,-.29510840E-03,
     *.62472312E-05 ,.55705315E-05 ,.15734002E-05 ,-.11295580E-05,
     *-.10010205E-06,.31754896E-05 ,.21517209E-05 ,-.17278762E-05/
C
      DATA (C(I,3),I=41,80) /
     *-.26536744E-05,-.10422028E-05,-.14070362E-05,.26898674E-05 ,
     *.83574928E-05 ,-.51701681E-05,-.39966796E-05,.13274132E-05 ,
     *.98278134E-06 ,.58342858E-06 ,-.65263428E-06,.14964928E-05 ,
     *.10820104E-05 ,-.21047477E-05,.16945283E-05 ,.41504175E-05 ,
     *.13068364E-05 ,.21644190E-05 ,-.77833487E-06,-.76742355E-06,
     *-.27239388E-05,-.26026092E-06,.50747835E-06 ,-.99988898E-06,
     *-.60424800E-06,.54804188E-05 ,.25083001E-05 ,-.24746798E-05,
     *.31310973E-05 ,.16298295E-05 ,.90258177E-06 ,.28122555E-05 ,
     *-.15924446E-05,.15673069E-05 ,.34054093E-05 ,-.60345054E-06,
     *.57609217E-05 ,.82638380E-06 ,-.54409033E-05,-.43767832E-05/
C
      DATA (C(I,3),I=81,120) /
     *-.33463816E-05,-.18551982E-05,.26256374E-05 ,.61508947E-06 ,
     *-.17759493E-06,.38013416E-06 ,.68113375E-05 ,-.40191664E-06,
     *-.57532034E-06,.34808869E-05 ,.28166177E-05 ,-.29007376E-05,
     *.99177358E-06 ,.97811707E-06 ,.49965896E-05 ,-.10195058E-05,
     *-.26054597E-05,-.51335234E-05,-.19071151E-07,.30051038E-05 ,
     *.48491983E-05 ,.79909746E-06 ,-.10915202E-05,-.25173010E-05,
     *-.18451400E-05,-.16587800E-05,-.20838448E-05,-.49260326E-05,
     *.26275412E-05 ,.35789065E-05 ,-.35378474E-05,-.60472730E-05,
     *-.38393963E-05,.14478817E-05 ,.10356719E-05 ,.62982858E-06 ,
     *.23099637E-05 ,.17606501E-05 ,.32583723E-05 ,-.36173018E-06/
C
      DATA (C(I,4),I=1,40) /
     *.96202343E+00 ,.17068489E-01 ,-.26314899E-02,-.30186743E-05,
     *.12710349E-05 ,-.84216639E-05,.61390962E-05 ,-.37097848E-05,
     *.47884698E-05 ,.24587600E-06 ,-.34663131E-05,.16662436E-05 ,
     *-.21086094E-05,-.91272594E-06,.40682255E-05 ,-.30348362E-01,
     *.14157054E-01 ,-.23518379E-02,-.23596776E-05,.67947996E-05 ,
     *-.35109624E-06,.14615840E-04 ,-.86195256E-05,-.40253382E-05,
     *.33091296E-05 ,-.40175026E-06,.89463260E-06 ,.15096449E-05 ,
     *-.12901375E-05,-.44573502E-02,.20096431E-02 ,-.24667535E-03,
     *-.16836663E-05,.16489190E-05 ,-.30938143E-05,.33340610E-05 ,
     *.12146511E-05 ,.56892884E-06 ,-.23782313E-05,-.13513581E-05/
C
      DATA (C(I,4),I=41,80) /
     *.25591206E-05 ,.13175439E-05 ,.21503554E-04 ,.43162146E-05 ,
     *-.11838682E-04,-.84723562E-05,.45327590E-06 ,.31186210E-05 ,
     *.32130681E-05 ,-.48033402E-05,.16459924E-05 ,.22125938E-05 ,
     *-.92599371E-06,-.70148242E-06,-.17825006E-04,-.97675966E-05,
     *-.55654645E-05,.73319825E-05 ,.21927973E-05 ,.49416585E-05 ,
     *.21947703E-05 ,.19887666E-05 ,.14799988E-05 ,-.31445329E-05,
     *-.13020633E-05,.24410801E-04 ,-.26738515E-04,-.49867617E-05,
     *-.48341969E-05,.67336466E-05 ,-.62256144E-05,-.85241418E-05,
     *-.41857174E-05,-.17100398E-05,.34717133E-05 ,.11500606E-04 ,
     *.65244421E-05 ,-.49634383E-05,.10260002E-04 ,.89916095E-06 /
C
      DATA (C(I,4),I=81,120) /
     *.13020966E-05 ,.44615161E-06 ,-.41883595E-05,.28076420E-06 ,
     *-.37800929E-04,.71016771E-05 ,-.39039889E-05,.10297441E-04 ,
     *.35444249E-05 ,-.81800834E-06,.13092993E-05 ,.53166632E-05 ,
     *-.20370662E-04,.96980299E-05 ,-.46476716E-05,-.56925104E-05,
     *-.15408134E-06,.27865507E-05 ,.30326409E-06 ,-.12401489E-05,
     *.81824164E-05 ,.60254471E-05 ,-.26700414E-05,.12188239E-05 ,
     *-.85285533E-06,.98184277E-05 ,-.79832483E-05,.34683685E-05 ,
     *.10220980E-05 ,-.76366289E-06,.17357836E-04 ,-.10776199E-04,
     *-.49884216E-05,-.12567652E-05,.54595835E-06 ,.92621377E-06 ,
     *.54341568E-06 ,-.10414248E-04,.58883290E-05 ,-.34779729E-05/
C
      DATA (C(I,5),I=1,40) /
     *.96570203E+00 ,.16248161E-01 ,-.28502838E-02,.21256665E-06 ,
     *-.31622247E-05,.29636123E-05 ,-.47919063E-05,-.19305522E-05,
     *.32330505E-05 ,.58314174E-06 ,-.18167408E-05,-.29736158E-06,
     *-.98272636E-06,-.15807521E-06,.23215859E-05 ,-.27692961E-01,
     *.14712063E-01 ,-.28143965E-02,-.16555584E-04,-.32402063E-05,
     *.20734844E-06 ,.38976805E-05 ,-.18926575E-05,.18683538E-05 ,
     *.26866209E-05 ,-.19655931E-05,-.21262756E-05,.24146068E-05 ,
     *.13038458E-05 ,-.52727840E-02,.25848668E-02 ,-.42819661E-03,
     *.13536635E-05 ,-.28851650E-05,.29815856E-05 ,-.78219475E-05,
     *.75112206E-05 ,-.72354918E-05,.20962818E-05 ,.67693495E-05 /
C
      DATA (C(I,5),I=41,80) /
     *-.74985406E-05,-.25063537E-05,.30586225E-04 ,-.59336101E-04,
     *.55134322E-04 ,-.13491422E-04,-.11185052E-04,-.80666511E-05,
     *.23947212E-05 ,-.97083215E-06,-.22853643E-05,.48326501E-05 ,
     *.14927805E-05 ,-.47091591E-05,-.88369377E-05,.11370410E-04 ,
     *-.18455336E-04,.94729123E-05 ,.46846757E-05 ,-.61061866E-05,
     *.60831064E-05 ,-.89447573E-06,-.44403840E-05,.87855579E-06 ,
     *.16366918E-05 ,-.33571089E-04,.40622728E-04 ,-.38254625E-04,
     *.61827821E-05 ,.10905570E-04 ,.99585279E-05 ,.18385905E-05 ,
     *-.24557080E-05,.82534407E-06 ,.32384524E-06 ,.35496891E-05 ,
     *.15371948E-05 ,.37558319E-05 ,.54184271E-05 ,-.10674187E-04/
C
      DATA (C(I,5),I=81,120) /
     *-.32217844E-05,.28256821E-05 ,-.64692916E-05,-.63692134E-05,
     *-.21123172E-07,.12714920E-04 ,.44164312E-05 ,-.11242271E-04,
     *-.15132974E-05,-.61149018E-05,-.70237897E-05,.37297818E-05 ,
     *.20314270E-04 ,.53343279E-05 ,-.15070210E-04,-.40736057E-05,
     *-.31338043E-05,-.51216280E-06,-.44613527E-06,.10641224E-04 ,
     *-.83632249E-05,-.80819471E-05,.47626813E-05 ,.39155111E-05 ,
     *-.18754374E-06,-.12597524E-04,-.76081826E-05,.10862568E-05 ,
     *.31009686E-05 ,.83171193E-05 ,-.10399613E-04,.40833992E-06 ,
     *.99894557E-05 ,.31892488E-06 ,-.36252401E-05,.57577166E-05 ,
     *.14753390E-04 ,.49946368E-05 ,.58953369E-06 ,.89879982E-05 /
C
      DATA (C(I,6),I=1,40) /
     *.96851360E+00 ,.15784505E-01 ,-.28191413E-02,-.30002358E-05,
     *-.56392321E-06,-.70967531E-05,-.63750884E-06,.38099517E-06 ,
     *.35069958E-05 ,.28715119E-06 ,-.28599593E-05,.64590693E-06 ,
     *.23701111E-06 ,-.61819246E-06,.10428120E-05 ,-.28867974E-01,
     *.15554044E-01 ,-.33860556E-02,-.27991203E-05,-.96344607E-05,
     *-.48198754E-06,.58419268E-05 ,-.97657491E-05,.32986552E-06 ,
     *.39825423E-07 ,-.27868770E-06,.49345276E-05 ,-.18081789E-06,
     *-.27436939E-05,-.53875125E-02,.33916954E-02 ,-.13377927E-02,
     *-.14612983E-06,-.31878363E-06,-.16584473E-05,-.46383062E-05,
     *-.50719237E-05,-.18493452E-05,.21233662E-05 ,.28445077E-05 /
C
      DATA (C(I,6),I=41,80) /
     *.26166949E-06 ,.26180636E-07 ,-.45937937E-05,.78062690E-04 ,
     *.55397050E-05 ,-.45520342E-07,.16648340E-05 ,-.58340606E-05,
     *-.38040254E-05,-.88012196E-06,.44545250E-05 ,.24025528E-05 ,
     *-.44382088E-05,-.14229397E-05,-.58233565E-05,.16775553E-04 ,
     *-.19355580E-04,.12311794E-05 ,-.25051988E-05,-.15104516E-05,
     *.41971203E-05 ,-.76738367E-05,.60004244E-05 ,-.36770206E-07,
     *-.55650646E-05,-.11006023E-04,-.26333658E-04,-.34701657E-04,
     *.41106370E-05 ,.43578897E-05 ,-.46865842E-05,-.79187043E-05,
     *-.25238953E-05,.67816157E-05 ,-.19288691E-06,.43539046E-05 ,
     *-.49060900E-04,-.32136599E-04,.48832464E-05 ,.18332201E-05 /
C
      DATA (C(I,6),I=81,120) /
     *.43205778E-05 ,-.14401332E-05,.76554492E-06 ,.13235070E-05 ,
     *-.31048285E-05,-.35871508E-04,-.23738317E-04,.44570143E-06 ,
     *.12961585E-06 ,.10031837E-04 ,.43691791E-05 ,.33138004E-05 ,
     *-.13008581E-05,-.13056831E-04,-.28952986E-05,-.30895165E-05,
     *-.25913629E-05,.41473628E-05 ,.19323965E-05 ,.99010730E-07 ,
     *.26372971E-05 ,.67686178E-05 ,-.20541719E-05,.19276836E-05 ,
     *-.36565305E-05,-.25610376E-05,.15909444E-04 ,.99343834E-05 ,
     *-.32989431E-06,.73988495E-06 ,-.14074558E-05,.12260802E-04 ,
     *.42301192E-05 ,.80048475E-07 ,.60987087E-06 ,-.44364218E-05,
     *-.70656598E-05,.25460829E-05 ,-.56817703E-05,.24838273E-05 /
C
      END
C     --------------------------------------------------------
      SUBROUTINE FIG40A(W,X,Y,Z,FAULT)
C     ================================
C
C     Purpose
C     -------
C     Item 97020 Figures 7 to 9
C     Delta[(a1)V/(a1)T]
C
C     Input
C     -----
C     W     - log10(R)
C     X     - tan(tau au) - tan(tau a / 2)
C     Y     - M
C
C     Output
C     ------
C     Z     - Delta [(a1)V / (a1)T]
C     FAULT - fault number (0 means "none",  999 means "out of range")
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL W,X,Y,Z
C
      INTEGER FOUND
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
C
      DATA TEXT /
     *'log10(R)',
     *'tan(tau au) - tan(tau a / 2)',
     *'M',
     *'Delta [(a1)V / (a1)T]',
     *'Figures 7 to 9 of Item 97020' /
C
      DATA FLAGS /
     * 1, 1, 1,
     * 1, 1, 1,
     * 1, 1, 1,
     * 0, 0, 1 /
C
      DATA WXYZ /
     * 6.0,    9.0,  0.0,
     * 0.0,   0.25,  0.0,
     * 0.0,    0.7,  0.0,
     * 0.0,    0.0,  0.0 /
C
      FAULT = 0
      WXYZ(3,1) = W
      WXYZ(3,2) = X
      WXYZ(3,3) = Y
C
C     Read Figures 6 to 9 of Item 97020
C     ---------------------------------
      CALL FIG40B(W,X,Y,Z,FOUND)
C
C     Store the data if FIG40B failed
C     -------------------------------
      IF (FOUND .NE. 1) THEN
       FAULT = 3040
       WXYZ(3,4) = Z
       CALL PLERR1(TEXT,FLAGS,WXYZ)
      END IF
C
      RETURN
      END
C     --------------------------------------------------------
      SUBROUTINE FIG40B(W,X,Y,Z,FOUND)
C     ================================
C
C     Purpose
C     -------
C     Item 97020 Figures 7 to 9
C     Delta[(a1)V/(a1)T]
C
C     Input
C     -----
C     W     - log10(R)
C     X     - tan(tau au) - tan(tau a / 2)
C     Y     - M
C
C     Output
C     ------
C     Z     - Delta [(a1)V / (a1)T]
C     FOUND - flag (0=out of range    1=success)
C
C     Local
C     -----
C     ORDER     - order of polynomial
C     C(120,3)  - sets of polynomial coefficients for W = 6, 7 and 8
C     XMN,XMX   - minimum and maximum X
C     YMN,YMX   - minimum and maximum Y
C     WW(3)     - 0.6, 0.7 and 0.8
C     ZZ(3)     - Z for the given X and Y and W = 0.6, 0.7 and 0.8
C     I         - array index
C
C     Subroutine Called
C     -----------------
C     ZVSXY   - evaluation of a double Chebyschev polynomial
C
C     --------------------------------------------------------
C
      INTEGER FOUND, ORDER
      REAL X,Y,Z,ZZ(3)
      INTEGER K
C
      REAL XMN,XMX,YMN,YMX,C,WW,W
      COMMON /PLTB40/ XMN,XMX,YMN,YMX,C(120,3),WW(3)
C
      DATA ORDER/15/
C
C     Check W
C     -------
      FOUND = 0
      IF (W .LT. 6.0 .OR. W .GT. 8.0) GO TO 20
C
C     The grid of Xs and Ys is not complete.
C     Check that Y is below the lines Y = 0.75 - X and Y = 0.9 - 2 * X
C     ----------------------------------------------------------------
      IF (Y .GT. (0.751 - X) .OR. Y .GT. (0.901 - 2.0 * X)) GO TO 20
C
C     Calculate Z for the given X and Y and each WW
C     ---------------------------------------------
      DO 10 K = 1,3
      CALL A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C(1,K),ZZ(K),FOUND)
      IF (FOUND .NE. 1) GO TO 20
   10 CONTINUE
C
C     Interpolate Z for the given W
C     -----------------------------
      Z = ZZ(1) * (W - WW(2)) * (W - WW(3))
     *    / ((WW(1) - WW(2)) * (WW(1) - WW(3)))
     *  + ZZ(2) * (W - WW(1)) * (W - WW(3))
     *    / ((WW(2) - WW(1)) * (WW(2) - WW(3)))
     *  + ZZ(3) * (W - WW(1)) * (W - WW(2))
     *    / ((WW(3) - WW(1)) * (WW(3) - WW(2)))
C
C     N.B.  The plots give negative Zs.  So change the sign of Z.
C     ===========================================================
      Z = - Z
C
C     Z never exceeds 0.0
C     -------------------
      Z = AMIN1(Z,0.0)
C
   20 RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA FIGB40
C     =================
C
C     Data for Item 97020 Figures 7 to 9
C     ----------------------------------
C
      REAL XMN,XMX,YMN,YMX,C,WW
      COMMON /PLTB40/ XMN,XMX,YMN,YMX,C(120,3),WW(3)
C
      INTEGER I
C
      DATA XMN,XMX,YMN,YMX/ 0.0, 0.25, 0.0, 0.7/
C
      DATA WW / 6.0, 7.0, 8.0 /
C
      DATA (C(I,1),I=1,40) /
     *.34776385E-01 ,.28490197E-01 ,.14193616E-01 ,.48089695E-02 ,
     *.10162288E-02 ,.68483614E-04 ,.60817215E-04 ,.10101938E-03 ,
     *.30166482E-04 ,-.32904467E-04,-.19692933E-04,.12965949E-04 ,
     *.11158680E-04 ,-.90089503E-05,-.11621529E-04,.45390314E-01 ,
     *.37929359E-01 ,.18113091E-01 ,.52674058E-02 ,.53888563E-03 ,
     *-.29058923E-03,-.41466405E-04,.12071807E-03 ,.25633515E-04 ,
     *-.78140380E-04,-.38093162E-04,.36011626E-04 ,.32670961E-04 ,
     *-.12280475E-04,.11185907E-01 ,.10525678E-01 ,.42843962E-02 ,
     *.20806964E-03 ,-.87722174E-03,-.66071541E-03,-.25994125E-03,
     *.49557683E-06 ,.12669646E-05 ,-.69955421E-04,-.25567089E-04/
C
      DATA (C(I,1),I=41,80) /
     *.45923678E-04 ,.35587456E-04 ,.69325597E-03 ,.13095152E-02 ,
     *.38586764E-03 ,-.35507691E-03,-.52708288E-03,-.39623196E-03,
     *-.17372690E-03,.52864012E-04 ,.64441645E-04 ,-.27342534E-04,
     *-.16527853E-04,.30444956E-04 ,.20644631E-03 ,.59008762E-04 ,
     *-.79253973E-04,-.11157027E-03,-.69728396E-04,-.64792257E-04,
     *.34199514E-06 ,.91645253E-04 ,.63104990E-04 ,-.13173528E-04,
     *-.12983796E-04,.32137971E-04 ,-.14053384E-03,-.30014447E-04,
     *.31824799E-04 ,.63885121E-04 ,.82146668E-05 ,-.64447862E-05,
     *.10268057E-05 ,-.34290536E-05,-.70349663E-05,-.56167195E-04,
     *.41676103E-04 ,.57086289E-04 ,.25491519E-04 ,-.44934562E-05/
C
      DATA (C(I,1),I=81,120) /
     *-.14311219E-04,-.13868466E-04,-.16700001E-04,-.80467771E-05,
     *.18194132E-04 ,.73485075E-05 ,-.41358441E-04,-.28184727E-04,
     *-.11610604E-04,.19405507E-04 ,.19641949E-04 ,.51939643E-05 ,
     *.47008050E-05 ,-.36130817E-05,-.43407078E-05,-.39040750E-05,
     *-.50039022E-06,.41788429E-05 ,.38453320E-05 ,-.18583090E-04,
     *-.64758908E-07,.20061669E-04 ,.13557978E-04 ,.41006323E-05 ,
     *-.62730605E-05,.14076621E-05 ,-.11046548E-04,-.93005034E-05,
     *.14524099E-05 ,.48383248E-05 ,.70915643E-06 ,-.48261148E-06,
     *.88119938E-06 ,.33349312E-06 ,.27691635E-05 ,.68711991E-05 ,
     *.46264298E-05 ,.77024008E-05 ,.73376194E-05 ,-.20583067E-05/
C
      DATA (C(I,2),I=1,40) /
     *.25149133E-01 ,.20235626E-01 ,.98448413E-02 ,.31929250E-02 ,
     *.47669773E-03 ,-.12634299E-03,-.10013622E-03,-.59222103E-04,
     *-.59351011E-04,-.30333174E-04,.29840184E-04 ,.59370453E-04 ,
     *.33861368E-04 ,-.89440581E-05,-.26400560E-04,.32893250E-01 ,
     *.26284574E-01 ,.12475107E-01 ,.37524948E-02 ,.45598909E-03 ,
     *-.12997119E-03,-.15855936E-04,.50432839E-04 ,-.64260826E-05,
     *-.43088984E-04,.44084522E-05 ,.49697806E-04 ,.32200902E-04 ,
     *-.10513322E-04,.82074139E-02 ,.67314142E-02 ,.27991023E-02 ,
     *.41502865E-03 ,-.13356572E-03,.23725096E-05 ,.18815539E-03 ,
     *.25322532E-03 ,.14353418E-03 ,-.86341772E-05,-.62167749E-04/
C
      DATA (C(I,2),I=41,80) /
     *-.42928647E-04,-.20521210E-04,.32621005E-03 ,.60868350E-03 ,
     *.92344014E-04 ,-.15532087E-03,-.13434733E-03,-.43506435E-04,
     *.10362567E-03 ,.18880682E-03 ,.12954393E-03 ,.14561624E-04 ,
     *-.42467498E-04,-.41673373E-04,-.39597041E-04,-.55668089E-05,
     *-.10131865E-03,.19338682E-04 ,.21335547E-05 ,-.74589365E-04,
     *-.25260691E-04,.42313788E-04 ,.42534971E-04 ,.12713721E-04 ,
     *-.22963058E-05,.65688260E-04 ,.51753461E-04 ,-.44541356E-04,
     *.32897838E-04 ,.43374105E-04 ,-.10609300E-04,-.25816195E-04,
     *-.86385874E-05,-.27013148E-05,-.18027205E-05,-.38080285E-04,
     *-.29147298E-04,-.34400532E-06,-.24018267E-05,.94044442E-05 /
C
      DATA (C(I,2),I=81,120) /
     *.17144416E-04 ,.37866542E-05 ,-.76384118E-05,-.98994498E-05,
     *.14736966E-04 ,.54271124E-06 ,.32246081E-04 ,-.81085816E-05,
     *-.19544595E-04,-.60238588E-06,.57443409E-05 ,-.19228262E-05,
     *.64214665E-05 ,.77856234E-05 ,.22232783E-05 ,-.56867710E-06,
     *-.23418151E-05,-.66607161E-07,.29228432E-06 ,-.15429228E-04,
     *-.66656991E-05,-.11741597E-04,.45064281E-05 ,.88175692E-05 ,
     *.27962176E-05 ,.40362067E-05 ,-.76919667E-07,.17527779E-05 ,
     *-.20748399E-06,-.12599549E-05,.12457732E-05 ,-.27228608E-05,
     *.58085891E-06 ,-.32985154E-05,-.28979277E-05,-.15884106E-05,
     *-.24621890E-05,.41838338E-05 ,.76905062E-05 ,.18362272E-05 /
C
      DATA (C(I,3),I=1,40) /
     *.17254191E-01 ,.13350067E-01 ,.65744152E-02 ,.20008217E-02 ,
     *.30205329E-03 ,-.71192405E-04,-.68974242E-04,.87466129E-05 ,
     *.44931884E-04 ,.19533667E-04 ,-.10761579E-04,-.14515853E-04,
     *-.36754759E-05,.52572146E-05 ,.72517535E-05 ,.22638564E-01 ,
     *.17490771E-01 ,.86046912E-02 ,.27944486E-02 ,.63108013E-03 ,
     *.22754412E-04 ,-.73985566E-04,.50435277E-05 ,.62002348E-04 ,
     *.35667904E-04 ,-.92339725E-05,-.24240024E-04,-.13524261E-04,
     *.22482641E-05 ,.57341854E-02 ,.48591983E-02 ,.26740752E-02 ,
     *.14112247E-02 ,.77424338E-03 ,.25821734E-03 ,-.34054326E-04,
     *-.78511269E-04,-.21188446E-04,.19915310E-04 ,.18915877E-04 /
C
      DATA (C(I,3),I=41,80) /
     *-.17354598E-05,-.13977453E-04,.22327367E-03 ,.63231534E-03 ,
     *.73346474E-03 ,.79114893E-03 ,.58777539E-03 ,.21461655E-03 ,
     *-.66233441E-04,-.15144809E-03,-.98004692E-04,-.14434709E-04,
     *.28780871E-04 ,.26088105E-04 ,-.62742049E-04,-.88617684E-04,
     *.57957538E-04 ,.12355274E-03 ,.10826368E-03 ,.45893470E-04 ,
     *-.26363517E-04,-.66102263E-04,-.54127328E-04,-.18696482E-04,
     *.52795600E-05 ,.57019722E-04 ,.25545644E-04 ,-.32434454E-04,
     *-.65665387E-04,-.50614180E-04,-.94627820E-05,.19161588E-04 ,
     *.26086875E-04 ,.18419218E-04 ,.33199788E-05 ,-.14393040E-04,
     *.21873867E-04 ,.61351465E-05 ,-.46017337E-05,-.10386399E-04/
C
      DATA (C(I,3),I=81,120) /
     *-.62027402E-05,.50945965E-05 ,.13253095E-04 ,.10730948E-04 ,
     *.11234411E-05 ,-.11775929E-04,.27668461E-05 ,.82886995E-05 ,
     *.45539143E-05 ,-.20559647E-05,-.34344263E-05,-.20311667E-05,
     *.26526103E-05 ,-.19356034E-05,-.42716122E-05,-.43694086E-05,
     *-.28063265E-05,-.70061847E-06,.96222145E-06 ,-.56752096E-05,
     *.25977574E-05 ,.14130290E-06 ,-.13266235E-05,-.12403038E-05,
     *.44237580E-06 ,.18984364E-05 ,-.36743643E-05,-.24321020E-05,
     *-.10983516E-05,.35035586E-06 ,-.11669825E-05,-.38337031E-05,
     *-.38414655E-05,-.15599164E-05,-.18453973E-05,.39074338E-06 ,
     *.24397522E-05 ,.37249782E-05 ,.68068196E-05 ,.18108310E-05 /
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE PLERR1(TXT,FLGS,XYZ)
C     ===============================
C
C     Purpose
C     -------
C     To store data for an error message about a plot
C
C     Input
C     -----
C     TXT(5)    - character strings for W, X, Y, Z and plot name
C     FLGS(3,4) - three flags for each of W, X, Y, Z
C                 (1) flag on minimum
C                 (2) flag on maximum
C                 (3) flag on actual number
C                 0 means "absent",  1 means "present"
C     XYZ(3,4)  - minimum, maximum and actual W, X, Y and Z
C
C     Output
C     ------
C     Output is to Common Block PLTERR
C
C     -----------------------------------------------------------------
C
      CHARACTER*44 TXT(5)
      INTEGER FLGS(3,4)
      REAL XYZ(3,4)
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
      COMMON /ERRCHR/ TEXT
      COMMON /ERRDAT/ FLAGS,WXYZ
C
      INTEGER I,J
C
      DO 20 J = 1,4
      TEXT(J) = TXT(J)
      DO 10 I = 1,3
      FLAGS(I,J) = FLGS(I,J)
      WXYZ(I,J) = XYZ(I,J)
   10 CONTINUE
   20 CONTINUE
      TEXT(5) = TXT(5)
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE PLERR2(OUTFIL,FAULT)
C     ===============================
C
C     Purpose
C     -------
C     To print an error message for a plot
C
C     Input
C     -----
C     OUTFIL - output unit number
C     FAULT  - fault number
C
C     Method
C     ------
C     Common Blocks ERRDAT and ERRCHR provide data for the message.
C
C     TEXT(5)    - character strings for W, X, Y, Z and plot name
C     FLAGS(3,4) - three flags for each of W, X, Y, Z
C                  (1) flag on minimum
C                  (2) flag on maximum
C                  (3) flag on actual number
C                  0 means "absent",  1 means "present"
C     WXYZ(3,4)  - minimum, maximum and actual W, X, Y and Z
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,FAULT
C
      CHARACTER*44 TEXT(5)
      INTEGER FLAGS(3,4)
      REAL WXYZ(3,4)
      COMMON /ERRCHR/ TEXT
      COMMON /ERRDAT/ FLAGS,WXYZ
C
      INTEGER I,J,LINE,PLOT
C
      CHARACTER*12 BLANK
C
      DATA BLANK / '     -      ' /
C
      PLOT = FAULT - 3000
      PLOT = PLOT
C
      WRITE(OUTFIL,5) TEXT(5)
    5 FORMAT(/,
     *1X,'Error - out of range of ',A44,/,
     *1X,31(1H-),44(1H-),//,
     *1X,'Item',40X,'   Lower    ','   Upper    ','   Value',/,
     *1X,44X,       '   Limit    ','   Limit    ',/)
C
      DO 500 J = 1,4
C
      IF (FLAGS(3,J) .NE. 1) GO TO 500
C
      LINE = 2 * FLAGS(1,J) + FLAGS(2,J) + 1
C
C
      GO TO (100,200,300,400), LINE
C
  100 GO TO 500
C
  200 WRITE(OUTFIL,210) TEXT(J),BLANK,WXYZ(2,J),WXYZ(3,J)
  210 FORMAT(1X,A44,A12,2G12.4)
      GO TO 500
C
  300 WRITE(OUTFIL,310) TEXT(J),WXYZ(1,J),BLANK,WXYZ(3,J)
  310 FORMAT(1X,A44,G12.4,A12,G12.4)
      GO TO 500
C
  400 WRITE(OUTFIL,410) TEXT(J),(WXYZ(I,J), I = 1,3)
  410 FORMAT(1X,A44,3G12.4)
      GO TO 500
C
  500 CONTINUE
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE A9E799(X,Y,XMN,XMX,YMN,YMX,ORDER,C,Z,FOUND)
C     =====================================================
C
C     Purpose
C     -------
C     To interpolate Z for a given X and Y using a complete double
C     Chebyschev polynomial
C
C     Input
C     -----
C     X,Y     - coordinates of the required point
C     XMN,XMX - range of X
C     YMN,YMX - range of Y
C     ORDER   - order of polynomial
C     C(M)    - coefficients of polynomial
C               where M = (ORDER*(ORDER+1))/2
C
C     Output
C     ------
C     Z       - Z for a given (XMN <= X <= XMX) and (YMN <= Y <= YMX)
C               otherwise zero
C     FOUND   - flag    0 = out of range
C                       1 = success
C
C     Local
C     -----
C     I,J,K   - multipliers and index in cos(I*S)*cos(J*T)*C(K)
C     JF      - upper limit of J
C     CX(),CY() - cos((I-1)*S) and cos((J-1)*T)
C                 for I = 1 to ORDER and J = 1 to ORDER
C
C     Method
C     ------
C     For example if ORDER = 4, the formula for Z is:
C     Z = cos(0) * (cos(0)*C(1)+cos(T)*C(2)+cos(2*T)*C(3)+cos(3*T)*C(4))
C       + cos(S) * (cos(0)*C(5)+cos(T)*C(6)+cos(2*T)*C(7))
C       + cos(2*S)*(cos(0)*C(8)+cos(T)*C(9))
C       + cos(3*S)* cos(0)*C(10)
C     where S and T are parameters given by:
C     cos(S) = xx where xx = (2*X-XMX-XMN)/(XMX-XMN)
C     cos(T) = yy where yy = (2*Y-YMX-YMN)/(YMX-YMN)
C     so that when X = XMN, xx = -1.0 and S = -pi
C         and when X = XMX, xx = +1.0 and S = 0.0
C     and similarly for Y, yy and T.
C
C     Subroutines Called
C     ------------------
C     none
C
C     -----------------------------------------------------------------
C
      REAL X,Y,XMN,XMX,YMN,YMX,C(*),Z
      INTEGER ORDER,FOUND
      INTEGER I,J,K,JF
      REAL CX(16),CY(16)
C
C     Calculate cos(I*S) and cos(I*T) for I=1 to ORDER
C     ------------------------------------------------
      CX(1) = 1.0
      CX(2) = (2.0 * X - XMX - XMN) / (XMX - XMN)
      CY(1) = 1.0
      CY(2) = (2.0 * Y - YMX - YMN) / (YMX - YMN)
      DO 10 I = 3, ORDER
      CX(I) = 2.0 * CX(2) * CX(I-1) - CX(I-2)
      CY(I) = 2.0 * CY(2) * CY(I-1) - CY(I-2)
   10 CONTINUE
C
C     Check that X and Y are in range
C     -------------------------------
      Z = 0.0
      FOUND = 0
      IF (ABS(CX(2)) .GT. 1.0 .OR. ABS(CY(2)) .GT. 1.0) GO TO 40
C
C     Calculate the polynomial
C     ------------------------
      K = 0
      DO 30 I = 1, ORDER
      JF = ORDER - I + 1
      DO 20 J = 1, JF
      K = K + 1
      Z = Z + C(K) * CX(I) * CY(J)
   20 CONTINUE
   30 CONTINUE
C
      FOUND = 1
C
   40 RETURN
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE A9F799(X,XMN,XMX,N,C,Z,FOUND)
C     =====================================================
C
C     Purpose
C     -------
C     To interpolate Z for a given X using a Chebyschev polynomial
C
C     Input
C     -----
C     X       - X coordinate of the required point
C     XMN,XMX - range of X
C     N       - number of coefficients
C     C(N)    - coefficients of polynomial
C
C     Output
C     ------
C     Z       - Z for a given (XMN <= X <= XMX)
C               otherwise zero
C     FOUND   - flag    0 = out of range
C                       1 = success
C
C     Local
C     -----
C     I           - array index
C     CX          - X scaled so that CX = -1.0 when X = XMN and
C                                    CX = +1.0 when X = XMX
C                   N.B. The polynomial uses a parameter S
C                        which is given by cos(S) = X
C     CX1,CX2,CX3 - cos((I-2)*S), cos((I-1)*S) and cos(I*S)
C
C     Method
C     ------
C     The formula is:
C     Z = C(1) + C(2) * cos(S) + C(3) * cos(2*S) + ....C(N)*cos((N-1)*S)
C     The recurrence relation for cosines calculates:
C     cos(2*S),cos(3*S),........cos((N-1)*S)
C
C     Subroutines Called
C     ------------------
C     none
C
C     -----------------------------------------------------------------
C
      INTEGER N,FOUND
      REAL X,XMN,XMX,C(*),Z
      INTEGER I
      REAL CX,CX1,CX2,CX3
C
      Z = 0.0
      FOUND = 0
C
C     Scale CX so that CX = -1.0 if X = XMN and CX = +1.0 if X = XMX
C     --------------------------------------------------------------
      CX = (2.0 * X - XMX - XMN) / (XMX - XMN)
C
C     Check that X is in range
C     ------------------------
      IF (ABS(CX) .GT. 1.0) GO TO 20
      FOUND = 1
C
C     Cos(0*S) = 1.0 and cos(S) = CX
C     ------------------------------
      CX1 = 1.0
      CX2 = CX
C
C     N is at least 1
C     ---------------
      Z = C(1)
      IF (N .LT. 2) GO TO 20
C
C     Z = C(1) + C(2) * cos(S) + C(3) * cos(2*S) + ....C(N)*cos((N-1)*S)
C     ------------------------------------------------------------------
      DO 10 I = 2,N
      Z = Z + C(I) * CX2
C
C     Use the recurrence relation to calculate cos(I*S)
C     for use with C(I+1)
C     -------------------------------------------------
      CX3 = 2.0 * CX * CX2 - CX1
      CX1 = CX2
      CX2 = CX3
C
   10 CONTINUE
C
   20 RETURN
C
      END
C     -----------------------------------------------------------------
      SUBROUTINE A9G799(N,XX,ZZ,X,Z,FOUND)
C     ====================================
C
C     Purpose
C     -------
C     Interpolation based on a cubic spline fit
C
C     Input
C     -----
C     N           - number of data points
C     XX(N),ZZ(N) - coordinates of the N data points
C     X           - position at which Z is to be found
C
C     Output
C     ------
C     Z           - height of curve at X
C     FOUND       - flag (0=failure  1=success)
C
C     Local
C     -----
C     S()         - slopes dZ/dX at the N data points
C     I           - array index
C     K           - spline that contains X
C     XL,ZL,SL    - X, Z and S at lhs. of spline K
C     XR,ZR,SR    - X, Z and S at rhs. of spline K
C     XRXL,ZRZL   - (XR-XL) and (ZR-ZL)
C     XXL,XXR     - (X-XL) and (X-XR)
C
C     Method
C     ------
C     1. The routine fits a curve to the data.  This curve fit favours
C        large radii of curvature.  The curve fit supplies slopes dZ/dX
C        at each data point.
C     2. The routine finds the spline, K, that contains X.
C     3. The routine uses the following formula to interpolate Z for
C        the given X:
C        Z =   A * (X-XL) / (XR-XL) + B * (X-XR) / (XR-XL)
C            + C * (X-XL)**2 * (X-XR) / (XR-XL)**3
C            + D * (X-XL) * (X-XR)**2 / (XR-XL)**3
C        where:
C        A =  ZR
C        B = -ZL
C        C = (XR-XL) * SR - (ZR-ZL)
C        D = (XR-XL) * SL - (ZR-ZL)
C        The subroutine substitutes A, B, C and D into the above
C        equation to get the formula at the end of the subroutine.
C
C     Subroutine Called
C     -----------------
C     A9H799 - spline fit
C
C     -----------------------------------------------------------------
C
      INTEGER N,FOUND
      REAL XX(N),ZZ(N),X,Z
C
      INTEGER I,K
      REAL S(20),XL,ZL,SL,XR,ZR,SR,XRXL,ZRZL,XXL,XXR
C
C     Calculate the slope S = dZ/dX at each data point
C     ------------------------------------------------
      CALL A9H799(N,XX,ZZ,S)
C
C     Find the spline, K, that contains X
C     -----------------------------------
      FOUND = 0
      IF (X .LT. XX(1) .OR. X .GT. XX(N)) GO TO 30
      FOUND = 1
      K = 1
      DO 10 I = 2,N
      IF (X .LE. XX(I)) GO TO 20
      K = I
   10 CONTINUE
C
C     Interpolate Z at the given X
C     ----------------------------
   20 XL = XX(K)
      ZL = ZZ(K)
      SL = S(K)
      XR = XX(K+1)
      ZR = ZZ(K+1)
      SR = S(K+1)
      XRXL = XR - XL
      ZRZL = ZR - ZL
      XXL = X - XL
      XXR = X - XR
C
      Z = (ZR * XXL - ZL * XXR + XXL * XXR * (SR * XXL + SL * XXR
     *    - ZRZL * (XXL + XXR) / XRXL) / XRXL) / XRXL
C
   30 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE A9H799(N,X,Z,S)
C     ==========================
C
C     Purpose
C     -------
C     Slopes for a spline fit that favours large radii of curvature
C
C     Input
C     -----
C     N         - number of data points
C     X(N),Z(N) - coordinates of the N points
C
C     Output
C     ------
C     S(N)      - slopes at tne N points
C
C     Local
C     -----
C     I,J,L          - array indices
C     NS(20)         - count of estimates of slope and curvature
C                      at each point
C     SS(20,3)       - up to three estimates of slope
C     KK(20,3)         and curvature at each data point
C     SX(3),KX(3)    - three estimates of slope and curvature
C     TOP,BOT,TOL    - dividend, divisor and tolerance
C     K1K2,K1K3,K2K3 - KX(1)*KX(2), KX(1)*KX(3) and KX(2)*KX(3)
C
C     -----------------------------------------------------------------
C
      INTEGER N
      REAL X(N),Z(N),S(N)
      INTEGER I,J,L,NS(20)
      REAL SS(20,3),KK(20,3),SX(3),KX(3),TOP,BOT,TOL,
     *                 K1K2,K1K3,K2K3
C
      TOL = 1.0E-10
      IF (N .GT. 3) GO TO 10
C
C     Only Two or Three Points
C     ========================
      CALL A9J799(N,X,Z,S)
      GO TO 80
C
C     Four or More Points
C     ===================
   10 DO 20 I=1,N
      NS(I) = 0
   20 CONTINUE
C
C     Take successive sets of three points.  Fit a quadratic to each
C     set.  This gives up to three estimates of the slope and curvature
C     at each point.
C     -----------------------------------------------------------------
      DO 40 I = 1,N-2
      CALL A9I799(X(I),Z(I),SX,KX)
C
      L = I
      DO 30 J = 1,3
      NS(L) = NS(L) + 1
      SS(L,NS(L)) = SX(J)
      KK(L,NS(L)) = KX(J)
      L = L + 1
   30 CONTINUE
C
   40 CONTINUE
C
C     Points 2 to N-1 have two or three estimates.
C     Calculate the slopes at these points.
C     --------------------------------------------
      DO 70 I=2,N-1

      DO 50 J = 1,NS(I)
      SX(J) = SS(I,J)
      KX(J) = KK(I,J)
   50 CONTINUE
C
      IF (NS(I) .GT. 2) GO TO 60
C
C     Two Estimates (Points 2 and N-1)
C     -------------
C     Favour the larger radius of curvature.
      TOP = KX(1) * SX(2) + KX(2) * SX(1)
      BOT = KX(1) + KX(2)
      S(I) = 0.5 * (SX(1) + SX(2))
      IF (BOT .GT. TOL * ABS(TOP)) S(I) = TOP / BOT
      GO TO 70
C
C     Three Estimates (Points 3 to N-2)
C     ---------------
C     Favour the larger radii of curvature.
   60 K1K2 = KX(1) * KX(2)
      K1K3 = KX(1) * KX(3)
      K2K3 = KX(2) * KX(3)
      BOT = K1K2 + K1K3 + K2K3
      TOP = SX(3) * K1K2 + SX(2) * K1K3 + SX(1) * K2K3
      S(I) = (SX(1) + SX(2) + SX(3)) / 3.0
      IF (BOT .GT. TOL * ABS(TOP)) S(I) = TOP / BOT
C
   70 CONTINUE
C
C     Make the second derivative constant in the first and last splines.
C     ------------------------------------------------------------------
      S(1) = 2.0 * (Z(2) - Z(1)  ) / (X(2) - X(1)  ) - S(2)
      S(N) = 2.0 * (Z(N) - Z(N-1)) / (X(N) - X(N-1)) - S(N-1)
C
   80 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE A9I799(X,Z,S,K)
C     ==========================
C
C     Purpose
C     -------
C     Slopes and curvatures at three given points on a quadratic
C
C     Input
C     -----
C     X(3),Z(3) - coordinates
C
C     Output
C     ------
C     S(3)      - slopes at the three points
C     K(3)      - curvatures at the three points
C
C     Local
C     -----
C     X1X2      - X(1) - X(2)
C     X1X3      - X(1) - X(3)
C     X2X3      - X(2) - X(3)
C     Q1        - Z(1) / (X1X2 * X1X3)
C     Q2        - Z(2) / (X1X2 * X2X3)
C     Q3        - Z(3) / (X1X3 * X2X3)
C     C         - |d2Z / dX2|
C     B         - 1 + (dZ/dX)**2
C
C     Method
C     ------
C     The quaddratic can be written:
C     Z = (X-X2)*(X-X3)*Q1 - (X-X1)*(X-X3)*Q2 + (X-X1)*(X-X2)*Q3
C     Then:
C     S(1) = (X1-X2)*(Q1+Q3) + (X1-X3)*(Q1-Q2)
C     S(2) = (X2-X3)*(Q1-Q2) + (X2-X1)*(Q3-Q2)
C     S(3) = (X1-X3)*(Q2-Q3) - (X2-X3)*(Q1+Q3)
C     and the second derivative is constant and is:
C     (d2Z/dX2) = 2 * (Q1 - Q2 + Q3)
C     and the curvatures are given by:
C     K = ABS(d2Z/dX2) / [1 + (dZ/dX)**2]**1.5
C
C     -----------------------------------------------------------------
C
      REAL X(3),Z(3),S(3),K(3)
      INTEGER I
      REAL X1X2,X1X3,X2X3,Q1,Q2,Q3,C,B
C
      X1X2 = X(1) - X(2)
      X1X3 = X(1) - X(3)
      X2X3 = X(2) - X(3)
C
      Q1 = Z(1) / (X1X2 * X1X3)
      Q2 = Z(2) / (X1X2 * X2X3)
      Q3 = Z(3) / (X1X3 * X2X3)
C
      C = 2.0 * ABS(Q1 - Q2 + Q3)
C
      S(1) = X1X2 * (Q1 + Q3) + X1X3 * (Q1 - Q2)
      S(2) = X2X3 * (Q1 - Q2) + X1X2 * (Q2 - Q3)
      S(3) = X1X3 * (Q2 - Q3) - X2X3 * (Q1 + Q3)
C
      DO 10 I = 1,3
      B = 1.0 + S(I) * S(I)
      K(I) = C / (B * SQRT(B))
   10 CONTINUE
C
      RETURN
      END
C     ------------------------------------------------------------------
      SUBROUTINE A9J799(N,X,Z,S)
C     ==========================
C
C     Purpose
C     -------
C     Slopes on a straight line or quadratic
C
C     Input
C     -----
C     N        - number of data points (2 or 3)
C     X(),Z()  - coordinates of data points
C
C     Output
C     ------
C     S()      - slopes at the data points
C
C     Local
C     -----
C     I        - array index
C
C     -----------------------------------------------------------------
C
      INTEGER N
      REAL X(N),Z(N),S(N)
      INTEGER I
C
      IF (N .GT. 2) GO TO 10
C
C     Just Two Points
C     ===============
      S(1) = (Z(2) - Z(1)) / (X(2) - X(1))
      S(2) = S(1)
      GO TO 30
C
C     Just Three Points
C     =================
   10 DO 20 I = 1,3
      S(I) =
     * (  Z(1) * (2.0 * X(I) - X(2) - X(3)) * (X(3) - X(2))
     *  - Z(2) * (2.0 * X(I) - X(1) - X(3)) * (X(3) - X(1))
     *  + Z(3) * (2.0 * X(I) - X(1) - X(2)) * (X(2) - X(1)) )
     * / ((X(2) - X(1)) * (X(3) - X(1)) * (X(3) - X(2)) )
   20 CONTINUE
C
   30 RETURN
      END
